Class: WhopSDK::Helpers::VerifyUserToken::UserTokenPayload

Inherits:
Object
  • Object
show all
Defined in:
lib/whop_sdk/helpers/verify_user_token.rb

Overview

User token payload structure

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(user_id:, app_id:) ⇒ UserTokenPayload

Returns a new instance of UserTokenPayload.



36
37
38
39
# File 'lib/whop_sdk/helpers/verify_user_token.rb', line 36

def initialize(user_id:, app_id:)
  @user_id = user_id
  @app_id = app_id
end

Instance Attribute Details

#app_idString (readonly)

Returns The app id of the app that is making the request.

Returns:

  • (String)

    The app id of the app that is making the request



34
35
36
# File 'lib/whop_sdk/helpers/verify_user_token.rb', line 34

def app_id
  @app_id
end

#user_idString (readonly)

Returns The user id of the user who is making the request.

Returns:

  • (String)

    The user id of the user who is making the request



31
32
33
# File 'lib/whop_sdk/helpers/verify_user_token.rb', line 31

def user_id
  @user_id
end