Class: WhopSDK::Models::AIChatCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/ai_chat_create_params.rb

Overview

Defined Under Namespace

Modules: MessageSource Classes: MessageAttachment

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

Input for an attachment

Parameters:

  • id (String)

    The ID of an existing file object.



# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 76

Instance Attribute Details

#current_company_idString?

The unique identifier of the company to set as context for the AI chat (e.g., “biz_XXXXX”).

Returns:

  • (String, nil)


21
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 21

optional :current_company_id, String, nil?: true

#message_attachmentsArray<WhopSDK::Models::AIChatCreateParams::MessageAttachment>?

A list of previously uploaded file attachments to include with the first message.



28
29
30
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 28

optional :message_attachments,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::AIChatCreateParams::MessageAttachment] },
nil?: true

#message_sourceSymbol, ...

The source of an AI chat message



36
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 36

optional :message_source, enum: -> { WhopSDK::AIChatCreateParams::MessageSource }, nil?: true

#message_textString

The text content of the first message to send to the AI agent.

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 14

required :message_text, String

#suggestion_typeString?

The type of suggestion prompt that was clicked, when message_source is ‘suggestion’.

Returns:

  • (String, nil)


43
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 43

optional :suggestion_type, String, nil?: true

#titleString?

An optional display title for the AI chat thread (e.g., “Help with billing”).

Returns:

  • (String, nil)


49
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 49

optional :title, String, nil?: true