Class: WhopSDK::Models::AIChatCreateParams::MessageAttachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/ai_chat_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(message_text:, current_company_id: nil, message_attachments: nil, message_source: nil, suggestion_type: nil, title: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AIChatCreateParams for more details.

Parameters:

  • message_text (String)

    The text content of the first message to send to the AI agent.

  • current_company_id (String, nil) (defaults to: nil)

    The unique identifier of the company to set as context for the AI chat (e.g., “b

  • message_attachments (Array<WhopSDK::Models::AIChatCreateParams::MessageAttachment>, nil) (defaults to: nil)

    A list of previously uploaded file attachments to include with the first message

  • message_source (Symbol, WhopSDK::Models::AIChatCreateParams::MessageSource, nil) (defaults to: nil)

    The source of an AI chat message

  • suggestion_type (String, nil) (defaults to: nil)

    The type of suggestion prompt that was clicked, when message_source is ‘suggesti

  • title (String, nil) (defaults to: nil)

    An optional display title for the AI chat thread (e.g., “Help with billing”).

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 69

class MessageAttachment < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing file object.
  #
  #   @return [String]
  required :id, String

  # @!method initialize(id:)
  #   Input for an attachment
  #
  #   @param id [String] The ID of an existing file object.
end

Instance Attribute Details

#idString

The ID of an existing file object.

Returns:

  • (String)


74
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 74

required :id, String