Class: WhopSDK::Models::AIChatUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/ai_chat_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, current_company_id: nil, notification_preference: nil, title: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AIChatUpdateParams for more details.

Parameters:

  • id (String)
  • current_company_id (String, nil) (defaults to: nil)

    The unique identifier of the company to set as context for the AI chat (e.g., “b

  • notification_preference (Symbol, WhopSDK::Models::NotificationPreferences, nil) (defaults to: nil)

    The notification preference for an AI chat

  • title (String, nil) (defaults to: nil)

    The new display title for the AI chat thread (e.g., “Help with billing”).

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 34

Instance Attribute Details

#current_company_idString?

The unique identifier of the company to set as context for the AI chat (e.g., “biz_XXXXX”).

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 20

optional :current_company_id, String, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 13

required :id, String

#notification_preferenceSymbol, ...

The notification preference for an AI chat



26
# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 26

optional :notification_preference, enum: -> { WhopSDK::NotificationPreferences }, nil?: true

#titleString?

The new display title for the AI chat thread (e.g., “Help with billing”).

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 32

optional :title, String, nil?: true