Class: WhopSDK::Models::AccessTokenCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/access_token_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id: nil, expires_at: nil, scoped_actions: nil, user_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AccessTokenCreateParams for more details.

Parameters:

  • company_id (String, nil) (defaults to: nil)

    The unique identifier of the company to generate the token for, starting with ‘b

  • expires_at (Time, nil) (defaults to: nil)

    The expiration timestamp for the access token. Defaults to 1 hour from now, with

  • scoped_actions (Array<String>, nil) (defaults to: nil)

    An array of permission scopes to grant to the access token. If empty or omitted,

  • user_id (String, nil) (defaults to: nil)

    The unique identifier of the user to generate the token for, starting with ‘user

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/access_token_create_params.rb', line 39

Instance Attribute Details

#company_idString?

The unique identifier of the company to generate the token for, starting with ‘biz_’. The API key must have permission to access this company.

Returns:

  • (String, nil)


15
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 15

optional :company_id, String, nil?: true

#expires_atTime?

The expiration timestamp for the access token. Defaults to 1 hour from now, with a maximum of 3 hours.

Returns:

  • (Time, nil)


22
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 22

optional :expires_at, Time, nil?: true

#scoped_actionsArray<String>?

An array of permission scopes to grant to the access token. If empty or omitted, all permissions from the authenticating credential are inherited. Must be a subset of the credential’s permissions.

Returns:

  • (Array<String>, nil)


30
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 30

optional :scoped_actions, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#user_idString?

The unique identifier of the user to generate the token for, starting with ‘user_’. The API key must have permission to access this user.

Returns:

  • (String, nil)


37
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 37

optional :user_id, String, nil?: true