Class: WhopSDK::Models::AccessTokenCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/access_token_create_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(token:, expires_at:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AccessTokenCreateResponse for more details.

A short-lived access token used to authenticate API requests on behalf of a user.

Parameters:

  • token (String)

    The signed JWT access token string to include in API request Authorization heade

  • expires_at (Time)

    The timestamp after which this access token is no longer valid and must be refre



# File 'lib/whop_sdk/models/access_token_create_response.rb', line 21

Instance Attribute Details

#expires_atTime

The timestamp after which this access token is no longer valid and must be refreshed.

Returns:

  • (Time)


19
# File 'lib/whop_sdk/models/access_token_create_response.rb', line 19

required :expires_at, Time

#tokenString

The signed JWT access token string to include in API request Authorization headers.

Returns:

  • (String)


12
# File 'lib/whop_sdk/models/access_token_create_response.rb', line 12

required :token, String