Class: WhopSDK::Models::AccountLinkCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AccountLinkCreateResponse
- Defined in:
- lib/whop_sdk/models/account_link_create_response.rb
Overview
Instance Attribute Summary collapse
-
#expires_at ⇒ Time
The timestamp after which this account link URL is no longer valid.
-
#url ⇒ String
The temporary URL to redirect the user to for account access.
Instance Method Summary collapse
-
#initialize(expires_at:, url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccountLinkCreateResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(expires_at:, url:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AccountLinkCreateResponse for more details.
A temporary, time-limited URL that grants a user access to an external account management page.
|
|
# File 'lib/whop_sdk/models/account_link_create_response.rb', line 20
|
Instance Attribute Details
#expires_at ⇒ Time
The timestamp after which this account link URL is no longer valid.
11 |
# File 'lib/whop_sdk/models/account_link_create_response.rb', line 11 required :expires_at, Time |
#url ⇒ String
The temporary URL to redirect the user to for account access. Expires at the time specified by expires_at.
18 |
# File 'lib/whop_sdk/models/account_link_create_response.rb', line 18 required :url, String |