Class: WhopSDK::Models::AccountListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/account_list_params.rb,
sig/whop_sdk/models/account_list_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Accounts#list

Defined Under Namespace

Modules: Direction, Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, direction: nil, first: nil, last: nil, order: nil, request_options: {}) ⇒ Object

Parameters:

  • after (String) (defaults to: nil)

    A cursor; returns accounts after this position.

  • before (String) (defaults to: nil)

    A cursor; returns accounts before this position.

  • direction (Symbol, WhopSDK::Models::AccountListParams::Direction) (defaults to: nil)

    Sort direction.

  • first (Integer) (defaults to: nil)

    The number of accounts to return (default 10, max 50).

  • last (Integer) (defaults to: nil)

    The number of accounts to return from the end of the range.

  • order (Symbol, WhopSDK::Models::AccountListParams::Order) (defaults to: nil)

    The field to sort accounts by.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/account_list_params.rb', line 46

Instance Attribute Details

#afterString?

A cursor; returns accounts after this position.

Parameters:

  • (String)

Returns:

  • (String, nil)


14
# File 'lib/whop_sdk/models/account_list_params.rb', line 14

optional :after, String

#beforeString?

A cursor; returns accounts before this position.

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/account_list_params.rb', line 20

optional :before, String

#directionSymbol, ...

Sort direction.



26
# File 'lib/whop_sdk/models/account_list_params.rb', line 26

optional :direction, enum: -> { WhopSDK::AccountListParams::Direction }

#firstInteger?

The number of accounts to return (default 10, max 50).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


32
# File 'lib/whop_sdk/models/account_list_params.rb', line 32

optional :first, Integer

#lastInteger?

The number of accounts to return from the end of the range.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


38
# File 'lib/whop_sdk/models/account_list_params.rb', line 38

optional :last, Integer

#orderSymbol, ...

The field to sort accounts by.



44
# File 'lib/whop_sdk/models/account_list_params.rb', line 44

optional :order, enum: -> { WhopSDK::AccountListParams::Order }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/account_list_params.rb', line 68

Instance Method Details

#to_hash{

Returns:

  • ({)


56
# File 'sig/whop_sdk/models/account_list_params.rbs', line 56

def to_hash: -> {