Class: WhopSDK::Models::AccountUpdateParams::BusinessAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/account_update_params.rb,
sig/whop_sdk/models/account_update_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, affiliate_application_required: nil, affiliate_instructions: nil, banner_image: nil, business_address: nil, business_type: nil, country: nil, description: nil, featured_affiliate_product_id: nil, home_preferences: nil, industry_group: nil, industry_type: nil, invoice_prefix: nil, logo: nil, metadata: nil, onboarding_type: nil, opengraph_image: nil, opengraph_image_variant: nil, other_business_description: nil, other_industry_description: nil, product_tax_code_id: nil, require_2fa: nil, route: nil, send_customer_emails: nil, show_joined_whops: nil, show_reviews_dtc: nil, show_user_directory: nil, social_links: nil, store_page_config: nil, target_audience: nil, tax_identifiers: nil, tax_remitted_by: nil, title: nil, use_logo_as_opengraph_image_fallback: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AccountUpdateParams for more details.

Parameters:

  • account_id (String)
  • affiliate_application_required (Boolean) (defaults to: nil)

    Whether prospective affiliates must submit an application before promoting this

  • affiliate_instructions (String, nil) (defaults to: nil)

    Guidelines shown to affiliates promoting this account.

  • banner_image (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Attachment input for the account banner image.

  • business_address (WhopSDK::Models::AccountUpdateParams::BusinessAddress) (defaults to: nil)

    Account business address used to calculate tax. A complete address in a supporte

  • business_type (String, nil) (defaults to: nil)

    High-level business category for the account.

  • country (String, nil) (defaults to: nil)

    Country where the account is located.

  • description (String, nil) (defaults to: nil)

    Account promotional description.

  • featured_affiliate_product_id (String, nil) (defaults to: nil)

    The ID of the product to feature for affiliates. Pass null to clear.

  • home_preferences (Array<String>) (defaults to: nil)

    Public account home page preferences.

  • industry_group (String, nil) (defaults to: nil)

    Account industry group.

  • industry_type (String, nil) (defaults to: nil)

    Specific industry vertical for the account.

  • invoice_prefix (String, nil) (defaults to: nil)

    Prefix used for account invoices.

  • logo (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Attachment input for the account logo.

  • metadata (Hash{Symbol=>Object}) (defaults to: nil)

    Arbitrary key/value metadata to store on the account.

  • onboarding_type (String, nil) (defaults to: nil)

    The type of onboarding the account has completed.

  • opengraph_image (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Attachment input for the account Open Graph image.

  • opengraph_image_variant (String, nil) (defaults to: nil)

    The account Open Graph image variant.

  • other_business_description (String, nil) (defaults to: nil)

    The description of the business type when business_type is other.

  • other_industry_description (String, nil) (defaults to: nil)

    The description of the industry type when industry_type is other.

  • product_tax_code_id (String, nil) (defaults to: nil)

    ID of the tax classification code applied by default to the account's products.

  • require_2fa (Boolean) (defaults to: nil)

    Whether the account requires authorized users to have two-factor authentication

  • route (String, nil) (defaults to: nil)

    The unique URL slug for the account.

  • send_customer_emails (Boolean) (defaults to: nil)

    Whether Whop sends transactional emails to customers on behalf of this account.

  • show_joined_whops (Boolean) (defaults to: nil)

    Whether the account appears in joined whops on other accounts.

  • show_reviews_dtc (Boolean) (defaults to: nil)

    Whether reviews are displayed on direct-to-consumer product pages.

  • show_user_directory (Boolean) (defaults to: nil)

    Whether the account shows users in the user directory.

  • social_links (Array<Hash{Symbol=>Object}>) (defaults to: nil)

    The full list of social links to display for the account.

  • store_page_config (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Account store page display configuration.

  • target_audience (String, nil) (defaults to: nil)

    The target audience for this account.

  • tax_identifiers (Array<WhopSDK::Models::AccountUpdateParams::TaxIdentifier>) (defaults to: nil)

    Account tax/VAT registrations to add or update. When tax_remitted_by is self

  • tax_remitted_by (Symbol, WhopSDK::Models::AccountUpdateParams::TaxRemittedBy) (defaults to: nil)

    Who calculates and remits tax for the account: whop (Whop calculates and remit

  • title (String, nil) (defaults to: nil)

    The display name of the account.

  • use_logo_as_opengraph_image_fallback (Boolean) (defaults to: nil)

    Whether the account uses its logo as the fallback Open Graph image.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/whop_sdk/models/account_update_params.rb', line 301

class BusinessAddress < WhopSDK::Internal::Type::BaseModel
  # @!attribute city
  #   City name.
  #
  #   @return [String, nil]
  optional :city, String, nil?: true

  # @!attribute country
  #   Two-letter ISO 3166-1 country code, for example `US`, `DE`, or `GB`.
  #
  #   @return [String, nil]
  optional :country, String

  # @!attribute line1
  #   First line of the street address.
  #
  #   @return [String, nil]
  optional :line1, String

  # @!attribute line2
  #   Second line of the street address.
  #
  #   @return [String, nil]
  optional :line2, String, nil?: true

  # @!attribute postal_code
  #   Postal or ZIP code.
  #
  #   @return [String, nil]
  optional :postal_code, String, nil?: true

  # @!attribute state
  #   State, province, or region code, for example `CA`.
  #
  #   @return [String, nil]
  optional :state, String, nil?: true

  # @!method initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil)
  #   Account business address used to calculate tax. A complete address in a
  #   supported country is required when `tax_remitted_by` is `self`.
  #
  #   @param city [String, nil] City name.
  #
  #   @param country [String] Two-letter ISO 3166-1 country code, for example `US`, `DE`, or `GB`.
  #
  #   @param line1 [String] First line of the street address.
  #
  #   @param line2 [String, nil] Second line of the street address.
  #
  #   @param postal_code [String, nil] Postal or ZIP code.
  #
  #   @param state [String, nil] State, province, or region code, for example `CA`.
end

Instance Attribute Details

#cityString?

City name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


306
# File 'lib/whop_sdk/models/account_update_params.rb', line 306

optional :city, String, nil?: true

#countryString?

Two-letter ISO 3166-1 country code, for example US, DE, or GB.

Parameters:

  • (String)

Returns:

  • (String, nil)


312
# File 'lib/whop_sdk/models/account_update_params.rb', line 312

optional :country, String

#line1String?

First line of the street address.

Parameters:

  • (String)

Returns:

  • (String, nil)


318
# File 'lib/whop_sdk/models/account_update_params.rb', line 318

optional :line1, String

#line2String?

Second line of the street address.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


324
# File 'lib/whop_sdk/models/account_update_params.rb', line 324

optional :line2, String, nil?: true

#postal_codeString?

Postal or ZIP code.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


330
# File 'lib/whop_sdk/models/account_update_params.rb', line 330

optional :postal_code, String, nil?: true

#stateString?

State, province, or region code, for example CA.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


336
# File 'lib/whop_sdk/models/account_update_params.rb', line 336

optional :state, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


260
# File 'sig/whop_sdk/models/account_update_params.rbs', line 260

def to_hash: -> {