Class: WhopSDK::Models::AccountWallet

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/account_wallet.rb

Defined Under Namespace

Modules: Network

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, address:, network:) ⇒ Object

Parameters:

  • id (String)

    The ID of the wallet, which will look like wallet_*************

  • address (String)

    The on-chain address of the wallet

  • network (Symbol, WhopSDK::Models::AccountWallet::Network)

    The blockchain network the wallet lives on



# File 'lib/whop_sdk/models/account_wallet.rb', line 24

Instance Attribute Details

#addressString

The on-chain address of the wallet

Returns:

  • (String)


16
# File 'lib/whop_sdk/models/account_wallet.rb', line 16

required :address, String

#idString

The ID of the wallet, which will look like wallet_*************

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/account_wallet.rb', line 10

required :id, String

#networkSymbol, WhopSDK::Models::AccountWallet::Network

The blockchain network the wallet lives on



22
# File 'lib/whop_sdk/models/account_wallet.rb', line 22

required :network, enum: -> { WhopSDK::AccountWallet::Network }