Class: WhopSDK::Models::Ad::Creative::Crop

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/ad.rb,
sig/whop_sdk/models/ad.rbs

Overview

See Also:

  • WhopSDK::Models::Ad::Creative#crop

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



447
# File 'sig/whop_sdk/models/ad.rbs', line 447

def initialize: (

Instance Attribute Details

#heightFloat

Height of the crop window in source pixels.

Parameters:

  • value (Float)

Returns:

  • (Float)


634
# File 'lib/whop_sdk/models/ad.rb', line 634

required :height, Float

#widthFloat

Width of the crop window in source pixels.

Parameters:

  • value (Float)

Returns:

  • (Float)


640
# File 'lib/whop_sdk/models/ad.rb', line 640

required :width, Float

#xFloat

Left edge of the crop window in source pixels.

Parameters:

  • value (Float)

Returns:

  • (Float)


646
# File 'lib/whop_sdk/models/ad.rb', line 646

required :x, Float

#y_Float

Top edge of the crop window in source pixels.

Parameters:

  • value (Float)

Returns:

  • (Float)


652
# File 'lib/whop_sdk/models/ad.rb', line 652

required :y_, Float, api_name: :y

Instance Method Details

#to_hash{ height: Float, width: Float, x: Float, y_: Float }

Returns:

  • ({ height: Float, width: Float, x: Float, y_: Float })


454
# File 'sig/whop_sdk/models/ad.rbs', line 454

def to_hash: -> { height: Float, width: Float, x: Float, y_: Float }