Class: WhopSDK::Models::AdCampaign::Issue
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AdCampaign::Issue
- Defined in:
- lib/whop_sdk/models/ad_campaign.rb,
sig/whop_sdk/models/ad_campaign.rbs
Defined Under Namespace
Modules: ResourceType
Instance Attribute Summary collapse
-
#id ⇒ String
Unique identifier for the issue.
-
#message ⇒ String
A description of what the issue is and how it can be resolved.
-
#resource_id ⇒ String?
The ID of the campaign, ad group, or ad the issue is attached to.
-
#resource_type ⇒ Symbol, WhopSDK::Models::AdCampaign::Issue::ResourceType
The type of resource the issue is attached to.
Instance Method Summary collapse
-
#initialize(id:, message:, resource_id:, resource_type:) ⇒ Object
constructor
Open issues affecting the campaign and its descendant ad groups and ads.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, message:, resource_id:, resource_type:) ⇒ Object
Open issues affecting the campaign and its descendant ad groups and ads.
|
|
# File 'lib/whop_sdk/models/ad_campaign.rb', line 522
|
Instance Attribute Details
#id ⇒ String
Unique identifier for the issue.
502 |
# File 'lib/whop_sdk/models/ad_campaign.rb', line 502 required :id, String |
#message ⇒ String
A description of what the issue is and how it can be resolved.
508 |
# File 'lib/whop_sdk/models/ad_campaign.rb', line 508 required :message, String |
#resource_id ⇒ String?
The ID of the campaign, ad group, or ad the issue is attached to.
514 |
# File 'lib/whop_sdk/models/ad_campaign.rb', line 514 required :resource_id, String, nil?: true |
#resource_type ⇒ Symbol, WhopSDK::Models::AdCampaign::Issue::ResourceType
The type of resource the issue is attached to.
520 |
# File 'lib/whop_sdk/models/ad_campaign.rb', line 520 required :resource_type, enum: -> { WhopSDK::AdCampaign::Issue::ResourceType } |
Instance Method Details
#to_hash ⇒ {
355 |
# File 'sig/whop_sdk/models/ad_campaign.rbs', line 355
def to_hash: -> {
|