Class: WhopSDK::Models::AdCampaign::MetaConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/ad_campaign.rb

Overview

See Also:

Defined Under Namespace

Modules: BidStrategy, EffectiveStatus, Objective, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bid_amount:, bid_strategy:, budget_optimization:, effective_status:, end_time:, objective:, special_categories:, start_time:, status:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AdCampaign::MetaConfig for more details.

Meta-specific campaign configuration (objective, budget mode, etc.). Null for non-Meta campaigns.

Parameters:

  • bid_amount (Integer, nil)

    Bid cap amount in cents. Only used when bid_strategy is bid_cap.

  • bid_strategy (Symbol, WhopSDK::Models::AdCampaign::MetaConfig::BidStrategy, nil)

    The bidding strategy used to optimize spend for this campaign.

  • budget_optimization (Boolean, nil)

    Whether campaign budget optimization (CBO) is enabled, allowing the platform to

  • effective_status (Symbol, WhopSDK::Models::AdCampaign::MetaConfig::EffectiveStatus, nil)

    The actual delivery status, accounting for platform overrides (e.g., in_review,

  • end_time (String, nil)

    The scheduled end time of the campaign (ISO8601).

  • objective (Symbol, WhopSDK::Models::AdCampaign::MetaConfig::Objective, nil)

    The campaign objective that determines how Meta optimizes delivery.

  • special_categories (Array<String>, nil)

    Special ad categories required by the platform (e.g., housing, employment, credi

  • start_time (String, nil)

    The scheduled start time of the campaign (ISO8601).

  • status (Symbol, WhopSDK::Models::AdCampaign::MetaConfig::Status, nil)

    The campaign status as set by the advertiser (active or paused).



# File 'lib/whop_sdk/models/ad_campaign.rb', line 191

Instance Attribute Details

#bid_amountInteger?

Bid cap amount in cents. Only used when bid_strategy is bid_cap.

Returns:

  • (Integer, nil)


138
# File 'lib/whop_sdk/models/ad_campaign.rb', line 138

required :bid_amount, Integer, nil?: true

#bid_strategySymbol, ...

The bidding strategy used to optimize spend for this campaign.



144
# File 'lib/whop_sdk/models/ad_campaign.rb', line 144

required :bid_strategy, enum: -> { WhopSDK::AdCampaign::MetaConfig::BidStrategy }, nil?: true

#budget_optimizationBoolean?

Whether campaign budget optimization (CBO) is enabled, allowing the platform to distribute budget across ad groups.

Returns:

  • (Boolean, nil)


151
# File 'lib/whop_sdk/models/ad_campaign.rb', line 151

required :budget_optimization, WhopSDK::Internal::Type::Boolean, nil?: true

#effective_statusSymbol, ...

The actual delivery status, accounting for platform overrides (e.g., in_review, rejected).



158
# File 'lib/whop_sdk/models/ad_campaign.rb', line 158

required :effective_status, enum: -> { WhopSDK::AdCampaign::MetaConfig::EffectiveStatus }, nil?: true

#end_timeString?

The scheduled end time of the campaign (ISO8601).

Returns:

  • (String, nil)


164
# File 'lib/whop_sdk/models/ad_campaign.rb', line 164

required :end_time, String, nil?: true

#objectiveSymbol, ...

The campaign objective that determines how Meta optimizes delivery.



170
# File 'lib/whop_sdk/models/ad_campaign.rb', line 170

required :objective, enum: -> { WhopSDK::AdCampaign::MetaConfig::Objective }, nil?: true

#special_categoriesArray<String>?

Special ad categories required by the platform (e.g., housing, employment, credit).

Returns:

  • (Array<String>, nil)


177
# File 'lib/whop_sdk/models/ad_campaign.rb', line 177

required :special_categories, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#start_timeString?

The scheduled start time of the campaign (ISO8601).

Returns:

  • (String, nil)


183
# File 'lib/whop_sdk/models/ad_campaign.rb', line 183

required :start_time, String, nil?: true

#statusSymbol, ...

The campaign status as set by the advertiser (active or paused).



189
# File 'lib/whop_sdk/models/ad_campaign.rb', line 189

required :status, enum: -> { WhopSDK::AdCampaign::MetaConfig::Status }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/ad_campaign.rb', line 226