Module: WhopSDK::Models::AdCampaignUpdateParams::BudgetOptimization
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/whop_sdk/models/ad_campaign_update_params.rb,
sig/whop_sdk/models/ad_campaign_update_params.rbs
Overview
Which level owns the budget — the campaign (CBO) or each ad group (ABO). Only changeable before the campaign is live on Meta; switching to ad_campaign requires budget_amount in the same request, and switching to ad_group clears the campaign budget.
Constant Summary collapse
- AD_CAMPAIGN =
:ad_campaign- AD_GROUP =
:ad_group
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[WhopSDK::Models::AdCampaignUpdateParams::budget_optimization]
100 |
# File 'sig/whop_sdk/models/ad_campaign_update_params.rbs', line 100
def self?.values: -> ::Array[WhopSDK::Models::AdCampaignUpdateParams::budget_optimization]
|