Class: WhopSDK::Models::AdGroupListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/ad_group_list_response.rb

Overview

Defined Under Namespace

Classes: AdCampaign

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, ad_campaign:, budget:, budget_type:, created_at:, platform:, status:, title:, updated_at:) ⇒ Object

An ad group (ad set) belonging to an ad campaign.

Parameters:

  • id (String)

    The unique identifier for this ad group.

  • ad_campaign (WhopSDK::Models::AdGroupListResponse::AdCampaign)

    The ad campaign this ad group belongs to.

  • budget (Float, nil)

    Budget amount in dollars.

  • budget_type (Symbol, WhopSDK::Models::AdBudgetType, nil)

    The budget type for an ad campaign or ad group.

  • created_at (Time)

    When the ad group was created.

  • platform (Symbol, WhopSDK::Models::AdCampaignPlatform)

    The external ad platform this ad group is running on (e.g., meta, tiktok).

  • status (Symbol, WhopSDK::Models::AdGroupStatus)

    Current operational status of the ad group.

  • title (String, nil)

    Human-readable name shown on the external platform.

  • updated_at (Time)

    When the ad group was last updated.



# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 61

Instance Attribute Details

#ad_campaignWhopSDK::Models::AdGroupListResponse::AdCampaign

The ad campaign this ad group belongs to.



17
# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 17

required :ad_campaign, -> { WhopSDK::Models::AdGroupListResponse::AdCampaign }

#budgetFloat?

Budget amount in dollars.

Returns:

  • (Float, nil)


23
# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 23

required :budget, Float, nil?: true

#budget_typeSymbol, ...

The budget type for an ad campaign or ad group.

Returns:



29
# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 29

required :budget_type, enum: -> { WhopSDK::AdBudgetType }, nil?: true

#created_atTime

When the ad group was created.

Returns:

  • (Time)


35
# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 35

required :created_at, Time

#idString

The unique identifier for this ad group.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 11

required :id, String

#platformSymbol, WhopSDK::Models::AdCampaignPlatform

The external ad platform this ad group is running on (e.g., meta, tiktok).



41
# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 41

required :platform, enum: -> { WhopSDK::AdCampaignPlatform }

#statusSymbol, WhopSDK::Models::AdGroupStatus

Current operational status of the ad group.

Returns:



47
# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 47

required :status, enum: -> { WhopSDK::AdGroupStatus }

#titleString?

Human-readable name shown on the external platform.

Returns:

  • (String, nil)


53
# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 53

required :title, String, nil?: true

#updated_atTime

When the ad group was last updated.

Returns:

  • (Time)


59
# File 'lib/whop_sdk/models/ad_group_list_response.rb', line 59

required :updated_at, Time