Class: WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/whop_sdk/models/ad_group_update_params.rb

Defined Under Namespace

Classes: Option

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, conditional_questions_group_id: nil, dependent_conditional_questions: nil, inline_context: nil, key: nil, label: nil, options: nil, question_format: nil) ⇒ Object

A question on a Meta lead gen form.

Parameters:



1667
1668
1669
1670
1671
1672
1673
1674
1675
1676
1677
1678
1679
1680
1681
1682
1683
1684
1685
1686
1687
1688
1689
1690
1691
1692
1693
1694
1695
1696
1697
1698
1699
1700
1701
1702
1703
1704
1705
1706
1707
1708
1709
1710
1711
1712
1713
1714
1715
1716
1717
1718
1719
1720
1721
1722
1723
1724
1725
1726
1727
1728
1729
1730
1731
1732
1733
1734
1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
1746
1747
1748
1749
1750
1751
1752
1753
1754
1755
1756
1757
1758
1759
1760
1761
1762
1763
1764
1765
1766
1767
1768
1769
1770
1771
1772
1773
1774
1775
1776
1777
1778
1779
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1667

class DependentConditionalQuestion < WhopSDK::Internal::Type::BaseModel
  # @!attribute type
  #   Question type (EMAIL, FULL_NAME, PHONE, CUSTOM, DATE_TIME, etc.).
  #
  #   @return [String]
  required :type, String

  # @!attribute inline_context
  #   Helper text shown below the question.
  #
  #   @return [String, nil]
  optional :inline_context, String, nil?: true

  # @!attribute key
  #   Unique key for this question.
  #
  #   @return [String, nil]
  optional :key, String, nil?: true

  # @!attribute label
  #   Custom label for CUSTOM questions.
  #
  #   @return [String, nil]
  optional :label, String, nil?: true

  # @!attribute options
  #   Answer options for multiple choice questions.
  #
  #   @return [Array<WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion::Option>, nil]
  optional :options,
           -> do
             WhopSDK::Internal::Type::ArrayOf[
               WhopSDK::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion::Option
             ]
           end,
           nil?: true

  # @!method initialize(type:, inline_context: nil, key: nil, label: nil, options: nil)
  #   A dependent conditional question (non-recursive to avoid schema recursion).
  #
  #   @param type [String] Question type (EMAIL, FULL_NAME, PHONE, CUSTOM, DATE_TIME, etc.).
  #
  #   @param inline_context [String, nil] Helper text shown below the question.
  #
  #   @param key [String, nil] Unique key for this question.
  #
  #   @param label [String, nil] Custom label for CUSTOM questions.
  #
  #   @param options [Array<WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion::Option>, nil] Answer options for multiple choice questions.

  class Option < WhopSDK::Internal::Type::BaseModel
    # @!attribute key
    #   Unique key for this option.
    #
    #   @return [String]
    required :key, String

    # @!attribute value
    #   Display text for this option.
    #
    #   @return [String]
    required :value, String

    # @!attribute logic
    #   Conditional logic routing for this answer option.
    #
    #   @return [WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion::Option::Logic, nil]
    optional :logic,
             -> {
               WhopSDK::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion::Option::Logic
             },
             nil?: true

    # @!method initialize(key:, value:, logic: nil)
    #   An answer option for a multiple choice lead form question.
    #
    #   @param key [String] Unique key for this option.
    #
    #   @param value [String] Display text for this option.
    #
    #   @param logic [WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion::Option::Logic, nil] Conditional logic routing for this answer option.

    # @see WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion::Option#logic
    class Logic < WhopSDK::Internal::Type::BaseModel
      # @!attribute type
      #   Logic type: go_to_question, submit_form, or close_form.
      #
      #   @return [String]
      required :type, String

      # @!attribute target_end_page_index
      #   Index of the end page to route to (for submit_form type).
      #
      #   @return [Integer, nil]
      optional :target_end_page_index, Integer, nil?: true

      # @!attribute target_question_index
      #   Index of the question to route to (for go_to_question type).
      #
      #   @return [Integer, nil]
      optional :target_question_index, Integer, nil?: true

      # @!method initialize(type:, target_end_page_index: nil, target_question_index: nil)
      #   Conditional logic routing for this answer option.
      #
      #   @param type [String] Logic type: go_to_question, submit_form, or close_form.
      #
      #   @param target_end_page_index [Integer, nil] Index of the end page to route to (for submit_form type).
      #
      #   @param target_question_index [Integer, nil] Index of the question to route to (for go_to_question type).
    end
  end
end

Instance Attribute Details

#inline_contextString?

Helper text shown below the question.

Returns:

  • (String, nil)


1678
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1678

optional :inline_context, String, nil?: true

#keyString?

Unique key for this question.

Returns:

  • (String, nil)


1684
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1684

optional :key, String, nil?: true

#labelString?

Custom label for CUSTOM questions.

Returns:

  • (String, nil)


1690
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1690

optional :label, String, nil?: true

#optionsArray<WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion::Option>?

Answer options for multiple choice questions.



1696
1697
1698
1699
1700
1701
1702
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1696

optional :options,
-> do
  WhopSDK::Internal::Type::ArrayOf[
    WhopSDK::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::DependentConditionalQuestion::Option
  ]
end,
nil?: true

#typeString

Question type (EMAIL, FULL_NAME, PHONE, CUSTOM, DATE_TIME, etc.).

Returns:

  • (String)


1672
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1672

required :type, String