Class: WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::Option
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::Option
- Defined in:
- lib/whop_sdk/models/ad_group_update_params.rb
Defined Under Namespace
Classes: Logic
Instance Attribute Summary collapse
-
#key ⇒ String
Unique key for this option.
-
#logic ⇒ WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::Option::Logic?
Conditional logic routing for this answer option.
-
#value ⇒ String
Display text for this option.
Instance Method Summary collapse
-
#initialize(key:, value:, logic: nil) ⇒ Object
constructor
An answer option for a multiple choice lead form question.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key:, value:, logic: nil) ⇒ Object
An answer option for a multiple choice lead form question.
|
|
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1804
|
Instance Attribute Details
#key ⇒ String
Unique key for this option.
1786 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1786 required :key, String |
#logic ⇒ WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::Option::Logic?
Conditional logic routing for this answer option.
1798 1799 1800 1801 1802 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1798 optional :logic, -> { WhopSDK::AdGroupUpdateParams::PlatformConfig::Meta::LeadFormConfig::Question::Option::Logic }, nil?: true |
#value ⇒ String
Display text for this option.
1792 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 1792 required :value, String |