Class: WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Tiktok::InstantFormConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Tiktok::InstantFormConfig
- Defined in:
- lib/whop_sdk/models/ad_group_update_params.rb
Overview
Defined Under Namespace
Classes: Question
Instance Attribute Summary collapse
-
#button_text ⇒ String?
Submit button text.
-
#greeting ⇒ String?
Greeting text shown at the top of the form.
-
#name ⇒ String?
Form name.
-
#privacy_policy_url ⇒ String
URL to your privacy policy.
-
#questions ⇒ Array<WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Tiktok::InstantFormConfig::Question>
Form questions (at least one required).
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#button_text ⇒ String?
Submit button text.
2972 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 2972 optional :button_text, String, nil?: true |
#greeting ⇒ String?
Greeting text shown at the top of the form.
2978 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 2978 optional :greeting, String, nil?: true |
#name ⇒ String?
Form name. Auto-generated if omitted.
2984 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 2984 optional :name, String, nil?: true |
#privacy_policy_url ⇒ String
URL to your privacy policy.
2959 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 2959 required :privacy_policy_url, String |
#questions ⇒ Array<WhopSDK::Models::AdGroupUpdateParams::PlatformConfig::Tiktok::InstantFormConfig::Question>
Form questions (at least one required).
2965 2966 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 2965 required :questions, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::AdGroupUpdateParams::PlatformConfig::Tiktok::InstantFormConfig::Question] } |