Class: WhopSDK::Models::AdReportRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/ad_report_retrieve_params.rb,
sig/whop_sdk/models/ad_report_retrieve_params.rbs

Overview

See Also:

  • WhopSDK::Resources::AdReports#retrieve

Defined Under Namespace

Modules: Breakdown

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(from:, to:, ad_campaign_ids: nil, ad_group_ids: nil, ad_ids: nil, breakdown: nil, company_id: nil, currency: nil, granularity: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AdReportRetrieveParams for more details.

Parameters:

  • from (Time)

    Inclusive start of the reporting window.

  • to (Time)

    Inclusive end of the reporting window.

  • ad_campaign_ids (Array<String>, nil) (defaults to: nil)

    Scope the report to these ad campaigns (max 100); stats are summed across them.

  • ad_group_ids (Array<String>, nil) (defaults to: nil)

    Scope the report to these ad groups (max 100); stats are summed across them. Mut

  • ad_ids (Array<String>, nil) (defaults to: nil)

    Scope the report to these ads (max 100); stats are summed across them. Mutually

  • breakdown (Symbol, WhopSDK::Models::AdReportRetrieveParams::Breakdown, nil) (defaults to: nil)

    Entity level to group an ad report by.

  • company_id (String, nil) (defaults to: nil)

    The unique identifier of a company. Mutually exclusive with adCampaignIds, `ad

  • currency (String, nil) (defaults to: nil)

    ISO 4217 currency code to report spend in. Defaults to the company's ads repor

  • granularity (Symbol, WhopSDK::Models::Granularities, nil) (defaults to: nil)

    Bucket size for external ad stat rows.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 70

Instance Attribute Details

#ad_campaign_idsArray<String>?

Scope the report to these ad campaigns (max 100); stats are summed across them. Mutually exclusive with companyId, adGroupIds, and adIds.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


27
# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 27

optional :ad_campaign_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#ad_group_idsArray<String>?

Scope the report to these ad groups (max 100); stats are summed across them. Mutually exclusive with companyId, adCampaignIds, and adIds.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


34
# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 34

optional :ad_group_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#ad_idsArray<String>?

Scope the report to these ads (max 100); stats are summed across them. Mutually exclusive with companyId, adCampaignIds, and adGroupIds.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


41
# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 41

optional :ad_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#breakdownSymbol, ...

Entity level to group an ad report by.

Parameters:

  • value (WhopSDK::Models::AdReportRetrieveParams::breakdown, nil)

Returns:



47
# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 47

optional :breakdown, enum: -> { WhopSDK::AdReportRetrieveParams::Breakdown }, nil?: true

#company_idString?

The unique identifier of a company. Mutually exclusive with adCampaignIds, adGroupIds, and adIds. Use with breakdown to fan out across every campaign, ad group, or ad in the company without paging.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


55
# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 55

optional :company_id, String, nil?: true

#currencyString?

ISO 4217 currency code to report spend in. Defaults to the company's ads reporting currency.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


62
# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 62

optional :currency, String, nil?: true

#fromTime

Inclusive start of the reporting window.

Parameters:

  • value (Time)

Returns:

  • (Time)


14
# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 14

required :from, Time

#granularitySymbol, ...

Bucket size for external ad stat rows.

Parameters:

  • value (WhopSDK::Models::granularities, nil)

Returns:



68
# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 68

optional :granularity, enum: -> { WhopSDK::Granularities }, nil?: true

#toTime

Inclusive end of the reporting window.

Parameters:

  • value (Time)

Returns:

  • (Time)


20
# File 'lib/whop_sdk/models/ad_report_retrieve_params.rb', line 20

required :to, Time

Instance Method Details

#to_hash{

Returns:

  • ({)


52
# File 'sig/whop_sdk/models/ad_report_retrieve_params.rbs', line 52

def to_hash: -> {