Class: WhopSDK::Models::AdReportRetrieveResponse::Breakdown::Summary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AdReportRetrieveResponse::Breakdown::Summary
- Defined in:
- lib/whop_sdk/models/ad_report_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#clicks ⇒ Integer
Total clicks over the date range.
-
#cost_per_result ⇒ Float?
Spend divided by ‘resultCount`.
-
#cpc ⇒ Float
Cost per click in the requested reporting currency.
-
#cpm ⇒ Float?
Cost per thousand impressions in the requested reporting currency.
-
#ctr ⇒ Float
Click-through rate (clicks / impressions).
-
#frequency ⇒ Float?
Average number of times each reached user saw an ad.
-
#impressions ⇒ Integer
Total impressions over the date range.
-
#reach ⇒ Integer
Unique users reached, deduplicated by the external ad platform.
-
#result_count ⇒ Integer?
Count of the campaign’s primary optimization result (purchases, clicks, etc.) — see ‘resultLabelKey`.
-
#result_label_key ⇒ Symbol, ...
Types of optimization results tracked from external ad platforms.
-
#result_label_override ⇒ String?
Advertiser-defined label for the result when ‘resultLabelKey` is `custom`.
-
#roas ⇒ Float?
Alias for ‘purchaseRoas` — return on ad spend for purchases, as reported by the external ad platform.
-
#spend ⇒ Float
Total spend over the date range in the requested reporting currency.
-
#spend_currency ⇒ Symbol, ...
The available currencies on the platform.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#clicks ⇒ Integer
Total clicks over the date range.
231 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 231 required :clicks, Integer |
#cost_per_result ⇒ Float?
Spend divided by ‘resultCount`. Null when there are no results.
237 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 237 required :cost_per_result, Float, nil?: true |
#cpc ⇒ Float
Cost per click in the requested reporting currency.
243 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 243 required :cpc, Float |
#cpm ⇒ Float?
Cost per thousand impressions in the requested reporting currency.
249 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 249 required :cpm, Float, nil?: true |
#ctr ⇒ Float
Click-through rate (clicks / impressions).
255 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 255 required :ctr, Float |
#frequency ⇒ Float?
Average number of times each reached user saw an ad.
261 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 261 required :frequency, Float, nil?: true |
#impressions ⇒ Integer
Total impressions over the date range.
267 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 267 required :impressions, Integer |
#reach ⇒ Integer
Unique users reached, deduplicated by the external ad platform.
273 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 273 required :reach, Integer |
#result_count ⇒ Integer?
Count of the campaign’s primary optimization result (purchases, clicks, etc.) —see ‘resultLabelKey`.
280 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 280 required :result_count, Integer, nil?: true |
#result_label_key ⇒ Symbol, ...
Types of optimization results tracked from external ad platforms
286 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 286 required :result_label_key, enum: -> { WhopSDK::ResultLabelKeys }, nil?: true |
#result_label_override ⇒ String?
Advertiser-defined label for the result when ‘resultLabelKey` is `custom`.
292 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 292 required :result_label_override, String, nil?: true |
#roas ⇒ Float?
Alias for ‘purchaseRoas` — return on ad spend for purchases, as reported by the external ad platform.
299 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 299 required :roas, Float, nil?: true |
#spend ⇒ Float
Total spend over the date range in the requested reporting currency.
305 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 305 required :spend, Float |