Class: WhopSDK::Models::Affiliate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Affiliate
- Defined in:
- lib/whop_sdk/models/affiliate.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#active_members_count ⇒ Integer
The total active members of the affiliate.
-
#company ⇒ WhopSDK::Models::Affiliate::Company
The company attached to this affiliate.
-
#created_at ⇒ Time
The datetime the affiliate was created.
-
#customer_retention_rate ⇒ String
The percentage of referred customers who are still active members.
-
#customer_retention_rate_ninety_days ⇒ String
The percentage of referred customers who remained active over the last 90 days.
-
#id ⇒ String
The unique identifier for the affiliate.
-
#monthly_recurring_revenue_usd ⇒ String
The monthly recurring revenue generated by this affiliate’s referrals, formatted as a USD currency string.
-
#status ⇒ Symbol, ...
Statuses for resources.
-
#total_overrides_count ⇒ Integer
The total count of all overrides for this affiliate.
-
#total_referral_earnings_usd ⇒ String
The total commission earnings paid to this affiliate, formatted as a USD currency string.
-
#total_referrals_count ⇒ Integer
The total referrals of the affiliate.
-
#total_revenue_usd ⇒ String
The total revenue generated from this affiliate’s referrals, formatted as a USD currency string.
-
#updated_at ⇒ Time
The datetime the affiliate was last updated.
-
#user ⇒ WhopSDK::Models::Affiliate::User
The user attached to this affiliate.
Instance Method Summary collapse
-
#initialize(id:, title:) ⇒ Object
constructor
The company attached to this affiliate.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, title:) ⇒ Object
The company attached to this affiliate
|
|
# File 'lib/whop_sdk/models/affiliate.rb', line 94
|
Instance Attribute Details
#active_members_count ⇒ Integer
The total active members of the affiliate
17 |
# File 'lib/whop_sdk/models/affiliate.rb', line 17 required :active_members_count, Integer |
#company ⇒ WhopSDK::Models::Affiliate::Company
The company attached to this affiliate
23 |
# File 'lib/whop_sdk/models/affiliate.rb', line 23 required :company, -> { WhopSDK::Affiliate::Company } |
#created_at ⇒ Time
The datetime the affiliate was created.
29 |
# File 'lib/whop_sdk/models/affiliate.rb', line 29 required :created_at, Time |
#customer_retention_rate ⇒ String
The percentage of referred customers who are still active members
35 |
# File 'lib/whop_sdk/models/affiliate.rb', line 35 required :customer_retention_rate, String |
#customer_retention_rate_ninety_days ⇒ String
The percentage of referred customers who remained active over the last 90 days
41 |
# File 'lib/whop_sdk/models/affiliate.rb', line 41 required :customer_retention_rate_ninety_days, String |
#id ⇒ String
The unique identifier for the affiliate.
11 |
# File 'lib/whop_sdk/models/affiliate.rb', line 11 required :id, String |
#monthly_recurring_revenue_usd ⇒ String
The monthly recurring revenue generated by this affiliate’s referrals, formatted as a USD currency string
48 |
# File 'lib/whop_sdk/models/affiliate.rb', line 48 required :monthly_recurring_revenue_usd, String |
#status ⇒ Symbol, ...
Statuses for resources
54 |
# File 'lib/whop_sdk/models/affiliate.rb', line 54 required :status, enum: -> { WhopSDK::Status }, nil?: true |
#total_overrides_count ⇒ Integer
The total count of all overrides for this affiliate
60 |
# File 'lib/whop_sdk/models/affiliate.rb', line 60 required :total_overrides_count, Integer |
#total_referral_earnings_usd ⇒ String
The total commission earnings paid to this affiliate, formatted as a USD currency string
67 |
# File 'lib/whop_sdk/models/affiliate.rb', line 67 required :total_referral_earnings_usd, String |
#total_referrals_count ⇒ Integer
The total referrals of the affiliate
73 |
# File 'lib/whop_sdk/models/affiliate.rb', line 73 required :total_referrals_count, Integer |
#total_revenue_usd ⇒ String
The total revenue generated from this affiliate’s referrals, formatted as a USD currency string
80 |
# File 'lib/whop_sdk/models/affiliate.rb', line 80 required :total_revenue_usd, String |
#updated_at ⇒ Time
The datetime the affiliate was last updated.
86 |
# File 'lib/whop_sdk/models/affiliate.rb', line 86 required :updated_at, Time |
#user ⇒ WhopSDK::Models::Affiliate::User
The user attached to this affiliate
92 |
# File 'lib/whop_sdk/models/affiliate.rb', line 92 required :user, -> { WhopSDK::Affiliate::User } |