Class: WhopSDK::Models::AffiliateListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/affiliate_list_response.rb

Overview

Defined Under Namespace

Classes: Company, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, title:) ⇒ Object

The company attached to this affiliate

Parameters:

  • id (String)

    The unique identifier for the company.

  • title (String)

    The written name of the company.



# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 94

Instance Attribute Details

#active_members_countInteger

The total active members of the affiliate

Returns:

  • (Integer)


17
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 17

required :active_members_count, Integer

#companyWhopSDK::Models::AffiliateListResponse::Company

The company attached to this affiliate



23
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 23

required :company, -> { WhopSDK::Models::AffiliateListResponse::Company }

#created_atTime

The datetime the affiliate was created.

Returns:

  • (Time)


29
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 29

required :created_at, Time

#customer_retention_rateString

The percentage of referred customers who are still active members

Returns:

  • (String)


35
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 35

required :customer_retention_rate, String

#customer_retention_rate_ninety_daysString

The percentage of referred customers who remained active over the last 90 days

Returns:

  • (String)


41
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 41

required :customer_retention_rate_ninety_days, String

#idString

The unique identifier for the affiliate.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 11

required :id, String

#monthly_recurring_revenue_usdString

The monthly recurring revenue generated by this affiliate’s referrals, formatted as a USD currency string

Returns:

  • (String)


48
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 48

required :monthly_recurring_revenue_usd, String

#statusSymbol, ...

Statuses for resources

Returns:



54
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 54

required :status, enum: -> { WhopSDK::Status }, nil?: true

#total_overrides_countInteger

The total count of all overrides for this affiliate

Returns:

  • (Integer)


60
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 60

required :total_overrides_count, Integer

#total_referral_earnings_usdString

The total commission earnings paid to this affiliate, formatted as a USD currency string

Returns:

  • (String)


67
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 67

required :total_referral_earnings_usd, String

#total_referrals_countInteger

The total referrals of the affiliate

Returns:

  • (Integer)


73
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 73

required :total_referrals_count, Integer

#total_revenue_usdString

The total revenue generated from this affiliate’s referrals, formatted as a USD currency string

Returns:

  • (String)


80
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 80

required :total_revenue_usd, String

#updated_atTime

The datetime the affiliate was last updated.

Returns:

  • (Time)


86
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 86

required :updated_at, Time

#userWhopSDK::Models::AffiliateListResponse::User

The user attached to this affiliate



92
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 92

required :user, -> { WhopSDK::Models::AffiliateListResponse::User }