Class: WhopSDK::Models::AffiliateListResponse::User
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AffiliateListResponse::User
- Defined in:
- lib/whop_sdk/models/affiliate_list_response.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the user.
-
#name ⇒ String?
The display name set on the user’s Whop profile.
-
#username ⇒ String?
The unique username chosen by the user for their Whop profile.
Instance Method Summary collapse
-
#initialize(id:, name:, username:) ⇒ Object
constructor
Some parameter documentations has been truncated, see User for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, username:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AffiliateListResponse::User for more details.
The user attached to this affiliate
|
|
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 173
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the user.
157 |
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 157 required :id, String |
#name ⇒ String?
The display name set on the user’s Whop profile. Null if the user has not set a name.
164 |
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 164 required :name, String, nil?: true |
#username ⇒ String?
The unique username chosen by the user for their Whop profile. Null if the user has not set a username.
171 |
# File 'lib/whop_sdk/models/affiliate_list_response.rb', line 171 required :username, String, nil?: true |