Class: WhopSDK::Models::Affiliates::OverrideUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Affiliates::OverrideUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/affiliates/override_update_params.rb
Overview
Instance Attribute Summary collapse
-
#applies_to_payments ⇒ Symbol, ...
Whether the affiliate commission applies to the first payment or all payments.
-
#commission_type ⇒ Symbol, ...
The types of payouts an affiliate can have.
-
#commission_value ⇒ Float?
The commission value (percentage 1-100 or flat fee in dollars).
- #id ⇒ String
- #override_id ⇒ String
-
#revenue_basis ⇒ Symbol, ...
The calculation method for affiliate rev-share percentages.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, override_id:, applies_to_payments: nil, commission_type: nil, commission_value: nil, revenue_basis: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/affiliates/override_update_params.rb', line 49
|
Instance Attribute Details
#applies_to_payments ⇒ Symbol, ...
Whether the affiliate commission applies to the first payment or all payments
25 26 27 28 29 |
# File 'lib/whop_sdk/models/affiliates/override_update_params.rb', line 25 optional :applies_to_payments, enum: -> { WhopSDK::Affiliates::AffiliateAppliesToPayments }, nil?: true |
#commission_type ⇒ Symbol, ...
The types of payouts an affiliate can have
35 |
# File 'lib/whop_sdk/models/affiliates/override_update_params.rb', line 35 optional :commission_type, enum: -> { WhopSDK::Affiliates::AffiliatePayoutTypes }, nil?: true |
#commission_value ⇒ Float?
The commission value (percentage 1-100 or flat fee in dollars).
41 |
# File 'lib/whop_sdk/models/affiliates/override_update_params.rb', line 41 optional :commission_value, Float, nil?: true |
#id ⇒ String
14 |
# File 'lib/whop_sdk/models/affiliates/override_update_params.rb', line 14 required :id, String |
#override_id ⇒ String
19 |
# File 'lib/whop_sdk/models/affiliates/override_update_params.rb', line 19 required :override_id, String |
#revenue_basis ⇒ Symbol, ...
The calculation method for affiliate rev-share percentages
47 |
# File 'lib/whop_sdk/models/affiliates/override_update_params.rb', line 47 optional :revenue_basis, enum: -> { WhopSDK::Affiliates::AffiliateRevenueBases }, nil?: true |