Class: WhopSDK::Models::App::Creator

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#idString

The internal ID of the user.

Returns:

  • (String)


211
# File 'lib/whop_sdk/models/app.rb', line 211

required :id, String

#nameString?

The name of the user from their Whop account.

Returns:

  • (String, nil)


217
# File 'lib/whop_sdk/models/app.rb', line 217

required :name, String, nil?: true

#usernameString

The username of the user from their Whop account.

Returns:

  • (String)


223
# File 'lib/whop_sdk/models/app.rb', line 223

required :username, String