Class: WhopSDK::Models::App::Stats
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::App::Stats
- Defined in:
- lib/whop_sdk/models/app.rb,
sig/whop_sdk/models/app.rbs
Overview
Instance Attribute Summary collapse
-
#dau ⇒ Integer
The number of unique users who have spent time in this app in the last 24 hours.
-
#mau ⇒ Integer
The number of unique users who have spent time in this app in the last 28 days.
-
#time_spent_last24_hours ⇒ Integer
The total time, in seconds, that all users have spent in this app over the last 24 hours.
-
#wau ⇒ Integer
The number of unique users who have spent time in this app in the last 7 days.
Instance Method Summary collapse
-
#initialize(dau:, mau:, time_spent_last24_hours:, wau:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Stats for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(dau:, mau:, time_spent_last24_hours:, wau:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::App::Stats for more details.
Aggregate usage statistics for this app, including daily, weekly, and monthly active user counts.
|
|
# File 'lib/whop_sdk/models/app.rb', line 470
|
Instance Attribute Details
#dau ⇒ Integer
The number of unique users who have spent time in this app in the last 24 hours. Returns 0 if no usage data is available.
447 |
# File 'lib/whop_sdk/models/app.rb', line 447 required :dau, Integer |
#mau ⇒ Integer
The number of unique users who have spent time in this app in the last 28 days. Returns 0 if no usage data is available.
454 |
# File 'lib/whop_sdk/models/app.rb', line 454 required :mau, Integer |
#time_spent_last24_hours ⇒ Integer
The total time, in seconds, that all users have spent in this app over the last 24 hours. Returns 0 if no usage data is available.
461 |
# File 'lib/whop_sdk/models/app.rb', line 461 required :time_spent_last24_hours, Integer |
#wau ⇒ Integer
The number of unique users who have spent time in this app in the last 7 days. Returns 0 if no usage data is available.
468 |
# File 'lib/whop_sdk/models/app.rb', line 468 required :wau, Integer |
Instance Method Details
#to_hash ⇒ {
284 |
# File 'sig/whop_sdk/models/app.rbs', line 284
def to_hash: -> {
|