Class: WhopSDK::Models::AppBuild

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app_build.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, checksum:, created_at:, file_url:, is_production:, platform:, review_message:, status:, supported_app_view_types:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AppBuild for more details.

A versioned build artifact for a Whop React Native App, submitted for review and deployment to a specific platform.

Parameters:

  • id (String)

    The unique identifier for the app build.

  • checksum (String)

    A SHA-256 hash of the uploaded build file, generated by the client and used to v

  • created_at (Time)

    The datetime the app build was created.

  • file_url (String)

    A URL to download the app build as a .zip archive.

  • is_production (Boolean)

    Whether this build is the currently active production build for its platform.

  • platform (Symbol, WhopSDK::Models::AppBuildPlatforms)

    The target platform for this build.

  • review_message (String, nil)

    Feedback from the reviewer explaining why the build was rejected. Null if the bu

  • status (Symbol, WhopSDK::Models::AppBuildStatuses)

    The current review status of this build.

  • supported_app_view_types (Array<Symbol, WhopSDK::Models::AppViewType>)

    The list of view types this build supports, as declared by the developer.



# File 'lib/whop_sdk/models/app_build.rb', line 62

Instance Attribute Details

#checksumString

A SHA-256 hash of the uploaded build file, generated by the client and used to verify file integrity.

Returns:

  • (String)


17
# File 'lib/whop_sdk/models/app_build.rb', line 17

required :checksum, String

#created_atTime

The datetime the app build was created.

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/app_build.rb', line 23

required :created_at, Time

#file_urlString

A URL to download the app build as a .zip archive.

Returns:

  • (String)


29
# File 'lib/whop_sdk/models/app_build.rb', line 29

required :file_url, String

#idString

The unique identifier for the app build.

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/app_build.rb', line 10

required :id, String

#is_productionBoolean

Whether this build is the currently active production build for its platform.

Returns:

  • (Boolean)


35
# File 'lib/whop_sdk/models/app_build.rb', line 35

required :is_production, WhopSDK::Internal::Type::Boolean

#platformSymbol, WhopSDK::Models::AppBuildPlatforms

The target platform for this build.



41
# File 'lib/whop_sdk/models/app_build.rb', line 41

required :platform, enum: -> { WhopSDK::AppBuildPlatforms }

#review_messageString?

Feedback from the reviewer explaining why the build was rejected. Null if the build has not been reviewed or was approved.

Returns:

  • (String, nil)


48
# File 'lib/whop_sdk/models/app_build.rb', line 48

required :review_message, String, nil?: true

#statusSymbol, WhopSDK::Models::AppBuildStatuses

The current review status of this build.



54
# File 'lib/whop_sdk/models/app_build.rb', line 54

required :status, enum: -> { WhopSDK::AppBuildStatuses }

#supported_app_view_typesArray<Symbol, WhopSDK::Models::AppViewType>

The list of view types this build supports, as declared by the developer.

Returns:



60
# File 'lib/whop_sdk/models/app_build.rb', line 60

required :supported_app_view_types, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppViewType] }