Class: WhopSDK::Models::AppCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/app_create_params.rb,
sig/whop_sdk/models/app_create_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Apps#create

Defined Under Namespace

Classes: Icon

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



30
# File 'sig/whop_sdk/models/app_create_params.rbs', line 30

def initialize: (

Instance Attribute Details

#base_urlString?

The base production URL where the app is hosted, such as 'https://myapp.example.com'.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


28
# File 'lib/whop_sdk/models/app_create_params.rb', line 28

optional :base_url, String, nil?: true

#company_idString

The unique identifier of the company to create the app for, starting with 'biz_'.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/whop_sdk/models/app_create_params.rb', line 15

required :company_id, String

#iconWhopSDK::Models::AppCreateParams::Icon?

The icon image for the app in PNG, JPEG, or GIF format.

Parameters:

  • value (WhopSDK::AppCreateParams::Icon, nil)

Returns:



34
# File 'lib/whop_sdk/models/app_create_params.rb', line 34

optional :icon, -> { WhopSDK::AppCreateParams::Icon }, nil?: true

#nameString

The display name for the app, shown to users on the app store and product pages.

Parameters:

  • value (String)

Returns:

  • (String)


21
# File 'lib/whop_sdk/models/app_create_params.rb', line 21

required :name, String

#redirect_urisArray<String>?

The whitelisted OAuth callback URLs that users are redirected to after authorizing the app.

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


41
# File 'lib/whop_sdk/models/app_create_params.rb', line 41

optional :redirect_uris, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#routeString?

The unique subdomain route where the app's hosted web builds are served, such as 'myapp' for myapp.whop.app.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


48
# File 'lib/whop_sdk/models/app_create_params.rb', line 48

optional :route, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


40
# File 'sig/whop_sdk/models/app_create_params.rbs', line 40

def to_hash: -> {