Class: WhopSDK::Models::AppListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/app_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#app_type ⇒ Symbol, ...
The type of end-user an app is built for.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#company_id ⇒ String?
The ID of the company to filter apps by.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#order ⇒ Symbol, ...
The order to fetch the apps in for discovery.
-
#query ⇒ String?
The query to search for apps by name.
-
#verified_apps_only ⇒ Boolean?
If true, you will only get apps that are verified by Whop.
-
#view_type ⇒ Symbol, ...
The different types of an app view.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, app_type: nil, before: nil, company_id: nil, direction: nil, first: nil, last: nil, order: nil, query: nil, verified_apps_only: nil, view_type: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AppListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, app_type: nil, before: nil, company_id: nil, direction: nil, first: nil, last: nil, order: nil, query: nil, verified_apps_only: nil, view_type: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AppListParams for more details.
|
|
# File 'lib/whop_sdk/models/app_list_params.rb', line 77
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
14 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 14 optional :after, String, nil?: true |
#app_type ⇒ Symbol, ...
The type of end-user an app is built for
20 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 20 optional :app_type, enum: -> { WhopSDK::AppType }, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
26 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 26 optional :before, String, nil?: true |
#company_id ⇒ String?
The ID of the company to filter apps by
32 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 32 optional :company_id, String, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
38 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 38 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
44 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 44 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
50 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 50 optional :last, Integer, nil?: true |
#order ⇒ Symbol, ...
The order to fetch the apps in for discovery.
56 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 56 optional :order, enum: -> { WhopSDK::AppListParams::Order }, nil?: true |
#query ⇒ String?
The query to search for apps by name.
62 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 62 optional :query, String, nil?: true |
#verified_apps_only ⇒ Boolean?
If true, you will only get apps that are verified by Whop. Use this to populate a ‘featured apps’ section on the app store.
69 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 69 optional :verified_apps_only, WhopSDK::Internal::Type::Boolean, nil?: true |
#view_type ⇒ Symbol, ...
The different types of an app view
75 |
# File 'lib/whop_sdk/models/app_list_params.rb', line 75 optional :view_type, enum: -> { WhopSDK::AppViewType }, nil?: true |