Class: WhopSDK::Models::AppListResponse::Icon
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppListResponse::Icon
- Defined in:
- lib/whop_sdk/models/app_list_response.rb
Overview
Instance Attribute Summary collapse
-
#url ⇒ String?
This is the URL you use to render optimized attachments on the client.
Instance Method Summary collapse
-
#initialize(url: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Icon for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AppListResponse::Icon for more details.
The icon for the app. This icon is shown on discovery, on the product page, on checkout, and as a default icon for the experiences.
|
|
# File 'lib/whop_sdk/models/app_list_response.rb', line 197
|
Instance Attribute Details
#url ⇒ String?
This is the URL you use to render optimized attachments on the client. This should be used for apps.
195 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 195 required :url, String, nil?: true |