Class: WhopSDK::Models::AppLogsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/app_logs_params.rb,
sig/whop_sdk/models/app_logs_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Apps#logs

Defined Under Namespace

Modules: Level

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, after: nil, app_build_id: nil, before: nil, created_after: nil, created_before: nil, first: nil, level: nil, query: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AppLogsParams for more details.

Parameters:

  • id (String)
  • after (String) (defaults to: nil)

    A cursor for fetching logs after a previous page.

  • app_build_id (String) (defaults to: nil)

    Only return logs from this build.

  • before (String) (defaults to: nil)

    A cursor for fetching logs before a later page.

  • created_after (Time) (defaults to: nil)

    Start of the time window as an ISO 8601 timestamp. Defaults to 7 days before cre

  • created_before (Time) (defaults to: nil)

    End of the time window as an ISO 8601 timestamp. Defaults to now.

  • first (Integer) (defaults to: nil)

    The number of log lines to return (max 500).

  • level (Symbol, WhopSDK::Models::AppLogsParams::Level) (defaults to: nil)

    Only return console lines of this level.

  • query (String) (defaults to: nil)

    Only return logs whose message contains this text (case-insensitive).

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/app_logs_params.rb', line 64

Instance Attribute Details

#afterString?

A cursor for fetching logs after a previous page.

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/whop_sdk/models/app_logs_params.rb', line 19

optional :after, String

#app_build_idString?

Only return logs from this build.

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/whop_sdk/models/app_logs_params.rb', line 25

optional :app_build_id, String

#beforeString?

A cursor for fetching logs before a later page.

Parameters:

  • (String)

Returns:

  • (String, nil)


31
# File 'lib/whop_sdk/models/app_logs_params.rb', line 31

optional :before, String

#created_afterTime?

Start of the time window as an ISO 8601 timestamp. Defaults to 7 days before created_before.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


38
# File 'lib/whop_sdk/models/app_logs_params.rb', line 38

optional :created_after, Time

#created_beforeTime?

End of the time window as an ISO 8601 timestamp. Defaults to now.

Parameters:

  • (Time)

Returns:

  • (Time, nil)


44
# File 'lib/whop_sdk/models/app_logs_params.rb', line 44

optional :created_before, Time

#firstInteger?

The number of log lines to return (max 500).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


50
# File 'lib/whop_sdk/models/app_logs_params.rb', line 50

optional :first, Integer

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/app_logs_params.rb', line 13

required :id, String

#levelSymbol, ...

Only return console lines of this level.

Returns:



56
# File 'lib/whop_sdk/models/app_logs_params.rb', line 56

optional :level, enum: -> { WhopSDK::AppLogsParams::Level }

#queryString?

Only return logs whose message contains this text (case-insensitive).

Parameters:

  • (String)

Returns:

  • (String, nil)


62
# File 'lib/whop_sdk/models/app_logs_params.rb', line 62

optional :query, String

Instance Method Details

#to_hash{

Returns:

  • ({)


70
# File 'sig/whop_sdk/models/app_logs_params.rbs', line 70

def to_hash: -> {