Class: WhopSDK::Models::AppUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/app_update_params.rb,
sig/whop_sdk/models/app_update_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Apps#update

Defined Under Namespace

Modules: OAuthClientType, RequiredScope Classes: Icon

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

The icon image for the app, used in listings and navigation.

Parameters:

  • id (String)

    The ID of an existing file object.



# File 'lib/whop_sdk/models/app_update_params.rb', line 176

Instance Attribute Details

#app_store_descriptionString?

The detailed description shown on the app store's in-depth app view page.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


19
# File 'lib/whop_sdk/models/app_update_params.rb', line 19

optional :app_store_description, String, nil?: true

#app_typeSymbol, ...

The type of end-user an app is built for

Parameters:

  • value (WhopSDK::Models::app_type, nil)

Returns:



25
# File 'lib/whop_sdk/models/app_update_params.rb', line 25

optional :app_type, enum: -> { WhopSDK::AppType }, nil?: true

#base_urlString?

The base production URL where the app is hosted, such as 'https://myapp.example.com'.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/app_update_params.rb', line 32

optional :base_url, String, nil?: true

#dashboard_pathString?

The URL path for the company dashboard view of the app, such as '/dashboard'.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/whop_sdk/models/app_update_params.rb', line 38

optional :dashboard_path, String, nil?: true

#descriptionString?

A short description of the app shown in listings and search results.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


44
# File 'lib/whop_sdk/models/app_update_params.rb', line 44

optional :description, String, nil?: true

#discover_pathString?

The URL path for the discover view of the app, such as '/discover'.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


50
# File 'lib/whop_sdk/models/app_update_params.rb', line 50

optional :discover_path, String, nil?: true

#experience_pathString?

The URL path for the member-facing hub view of the app, such as '/experiences/[experienceId]'.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


57
# File 'lib/whop_sdk/models/app_update_params.rb', line 57

optional :experience_path, String, nil?: true

#iconWhopSDK::Models::AppUpdateParams::Icon?

The icon image for the app, used in listings and navigation.

Parameters:

  • value (WhopSDK::AppUpdateParams::Icon, nil)

Returns:



63
# File 'lib/whop_sdk/models/app_update_params.rb', line 63

optional :icon, -> { WhopSDK::AppUpdateParams::Icon }, nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/app_update_params.rb', line 13

required :id, String

#nameString?

The display name for the app, shown to users on the app store and product pages.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


69
# File 'lib/whop_sdk/models/app_update_params.rb', line 69

optional :name, String, nil?: true

#oauth_client_typeSymbol, ...

How this app authenticates at the OAuth token endpoint.

Parameters:

  • value (WhopSDK::Models::AppUpdateParams::oauth_client_type, nil)

Returns:



75
# File 'lib/whop_sdk/models/app_update_params.rb', line 75

optional :oauth_client_type, enum: -> { WhopSDK::AppUpdateParams::OAuthClientType }, nil?: true

#openapi_pathString?

The URL path to the OpenAPI spec file of the app, such as '/assets/openapi.json'.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


82
# File 'lib/whop_sdk/models/app_update_params.rb', line 82

optional :openapi_path, String, nil?: true

#redirect_urisArray<String>?

The whitelisted OAuth callback URLs that users are redirected to after authorizing the app

Parameters:

  • value (::Array[String], nil)

Returns:

  • (Array<String>, nil)


89
# File 'lib/whop_sdk/models/app_update_params.rb', line 89

optional :redirect_uris, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#required_scopesArray<Symbol, WhopSDK::Models::AppUpdateParams::RequiredScope>?

The permission scopes the app will request from users when they install it.

Parameters:

  • value (::Array[WhopSDK::Models::AppUpdateParams::required_scope], nil)

Returns:



95
96
97
# File 'lib/whop_sdk/models/app_update_params.rb', line 95

optional :required_scopes,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppUpdateParams::RequiredScope] },
nil?: true

#routeString?

The unique subdomain route where the app's hosted web builds are served, such as 'myapp' for myapp.whop.app.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


104
# File 'lib/whop_sdk/models/app_update_params.rb', line 104

optional :route, String, nil?: true

#secretsHash{Symbol=>Object}?

Secrets to add or overwrite on the app, as an object of string values (e.g. "..."). Keys not included are left untouched. Pass null or an empty string as the value to delete a secret. Secrets are encrypted at rest and injected into the app's hosted server runtime as environment bindings.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


113
# File 'lib/whop_sdk/models/app_update_params.rb', line 113

optional :secrets, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#skills_pathString?

The URL path to the skills directory of the app, such as '/assets/skills/'.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


119
# File 'lib/whop_sdk/models/app_update_params.rb', line 119

optional :skills_path, String, nil?: true

#statusSymbol, ...

The status of an experience interface

Parameters:

  • value (WhopSDK::Models::app_statuses, nil)

Returns:



125
# File 'lib/whop_sdk/models/app_update_params.rb', line 125

optional :status, enum: -> { WhopSDK::AppStatuses }, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/app_update_params.rb', line 189

Instance Method Details

#to_hash{

Returns:

  • ({)


88
# File 'sig/whop_sdk/models/app_update_params.rbs', line 88

def to_hash: -> {