Class: WhopSDK::Models::AppUpdateParams::Icon

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, app_store_description: nil, app_type: nil, base_url: nil, dashboard_path: nil, description: nil, discover_path: nil, experience_path: nil, icon: nil, name: nil, oauth_client_type: nil, openapi_path: nil, redirect_uris: nil, required_scopes: nil, skills_path: nil, status: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AppUpdateParams for more details.

Parameters:

  • id (String)
  • app_store_description (String, nil) (defaults to: nil)

    The detailed description shown on the app store’s in-depth app view page.

  • app_type (Symbol, WhopSDK::Models::AppType, nil) (defaults to: nil)

    The type of end-user an app is built for

  • base_url (String, nil) (defaults to: nil)

    The base production URL where the app is hosted, such as ‘myapp.example.

  • dashboard_path (String, nil) (defaults to: nil)

    The URL path for the company dashboard view of the app, such as ‘/dashboard’.

  • description (String, nil) (defaults to: nil)

    A short description of the app shown in listings and search results.

  • discover_path (String, nil) (defaults to: nil)

    The URL path for the discover view of the app, such as ‘/discover’.

  • experience_path (String, nil) (defaults to: nil)

    The URL path for the member-facing hub view of the app, such as ‘/experiences/[e

  • icon (WhopSDK::Models::AppUpdateParams::Icon, nil) (defaults to: nil)

    The icon image for the app, used in listings and navigation.

  • name (String, nil) (defaults to: nil)

    The display name for the app, shown to users on the app store and product pages.

  • oauth_client_type (Symbol, WhopSDK::Models::AppUpdateParams::OAuthClientType, nil) (defaults to: nil)

    How this app authenticates at the OAuth token endpoint.

  • openapi_path (String, nil) (defaults to: nil)

    The URL path to the OpenAPI spec file of the app, such as ‘/assets/openapi.json’

  • redirect_uris (Array<String>, nil) (defaults to: nil)

    The whitelisted OAuth callback URLs that users are redirected to after authorizi

  • required_scopes (Array<Symbol, WhopSDK::Models::AppUpdateParams::RequiredScope>, nil) (defaults to: nil)

    The permission scopes the app will request from users when they install it.

  • skills_path (String, nil) (defaults to: nil)

    The URL path to the skills directory of the app, such as ‘/assets/skills/’.

  • status (Symbol, WhopSDK::Models::AppStatuses, nil) (defaults to: nil)

    The status of an experience interface

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/whop_sdk/models/app_update_params.rb', line 149

class Icon < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing file object.
  #
  #   @return [String]
  required :id, String

  # @!method initialize(id:)
  #   The icon image for the app, used in listings and navigation.
  #
  #   @param id [String] The ID of an existing file object.
end

Instance Attribute Details

#idString

The ID of an existing file object.

Returns:

  • (String)


154
# File 'lib/whop_sdk/models/app_update_params.rb', line 154

required :id, String