Class: WhopSDK::Models::AuthorizedUser

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/authorized_user.rb

Overview

Defined Under Namespace

Classes: Company, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, title:) ⇒ Object

The company this authorized user has access to.

Parameters:

  • id (String)

    The unique identifier for the company.

  • title (String)

    The display name of the company shown to customers.



# File 'lib/whop_sdk/models/authorized_user.rb', line 31

Instance Attribute Details

#companyWhopSDK::Models::AuthorizedUser::Company

The company this authorized user has access to.



17
# File 'lib/whop_sdk/models/authorized_user.rb', line 17

required :company, -> { WhopSDK::AuthorizedUser::Company }

#idString

The unique identifier for the authorized user.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/authorized_user.rb', line 11

required :id, String

#roleSymbol, WhopSDK::Models::AuthorizedUserRoles

The permission role assigned to this authorized user within the company.



23
# File 'lib/whop_sdk/models/authorized_user.rb', line 23

required :role, enum: -> { WhopSDK::AuthorizedUserRoles }

#userWhopSDK::Models::AuthorizedUser::User

The user account linked to this authorized user record.



29
# File 'lib/whop_sdk/models/authorized_user.rb', line 29

required :user, -> { WhopSDK::AuthorizedUser::User }