Class: WhopSDK::Models::AuthorizedUser::Company
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AuthorizedUser::Company
- Defined in:
- lib/whop_sdk/models/authorized_user.rb,
sig/whop_sdk/models/authorized_user.rbs
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the company.
-
#title ⇒ String
The display name of the company shown to customers.
Instance Method Summary collapse
-
#initialize ⇒ Company
constructor
A new instance of Company.
- #to_hash ⇒ { id: String, title: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Company
Returns a new instance of Company.
41 |
# File 'sig/whop_sdk/models/authorized_user.rbs', line 41
def initialize: (id: String, title: String) -> void
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the company.
49 |
# File 'lib/whop_sdk/models/authorized_user.rb', line 49 required :id, String |
#title ⇒ String
The display name of the company shown to customers.
55 |
# File 'lib/whop_sdk/models/authorized_user.rb', line 55 required :title, String |
Instance Method Details
#to_hash ⇒ { id: String, title: String }
43 |
# File 'sig/whop_sdk/models/authorized_user.rbs', line 43
def to_hash: -> { id: String, title: String }
|