Class: WhopSDK::Models::AuthorizedUserCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/authorized_user_create_params.rb,
sig/whop_sdk/models/authorized_user_create_params.rbs

Overview

See Also:

  • WhopSDK::Resources::AuthorizedUsers#create

Defined Under Namespace

Classes: Elevation

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



27
# File 'sig/whop_sdk/models/authorized_user_create_params.rbs', line 27

def initialize: (

Instance Attribute Details

#company_idString

The ID of the company to add the authorized user to.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 14

required :company_id, String

#elevationWhopSDK::Models::AuthorizedUserCreateParams::Elevation?

Re-authentication proof required to perform this sensitive action.

Parameters:

  • value (WhopSDK::AuthorizedUserCreateParams::Elevation, nil)

Returns:



33
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 33

optional :elevation, -> { WhopSDK::AuthorizedUserCreateParams::Elevation }, nil?: true

#roleSymbol, WhopSDK::Models::AuthorizedUserRoles

The role to assign to the authorized user within the company. Supported roles: 'moderator', 'sales_manager'.

Parameters:

  • value (WhopSDK::Models::authorized_user_roles)

Returns:



21
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 21

required :role, enum: -> { WhopSDK::AuthorizedUserRoles }

#send_emailsBoolean?

Whether to send notification emails to the user on creation.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


39
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 39

optional :send_emails, WhopSDK::Internal::Type::Boolean, nil?: true

#user_idString

The ID of the user to add as an authorized user.

Parameters:

  • value (String)

Returns:

  • (String)


27
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 27

required :user_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


36
# File 'sig/whop_sdk/models/authorized_user_create_params.rbs', line 36

def to_hash: -> {