Class: WhopSDK::Models::AuthorizedUserDeleteParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/authorized_user_delete_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, company_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AuthorizedUserDeleteParams for more details.

Parameters:

  • id (String)
  • company_id (String, nil) (defaults to: nil)

    The ID of the company the authorized user belongs to. Optional if the authorized

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/authorized_user_delete_params.rb', line 22

Instance Attribute Details

#company_idString?

The ID of the company the authorized user belongs to. Optional if the authorized user ID is provided.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/authorized_user_delete_params.rb', line 20

optional :company_id, String, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/authorized_user_delete_params.rb', line 13

required :id, String