Class: WhopSDK::Models::AuthorizedUserListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/authorized_user_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id: , after: nil, before: nil, first: nil, last: nil, role: nil, user_id: nil, request_options: {}) ⇒ Object

Parameters:

  • company_id (String) (defaults to: )

    The ID of the company to list authorized users for

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • role (Symbol, WhopSDK::Models::AuthorizedUserRoles, nil) (defaults to: nil)

    Possible roles an authorized user can have

  • user_id (String, nil) (defaults to: nil)

    Filter by the user ID to check if the user is an authorized user

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/authorized_user_list_params.rb', line 52

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/authorized_user_list_params.rb', line 20

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/authorized_user_list_params.rb', line 26

optional :before, String, nil?: true

#company_idString

The ID of the company to list authorized users for

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/authorized_user_list_params.rb', line 14

required :company_id, String

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


32
# File 'lib/whop_sdk/models/authorized_user_list_params.rb', line 32

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


38
# File 'lib/whop_sdk/models/authorized_user_list_params.rb', line 38

optional :last, Integer, nil?: true

#roleSymbol, ...

Possible roles an authorized user can have

Returns:



44
# File 'lib/whop_sdk/models/authorized_user_list_params.rb', line 44

optional :role, enum: -> { WhopSDK::AuthorizedUserRoles }, nil?: true

#user_idString?

Filter by the user ID to check if the user is an authorized user

Returns:

  • (String, nil)


50
# File 'lib/whop_sdk/models/authorized_user_list_params.rb', line 50

optional :user_id, String, nil?: true