Class: WhopSDK::Models::AuthorizedUserListResponse::User
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AuthorizedUserListResponse::User
- Defined in:
- lib/whop_sdk/models/authorized_user_list_response.rb
Overview
Instance Attribute Summary collapse
-
#email ⇒ String?
The email of the user.
-
#id ⇒ String
The internal ID of the user.
-
#name ⇒ String?
The name of the user from their Whop account.
-
#username ⇒ String
The username of the user from their Whop account.
Instance Method Summary collapse
-
#initialize(id: , email: , name: , username: ) ⇒ Object
constructor
The user associated with the authorized user.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , email: , name: , username: ) ⇒ Object
The user associated with the authorized user.
|
|
# File 'lib/whop_sdk/models/authorized_user_list_response.rb', line 60
|
Instance Attribute Details
#email ⇒ String?
The email of the user
46 |
# File 'lib/whop_sdk/models/authorized_user_list_response.rb', line 46 required :email, String, nil?: true |
#id ⇒ String
The internal ID of the user.
40 |
# File 'lib/whop_sdk/models/authorized_user_list_response.rb', line 40 required :id, String |
#name ⇒ String?
The name of the user from their Whop account.
52 |
# File 'lib/whop_sdk/models/authorized_user_list_response.rb', line 52 required :name, String, nil?: true |
#username ⇒ String
The username of the user from their Whop account.
58 |
# File 'lib/whop_sdk/models/authorized_user_list_response.rb', line 58 required :username, String |