Module: WhopSDK::Models::BountyCreateParams::BusinessGoalType

Extended by:
Internal::Type::Enum
Defined in:
lib/whop_sdk/models/bounty_create_params.rb,
sig/whop_sdk/models/bounty_create_params.rbs

Overview

What the poster is trying to accomplish with a workforce bounty. Used for product taxonomy and analytics, separate from the bounty's implementation type.

Constant Summary collapse

CLIPPING =

Returns:

  • (:clipping)
:clipping
POST_ENGAGEMENT =

Returns:

  • (:post_engagement)
:post_engagement
OWNED_ACCOUNT_GROWTH =

Returns:

  • (:owned_account_growth)
:owned_account_growth
UGC_CONTENT =

Returns:

  • (:ugc_content)
:ugc_content
LOCAL_ACTIVATION =

Returns:

  • (:local_activation)
:local_activation
OTHER =

Returns:

  • (:other)
:other

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[WhopSDK::Models::BountyCreateParams::business_goal_type]

Returns:

  • (::Array[WhopSDK::Models::BountyCreateParams::business_goal_type])


108
# File 'sig/whop_sdk/models/bounty_create_params.rbs', line 108

def self?.values: -> ::Array[WhopSDK::Models::BountyCreateParams::business_goal_type]