Class: WhopSDK::Models::BountyCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::BountyCreateResponse
- Defined in:
- lib/whop_sdk/models/bounty_create_response.rb
Overview
Defined Under Namespace
Modules: BountyType, Status
Instance Attribute Summary collapse
-
#bounty_type ⇒ Symbol, WhopSDK::Models::BountyCreateResponse::BountyType
The underlying bounty implementation type.
-
#created_at ⇒ Time
The datetime the bounty was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency used for the bounty funds.
-
#description ⇒ String
The description of the bounty.
-
#id ⇒ String
The unique identifier for the bounty.
-
#status ⇒ Symbol, WhopSDK::Models::BountyCreateResponse::Status
The current lifecycle status of the bounty.
-
#title ⇒ String
The title of the bounty.
-
#total_available ⇒ Float
The total amount currently funded in the bounty pool for payout.
-
#total_paid ⇒ Float
The total amount paid out for this bounty.
-
#updated_at ⇒ Time
The datetime the bounty was last updated.
-
#vote_threshold ⇒ Integer
The number of watcher votes required before the submission can resolve.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, bounty_type:, created_at:, currency:, description:, status:, title:, total_available:, total_paid:, updated_at:, vote_threshold:) ⇒ Object
constructor
A privately accessible bounty.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, bounty_type:, created_at:, currency:, description:, status:, title:, total_available:, total_paid:, updated_at:, vote_threshold:) ⇒ Object
A privately accessible bounty.
|
|
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 73
|
Instance Attribute Details
#bounty_type ⇒ Symbol, WhopSDK::Models::BountyCreateResponse::BountyType
The underlying bounty implementation type.
17 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 17 required :bounty_type, enum: -> { WhopSDK::Models::BountyCreateResponse::BountyType } |
#created_at ⇒ Time
The datetime the bounty was created.
23 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 23 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency used for the bounty funds.
29 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 29 required :currency, enum: -> { WhopSDK::Currency } |
#description ⇒ String
The description of the bounty.
35 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 35 required :description, String |
#id ⇒ String
The unique identifier for the bounty.
11 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 11 required :id, String |
#status ⇒ Symbol, WhopSDK::Models::BountyCreateResponse::Status
The current lifecycle status of the bounty.
41 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 41 required :status, enum: -> { WhopSDK::Models::BountyCreateResponse::Status } |
#title ⇒ String
The title of the bounty.
47 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 47 required :title, String |
#total_available ⇒ Float
The total amount currently funded in the bounty pool for payout.
53 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 53 required :total_available, Float |
#total_paid ⇒ Float
The total amount paid out for this bounty.
59 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 59 required :total_paid, Float |
#updated_at ⇒ Time
The datetime the bounty was last updated.
65 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 65 required :updated_at, Time |
#vote_threshold ⇒ Integer
The number of watcher votes required before the submission can resolve.
71 |
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 71 required :vote_threshold, Integer |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/bounty_create_response.rb', line 108
|