Class: WhopSDK::Models::BountyListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/bounty_list_params.rb

Overview

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, direction: nil, experience_id: nil, first: nil, last: nil, status: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::BountyListParams for more details.

Parameters:

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • experience_id (String, nil) (defaults to: nil)

    The experience to list bounties for. When omitted, returns bounties with no expe

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • status (Symbol, WhopSDK::Models::BountyListParams::Status, nil) (defaults to: nil)

    The available bounty statuses to choose from.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/bounty_list_params.rb', line 53

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


14
# File 'lib/whop_sdk/models/bounty_list_params.rb', line 14

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/bounty_list_params.rb', line 20

optional :before, String, nil?: true

#directionSymbol, ...

The direction of the sort.

Returns:



26
# File 'lib/whop_sdk/models/bounty_list_params.rb', line 26

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#experience_idString?

The experience to list bounties for. When omitted, returns bounties with no experience.

Returns:

  • (String, nil)


33
# File 'lib/whop_sdk/models/bounty_list_params.rb', line 33

optional :experience_id, String, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


39
# File 'lib/whop_sdk/models/bounty_list_params.rb', line 39

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


45
# File 'lib/whop_sdk/models/bounty_list_params.rb', line 45

optional :last, Integer, nil?: true

#statusSymbol, ...

The available bounty statuses to choose from.



51
# File 'lib/whop_sdk/models/bounty_list_params.rb', line 51

optional :status, enum: -> { WhopSDK::BountyListParams::Status }, nil?: true