Class: WhopSDK::Models::BountyListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/bounty_list_response.rb

Overview

Defined Under Namespace

Modules: BountyType, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, bounty_type:, created_at:, currency:, description:, status:, title:, total_available:, total_paid:, updated_at:, vote_threshold:) ⇒ Object

A privately accessible bounty.

Parameters:

  • id (String)

    The unique identifier for the bounty.

  • bounty_type (Symbol, WhopSDK::Models::BountyListResponse::BountyType)

    The underlying bounty implementation type.

  • created_at (Time)

    The datetime the bounty was created.

  • currency (Symbol, WhopSDK::Models::Currency)

    The currency used for the bounty funds.

  • description (String)

    The description of the bounty.

  • status (Symbol, WhopSDK::Models::BountyListResponse::Status)

    The current lifecycle status of the bounty.

  • title (String)

    The title of the bounty.

  • total_available (Float)

    The total amount currently funded in the bounty pool for payout.

  • total_paid (Float)

    The total amount paid out for this bounty.

  • updated_at (Time)

    The datetime the bounty was last updated.

  • vote_threshold (Integer)

    The number of watcher votes required before the submission can resolve.



# File 'lib/whop_sdk/models/bounty_list_response.rb', line 73

Instance Attribute Details

#bounty_typeSymbol, WhopSDK::Models::BountyListResponse::BountyType

The underlying bounty implementation type.



17
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 17

required :bounty_type, enum: -> { WhopSDK::Models::BountyListResponse::BountyType }

#created_atTime

The datetime the bounty was created.

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 23

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The currency used for the bounty funds.

Returns:



29
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 29

required :currency, enum: -> { WhopSDK::Currency }

#descriptionString

The description of the bounty.

Returns:

  • (String)


35
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 35

required :description, String

#idString

The unique identifier for the bounty.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 11

required :id, String

#statusSymbol, WhopSDK::Models::BountyListResponse::Status

The current lifecycle status of the bounty.



41
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 41

required :status, enum: -> { WhopSDK::Models::BountyListResponse::Status }

#titleString

The title of the bounty.

Returns:

  • (String)


47
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 47

required :title, String

#total_availableFloat

The total amount currently funded in the bounty pool for payout.

Returns:

  • (Float)


53
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 53

required :total_available, Float

#total_paidFloat

The total amount paid out for this bounty.

Returns:

  • (Float)


59
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 59

required :total_paid, Float

#updated_atTime

The datetime the bounty was last updated.

Returns:

  • (Time)


65
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 65

required :updated_at, Time

#vote_thresholdInteger

The number of watcher votes required before the submission can resolve.

Returns:

  • (Integer)


71
# File 'lib/whop_sdk/models/bounty_list_response.rb', line 71

required :vote_threshold, Integer

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/bounty_list_response.rb', line 108