Class: WhopSDK::Models::CardUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/card_update_params.rb,
sig/whop_sdk/models/card_update_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Cards#update

Defined Under Namespace

Modules: SpendLimitFrequency Classes: Billing

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(city:, country_code:, line1:, postal_code:, region:, line2: nil) ⇒ Object

New billing address. Requires line1, city, region, postal_code, and country_code.

Parameters:

  • city (String)

    Billing city.

  • country_code (String)

    Billing country code, ISO 3166-1 alpha-2.

  • line1 (String)

    Street address line 1.

  • postal_code (String)

    Billing postal code.

  • region (String)

    Billing region or state.

  • line2 (String) (defaults to: nil)

    Street address line 2.



# File 'lib/whop_sdk/models/card_update_params.rb', line 150

Instance Attribute Details

#account_idString?

The owning account ID (a biz_ identifier). Provide this or user_id.

Parameters:

  • (String)

Returns:

  • (String, nil)


19
# File 'lib/whop_sdk/models/card_update_params.rb', line 19

optional :account_id, String

#billingWhopSDK::Models::CardUpdateParams::Billing?

New billing address. Requires line1, city, region, postal_code, and country_code.



26
# File 'lib/whop_sdk/models/card_update_params.rb', line 26

optional :billing, -> { WhopSDK::CardUpdateParams::Billing }

#canceledBoolean?

Pass true to permanently cancel the card. A canceled card cannot be uncanceled. Cannot be combined with other fields.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


33
# File 'lib/whop_sdk/models/card_update_params.rb', line 33

optional :canceled, WhopSDK::Internal::Type::Boolean

#card_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/card_update_params.rb', line 13

required :card_id, String

#frozenBoolean?

Pass true to freeze the card, false to unfreeze it.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


39
# File 'lib/whop_sdk/models/card_update_params.rb', line 39

optional :frozen, WhopSDK::Internal::Type::Boolean

#nameString?

A display name for the card.

Parameters:

  • (String)

Returns:

  • (String, nil)


45
# File 'lib/whop_sdk/models/card_update_params.rb', line 45

optional :name, String

#pinString?

New 4-digit PIN. Can only be set on a card assigned to the acting user.

Parameters:

  • (String)

Returns:

  • (String, nil)


51
# File 'lib/whop_sdk/models/card_update_params.rb', line 51

optional :pin, String

#remove_limitBoolean?

Pass true to remove the spending limit (make the card unlimited).

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


57
# File 'lib/whop_sdk/models/card_update_params.rb', line 57

optional :remove_limit, WhopSDK::Internal::Type::Boolean

#spend_limitFloat?

Spending limit amount, in dollars.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


63
# File 'lib/whop_sdk/models/card_update_params.rb', line 63

optional :spend_limit, Float

#spend_limit_frequencySymbol, ...

The spending limit window.



69
# File 'lib/whop_sdk/models/card_update_params.rb', line 69

optional :spend_limit_frequency, enum: -> { WhopSDK::CardUpdateParams::SpendLimitFrequency }

#transaction_limitFloat?

Per-transaction limit amount, in dollars.

Parameters:

  • (Float)

Returns:

  • (Float, nil)


75
# File 'lib/whop_sdk/models/card_update_params.rb', line 75

optional :transaction_limit, Float

#user_idString?

The owning user ID (a user_ identifier). Provide this or account_id.

Parameters:

  • (String)

Returns:

  • (String, nil)


81
# File 'lib/whop_sdk/models/card_update_params.rb', line 81

optional :user_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


90
# File 'sig/whop_sdk/models/card_update_params.rbs', line 90

def to_hash: -> {