Class: WhopSDK::Models::ChatChannel

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/chat_channel.rb

Defined Under Namespace

Classes: Experience

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, ban_media:, ban_urls:, banned_words:, experience:, user_posts_cooldown_seconds:, who_can_post:, who_can_react:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ChatChannel for more details.

A real-time chat feed attached to an experience, with configurable moderation and posting permissions.

Parameters:

  • id (String)

    The unique identifier for the entity

  • ban_media (Boolean)

    Whether media uploads such as images and videos are blocked in this chat.

  • ban_urls (Boolean)

    Whether URL links are blocked from being posted in this chat.

  • banned_words (Array<String>)

    A list of words that are automatically filtered from messages in this chat.

  • experience (WhopSDK::Models::ChatChannel::Experience)

    The experience this chat feed is attached to.

  • user_posts_cooldown_seconds (Integer, nil)

    The minimum number of seconds a user must wait between consecutive messages. Nul

  • who_can_post (Symbol, WhopSDK::Models::WhoCanPost)

    The permission level controlling which users can send messages in this chat.

  • who_can_react (Symbol, WhopSDK::Models::WhoCanReact)

    The permission level controlling which users can add reactions in this chat.



# File 'lib/whop_sdk/models/chat_channel.rb', line 55

Instance Attribute Details

#ban_mediaBoolean

Whether media uploads such as images and videos are blocked in this chat.

Returns:

  • (Boolean)


16
# File 'lib/whop_sdk/models/chat_channel.rb', line 16

required :ban_media, WhopSDK::Internal::Type::Boolean

#ban_urlsBoolean

Whether URL links are blocked from being posted in this chat.

Returns:

  • (Boolean)


22
# File 'lib/whop_sdk/models/chat_channel.rb', line 22

required :ban_urls, WhopSDK::Internal::Type::Boolean

#banned_wordsArray<String>

A list of words that are automatically filtered from messages in this chat.

Returns:

  • (Array<String>)


28
# File 'lib/whop_sdk/models/chat_channel.rb', line 28

required :banned_words, WhopSDK::Internal::Type::ArrayOf[String]

#experienceWhopSDK::Models::ChatChannel::Experience

The experience this chat feed is attached to.



34
# File 'lib/whop_sdk/models/chat_channel.rb', line 34

required :experience, -> { WhopSDK::ChatChannel::Experience }

#idString

The unique identifier for the entity

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/chat_channel.rb', line 10

required :id, String

#user_posts_cooldown_secondsInteger?

The minimum number of seconds a user must wait between consecutive messages. Null if no cooldown is enforced.

Returns:

  • (Integer, nil)


41
# File 'lib/whop_sdk/models/chat_channel.rb', line 41

required :user_posts_cooldown_seconds, Integer, nil?: true

#who_can_postSymbol, WhopSDK::Models::WhoCanPost

The permission level controlling which users can send messages in this chat.

Returns:



47
# File 'lib/whop_sdk/models/chat_channel.rb', line 47

required :who_can_post, enum: -> { WhopSDK::WhoCanPost }

#who_can_reactSymbol, WhopSDK::Models::WhoCanReact

The permission level controlling which users can add reactions in this chat.

Returns:



53
# File 'lib/whop_sdk/models/chat_channel.rb', line 53

required :who_can_react, enum: -> { WhopSDK::WhoCanReact }