Class: WhopSDK::Models::ChatChannelListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ChatChannelListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/chat_channel_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#company_id ⇒ String
The ID of the company to list chat channels for.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#product_id ⇒ String?
If provided, only chat channels connected to this product are returned.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id: , after: nil, before: nil, first: nil, last: nil, product_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/chat_channel_list_params.rb', line 46
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
20 |
# File 'lib/whop_sdk/models/chat_channel_list_params.rb', line 20 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
26 |
# File 'lib/whop_sdk/models/chat_channel_list_params.rb', line 26 optional :before, String, nil?: true |
#company_id ⇒ String
The ID of the company to list chat channels for
14 |
# File 'lib/whop_sdk/models/chat_channel_list_params.rb', line 14 required :company_id, String |
#first ⇒ Integer?
Returns the first n elements from the list.
32 |
# File 'lib/whop_sdk/models/chat_channel_list_params.rb', line 32 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
38 |
# File 'lib/whop_sdk/models/chat_channel_list_params.rb', line 38 optional :last, Integer, nil?: true |
#product_id ⇒ String?
If provided, only chat channels connected to this product are returned
44 |
# File 'lib/whop_sdk/models/chat_channel_list_params.rb', line 44 optional :product_id, String, nil?: true |