Class: WhopSDK::Models::ChatChannelListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ChatChannelListResponse
- Defined in:
- lib/whop_sdk/models/chat_channel_list_response.rb
Overview
Defined Under Namespace
Classes: Experience
Instance Attribute Summary collapse
-
#ban_media ⇒ Boolean
Whether media uploads such as images and videos are blocked in this chat.
-
#ban_urls ⇒ Boolean
Whether URL links are blocked from being posted in this chat.
-
#banned_words ⇒ Array<String>
A list of words that are automatically filtered from messages in this chat.
-
#experience ⇒ WhopSDK::Models::ChatChannelListResponse::Experience
The experience this chat feed is attached to.
-
#id ⇒ String
The unique identifier for the entity.
-
#user_posts_cooldown_seconds ⇒ Integer?
The minimum number of seconds a user must wait between consecutive messages.
-
#who_can_post ⇒ Symbol, WhopSDK::Models::WhoCanPost
The permission level controlling which users can send messages in this chat.
-
#who_can_react ⇒ Symbol, WhopSDK::Models::WhoCanReact
The permission level controlling which users can add reactions in this chat.
Instance Method Summary collapse
-
#initialize(id:, ban_media:, ban_urls:, banned_words:, experience:, user_posts_cooldown_seconds:, who_can_post:, who_can_react:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ChatChannelListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, ban_media:, ban_urls:, banned_words:, experience:, user_posts_cooldown_seconds:, who_can_post:, who_can_react:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ChatChannelListResponse for more details.
A real-time chat feed attached to an experience, with configurable moderation and posting permissions.
|
|
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 56
|
Instance Attribute Details
#ban_media ⇒ Boolean
Whether media uploads such as images and videos are blocked in this chat.
17 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 17 required :ban_media, WhopSDK::Internal::Type::Boolean |
#ban_urls ⇒ Boolean
Whether URL links are blocked from being posted in this chat.
23 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 23 required :ban_urls, WhopSDK::Internal::Type::Boolean |
#banned_words ⇒ Array<String>
A list of words that are automatically filtered from messages in this chat.
29 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 29 required :banned_words, WhopSDK::Internal::Type::ArrayOf[String] |
#experience ⇒ WhopSDK::Models::ChatChannelListResponse::Experience
The experience this chat feed is attached to.
35 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 35 required :experience, -> { WhopSDK::Models::ChatChannelListResponse::Experience } |
#id ⇒ String
The unique identifier for the entity
11 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 11 required :id, String |
#user_posts_cooldown_seconds ⇒ Integer?
The minimum number of seconds a user must wait between consecutive messages. Null if no cooldown is enforced.
42 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 42 required :user_posts_cooldown_seconds, Integer, nil?: true |
#who_can_post ⇒ Symbol, WhopSDK::Models::WhoCanPost
The permission level controlling which users can send messages in this chat.
48 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 48 required :who_can_post, enum: -> { WhopSDK::WhoCanPost } |
#who_can_react ⇒ Symbol, WhopSDK::Models::WhoCanReact
The permission level controlling which users can add reactions in this chat.
54 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 54 required :who_can_react, enum: -> { WhopSDK::WhoCanReact } |