Class: WhopSDK::Models::ChatChannelUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ChatChannelUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/chat_channel_update_params.rb
Overview
Instance Attribute Summary collapse
-
#ban_media ⇒ Boolean?
Whether media uploads such as images and videos are banned in this chat channel.
-
#ban_urls ⇒ Boolean?
Whether URLs and links are banned from being posted in this chat channel.
-
#banned_words ⇒ Array<String>?
A list of words that are automatically blocked from messages in this chat channel.
- #id ⇒ String
-
#user_posts_cooldown_seconds ⇒ Integer?
The minimum number of seconds a user must wait between sending messages in this chat channel.
-
#who_can_post ⇒ Symbol, ...
Who can post on a chat feed.
-
#who_can_react ⇒ Symbol, ...
Who can react on a chat feed.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, ban_media: nil, ban_urls: nil, banned_words: nil, user_posts_cooldown_seconds: nil, who_can_post: nil, who_can_react: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ChatChannelUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, ban_media: nil, ban_urls: nil, banned_words: nil, user_posts_cooldown_seconds: nil, who_can_post: nil, who_can_react: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ChatChannelUpdateParams for more details.
|
|
# File 'lib/whop_sdk/models/chat_channel_update_params.rb', line 53
|
Instance Attribute Details
#ban_media ⇒ Boolean?
Whether media uploads such as images and videos are banned in this chat channel.
19 |
# File 'lib/whop_sdk/models/chat_channel_update_params.rb', line 19 optional :ban_media, WhopSDK::Internal::Type::Boolean, nil?: true |
#ban_urls ⇒ Boolean?
Whether URLs and links are banned from being posted in this chat channel.
25 |
# File 'lib/whop_sdk/models/chat_channel_update_params.rb', line 25 optional :ban_urls, WhopSDK::Internal::Type::Boolean, nil?: true |
#banned_words ⇒ Array<String>?
A list of words that are automatically blocked from messages in this chat channel. For example, [‘spam’, ‘scam’].
32 |
# File 'lib/whop_sdk/models/chat_channel_update_params.rb', line 32 optional :banned_words, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/chat_channel_update_params.rb', line 13 required :id, String |
#user_posts_cooldown_seconds ⇒ Integer?
The minimum number of seconds a user must wait between sending messages in this chat channel.
39 |
# File 'lib/whop_sdk/models/chat_channel_update_params.rb', line 39 optional :user_posts_cooldown_seconds, Integer, nil?: true |
#who_can_post ⇒ Symbol, ...
Who can post on a chat feed
45 |
# File 'lib/whop_sdk/models/chat_channel_update_params.rb', line 45 optional :who_can_post, enum: -> { WhopSDK::WhoCanPost }, nil?: true |
#who_can_react ⇒ Symbol, ...
Who can react on a chat feed
51 |
# File 'lib/whop_sdk/models/chat_channel_update_params.rb', line 51 optional :who_can_react, enum: -> { WhopSDK::WhoCanReact }, nil?: true |