Class: WhopSDK::Models::ChatReactionCreatedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ChatReactionCreatedWebhookEvent
- Defined in:
- lib/whop_sdk/models/chat_reaction_created_webhook_event.rb,
sig/whop_sdk/models/chat_reaction_created_webhook_event.rbs
Defined Under Namespace
Classes: Data
Instance Attribute Summary collapse
-
#api_version ⇒ Symbol, :v1
The API version for this webhook.
-
#company_id ⇒ String?
The company ID that this webhook event is associated with.
- #data ⇒ WhopSDK::Models::ChatReactionCreatedWebhookEvent::Data
-
#id ⇒ String
A unique ID for every single webhook request.
-
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server.
-
#type ⇒ Symbol, :"chat.reaction.created"
The webhook event type.
Instance Method Summary collapse
- #initialize(id:, data:, timestamp:, company_id: nil, api_version: :v1, type: :"chat.reaction.created") ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, data:, timestamp:, company_id: nil, api_version: :v1, type: :"chat.reaction.created") ⇒ Object
|
|
# File 'lib/whop_sdk/models/chat_reaction_created_webhook_event.rb', line 41
|
Instance Attribute Details
#api_version ⇒ Symbol, :v1
The API version for this webhook
16 |
# File 'lib/whop_sdk/models/chat_reaction_created_webhook_event.rb', line 16 required :api_version, const: :v1 |
#company_id ⇒ String?
The company ID that this webhook event is associated with
39 |
# File 'lib/whop_sdk/models/chat_reaction_created_webhook_event.rb', line 39 optional :company_id, String, nil?: true |
#data ⇒ WhopSDK::Models::ChatReactionCreatedWebhookEvent::Data
21 |
# File 'lib/whop_sdk/models/chat_reaction_created_webhook_event.rb', line 21 required :data, -> { WhopSDK::ChatReactionCreatedWebhookEvent::Data } |
#id ⇒ String
A unique ID for every single webhook request
10 |
# File 'lib/whop_sdk/models/chat_reaction_created_webhook_event.rb', line 10 required :id, String |
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server
27 |
# File 'lib/whop_sdk/models/chat_reaction_created_webhook_event.rb', line 27 required :timestamp, Time |
#type ⇒ Symbol, :"chat.reaction.created"
The webhook event type
33 |
# File 'lib/whop_sdk/models/chat_reaction_created_webhook_event.rb', line 33 required :type, const: :"chat.reaction.created" |
Instance Method Details
#to_hash ⇒ {
35 |
# File 'sig/whop_sdk/models/chat_reaction_created_webhook_event.rbs', line 35
def to_hash: -> {
|