Class: WhopSDK::Models::CheckoutConfiguration::PaymentMethodConfiguration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/checkout_configuration.rb,
sig/whop_sdk/models/checkout_configuration.rbs

Overview

See Also:

  • WhopSDK::Models::CheckoutConfiguration#payment_method_configuration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



78
# File 'sig/whop_sdk/models/checkout_configuration.rbs', line 78

def initialize: (

Instance Attribute Details

#disabledArray<Symbol, WhopSDK::Models::PaymentMethodTypes>

An array of payment method identifiers that are explicitly disabled. Only applies if the include_platform_defaults is true.

Parameters:

  • value (::Array[WhopSDK::Models::payment_method_types])

Returns:



106
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 106

required :disabled, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::PaymentMethodTypes] }

#enabledArray<Symbol, WhopSDK::Models::PaymentMethodTypes>

An array of payment method identifiers that are explicitly enabled. This means these payment methods will be shown on checkout. Example use case is to only enable a specific payment method like cashapp, or extending the platform defaults with additional methods.

Parameters:

  • value (::Array[WhopSDK::Models::payment_method_types])

Returns:



115
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 115

required :enabled, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::PaymentMethodTypes] }

#include_platform_defaultsBoolean

Whether Whop's platform default payment method enablement settings are included in this configuration. The full list of default payment methods can be found in the documentation at docs.whop.com/payments.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


123
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 123

required :include_platform_defaults, WhopSDK::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


84
# File 'sig/whop_sdk/models/checkout_configuration.rbs', line 84

def to_hash: -> {