Class: WhopSDK::Models::CheckoutConfigurationCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb,
sig/whop_sdk/models/checkout_configuration_create_params.rbs
Overview
Defined Under Namespace
Modules: Mode Classes: PaymentMethodConfiguration, Plan
Instance Attribute Summary collapse
-
#affiliate_code ⇒ String?
Affiliate code to apply to the checkout.
-
#company_id ⇒ String?
Account ID, prefixed
biz_. -
#currency ⇒ String?
Currency used for setup-mode payment method availability.
-
#metadata ⇒ Object?
Custom key-value metadata copied to payments and memberships.
-
#mode ⇒ Symbol, ...
Checkout mode:
paymentcollects payment for a plan now;setupsaves payment details without charging. -
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::PaymentMethodConfiguration?
Payment method overrides for this checkout.
-
#plan ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Plan?
Plan attributes used to create or find a plan for this checkout configuration.
-
#plan_id ⇒ String?
Existing plan ID, prefixed
plan_. -
#redirect_url ⇒ String?
URL customers are sent to after checkout.
-
#three_ds_level ⇒ String?
3D Secure behavior for this checkout.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(disabled: nil, enabled: nil, include_platform_defaults: nil) ⇒ Object
constructor
Payment method overrides for this checkout.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(disabled: nil, enabled: nil, include_platform_defaults: nil) ⇒ Object
Payment method overrides for this checkout. null uses the plan or platform
defaults.
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 75
|
Instance Attribute Details
#affiliate_code ⇒ String?
Affiliate code to apply to the checkout.
14 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 14 optional :affiliate_code, String, nil?: true |
#company_id ⇒ String?
Account ID, prefixed biz_.
20 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 20 optional :company_id, String |
#currency ⇒ String?
Currency used for setup-mode payment method availability.
26 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 26 optional :currency, String, nil?: true |
#metadata ⇒ Object?
Custom key-value metadata copied to payments and memberships.
32 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 32 optional :metadata, WhopSDK::Internal::Type::Unknown, nil?: true |
#mode ⇒ Symbol, ...
Checkout mode: payment collects payment for a plan now; setup saves payment
details without charging. Defaults to payment.
39 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 39 optional :mode, enum: -> { WhopSDK::CheckoutConfigurationCreateParams::Mode } |
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::PaymentMethodConfiguration?
Payment method overrides for this checkout. null uses the plan or platform
defaults.
46 47 48 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 46 optional :payment_method_configuration, -> { WhopSDK::CheckoutConfigurationCreateParams::PaymentMethodConfiguration }, nil?: true |
#plan ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Plan?
Plan attributes used to create or find a plan for this checkout configuration.
Mutually exclusive with plan_id.
55 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 55 optional :plan, -> { WhopSDK::CheckoutConfigurationCreateParams::Plan }, nil?: true |
#plan_id ⇒ String?
Existing plan ID, prefixed plan_. Mutually exclusive with plan.
61 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 61 optional :plan_id, String, nil?: true |
#redirect_url ⇒ String?
URL customers are sent to after checkout.
67 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 67 optional :redirect_url, String, nil?: true |
#three_ds_level ⇒ String?
3D Secure behavior for this checkout.
73 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 73 optional :three_ds_level, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 109
|
Instance Method Details
#to_hash ⇒ {
62 |
# File 'sig/whop_sdk/models/checkout_configuration_create_params.rbs', line 62
def to_hash: -> {
|