Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::CheckoutStyling
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::CheckoutStyling
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Overview
Instance Attribute Summary collapse
-
#border_style ⇒ Symbol, ...
The different border-radius styles available for checkout pages.
-
#button_color ⇒ String?
A hex color code for the button color (e.g. #FF5733).
-
#font_family ⇒ Symbol, ...
The different font families available for checkout pages.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#border_style ⇒ Symbol, ...
The different border-radius styles available for checkout pages.
764 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 764 optional :border_style, enum: -> { WhopSDK::CheckoutShape }, nil?: true |
#button_color ⇒ String?
A hex color code for the button color (e.g. #FF5733).
770 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 770 optional :button_color, String, nil?: true |
#font_family ⇒ Symbol, ...
The different font families available for checkout pages.
776 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 776 optional :font_family, enum: -> { WhopSDK::CheckoutFont }, nil?: true |