Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/whop_sdk/models/checkout_configuration_create_params.rb

Defined Under Namespace

Modules: ThreeDSLevel Classes: CheckoutStyling, PaymentMethodConfiguration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(disabled:, enabled:, include_platform_defaults: nil) ⇒ Object

Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.

The explicit payment method configuration for the checkout session. Only applies to setup mode. If not provided, the platform or company defaults will apply.

Parameters:

  • disabled (Array<Symbol, WhopSDK::Models::PaymentMethodTypes>)

    An array of payment method identifiers that are explicitly disabled. Only applie

  • enabled (Array<Symbol, WhopSDK::Models::PaymentMethodTypes>)

    An array of payment method identifiers that are explicitly enabled. This means t

  • include_platform_defaults (Boolean, nil) (defaults to: nil)

    Whether Whop’s platform default payment method enablement settings are included



# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 951

Instance Attribute Details

#allow_promo_codesBoolean?

Whether the checkout should show the promo code input field and accept promo codes. Defaults to true.

Returns:

  • (Boolean, nil)


893
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 893

optional :allow_promo_codes, WhopSDK::Internal::Type::Boolean, nil?: true

#checkout_stylingWhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::CheckoutStyling?

Checkout styling overrides for this session. Overrides plan and company defaults.



900
901
902
903
904
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 900

optional :checkout_styling,
-> {
  WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::CheckoutStyling
},
nil?: true

#company_idString

The unique identifier of the company to create the checkout configuration for. Only required in setup mode.

Returns:

  • (String)


881
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 881

required :company_id, String

#currencySymbol, ...

The available currencies on the platform

Returns:



910
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 910

optional :currency, enum: -> { WhopSDK::Currency }, nil?: true

#metadataHash{Symbol=>Object}?

Custom key-value metadata to attach to the checkout configuration.

Returns:

  • (Hash{Symbol=>Object}, nil)


916
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 916

optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#modeSymbol, :setup

Returns:

  • (Symbol, :setup)


886
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 886

required :mode, const: :setup

#payment_method_configurationWhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::PaymentMethodConfiguration?

The explicit payment method configuration for the checkout session. Only applies to setup mode. If not provided, the platform or company defaults will apply.



923
924
925
926
927
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 923

optional :payment_method_configuration,
-> {
  WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::PaymentMethodConfiguration
},
nil?: true

#redirect_urlString?

The URL to redirect the user to after checkout is completed.

Returns:

  • (String, nil)


933
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 933

optional :redirect_url, String, nil?: true

#source_urlString?

The URL of the page where the checkout is being initiated from.

Returns:

  • (String, nil)


939
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 939

optional :source_url, String, nil?: true

#three_ds_levelSymbol, ...

The 3D Secure behavior for a plan.



945
946
947
948
949
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 945

optional :three_ds_level,
enum: -> {
  WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::ThreeDSLevel
},
nil?: true