Module: WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Image

Extended by:
Internal::Type::Union
Defined in:
lib/whop_sdk/models/checkout_configuration_create_params.rb

Overview

An image for the plan. This will be visible on the product page to customers.

See Also:

Defined Under Namespace

Classes: AttachmentInputWithDirectUploadID, AttachmentInputWithID

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(direct_upload_id: ) ⇒ Object

Some parameter documentations has been truncated, see AttachmentInputWithDirectUploadID for more details.

Input for an attachment

Parameters:

  • direct_upload_id (String) (defaults to: )

    This ID should be used the first time you upload an attachment. It is the ID of



# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 333