Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Product

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/checkout_configuration_create_params.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#business_typeSymbol, ...

The different business types a company can be.

Returns:



435
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 435

optional :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true

#collect_shipping_addressBoolean?

Whether or not to collect shipping information at checkout from the customer.

Returns:

  • (Boolean, nil)


441
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 441

optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true

#custom_statement_descriptorString?

The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ‘, “

Returns:

  • (String, nil)


449
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 449

optional :custom_statement_descriptor, String, nil?: true

#descriptionString?

A written description of the product.

Returns:

  • (String, nil)


455
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 455

optional :description, String, nil?: true

#external_identifierString

A unique ID used to find or create a product. When provided during creation, we will look for an existing product with this external identifier — if found, it will be updated; otherwise, a new product will be created.

Returns:

  • (String)


423
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 423

required :external_identifier, String

#global_affiliate_percentageFloat?

The percentage of the revenue that goes to the global affiliate program.

Returns:

  • (Float, nil)


461
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 461

optional :global_affiliate_percentage, Float, nil?: true

#global_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for a product.

Returns:



467
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 467

optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#headlineString?

The headline of the product.

Returns:

  • (String, nil)


473
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 473

optional :headline, String, nil?: true

#industry_typeSymbol, ...

The different industry types a company can be in.

Returns:



479
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 479

optional :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true

#product_tax_code_idString?

The ID of the product tax code to apply to this product.

Returns:

  • (String, nil)


485
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 485

optional :product_tax_code_id, String, nil?: true

#redirect_purchase_urlString?

The URL to redirect the customer to after a purchase.

Returns:

  • (String, nil)


491
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 491

optional :redirect_purchase_url, String, nil?: true

#routeString?

The route of the product.

Returns:

  • (String, nil)


497
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 497

optional :route, String, nil?: true

#titleString

The title of the product.

Returns:

  • (String)


429
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 429

required :title, String

#visibilitySymbol, ...

Visibility of a resource

Returns:



503
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 503

optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true