Class: WhopSDK::Models::CheckoutConfigurationCreateResponse::Plan

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/checkout_configuration_create_response.rb,
sig/whop_sdk/models/checkout_configuration_create_response.rbs

Overview

See Also:

  • WhopSDK::Models::CheckoutConfigurationCreateResponse#plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, adaptive_pricing_enabled:, billing_period:, currency:, expiration_days:, initial_price:, plan_type:, release_method:, renewal_price:, three_ds_level:, trial_period_days:, visibility:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CheckoutConfigurationCreateResponse::Plan for more details.

Plan used for payment checkout. null in setup mode.

Parameters:

  • id (String)

    Plan ID, prefixed plan_.

  • adaptive_pricing_enabled (Boolean)

    Whether this plan accepts local currency payments via adaptive pricing.

  • billing_period (Integer, nil)

    Recurring billing interval in days, such as 30 for monthly or 365 for annual. `n

  • currency (String)

    Three-letter ISO currency code for the plan's prices.

  • expiration_days (Integer, nil)

    Access duration in days for expiration-based plans.

  • initial_price (Float)

    Initial purchase price in the plan currency.

  • plan_type (String)

    Billing model for the plan: renewal (recurring) or one_time (single payment)

  • release_method (String)

    Sales method for the plan, such as buy_now or waitlist.

  • renewal_price (Float)

    Recurring price charged each billing period.

  • three_ds_level (String, nil)

    3D Secure behavior for this plan, or null to use the account default.

  • trial_period_days (Integer, nil)

    Free trial days before the first renewal charge.

  • visibility (String)

    Whether the plan is visible to customers or hidden from public view.



# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 243

Instance Attribute Details

#adaptive_pricing_enabledBoolean

Whether this plan accepts local currency payments via adaptive pricing.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


179
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 179

required :adaptive_pricing_enabled, WhopSDK::Internal::Type::Boolean

#billing_periodInteger?

Recurring billing interval in days, such as 30 for monthly or 365 for annual. null for one-time plans.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


186
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 186

required :billing_period, Integer, nil?: true

#currencyString

Three-letter ISO currency code for the plan's prices.

Parameters:

  • value (String)

Returns:

  • (String)


192
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 192

required :currency, String

#expiration_daysInteger?

Access duration in days for expiration-based plans.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


198
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 198

required :expiration_days, Integer, nil?: true

#idString

Plan ID, prefixed plan_.

Parameters:

  • value (String)

Returns:

  • (String)


173
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 173

required :id, String

#initial_priceFloat

Initial purchase price in the plan currency.

Parameters:

  • value (Float)

Returns:

  • (Float)


204
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 204

required :initial_price, Float

#plan_typeString

Billing model for the plan: renewal (recurring) or one_time (single payment).

Parameters:

  • value (String)

Returns:

  • (String)


211
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 211

required :plan_type, String

#release_methodString

Sales method for the plan, such as buy_now or waitlist.

Parameters:

  • value (String)

Returns:

  • (String)


217
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 217

required :release_method, String

#renewal_priceFloat

Recurring price charged each billing period.

Parameters:

  • value (Float)

Returns:

  • (Float)


223
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 223

required :renewal_price, Float

#three_ds_levelString?

3D Secure behavior for this plan, or null to use the account default.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


229
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 229

required :three_ds_level, String, nil?: true

#trial_period_daysInteger?

Free trial days before the first renewal charge.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


235
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 235

required :trial_period_days, Integer, nil?: true

#visibilityString

Whether the plan is visible to customers or hidden from public view.

Parameters:

  • value (String)

Returns:

  • (String)


241
# File 'lib/whop_sdk/models/checkout_configuration_create_response.rb', line 241

required :visibility, String

Instance Method Details

#to_hash{

Returns:

  • ({)


179
# File 'sig/whop_sdk/models/checkout_configuration_create_response.rbs', line 179

def to_hash: -> {