Class: WhopSDK::Models::CheckoutConfigurationListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/checkout_configuration_list_params.rb,
sig/whop_sdk/models/checkout_configuration_list_params.rbs

Overview

See Also:

  • WhopSDK::Resources::CheckoutConfigurations#list

Defined Under Namespace

Modules: Direction, Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id:, after: nil, created_after: nil, created_before: nil, direction: nil, first: nil, order: nil, plan_id: nil, request_options: {}) ⇒ Object

Parameters:

  • company_id (String)

    Account ID, prefixed biz_.

  • after (String) (defaults to: nil)

    Cursor for the next page of results.

  • created_after (Integer) (defaults to: nil)

    Only return checkout configurations created after this Unix timestamp.

  • created_before (Integer) (defaults to: nil)

    Only return checkout configurations created before this Unix timestamp.

  • direction (Symbol, WhopSDK::Models::CheckoutConfigurationListParams::Direction) (defaults to: nil)

    Sort direction. Defaults to desc.

  • first (Integer) (defaults to: nil)

    Number of checkout configurations to return.

  • order (Symbol, WhopSDK::Models::CheckoutConfigurationListParams::Order) (defaults to: nil)

    Field used to sort checkout configurations.

  • plan_id (String) (defaults to: nil)

    Only return checkout configurations for this plan ID, prefixed plan_.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 58

Instance Attribute Details

#afterString?

Cursor for the next page of results.

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 20

optional :after, String

#company_idString

Account ID, prefixed biz_.

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 14

required :company_id, String

#created_afterInteger?

Only return checkout configurations created after this Unix timestamp.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


26
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 26

optional :created_after, Integer

#created_beforeInteger?

Only return checkout configurations created before this Unix timestamp.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


32
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 32

optional :created_before, Integer

#directionSymbol, ...

Sort direction. Defaults to desc.



38
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 38

optional :direction, enum: -> { WhopSDK::CheckoutConfigurationListParams::Direction }

#firstInteger?

Number of checkout configurations to return.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


44
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 44

optional :first, Integer

#orderSymbol, ...

Field used to sort checkout configurations.



50
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 50

optional :order, enum: -> { WhopSDK::CheckoutConfigurationListParams::Order }

#plan_idString?

Only return checkout configurations for this plan ID, prefixed plan_.

Parameters:

  • (String)

Returns:

  • (String, nil)


56
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 56

optional :plan_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 84

Instance Method Details

#to_hash{

Returns:

  • ({)


66
# File 'sig/whop_sdk/models/checkout_configuration_list_params.rbs', line 66

def to_hash: -> {