Class: WhopSDK::Models::CompanyCreateAPIKeyResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CompanyCreateAPIKeyResponse
- Defined in:
- lib/whop_sdk/models/company_create_api_key_response.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the authorized api key.
-
#name ⇒ String?
A user set name to identify an API key.
-
#secret_key ⇒ String
The secret key used to authenticate requests.
Instance Method Summary collapse
-
#initialize(id:, name:, secret_key:) ⇒ Object
constructor
An API key created for a child company, including the one-time secret key.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, secret_key:) ⇒ Object
An API key created for a child company, including the one-time secret key.
|
|
# File 'lib/whop_sdk/models/company_create_api_key_response.rb', line 25
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the authorized api key.
11 |
# File 'lib/whop_sdk/models/company_create_api_key_response.rb', line 11 required :id, String |
#name ⇒ String?
A user set name to identify an API key
17 |
# File 'lib/whop_sdk/models/company_create_api_key_response.rb', line 17 required :name, String, nil?: true |
#secret_key ⇒ String
The secret key used to authenticate requests. Only returned at creation time.
23 |
# File 'lib/whop_sdk/models/company_create_api_key_response.rb', line 23 required :secret_key, String |