Class: WhopSDK::Models::CompanyListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/company_list_response.rb

Overview

Defined Under Namespace

Classes: Logo, OwnerUser

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(url:) ⇒ Object

Some parameter documentations has been truncated, see Logo for more details.

The company’s logo.

Parameters:

  • url (String, nil)

    A pre-optimized URL for rendering this attachment on the client. This should be



# File 'lib/whop_sdk/models/company_list_response.rb', line 96

Instance Attribute Details

#created_atTime

The datetime the company was created.

Returns:

  • (Time)


17
# File 'lib/whop_sdk/models/company_list_response.rb', line 17

required :created_at, Time

#descriptionString?

A promotional pitch written by the company creator, displayed to potential customers on the store page.

Returns:

  • (String, nil)


24
# File 'lib/whop_sdk/models/company_list_response.rb', line 24

required :description, String, nil?: true

#idString

The unique identifier for the company.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/company_list_response.rb', line 11

required :id, String

#logoWhopSDK::Models::CompanyListResponse::Logo?

The company’s logo.



30
# File 'lib/whop_sdk/models/company_list_response.rb', line 30

required :logo, -> { WhopSDK::Models::CompanyListResponse::Logo }, nil?: true

#member_countInteger

The total number of users who currently hold active memberships across all of this company’s products.

Returns:

  • (Integer)


37
# File 'lib/whop_sdk/models/company_list_response.rb', line 37

required :member_count, Integer

#metadataHash{Symbol=>Object}?

A key-value JSON object of custom metadata for this company, managed by the platform that created the account.

Returns:

  • (Hash{Symbol=>Object}, nil)


44
# File 'lib/whop_sdk/models/company_list_response.rb', line 44

required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#owner_userWhopSDK::Models::CompanyListResponse::OwnerUser

The user who owns and has full administrative control over this company.



50
# File 'lib/whop_sdk/models/company_list_response.rb', line 50

required :owner_user, -> { WhopSDK::Models::CompanyListResponse::OwnerUser }

#published_reviews_countInteger

The total number of published customer reviews across all products for this company.

Returns:

  • (Integer)


57
# File 'lib/whop_sdk/models/company_list_response.rb', line 57

required :published_reviews_count, Integer

#routeString

The URL slug for the company’s store page (e.g., ‘pickaxe’ in whop.com/pickaxe).

Returns:

  • (String)


63
# File 'lib/whop_sdk/models/company_list_response.rb', line 63

required :route, String

#send_customer_emailsBoolean

Whether Whop sends transactional emails (receipts, updates) to customers on behalf of this company.

Returns:

  • (Boolean)


70
# File 'lib/whop_sdk/models/company_list_response.rb', line 70

required :send_customer_emails, WhopSDK::Internal::Type::Boolean

#target_audienceString?

The target audience for the company. Null if not set.

Returns:

  • (String, nil)


76
# File 'lib/whop_sdk/models/company_list_response.rb', line 76

required :target_audience, String, nil?: true

#titleString

The display name of the company shown to customers.

Returns:

  • (String)


82
# File 'lib/whop_sdk/models/company_list_response.rb', line 82

required :title, String

#updated_atTime

The datetime the company was last updated.

Returns:

  • (Time)


88
# File 'lib/whop_sdk/models/company_list_response.rb', line 88

required :updated_at, Time

#verifiedBoolean

Whether this company has been verified by Whop’s trust and safety team.

Returns:

  • (Boolean)


94
# File 'lib/whop_sdk/models/company_list_response.rb', line 94

required :verified, WhopSDK::Internal::Type::Boolean