Module: WhopSDK::Models::CompanyTokenTransactionCreateParams::Body

Extended by:
Internal::Type::Union
Defined in:
lib/whop_sdk/models/company_token_transaction_create_params.rb

Overview

Parameters for CreateCompanyTokenTransaction

Defined Under Namespace

Classes: CreateCompanyTokenTransactionInputTransactionTypeAdd, CreateCompanyTokenTransactionInputTransactionTypeSubtract, CreateCompanyTokenTransactionInputTransactionTypeTransfer

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(amount:, company_id:, user_id:, description: nil, idempotency_key: nil, transaction_type: :add) ⇒ Object

Some parameter documentations has been truncated, see CreateCompanyTokenTransactionInputTransactionTypeAdd for more details.

Autogenerated input type of CreateCompanyTokenTransaction

Parameters:

  • amount (Float)

    The positive number of tokens to transact. For example, 100.0 for 100 tokens.

  • company_id (String)

    The unique identifier of the company to create the transaction in, starting with

  • user_id (String)

    The unique identifier of the user whose token balance will be affected, starting

  • description (String, nil) (defaults to: nil)

    A human-readable description of why the transaction was created.

  • idempotency_key (String, nil) (defaults to: nil)

    A unique key to prevent duplicate transactions. Use a UUID or similar unique str

  • transaction_type (Symbol, :add) (defaults to: :add)


# File 'lib/whop_sdk/models/company_token_transaction_create_params.rb', line 80