Class: WhopSDK::Models::CompanyTokenTransactionListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/company_token_transaction_list_response.rb

Overview

Defined Under Namespace

Classes: Company, Member, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

The member whose token balance was affected by this transaction.

Parameters:

  • id (String)

    The unique identifier for the company member.



# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 71

Instance Attribute Details

#amountFloat

The token amount for this transaction. Always a positive value regardless of transaction type.

Returns:

  • (Float)


18
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 18

required :amount, Float

#companyWhopSDK::Models::CompanyTokenTransactionListResponse::Company

The company whose token balance this transaction affects.



24
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 24

required :company, -> { WhopSDK::Models::CompanyTokenTransactionListResponse::Company }

#created_atTime

The datetime the company token transaction was created.

Returns:

  • (Time)


30
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 30

required :created_at, Time

#descriptionString?

Free-text description explaining the reason for this token transaction. Null if no description was provided.

Returns:

  • (String, nil)


37
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 37

required :description, String, nil?: true

#idString

The unique identifier for the company token transaction.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 11

required :id, String

#idempotency_keyString?

A unique key used to prevent duplicate transactions when retrying API requests. Null if no idempotency key was provided.

Returns:

  • (String, nil)


44
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 44

required :idempotency_key, String, nil?: true

#linked_transaction_idString?

The ID of the corresponding transaction on the other side of a transfer. Null if this is not a transfer transaction.

Returns:

  • (String, nil)


51
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 51

required :linked_transaction_id, String, nil?: true

#memberWhopSDK::Models::CompanyTokenTransactionListResponse::Member

The member whose token balance was affected by this transaction.



57
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 57

required :member, -> { WhopSDK::Models::CompanyTokenTransactionListResponse::Member }

#transaction_typeSymbol, WhopSDK::Models::CompanyTokenTransactionType

The direction of this token transaction (add, subtract, or transfer).



63
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 63

required :transaction_type, enum: -> { WhopSDK::CompanyTokenTransactionType }

#userWhopSDK::Models::CompanyTokenTransactionListResponse::User

The user whose token balance was affected by this transaction.



69
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 69

required :user, -> { WhopSDK::Models::CompanyTokenTransactionListResponse::User }