Class: WhopSDK::Models::CompanyUpdateParams::BannerImage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/company_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, affiliate_application_required: nil, affiliate_instructions: nil, banner_image: nil, description: nil, featured_affiliate_product_id: nil, logo: nil, route: nil, send_customer_emails: nil, social_links: nil, target_audience: nil, title: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CompanyUpdateParams for more details.

Parameters:

  • id (String)
  • affiliate_application_required (Boolean, nil) (defaults to: nil)

    Whether prospective affiliates must submit an application before they can promot

  • affiliate_instructions (String, nil) (defaults to: nil)

    Guidelines and instructions shown to affiliates explaining how to promote this c

  • banner_image (WhopSDK::Models::CompanyUpdateParams::BannerImage, nil) (defaults to: nil)

    The company’s banner image. Accepts PNG or JPEG format.

  • description (String, nil) (defaults to: nil)

    A promotional pitch displayed to potential customers on the company’s store page

  • featured_affiliate_product_id (String, nil) (defaults to: nil)

    The ID of the product to feature on this company’s affiliate page. Pass null to

  • logo (WhopSDK::Models::CompanyUpdateParams::Logo, nil) (defaults to: nil)

    The company’s logo image. Accepts PNG, JPEG, or GIF format.

  • route (String, nil) (defaults to: nil)

    The unique URL slug for the company’s store page. Must be lowercase and can incl

  • send_customer_emails (Boolean, nil) (defaults to: nil)

    Whether Whop sends transactional emails (receipts, renewals, cancelations) to cu

  • social_links (Array<WhopSDK::Models::CompanyUpdateParams::SocialLink>, nil) (defaults to: nil)

    The social media links to display on the company’s store page. Pass the full lis

  • target_audience (String, nil) (defaults to: nil)

    The target audience for this company (e.g., ‘beginner day traders aged 18-25 loo

  • title (String, nil) (defaults to: nil)

    The display name of the company shown to customers.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/whop_sdk/models/company_update_params.rb', line 122

class BannerImage < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing file object.
  #
  #   @return [String]
  required :id, String

  # @!method initialize(id:)
  #   The company's banner image. Accepts PNG or JPEG format.
  #
  #   @param id [String] The ID of an existing file object.
end

Instance Attribute Details

#idString

The ID of an existing file object.

Returns:

  • (String)


127
# File 'lib/whop_sdk/models/company_update_params.rb', line 127

required :id, String