Class: WhopSDK::Models::CompanyUpdateParams::SocialLink
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CompanyUpdateParams::SocialLink
- Defined in:
- lib/whop_sdk/models/company_update_params.rb
Defined Under Namespace
Classes: Image
Instance Attribute Summary collapse
-
#image ⇒ WhopSDK::Models::CompanyUpdateParams::SocialLink::Image?
The custom image for the social link.
-
#order ⇒ String?
The order of the social link.
-
#title ⇒ String?
The title of the social link.
-
#url ⇒ String
The URL of the social link.
-
#website ⇒ Symbol, WhopSDK::Models::SocialLinkWebsites
The website this link is for.
-
#website_order ⇒ String?
The order of the website social link.
Instance Method Summary collapse
-
#initialize(url:, website:, image: nil, order: nil, title: nil, website_order: nil) ⇒ Object
constructor
Input for creating a social link for a company.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url:, website:, image: nil, order: nil, title: nil, website_order: nil) ⇒ Object
Input for creating a social link for a company
|
|
# File 'lib/whop_sdk/models/company_update_params.rb', line 185
|
Instance Attribute Details
#image ⇒ WhopSDK::Models::CompanyUpdateParams::SocialLink::Image?
The custom image for the social link
165 |
# File 'lib/whop_sdk/models/company_update_params.rb', line 165 optional :image, -> { WhopSDK::CompanyUpdateParams::SocialLink::Image }, nil?: true |
#order ⇒ String?
The order of the social link
171 |
# File 'lib/whop_sdk/models/company_update_params.rb', line 171 optional :order, String, nil?: true |
#title ⇒ String?
The title of the social link
177 |
# File 'lib/whop_sdk/models/company_update_params.rb', line 177 optional :title, String, nil?: true |
#url ⇒ String
The URL of the social link
153 |
# File 'lib/whop_sdk/models/company_update_params.rb', line 153 required :url, String |
#website ⇒ Symbol, WhopSDK::Models::SocialLinkWebsites
The website this link is for
159 |
# File 'lib/whop_sdk/models/company_update_params.rb', line 159 required :website, enum: -> { WhopSDK::SocialLinkWebsites } |
#website_order ⇒ String?
The order of the website social link
183 |
# File 'lib/whop_sdk/models/company_update_params.rb', line 183 optional :website_order, String, nil?: true |