Class: WhopSDK::Models::Course::Chapter::Lesson::VideoAsset
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Course::Chapter::Lesson::VideoAsset
- Defined in:
- lib/whop_sdk/models/course.rb
Overview
Instance Attribute Summary collapse
-
#duration_seconds ⇒ Integer?
The duration of the video in seconds.
-
#signed_playback_id ⇒ String?
The signed playback ID of the Mux asset.
-
#signed_thumbnail_playback_token ⇒ String?
The signed thumbnail playback token of the Mux asset.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#duration_seconds ⇒ Integer?
The duration of the video in seconds
262 |
# File 'lib/whop_sdk/models/course.rb', line 262 required :duration_seconds, Integer, nil?: true |
#signed_playback_id ⇒ String?
The signed playback ID of the Mux asset
268 |
# File 'lib/whop_sdk/models/course.rb', line 268 required :signed_playback_id, String, nil?: true |
#signed_thumbnail_playback_token ⇒ String?
The signed thumbnail playback token of the Mux asset
274 |
# File 'lib/whop_sdk/models/course.rb', line 274 required :signed_thumbnail_playback_token, String, nil?: true |