Class: WhopSDK::Models::CourseChapterCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseChapterCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_chapter_create_params.rb
Overview
Instance Attribute Summary collapse
-
#course_id ⇒ String
The ID of the course to create the chapter in.
-
#title ⇒ String?
The title of the chapter.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(course_id: , title: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/course_chapter_create_params.rb', line 22
|
Instance Attribute Details
#course_id ⇒ String
The ID of the course to create the chapter in
14 |
# File 'lib/whop_sdk/models/course_chapter_create_params.rb', line 14 required :course_id, String |
#title ⇒ String?
The title of the chapter
20 |
# File 'lib/whop_sdk/models/course_chapter_create_params.rb', line 20 optional :title, String, nil?: true |