Class: WhopSDK::Models::CourseChapterListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/course_chapter_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, order:, title:) ⇒ Object

A grouping of related lessons within a course, used to organize content into sections.

Parameters:

  • id (String)

    The unique identifier for the chapter.

  • order (Integer)

    The sort position of this chapter within its parent course, starting from zero.

  • title (String)

    The display name of the chapter shown to students. Maximum 150 characters.



# File 'lib/whop_sdk/models/course_chapter_list_response.rb', line 25

Instance Attribute Details

#idString

The unique identifier for the chapter.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/course_chapter_list_response.rb', line 11

required :id, String

#orderInteger

The sort position of this chapter within its parent course, starting from zero.

Returns:

  • (Integer)


17
# File 'lib/whop_sdk/models/course_chapter_list_response.rb', line 17

required :order, Integer

#titleString

The display name of the chapter shown to students. Maximum 150 characters.

Returns:

  • (String)


23
# File 'lib/whop_sdk/models/course_chapter_list_response.rb', line 23

required :title, String