Class: WhopSDK::Models::CourseLessonInteraction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonInteraction
- Defined in:
- lib/whop_sdk/models/course_lesson_interaction.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#completed ⇒ Boolean
Whether the lesson has been completed by the user.
-
#course ⇒ WhopSDK::Models::CourseLessonInteraction::Course
The course for this lesson interaction.
-
#created_at ⇒ Time
When the interaction was created.
-
#id ⇒ String
The ID of the lesson interaction.
-
#lesson ⇒ WhopSDK::Models::CourseLessonInteraction::Lesson
The lesson this interaction is for.
-
#user ⇒ WhopSDK::Models::CourseLessonInteraction::User
The user who interacted with the lesson.
Instance Method Summary collapse
-
#initialize(id: , title: ) ⇒ Object
constructor
The lesson this interaction is for.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , title: ) ⇒ Object
The lesson this interaction is for
|
|
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 42
|
Instance Attribute Details
#completed ⇒ Boolean
Whether the lesson has been completed by the user
16 |
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 16 required :completed, WhopSDK::Internal::Type::Boolean |
#course ⇒ WhopSDK::Models::CourseLessonInteraction::Course
The course for this lesson interaction
22 |
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 22 required :course, -> { WhopSDK::CourseLessonInteraction::Course } |
#created_at ⇒ Time
When the interaction was created
28 |
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 28 required :created_at, Time |
#id ⇒ String
The ID of the lesson interaction
10 |
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 10 required :id, String |
#lesson ⇒ WhopSDK::Models::CourseLessonInteraction::Lesson
The lesson this interaction is for
34 |
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 34 required :lesson, -> { WhopSDK::CourseLessonInteraction::Lesson } |
#user ⇒ WhopSDK::Models::CourseLessonInteraction::User
The user who interacted with the lesson
40 |
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 40 required :user, -> { WhopSDK::CourseLessonInteraction::User } |