Class: WhopSDK::Models::CourseLessonInteraction::Course
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonInteraction::Course
- Defined in:
- lib/whop_sdk/models/course_lesson_interaction.rb
Overview
Defined Under Namespace
Classes: Experience
Instance Attribute Summary collapse
-
#experience ⇒ WhopSDK::Models::CourseLessonInteraction::Course::Experience
The parent experience that this course belongs to.
-
#id ⇒ String
The unique identifier for the course.
-
#title ⇒ String?
The display name of the course shown to students.
Instance Method Summary collapse
-
#initialize(id:, experience:, title:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Course for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, experience:, title:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseLessonInteraction::Course for more details.
The course that contains the tracked lesson.
|
|
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 78
|
Instance Attribute Details
#experience ⇒ WhopSDK::Models::CourseLessonInteraction::Course::Experience
The parent experience that this course belongs to.
70 |
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 70 required :experience, -> { WhopSDK::CourseLessonInteraction::Course::Experience } |
#id ⇒ String
The unique identifier for the course.
64 |
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 64 required :id, String |
#title ⇒ String?
The display name of the course shown to students. Null if no title has been set.
76 |
# File 'lib/whop_sdk/models/course_lesson_interaction.rb', line 76 required :title, String, nil?: true |