Class: WhopSDK::Models::CourseLessonInteractionListItem::Lesson
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonInteractionListItem::Lesson
- Defined in:
- lib/whop_sdk/models/course_lesson_interaction_list_item.rb
Overview
Defined Under Namespace
Classes: Chapter
Instance Attribute Summary collapse
-
#chapter ⇒ WhopSDK::Models::CourseLessonInteractionListItem::Lesson::Chapter
The parent chapter that contains this lesson.
-
#id ⇒ String
The unique identifier for the lesson.
-
#title ⇒ String
The display name of the lesson shown to students.
Instance Method Summary collapse
-
#initialize(id:, chapter:, title:) ⇒ Object
constructor
The lesson that this progress record belongs to.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, chapter:, title:) ⇒ Object
The lesson that this progress record belongs to.
|
|
# File 'lib/whop_sdk/models/course_lesson_interaction_list_item.rb', line 70
|
Instance Attribute Details
#chapter ⇒ WhopSDK::Models::CourseLessonInteractionListItem::Lesson::Chapter
The parent chapter that contains this lesson.
62 |
# File 'lib/whop_sdk/models/course_lesson_interaction_list_item.rb', line 62 required :chapter, -> { WhopSDK::CourseLessonInteractionListItem::Lesson::Chapter } |
#id ⇒ String
The unique identifier for the lesson.
56 |
# File 'lib/whop_sdk/models/course_lesson_interaction_list_item.rb', line 56 required :id, String |
#title ⇒ String
The display name of the lesson shown to students. Maximum 120 characters.
68 |
# File 'lib/whop_sdk/models/course_lesson_interaction_list_item.rb', line 68 required :title, String |