Class: WhopSDK::Models::CourseLessonInteractionListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/course_lesson_interaction_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, completed: nil, course_id: nil, first: nil, last: nil, lesson_id: nil, user_id: nil, request_options: {}) ⇒ Object

Parameters:

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • completed (Boolean, nil) (defaults to: nil)

    Whether the lesson has been completed by the user

  • course_id (String, nil) (defaults to: nil)

    The ID of the course to list course lesson interactions for

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • lesson_id (String, nil) (defaults to: nil)

    The ID of the lesson to list course lesson interactions for

  • user_id (String, nil) (defaults to: nil)

    The ID of the user to list course lesson interactions for

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/course_lesson_interaction_list_params.rb', line 58

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


14
# File 'lib/whop_sdk/models/course_lesson_interaction_list_params.rb', line 14

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/course_lesson_interaction_list_params.rb', line 20

optional :before, String, nil?: true

#completedBoolean?

Whether the lesson has been completed by the user

Returns:

  • (Boolean, nil)


26
# File 'lib/whop_sdk/models/course_lesson_interaction_list_params.rb', line 26

optional :completed, WhopSDK::Internal::Type::Boolean, nil?: true

#course_idString?

The ID of the course to list course lesson interactions for

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/course_lesson_interaction_list_params.rb', line 32

optional :course_id, String, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


38
# File 'lib/whop_sdk/models/course_lesson_interaction_list_params.rb', line 38

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


44
# File 'lib/whop_sdk/models/course_lesson_interaction_list_params.rb', line 44

optional :last, Integer, nil?: true

#lesson_idString?

The ID of the lesson to list course lesson interactions for

Returns:

  • (String, nil)


50
# File 'lib/whop_sdk/models/course_lesson_interaction_list_params.rb', line 50

optional :lesson_id, String, nil?: true

#user_idString?

The ID of the user to list course lesson interactions for

Returns:

  • (String, nil)


56
# File 'lib/whop_sdk/models/course_lesson_interaction_list_params.rb', line 56

optional :user_id, String, nil?: true