Class: WhopSDK::Models::CourseLessonListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_lesson_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#chapter_id ⇒ String?
The ID of the chapter (returns lessons only for this chapter).
-
#course_id ⇒ String?
The ID of the course (returns all lessons across all chapters).
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, chapter_id: nil, course_id: nil, first: nil, last: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/course_lesson_list_params.rb', line 46
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
14 |
# File 'lib/whop_sdk/models/course_lesson_list_params.rb', line 14 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
20 |
# File 'lib/whop_sdk/models/course_lesson_list_params.rb', line 20 optional :before, String, nil?: true |
#chapter_id ⇒ String?
The ID of the chapter (returns lessons only for this chapter)
26 |
# File 'lib/whop_sdk/models/course_lesson_list_params.rb', line 26 optional :chapter_id, String, nil?: true |
#course_id ⇒ String?
The ID of the course (returns all lessons across all chapters)
32 |
# File 'lib/whop_sdk/models/course_lesson_list_params.rb', line 32 optional :course_id, String, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
38 |
# File 'lib/whop_sdk/models/course_lesson_list_params.rb', line 38 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
44 |
# File 'lib/whop_sdk/models/course_lesson_list_params.rb', line 44 optional :last, Integer, nil?: true |