Class: WhopSDK::Models::CourseLessonSubmitAssessmentParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonSubmitAssessmentParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_lesson_submit_assessment_params.rb,
sig/whop_sdk/models/course_lesson_submit_assessment_params.rbs
Overview
Defined Under Namespace
Classes: Answer
Instance Attribute Summary collapse
-
#answers ⇒ Array<WhopSDK::Models::CourseLessonSubmitAssessmentParams::Answer>
The list of answers to submit for each assessment question.
- #lesson_id ⇒ String
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
18 |
# File 'sig/whop_sdk/models/course_lesson_submit_assessment_params.rbs', line 18
def initialize: (
|
Instance Attribute Details
#answers ⇒ Array<WhopSDK::Models::CourseLessonSubmitAssessmentParams::Answer>
The list of answers to submit for each assessment question.
19 20 |
# File 'lib/whop_sdk/models/course_lesson_submit_assessment_params.rb', line 19 required :answers, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseLessonSubmitAssessmentParams::Answer] } |
#lesson_id ⇒ String
13 |
# File 'lib/whop_sdk/models/course_lesson_submit_assessment_params.rb', line 13 required :lesson_id, String |
Instance Method Details
#to_hash ⇒ {
24 |
# File 'sig/whop_sdk/models/course_lesson_submit_assessment_params.rbs', line 24
def to_hash: -> {
|