Class: WhopSDK::Models::CourseLessonSubmitAssessmentResponse::Lesson
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonSubmitAssessmentResponse::Lesson
- Defined in:
- lib/whop_sdk/models/course_lesson_submit_assessment_response.rb,
sig/whop_sdk/models/course_lesson_submit_assessment_response.rbs
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the lesson.
-
#title ⇒ String
The display name of the lesson shown to students.
Instance Method Summary collapse
-
#initialize ⇒ Lesson
constructor
A new instance of Lesson.
- #to_hash ⇒ { id: String, title: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Lesson
Returns a new instance of Lesson.
76 |
# File 'sig/whop_sdk/models/course_lesson_submit_assessment_response.rbs', line 76
def initialize: (id: String, title: String) -> void
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the lesson.
104 |
# File 'lib/whop_sdk/models/course_lesson_submit_assessment_response.rb', line 104 required :id, String |
#title ⇒ String
The display name of the lesson shown to students. Maximum 120 characters.
110 |
# File 'lib/whop_sdk/models/course_lesson_submit_assessment_response.rb', line 110 required :title, String |
Instance Method Details
#to_hash ⇒ { id: String, title: String }
78 |
# File 'sig/whop_sdk/models/course_lesson_submit_assessment_response.rbs', line 78
def to_hash: -> { id: String, title: String }
|