Class: WhopSDK::Models::CourseStudentListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseStudentListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_student_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#course_id ⇒ String
The ID of the course.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#keyword ⇒ String?
Filter students by name - returns students whose names match the keyword.
-
#last ⇒ Integer?
Returns the last n elements from the list.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(course_id: , after: nil, before: nil, first: nil, keyword: nil, last: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/course_student_list_params.rb', line 46
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
20 |
# File 'lib/whop_sdk/models/course_student_list_params.rb', line 20 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
26 |
# File 'lib/whop_sdk/models/course_student_list_params.rb', line 26 optional :before, String, nil?: true |
#course_id ⇒ String
The ID of the course
14 |
# File 'lib/whop_sdk/models/course_student_list_params.rb', line 14 required :course_id, String |
#first ⇒ Integer?
Returns the first n elements from the list.
32 |
# File 'lib/whop_sdk/models/course_student_list_params.rb', line 32 optional :first, Integer, nil?: true |
#keyword ⇒ String?
Filter students by name - returns students whose names match the keyword
38 |
# File 'lib/whop_sdk/models/course_student_list_params.rb', line 38 optional :keyword, String, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
44 |
# File 'lib/whop_sdk/models/course_student_list_params.rb', line 44 optional :last, Integer, nil?: true |