Class: WhopSDK::Models::CourseStudentRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/course_student_retrieve_response.rb

Overview

Defined Under Namespace

Classes: Course, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

The parent experience that this course belongs to.

Parameters:

  • id (String)

    The unique identifier for the experience.



# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 58

Instance Attribute Details

#completed_lessons_countInteger

The total number of lessons this student has marked as completed in the course.

Returns:

  • (Integer)


17
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 17

required :completed_lessons_count, Integer

#completion_rateFloat

The percentage of available lessons the student has completed, as a value from 0 to 100 rounded to two decimal places.

Returns:

  • (Float)


24
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 24

required :completion_rate, Float

#courseWhopSDK::Models::CourseStudentRetrieveResponse::Course

The course this student is enrolled in.



30
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 30

required :course, -> { WhopSDK::Models::CourseStudentRetrieveResponse::Course }

#first_interaction_atTime

The timestamp when the student first interacted with this course, as a Unix timestamp.

Returns:

  • (Time)


37
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 37

required :first_interaction_at, Time

#idString

The unique identifier for the course student type.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 11

required :id, String

#last_interaction_atTime

The timestamp when the student most recently interacted with this course, as a Unix timestamp.

Returns:

  • (Time)


44
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 44

required :last_interaction_at, Time

#total_lessons_countInteger

The total number of visible lessons available to this student in the course.

Returns:

  • (Integer)


50
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 50

required :total_lessons_count, Integer

#userWhopSDK::Models::CourseStudentRetrieveResponse::User

The user profile of the enrolled student.



56
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 56

required :user, -> { WhopSDK::Models::CourseStudentRetrieveResponse::User }