Class: WhopSDK::Models::CourseUpdateParams::Chapter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseUpdateParams::Chapter
- Defined in:
- lib/whop_sdk/models/course_update_params.rb
Defined Under Namespace
Classes: Lesson
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the chapter to update.
-
#lessons ⇒ Array<WhopSDK::Models::CourseUpdateParams::Chapter::Lesson>?
The lessons to update within this chapter.
-
#order ⇒ Integer
The order of the chapter within its course.
-
#title ⇒ String
The title of the chapter.
Instance Method Summary collapse
-
#initialize(certificate_after_completion_enabled: nil, chapters: nil, cover_image: nil, description: nil, language: nil, order: nil, require_completing_lessons_in_order: nil, tagline: nil, thumbnail: nil, title: nil, visibility: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhopSDK::Models::CourseUpdateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(certificate_after_completion_enabled: nil, chapters: nil, cover_image: nil, description: nil, language: nil, order: nil, require_completing_lessons_in_order: nil, tagline: nil, thumbnail: nil, title: nil, visibility: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseUpdateParams for more details.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 110 class Chapter < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of the chapter to update # # @return [String] required :id, String # @!attribute order # The order of the chapter within its course # # @return [Integer] required :order, Integer # @!attribute title # The title of the chapter # # @return [String] required :title, String # @!attribute lessons # The lessons to update within this chapter # # @return [Array<WhopSDK::Models::CourseUpdateParams::Chapter::Lesson>, nil] optional :lessons, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseUpdateParams::Chapter::Lesson] }, nil?: true # @!method initialize(id:, order:, title:, lessons: nil) # Input for updating a chapter while updating a course # # @param id [String] The ID of the chapter to update # # @param order [Integer] The order of the chapter within its course # # @param title [String] The title of the chapter # # @param lessons [Array<WhopSDK::Models::CourseUpdateParams::Chapter::Lesson>, nil] The lessons to update within this chapter class Lesson < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of the lesson to update # # @return [String] required :id, String # @!attribute chapter_id # The ID of the chapter this lesson belongs to (for moving between chapters) # # @return [String] required :chapter_id, String # @!attribute order # The order of the lesson within its chapter # # @return [Integer] required :order, Integer # @!attribute title # The title of the lesson # # @return [String] required :title, String # @!method initialize(id:, chapter_id:, order:, title:) # Input for updating a lesson while updating a course # # @param id [String] The ID of the lesson to update # # @param chapter_id [String] The ID of the chapter this lesson belongs to (for moving between chapters) # # @param order [Integer] The order of the lesson within its chapter # # @param title [String] The title of the lesson end end |
Instance Attribute Details
#id ⇒ String
The ID of the chapter to update
115 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 115 required :id, String |
#lessons ⇒ Array<WhopSDK::Models::CourseUpdateParams::Chapter::Lesson>?
The lessons to update within this chapter
133 134 135 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 133 optional :lessons, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseUpdateParams::Chapter::Lesson] }, nil?: true |
#order ⇒ Integer
The order of the chapter within its course
121 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 121 required :order, Integer |
#title ⇒ String
The title of the chapter
127 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 127 required :title, String |