Class: WhopSDK::Models::CourseUpdateParams::Chapter::Lesson

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/course_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , order: , title: , lessons: nil) ⇒ Object

Input for updating a chapter while updating a course

Parameters:

  • id (String) (defaults to: )

    The ID of the chapter to update

  • order (Integer) (defaults to: )

    The order of the chapter within its course

  • title (String) (defaults to: )

    The title of the chapter

  • lessons (Array<WhopSDK::Models::CourseUpdateParams::Chapter::Lesson>, nil) (defaults to: nil)

    The lessons to update within this chapter



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/whop_sdk/models/course_update_params.rb', line 148

class Lesson < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of the lesson to update
  #
  #   @return [String]
  required :id, String

  # @!attribute chapter_id
  #   The ID of the chapter this lesson belongs to (for moving between chapters)
  #
  #   @return [String]
  required :chapter_id, String

  # @!attribute order
  #   The order of the lesson within its chapter
  #
  #   @return [Integer]
  required :order, Integer

  # @!attribute title
  #   The title of the lesson
  #
  #   @return [String]
  required :title, String

  # @!method initialize(id:, chapter_id:, order:, title:)
  #   Input for updating a lesson while updating a course
  #
  #   @param id [String] The ID of the lesson to update
  #
  #   @param chapter_id [String] The ID of the chapter this lesson belongs to (for moving between chapters)
  #
  #   @param order [Integer] The order of the lesson within its chapter
  #
  #   @param title [String] The title of the lesson
end

Instance Attribute Details

#chapter_idString

The ID of the chapter this lesson belongs to (for moving between chapters)

Returns:

  • (String)


159
# File 'lib/whop_sdk/models/course_update_params.rb', line 159

required :chapter_id, String

#idString

The ID of the lesson to update

Returns:

  • (String)


153
# File 'lib/whop_sdk/models/course_update_params.rb', line 153

required :id, String

#orderInteger

The order of the lesson within its chapter

Returns:

  • (Integer)


165
# File 'lib/whop_sdk/models/course_update_params.rb', line 165

required :order, Integer

#titleString

The title of the lesson

Returns:

  • (String)


171
# File 'lib/whop_sdk/models/course_update_params.rb', line 171

required :title, String