Class: WhopSDK::Models::CourseUpdateParams::Thumbnail::AttachmentInputWithDirectUploadID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseUpdateParams::Thumbnail::AttachmentInputWithDirectUploadID
- Defined in:
- lib/whop_sdk/models/course_update_params.rb
Instance Attribute Summary collapse
-
#direct_upload_id ⇒ String
This ID should be used the first time you upload an attachment.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#direct_upload_id ⇒ String
This ID should be used the first time you upload an attachment. It is the ID of the direct upload that was created when uploading the file to S3 via the mediaDirectUpload mutation.
203 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 203 required :direct_upload_id, String |