Class: WhopSDK::Models::DepositCreateResponse::Methods

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/deposit_create_response.rb,
sig/whop_sdk/models/deposit_create_response.rbs

Overview

See Also:

  • WhopSDK::Models::DepositCreateResponse#methods_

Defined Under Namespace

Classes: Bank, Crypto

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_number:, currency:, deposit_bank_name:, deposit_beneficiary_name:, deposit_reference:, rails:, routing_number:) ⇒ Object

Parameters:

  • account_number (String, nil)

    Bank account number for deposits in this currency.

  • currency (String)

    Currency supported by these bank instructions.

  • deposit_bank_name (String, nil)

    Receiving bank name.

  • deposit_beneficiary_name (String, nil)

    Beneficiary name to use for transfer.

  • deposit_reference (String, nil)

    Reference to include with bank transfer.

  • rails (Array<String>)

    Active deposit rails for this currency, such as ach, wire, or sepa.

  • routing_number (String, nil)

    Bank routing number for deposits in this currency.



# File 'lib/whop_sdk/models/deposit_create_response.rb', line 72

Instance Attribute Details

#bankWhopSDK::Models::DepositCreateResponse::Methods::Bank?

Bank deposit details. Only present when bank deposits are active for the destination account.



62
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 62

required :bank, -> { WhopSDK::Models::DepositCreateResponse::Methods::Bank }, nil?: true

#cryptoArray<WhopSDK::Models::DepositCreateResponse::Methods::Crypto>

Crypto networks available for this deposit, each with its on-chain deposit address and the tokens accepted on that network.



69
70
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 69

required :crypto,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::DepositCreateResponse::Methods::Crypto] }

Instance Method Details

#to_hash{

Returns:

  • ({)


62
# File 'sig/whop_sdk/models/deposit_create_response.rbs', line 62

def to_hash: -> {