Class: WhopSDK::Models::DepositCreateResponse::Methods::Bank::Currency

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/deposit_create_response.rb,
sig/whop_sdk/models/deposit_create_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(currencies:) ⇒ Object

Bank deposit details. Only present when bank deposits are active for the destination account.

Parameters:



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 97

class Currency < WhopSDK::Internal::Type::BaseModel
  # @!attribute account_number
  #   Bank account number for deposits in this currency.
  #
  #   @return [String, nil]
  required :account_number, String, nil?: true

  # @!attribute currency
  #   Currency supported by these bank instructions.
  #
  #   @return [String]
  required :currency, String

  # @!attribute deposit_bank_name
  #   Receiving bank name.
  #
  #   @return [String, nil]
  required :deposit_bank_name, String, nil?: true

  # @!attribute deposit_beneficiary_name
  #   Beneficiary name to use for transfer.
  #
  #   @return [String, nil]
  required :deposit_beneficiary_name, String, nil?: true

  # @!attribute deposit_reference
  #   Reference to include with bank transfer.
  #
  #   @return [String, nil]
  required :deposit_reference, String, nil?: true

  # @!attribute rails
  #   Active deposit rails for this currency, such as `ach`, `wire`, or `sepa`.
  #
  #   @return [Array<String>]
  required :rails, WhopSDK::Internal::Type::ArrayOf[String]

  # @!attribute routing_number
  #   Bank routing number for deposits in this currency.
  #
  #   @return [String, nil]
  required :routing_number, String, nil?: true

  # @!method initialize(account_number:, currency:, deposit_bank_name:, deposit_beneficiary_name:, deposit_reference:, rails:, routing_number:)
  #   @param account_number [String, nil] Bank account number for deposits in this currency.
  #
  #   @param currency [String] Currency supported by these bank instructions.
  #
  #   @param deposit_bank_name [String, nil] Receiving bank name.
  #
  #   @param deposit_beneficiary_name [String, nil] Beneficiary name to use for transfer.
  #
  #   @param deposit_reference [String, nil] Reference to include with bank transfer.
  #
  #   @param rails [Array<String>] Active deposit rails for this currency, such as `ach`, `wire`, or `sepa`.
  #
  #   @param routing_number [String, nil] Bank routing number for deposits in this currency.
end

Instance Attribute Details

#account_numberString?

Bank account number for deposits in this currency.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


102
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 102

required :account_number, String, nil?: true

#currencyString

Currency supported by these bank instructions.

Parameters:

  • value (String)

Returns:

  • (String)


108
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 108

required :currency, String

#deposit_bank_nameString?

Receiving bank name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


114
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 114

required :deposit_bank_name, String, nil?: true

#deposit_beneficiary_nameString?

Beneficiary name to use for transfer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


120
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 120

required :deposit_beneficiary_name, String, nil?: true

#deposit_referenceString?

Reference to include with bank transfer.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


126
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 126

required :deposit_reference, String, nil?: true

#railsArray<String>

Active deposit rails for this currency, such as ach, wire, or sepa.

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


132
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 132

required :rails, WhopSDK::Internal::Type::ArrayOf[String]

#routing_numberString?

Bank routing number for deposits in this currency.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


138
# File 'lib/whop_sdk/models/deposit_create_response.rb', line 138

required :routing_number, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


119
# File 'sig/whop_sdk/models/deposit_create_response.rbs', line 119

def to_hash: -> {