Class: WhopSDK::Models::Dispute::CancellationPolicyAttachment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Dispute::CancellationPolicyAttachment
- Defined in:
- lib/whop_sdk/models/dispute.rb,
sig/whop_sdk/models/dispute.rbs
Overview
Instance Attribute Summary collapse
-
#content_type ⇒ String?
Uploaded file MIME type, such as image/jpeg, video/mp4, or audio/mpeg.
-
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
161 |
# File 'sig/whop_sdk/models/dispute.rbs', line 161
def initialize: (
|
Instance Attribute Details
#content_type ⇒ String?
Uploaded file MIME type, such as image/jpeg, video/mp4, or audio/mpeg.
268 |
# File 'lib/whop_sdk/models/dispute.rb', line 268 required :content_type, String, nil?: true |
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
274 |
# File 'lib/whop_sdk/models/dispute.rb', line 274 required :filename, String, nil?: true |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to
refetch an object or as key for a cache. The ID type appears in a JSON response
as a String; however, it is not intended to be human-readable. When expected as
an input type, any string (such as "VXNlci0xMA==") or integer (such as 4)
input value will be accepted as an ID.
262 |
# File 'lib/whop_sdk/models/dispute.rb', line 262 required :id, String |
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client. This should be used for displaying attachments in apps.
281 |
# File 'lib/whop_sdk/models/dispute.rb', line 281 required :url, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
168 |
# File 'sig/whop_sdk/models/dispute.rbs', line 168
def to_hash: -> {
|