Class: WhopSDK::Models::Dispute::Payment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Dispute::Payment
- Defined in:
- lib/whop_sdk/models/dispute.rb
Overview
Defined Under Namespace
Classes: Member, Membership, User
Instance Attribute Summary collapse
-
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed.
-
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#card_last4 ⇒ String?
The last four digits of the card used to make this payment.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed.
-
#id ⇒ String
The unique identifier for the payment.
-
#member ⇒ WhopSDK::Models::Dispute::Payment::Member?
The member attached to this payment.
-
#membership ⇒ WhopSDK::Models::Dispute::Payment::Membership?
The membership attached to this payment.
-
#paid_at ⇒ Time?
The time at which this payment was successfully collected.
-
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
-
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
-
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
-
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
-
#user ⇒ WhopSDK::Models::Dispute::Payment::User?
The user that made this payment.
Instance Method Summary collapse
-
#initialize(id:, status:) ⇒ Object
constructor
The membership attached to this payment.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, status:) ⇒ Object
The membership attached to this payment.
|
|
# File 'lib/whop_sdk/models/dispute.rb', line 463
|
Instance Attribute Details
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed
381 |
# File 'lib/whop_sdk/models/dispute.rb', line 381 required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true |
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have
387 |
# File 'lib/whop_sdk/models/dispute.rb', line 387 required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#card_last4 ⇒ String?
The last four digits of the card used to make this payment. Null if the payment was not made with a card.
394 |
# File 'lib/whop_sdk/models/dispute.rb', line 394 required :card_last4, String, nil?: true |
#created_at ⇒ Time
The datetime the payment was created.
400 |
# File 'lib/whop_sdk/models/dispute.rb', line 400 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
406 |
# File 'lib/whop_sdk/models/dispute.rb', line 406 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed
412 |
# File 'lib/whop_sdk/models/dispute.rb', line 412 required :dispute_alerted_at, Time, nil?: true |
#id ⇒ String
The unique identifier for the payment.
375 |
# File 'lib/whop_sdk/models/dispute.rb', line 375 required :id, String |
#member ⇒ WhopSDK::Models::Dispute::Payment::Member?
The member attached to this payment.
418 |
# File 'lib/whop_sdk/models/dispute.rb', line 418 required :member, -> { WhopSDK::Dispute::Payment::Member }, nil?: true |
#membership ⇒ WhopSDK::Models::Dispute::Payment::Membership?
The membership attached to this payment.
424 |
# File 'lib/whop_sdk/models/dispute.rb', line 424 required :membership, -> { WhopSDK::Dispute::Payment::Membership }, nil?: true |
#paid_at ⇒ Time?
The time at which this payment was successfully collected. Null if the payment has not yet succeeded. As a Unix timestamp.
431 |
# File 'lib/whop_sdk/models/dispute.rb', line 431 required :paid_at, Time, nil?: true |
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
437 |
# File 'lib/whop_sdk/models/dispute.rb', line 437 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true |
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
443 |
# File 'lib/whop_sdk/models/dispute.rb', line 443 required :subtotal, Float, nil?: true |
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
449 |
# File 'lib/whop_sdk/models/dispute.rb', line 449 required :total, Float, nil?: true |
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
455 |
# File 'lib/whop_sdk/models/dispute.rb', line 455 required :usd_total, Float, nil?: true |
#user ⇒ WhopSDK::Models::Dispute::Payment::User?
The user that made this payment.
461 |
# File 'lib/whop_sdk/models/dispute.rb', line 461 required :user, -> { WhopSDK::Dispute::Payment::User }, nil?: true |