Class: WhopSDK::Models::Dispute::UncategorizedAttachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dispute.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , content_type: , filename: , url: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::Dispute::UncategorizedAttachment for more details.

An attachment that did not fit into the other categories

Parameters:

  • id (String) (defaults to: )

    The ID of the attachment

  • content_type (String, nil) (defaults to: )

    The attachment’s content type (e.g., image/jpg, video/mp4)

  • filename (String, nil) (defaults to: )

    The name of the file

  • url (String, nil) (defaults to: )

    This is the URL you use to render optimized attachments on the client. This shou



# File 'lib/whop_sdk/models/dispute.rb', line 656

Instance Attribute Details

#content_typeString?

The attachment’s content type (e.g., image/jpg, video/mp4)

Returns:

  • (String, nil)


641
# File 'lib/whop_sdk/models/dispute.rb', line 641

required :content_type, String, nil?: true

#filenameString?

The name of the file

Returns:

  • (String, nil)


647
# File 'lib/whop_sdk/models/dispute.rb', line 647

required :filename, String, nil?: true

#idString

The ID of the attachment

Returns:

  • (String)


635
# File 'lib/whop_sdk/models/dispute.rb', line 635

required :id, String

#urlString?

This is the URL you use to render optimized attachments on the client. This should be used for apps.

Returns:

  • (String, nil)


654
# File 'lib/whop_sdk/models/dispute.rb', line 654

required :url, String, nil?: true