Class: WhopSDK::Models::DisputeAlertRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dispute_alert_retrieve_response.rb

Overview

Defined Under Namespace

Classes: Dispute, Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, currency:, reason:, status:) ⇒ Object

Some parameter documentations has been truncated, see Dispute for more details.

The dispute associated with the dispute alert.

Parameters:

  • id (String)

    The unique identifier for the dispute.

  • amount (Float)

    The disputed amount in the specified currency, formatted as a decimal.

  • created_at (Time, nil)

    The datetime the dispute was created.

  • currency (Symbol, WhopSDK::Models::Currency)

    The three-letter ISO currency code for the disputed amount.

  • reason (String, nil)

    A human-readable reason for the dispute.

  • status (Symbol, WhopSDK::Models::DisputeStatuses)

    The current status of the dispute lifecycle, such as needs_response, under_revie



# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 61

Instance Attribute Details

#alert_typeSymbol, WhopSDK::Models::DisputeAlertType

The type of the dispute alert.



17
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 17

required :alert_type, enum: -> { WhopSDK::DisputeAlertType }

#amountFloat

The alerted amount in the specified currency.

Returns:

  • (Float)


23
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 23

required :amount, Float

#charge_for_alertBoolean

Whether this alert incurs a charge.

Returns:

  • (Boolean)


29
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 29

required :charge_for_alert, WhopSDK::Internal::Type::Boolean

#created_atTime

The time the dispute alert was created.

Returns:

  • (Time)


35
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 35

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The three-letter ISO currency code for the alerted amount.

Returns:



41
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 41

required :currency, enum: -> { WhopSDK::Currency }

#disputeWhopSDK::Models::DisputeAlertRetrieveResponse::Dispute?

The dispute associated with the dispute alert.



47
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 47

required :dispute, -> { WhopSDK::Models::DisputeAlertRetrieveResponse::Dispute }, nil?: true

#idString

The unique identifier of the dispute alert.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 11

required :id, String

#paymentWhopSDK::Models::DisputeAlertRetrieveResponse::Payment?

The payment associated with the dispute alert.



53
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 53

required :payment, -> { WhopSDK::Models::DisputeAlertRetrieveResponse::Payment }, nil?: true

#transaction_dateTime?

The date of the original transaction.

Returns:

  • (Time, nil)


59
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 59

required :transaction_date, Time, nil?: true