Class: WhopSDK::Models::DisputeListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dispute_list_response.rb

Overview

Defined Under Namespace

Classes: Company, Payment, Plan, Product

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

The plan associated with the disputed payment. Null if the dispute is not linked to a specific plan.

Parameters:

  • id (String)

    The unique identifier for the plan.



# File 'lib/whop_sdk/models/dispute_list_response.rb', line 91

Instance Attribute Details

#amountFloat

The disputed amount in the specified currency, formatted as a decimal.

Returns:

  • (Float)


17
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 17

required :amount, Float

#companyWhopSDK::Models::DisputeListResponse::Company?

The company that the dispute was filed against.



23
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 23

required :company, -> { WhopSDK::Models::DisputeListResponse::Company }, nil?: true

#created_atTime?

The datetime the dispute was created.

Returns:

  • (Time, nil)


29
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 29

required :created_at, Time, nil?: true

#currencySymbol, WhopSDK::Models::Currency

The three-letter ISO currency code for the disputed amount.

Returns:



35
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 35

required :currency, enum: -> { WhopSDK::Currency }

#editableBoolean?

Whether the dispute evidence can still be edited and submitted. Returns true only when the dispute status requires a response.

Returns:

  • (Boolean, nil)


42
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 42

required :editable, WhopSDK::Internal::Type::Boolean, nil?: true

#idString

The unique identifier for the dispute.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 11

required :id, String

#needs_response_byTime?

The deadline by which dispute evidence must be submitted. Null if no response deadline is set.

Returns:

  • (Time, nil)


49
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 49

required :needs_response_by, Time, nil?: true

#paymentWhopSDK::Models::DisputeListResponse::Payment?

The original payment that was disputed.



55
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 55

required :payment, -> { WhopSDK::Models::DisputeListResponse::Payment }, nil?: true

#planWhopSDK::Models::DisputeListResponse::Plan?

The plan associated with the disputed payment. Null if the dispute is not linked to a specific plan.



62
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 62

required :plan, -> { WhopSDK::Models::DisputeListResponse::Plan }, nil?: true

#productWhopSDK::Models::DisputeListResponse::Product?

The product associated with the disputed payment. Null if the dispute is not linked to a specific product.



69
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 69

required :product, -> { WhopSDK::Models::DisputeListResponse::Product }, nil?: true

#reasonString?

A human-readable reason for the dispute.

Returns:

  • (String, nil)


75
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 75

required :reason, String, nil?: true

#statusSymbol, WhopSDK::Models::DisputeStatuses

The current status of the dispute lifecycle, such as needs_response, under_review, won, or lost.



82
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 82

required :status, enum: -> { WhopSDK::DisputeStatuses }

#visa_rdrBoolean

Whether the dispute was automatically resolved through Visa Rapid Dispute Resolution (RDR).

Returns:

  • (Boolean)


89
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 89

required :visa_rdr, WhopSDK::Internal::Type::Boolean