Class: WhopSDK::Models::DisputeUpdateEvidenceParams::CancellationPolicyAttachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dispute_update_evidence_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, access_activity_log: nil, billing_address: nil, cancellation_policy_attachment: nil, cancellation_policy_disclosure: nil, customer_communication_attachment: nil, customer_email_address: nil, customer_name: nil, notes: nil, product_description: nil, refund_policy_attachment: nil, refund_policy_disclosure: nil, refund_refusal_explanation: nil, service_date: nil, uncategorized_attachment: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::DisputeUpdateEvidenceParams for more details.

Parameters:

  • id (String)
  • access_activity_log (String, nil) (defaults to: nil)

    An IP access activity log showing the customer used the service.

  • billing_address (String, nil) (defaults to: nil)

    The billing address associated with the customer’s payment method.

  • cancellation_policy_attachment (WhopSDK::Models::DisputeUpdateEvidenceParams::CancellationPolicyAttachment, nil) (defaults to: nil)

    A file upload containing the company’s cancellation policy document.

  • cancellation_policy_disclosure (String, nil) (defaults to: nil)

    The company’s cancellation policy text to submit as evidence.

  • customer_communication_attachment (WhopSDK::Models::DisputeUpdateEvidenceParams::CustomerCommunicationAttachment, nil) (defaults to: nil)

    A file upload containing evidence of customer communication. Must be a JPEG, PNG

  • customer_email_address (String, nil) (defaults to: nil)

    The email address of the customer associated with the disputed payment.

  • customer_name (String, nil) (defaults to: nil)

    The full name of the customer associated with the disputed payment.

  • notes (String, nil) (defaults to: nil)

    Additional notes or context to submit as part of the dispute evidence.

  • product_description (String, nil) (defaults to: nil)

    A description of the product or service that was provided to the customer.

  • refund_policy_attachment (WhopSDK::Models::DisputeUpdateEvidenceParams::RefundPolicyAttachment, nil) (defaults to: nil)

    A file upload containing the company’s refund policy document.

  • refund_policy_disclosure (String, nil) (defaults to: nil)

    The company’s refund policy text to submit as evidence.

  • refund_refusal_explanation (String, nil) (defaults to: nil)

    An explanation of why the refund request was refused.

  • service_date (String, nil) (defaults to: nil)

    The date when the product or service was delivered to the customer.

  • uncategorized_attachment (WhopSDK::Models::DisputeUpdateEvidenceParams::UncategorizedAttachment, nil) (defaults to: nil)

    A file upload for evidence that does not fit into the other categories.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 144

class CancellationPolicyAttachment < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing file object.
  #
  #   @return [String]
  required :id, String

  # @!method initialize(id:)
  #   A file upload containing the company's cancellation policy document.
  #
  #   @param id [String] The ID of an existing file object.
end

Instance Attribute Details

#idString

The ID of an existing file object.

Returns:

  • (String)


149
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 149

required :id, String