Class: WhopSDK::Models::DmChannel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::DmChannel
- Defined in:
- lib/whop_sdk/models/dm_channel.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ String
The time the entity was created (in milliseconds since Unix epoch).
-
#id ⇒ String
The unique identifier for the entity.
-
#last_message_at ⇒ Time?
The timestamp when the most recent message was sent in this channel.
-
#name ⇒ String?
A custom display name assigned to this channel by the user.
Instance Method Summary collapse
-
#initialize(id:, created_at:, last_message_at:, name:) ⇒ Object
constructor
Some parameter documentations has been truncated, see DmChannel for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, last_message_at:, name:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::DmChannel for more details.
A messaging channel that can be a one-on-one DM, group chat, company support conversation, or platform-level direct message.
|
|
# File 'lib/whop_sdk/models/dm_channel.rb', line 33
|
Instance Attribute Details
#created_at ⇒ String
The time the entity was created (in milliseconds since Unix epoch)
17 |
# File 'lib/whop_sdk/models/dm_channel.rb', line 17 required :created_at, String |
#id ⇒ String
The unique identifier for the entity
11 |
# File 'lib/whop_sdk/models/dm_channel.rb', line 11 required :id, String |
#last_message_at ⇒ Time?
The timestamp when the most recent message was sent in this channel. Null if no messages have been sent.
24 |
# File 'lib/whop_sdk/models/dm_channel.rb', line 24 required :last_message_at, Time, nil?: true |
#name ⇒ String?
A custom display name assigned to this channel by the user. Null if no custom name has been set.
31 |
# File 'lib/whop_sdk/models/dm_channel.rb', line 31 required :name, String, nil?: true |