Class: WhopSDK::Models::DmChannelCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/dm_channel_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(with_user_ids:, company_id: nil, custom_name: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::DmChannelCreateParams for more details.

Parameters:

  • with_user_ids (Array<String>)

    The list of user identifiers to include in the DM channel. Each entry can be an

  • company_id (String, nil) (defaults to: nil)

    The unique identifier of the company to scope this DM channel to. When set, the

  • custom_name (String, nil) (defaults to: nil)

    A custom display name for the DM channel. For example, ‘Project Discussion’.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/dm_channel_create_params.rb', line 30

Instance Attribute Details

#company_idString?

The unique identifier of the company to scope this DM channel to. When set, the channel is visible only within that company context.

Returns:

  • (String, nil)


22
# File 'lib/whop_sdk/models/dm_channel_create_params.rb', line 22

optional :company_id, String, nil?: true

#custom_nameString?

A custom display name for the DM channel. For example, ‘Project Discussion’.

Returns:

  • (String, nil)


28
# File 'lib/whop_sdk/models/dm_channel_create_params.rb', line 28

optional :custom_name, String, nil?: true

#with_user_idsArray<String>

The list of user identifiers to include in the DM channel. Each entry can be an email, username, or user ID (e.g. ‘user_xxxxx’).

Returns:

  • (Array<String>)


15
# File 'lib/whop_sdk/models/dm_channel_create_params.rb', line 15

required :with_user_ids, WhopSDK::Internal::Type::ArrayOf[String]