Class: WhopSDK::Models::DmChannelListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dm_channel_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, last_message_at:, name:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::DmChannelListResponse for more details.

A messaging channel that can be a one-on-one DM, group chat, company support conversation, or platform-level direct message.

Parameters:

  • id (String)

    The unique identifier for the entity

  • created_at (String)

    The time the entity was created (in milliseconds since Unix epoch)

  • last_message_at (Time, nil)

    The timestamp when the most recent message was sent in this channel. Null if no

  • name (String, nil)

    A custom display name assigned to this channel by the user. Null if no custom na



# File 'lib/whop_sdk/models/dm_channel_list_response.rb', line 33

Instance Attribute Details

#created_atString

The time the entity was created (in milliseconds since Unix epoch)

Returns:

  • (String)


17
# File 'lib/whop_sdk/models/dm_channel_list_response.rb', line 17

required :created_at, String

#idString

The unique identifier for the entity

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/dm_channel_list_response.rb', line 11

required :id, String

#last_message_atTime?

The timestamp when the most recent message was sent in this channel. Null if no messages have been sent.

Returns:

  • (Time, nil)


24
# File 'lib/whop_sdk/models/dm_channel_list_response.rb', line 24

required :last_message_at, Time, nil?: true

#nameString?

A custom display name assigned to this channel by the user. Null if no custom name has been set.

Returns:

  • (String, nil)


31
# File 'lib/whop_sdk/models/dm_channel_list_response.rb', line 31

required :name, String, nil?: true