Class: WhopSDK::Models::DmMember

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dm_member.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, channel_id:, last_viewed_at:, notification_preference:, status:, user_id:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::DmMember for more details.

A user’s membership record in a messaging channel, including notification preferences and read state.

Parameters:

  • id (String)

    The unique identifier for the entity

  • channel_id (String)

    The unique identifier of the messaging channel this membership belongs to.

  • last_viewed_at (String, nil)

    The timestamp when this member last viewed the channel, as a Unix timestamp in m

  • notification_preference (Symbol, WhopSDK::Models::DmFeedMemberNotificationPreferences)

    The notification level for this channel: all, mentions, or none.

  • status (Symbol, WhopSDK::Models::DmFeedMemberStatuses)

    The current state of this membership: requested, accepted, hidden, closed, or ar

  • user_id (String)

    The unique identifier of the user who holds this channel membership.



# File 'lib/whop_sdk/models/dm_member.rb', line 45

Instance Attribute Details

#channel_idString

The unique identifier of the messaging channel this membership belongs to.

Returns:

  • (String)


17
# File 'lib/whop_sdk/models/dm_member.rb', line 17

required :channel_id, String

#idString

The unique identifier for the entity

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/dm_member.rb', line 11

required :id, String

#last_viewed_atString?

The timestamp when this member last viewed the channel, as a Unix timestamp in milliseconds. Null if the member has never viewed the channel.

Returns:

  • (String, nil)


24
# File 'lib/whop_sdk/models/dm_member.rb', line 24

required :last_viewed_at, String, nil?: true

#notification_preferenceSymbol, WhopSDK::Models::DmFeedMemberNotificationPreferences

The notification level for this channel: all, mentions, or none.



30
# File 'lib/whop_sdk/models/dm_member.rb', line 30

required :notification_preference, enum: -> { WhopSDK::DmFeedMemberNotificationPreferences }

#statusSymbol, WhopSDK::Models::DmFeedMemberStatuses

The current state of this membership: requested, accepted, hidden, closed, or archived.



37
# File 'lib/whop_sdk/models/dm_member.rb', line 37

required :status, enum: -> { WhopSDK::DmFeedMemberStatuses }

#user_idString

The unique identifier of the user who holds this channel membership.

Returns:

  • (String)


43
# File 'lib/whop_sdk/models/dm_member.rb', line 43

required :user_id, String