Class: WhopSDK::Models::DmMemberListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dm_member_list_response.rb,
sig/whop_sdk/models/dm_member_list_response.rbs

Overview

See Also:

  • WhopSDK::Resources::DmMembers#list

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, channel_id:, last_viewed_at:, status:, user_id:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::DmMemberListResponse for more details.

A user's membership record in a messaging channel, including notification preferences and read state.

Parameters:

  • id (String)

    The unique identifier for the entity

  • channel_id (String)

    The unique identifier of the messaging channel this membership belongs to.

  • last_viewed_at (String, nil)

    The timestamp when this member last viewed the channel, as a Unix timestamp in m

  • status (Symbol, WhopSDK::Models::DmFeedMemberStatuses)

    The current state of this membership: requested, accepted, hidden, closed, or ar

  • user_id (String)

    The unique identifier of the user who holds this channel membership.



# File 'lib/whop_sdk/models/dm_member_list_response.rb', line 39

Instance Attribute Details

#channel_idString

The unique identifier of the messaging channel this membership belongs to.

Parameters:

  • value (String)

Returns:

  • (String)


17
# File 'lib/whop_sdk/models/dm_member_list_response.rb', line 17

required :channel_id, String

#idString

The unique identifier for the entity

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/dm_member_list_response.rb', line 11

required :id, String

#last_viewed_atString?

The timestamp when this member last viewed the channel, as a Unix timestamp in milliseconds. Null if the member has never viewed the channel.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


24
# File 'lib/whop_sdk/models/dm_member_list_response.rb', line 24

required :last_viewed_at, String, nil?: true

#statusSymbol, WhopSDK::Models::DmFeedMemberStatuses

The current state of this membership: requested, accepted, hidden, closed, or archived.

Parameters:

  • value (WhopSDK::Models::dm_feed_member_statuses)

Returns:



31
# File 'lib/whop_sdk/models/dm_member_list_response.rb', line 31

required :status, enum: -> { WhopSDK::DmFeedMemberStatuses }

#user_idString

The unique identifier of the user who holds this channel membership.

Parameters:

  • value (String)

Returns:

  • (String)


37
# File 'lib/whop_sdk/models/dm_member_list_response.rb', line 37

required :user_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


31
# File 'sig/whop_sdk/models/dm_member_list_response.rbs', line 31

def to_hash: -> {