Class: WhopSDK::Models::Entry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Entry
- Defined in:
- lib/whop_sdk/models/entry.rb
Defined Under Namespace
Classes: CustomFieldResponse, Plan, Product, User
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
The datetime the entry was created.
-
#custom_field_responses ⇒ Array<WhopSDK::Models::Entry::CustomFieldResponse>?
The list of responses collected from the user when submitting their waitlist entry.
-
#id ⇒ String
The unique identifier for the entry.
-
#plan ⇒ WhopSDK::Models::Entry::Plan?
The waitlisted plan that this entry is a signup for.
-
#product ⇒ WhopSDK::Models::Entry::Product?
The product associated with this entry’s waitlisted plan.
-
#status ⇒ Symbol, WhopSDK::Models::EntryStatus
The current status of the waitlist entry (e.g., drafted, pending, approved, denied).
-
#user ⇒ WhopSDK::Models::Entry::User
The user who submitted this waitlist entry.
Instance Method Summary collapse
-
#initialize(id:, title:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Product for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, title:) ⇒ Object
Some parameter documentations has been truncated, see Product for more details.
The product associated with this entry’s waitlisted plan. Null if the plan is not tied to a product.
|
|
# File 'lib/whop_sdk/models/entry.rb', line 92
|
Instance Attribute Details
#created_at ⇒ Time?
The datetime the entry was created.
16 |
# File 'lib/whop_sdk/models/entry.rb', line 16 required :created_at, Time, nil?: true |
#custom_field_responses ⇒ Array<WhopSDK::Models::Entry::CustomFieldResponse>?
The list of responses collected from the user when submitting their waitlist entry.
23 24 25 |
# File 'lib/whop_sdk/models/entry.rb', line 23 required :custom_field_responses, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Entry::CustomFieldResponse] }, nil?: true |
#id ⇒ String
The unique identifier for the entry.
10 |
# File 'lib/whop_sdk/models/entry.rb', line 10 required :id, String |
#plan ⇒ WhopSDK::Models::Entry::Plan?
The waitlisted plan that this entry is a signup for.
31 |
# File 'lib/whop_sdk/models/entry.rb', line 31 required :plan, -> { WhopSDK::Entry::Plan }, nil?: true |
#product ⇒ WhopSDK::Models::Entry::Product?
The product associated with this entry’s waitlisted plan. Null if the plan is not tied to a product.
38 |
# File 'lib/whop_sdk/models/entry.rb', line 38 required :product, -> { WhopSDK::Entry::Product }, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::EntryStatus
The current status of the waitlist entry (e.g., drafted, pending, approved, denied).
45 |
# File 'lib/whop_sdk/models/entry.rb', line 45 required :status, enum: -> { WhopSDK::EntryStatus } |
#user ⇒ WhopSDK::Models::Entry::User
The user who submitted this waitlist entry.
51 |
# File 'lib/whop_sdk/models/entry.rb', line 51 required :user, -> { WhopSDK::Entry::User } |