Class: WhopSDK::Models::EntryCreatedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::EntryCreatedWebhookEvent
- Defined in:
- lib/whop_sdk/models/entry_created_webhook_event.rb
Instance Attribute Summary collapse
-
#api_version ⇒ Symbol, :v1
The API version for this webhook.
-
#company_id ⇒ String?
The company ID that this webhook event is associated with.
-
#data ⇒ WhopSDK::Models::Entry
An entry represents a user’s signup for a waitlisted plan.
-
#id ⇒ String
A unique ID for every single webhook request.
-
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server.
-
#type ⇒ Symbol, :"entry.created"
The webhook event type.
Instance Method Summary collapse
- #initialize(id:, data:, timestamp:, company_id: nil, api_version: :v1, type: :"entry.created") ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, data:, timestamp:, company_id: nil, api_version: :v1, type: :"entry.created") ⇒ Object
|
|
# File 'lib/whop_sdk/models/entry_created_webhook_event.rb', line 42
|
Instance Attribute Details
#api_version ⇒ Symbol, :v1
The API version for this webhook
16 |
# File 'lib/whop_sdk/models/entry_created_webhook_event.rb', line 16 required :api_version, const: :v1 |
#company_id ⇒ String?
The company ID that this webhook event is associated with
40 |
# File 'lib/whop_sdk/models/entry_created_webhook_event.rb', line 40 optional :company_id, String, nil?: true |
#data ⇒ WhopSDK::Models::Entry
An entry represents a user’s signup for a waitlisted plan.
22 |
# File 'lib/whop_sdk/models/entry_created_webhook_event.rb', line 22 required :data, -> { WhopSDK::Entry } |
#id ⇒ String
A unique ID for every single webhook request
10 |
# File 'lib/whop_sdk/models/entry_created_webhook_event.rb', line 10 required :id, String |
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server
28 |
# File 'lib/whop_sdk/models/entry_created_webhook_event.rb', line 28 required :timestamp, Time |
#type ⇒ Symbol, :"entry.created"
The webhook event type
34 |
# File 'lib/whop_sdk/models/entry_created_webhook_event.rb', line 34 required :type, const: :"entry.created" |