Class: WhopSDK::Models::EntryListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/entry_list_response.rb

Overview

Defined Under Namespace

Classes: Plan, Product, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, title:) ⇒ Object

Some parameter documentations has been truncated, see Product for more details.

The product associated with this entry’s waitlisted plan. Null if the plan is not tied to a product.

Parameters:

  • id (String)

    The unique identifier for the product.

  • title (String)

    The display name of the product shown to customers on the product page and in se



# File 'lib/whop_sdk/models/entry_list_response.rb', line 45

Instance Attribute Details

#created_atTime?

The datetime the entry was created.

Returns:

  • (Time, nil)


17
# File 'lib/whop_sdk/models/entry_list_response.rb', line 17

required :created_at, Time, nil?: true

#idString

The unique identifier for the entry.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/entry_list_response.rb', line 11

required :id, String

#planWhopSDK::Models::EntryListResponse::Plan?

The waitlisted plan that this entry is a signup for.



23
# File 'lib/whop_sdk/models/entry_list_response.rb', line 23

required :plan, -> { WhopSDK::Models::EntryListResponse::Plan }, nil?: true

#productWhopSDK::Models::EntryListResponse::Product?

The product associated with this entry’s waitlisted plan. Null if the plan is not tied to a product.



30
# File 'lib/whop_sdk/models/entry_list_response.rb', line 30

required :product, -> { WhopSDK::Models::EntryListResponse::Product }, nil?: true

#statusSymbol, WhopSDK::Models::EntryStatus

The current status of the waitlist entry (e.g., drafted, pending, approved, denied).

Returns:



37
# File 'lib/whop_sdk/models/entry_list_response.rb', line 37

required :status, enum: -> { WhopSDK::EntryStatus }

#userWhopSDK::Models::EntryListResponse::User

The user who submitted this waitlist entry.



43
# File 'lib/whop_sdk/models/entry_list_response.rb', line 43

required :user, -> { WhopSDK::Models::EntryListResponse::User }