Class: WhopSDK::Models::EntryListResponse::User

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/entry_list_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , email: , name: , username: ) ⇒ Object

The user who created the entry.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the user.

  • email (String, nil) (defaults to: )

    The email of the user

  • name (String, nil) (defaults to: )

    The name of the user from their Whop account.

  • username (String) (defaults to: )

    The username of the user from their Whop account.



# File 'lib/whop_sdk/models/entry_list_response.rb', line 120

Instance Attribute Details

#emailString?

The email of the user

Returns:

  • (String, nil)


106
# File 'lib/whop_sdk/models/entry_list_response.rb', line 106

required :email, String, nil?: true

#idString

The internal ID of the user.

Returns:

  • (String)


100
# File 'lib/whop_sdk/models/entry_list_response.rb', line 100

required :id, String

#nameString?

The name of the user from their Whop account.

Returns:

  • (String, nil)


112
# File 'lib/whop_sdk/models/entry_list_response.rb', line 112

required :name, String, nil?: true

#usernameString

The username of the user from their Whop account.

Returns:

  • (String)


118
# File 'lib/whop_sdk/models/entry_list_response.rb', line 118

required :username, String