Class: WhopSDK::Models::EventCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::EventCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/event_create_params.rb,
sig/whop_sdk/models/event_create_params.rbs
Overview
Defined Under Namespace
Modules: ActionSource, Currency, EventName Classes: Context, User
Instance Attribute Summary collapse
-
#account_id ⇒ String
The account to associate with this event.
-
#action_source ⇒ Symbol, ...
The channel where an event originated.
-
#context ⇒ WhopSDK::Models::EventCreateParams::Context?
Tracking and attribution context.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#custom_name ⇒ String?
Custom event name when event_name is 'custom'.
-
#duration ⇒ Integer?
For 'leave' events: milliseconds the visitor spent on the page.
-
#event_id ⇒ String?
Client-provided identifier for deduplication.
-
#event_name ⇒ Symbol, WhopSDK::Models::EventCreateParams::EventName
The type of conversion or engagement event.
-
#event_time ⇒ Time?
When the event occurred.
-
#plan_id ⇒ String?
The plan associated with the event.
-
#product_id ⇒ String?
The product associated with the event.
-
#referrer_url ⇒ String?
The referring URL.
-
#resumed ⇒ Boolean?
For 'page' events: true when the page was restored from the back/forward cache.
-
#source ⇒ String?
For 'identify' events: where the identity was captured (url, form, manual, iframe).
-
#title ⇒ String?
For 'page' events: the document title.
-
#url ⇒ String?
The URL where the event occurred.
-
#user ⇒ WhopSDK::Models::EventCreateParams::User?
User identity and profile data.
-
#value ⇒ Float?
Monetary value associated with the event.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(ad_campaign_id: nil, ad_id: nil, ad_set_id: nil, fbc: nil, fbclid: nil, fbp: nil, fingerprint: nil, fingerprint_confidence: nil, ga: nil, gbraid: nil, gclid: nil, ig_sid: nil, ip_address: nil, language: nil, li_fat_id: nil, msclkid: nil, rdt_cid: nil, sccid: nil, screen_resolution: nil, timezone: nil, ttclid: nil, ttp: nil, twclid: nil, user_agent: nil, utm_campaign: nil, utm_content: nil, utm_id: nil, utm_medium: nil, utm_source: nil, utm_term: nil, wbraid: nil) ⇒ Object
constructor
Tracking and attribution context.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(ad_campaign_id: nil, ad_id: nil, ad_set_id: nil, fbc: nil, fbclid: nil, fbp: nil, fingerprint: nil, fingerprint_confidence: nil, ga: nil, gbraid: nil, gclid: nil, ig_sid: nil, ip_address: nil, language: nil, li_fat_id: nil, msclkid: nil, rdt_cid: nil, sccid: nil, screen_resolution: nil, timezone: nil, ttclid: nil, ttp: nil, twclid: nil, user_agent: nil, utm_campaign: nil, utm_content: nil, utm_id: nil, utm_medium: nil, utm_source: nil, utm_term: nil, wbraid: nil) ⇒ Object
Tracking and attribution context.
|
|
# File 'lib/whop_sdk/models/event_create_params.rb', line 119
|
Instance Attribute Details
#account_id ⇒ String
The account to associate with this event.
14 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 14 required :account_id, String |
#action_source ⇒ Symbol, ...
The channel where an event originated
26 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 26 optional :action_source, enum: -> { WhopSDK::EventCreateParams::ActionSource }, nil?: true |
#context ⇒ WhopSDK::Models::EventCreateParams::Context?
Tracking and attribution context.
32 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 32 optional :context, -> { WhopSDK::EventCreateParams::Context }, nil?: true |
#currency ⇒ Symbol, ...
The available currencies on the platform
38 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 38 optional :currency, enum: -> { WhopSDK::EventCreateParams::Currency }, nil?: true |
#custom_name ⇒ String?
Custom event name when event_name is 'custom'. Maximum 35 chars for this value.
44 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 44 optional :custom_name, String, nil?: true |
#duration ⇒ Integer?
For 'leave' events: milliseconds the visitor spent on the page.
50 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 50 optional :duration, Integer, nil?: true |
#event_id ⇒ String?
Client-provided identifier for deduplication. Generated if omitted.
56 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 56 optional :event_id, String, nil?: true |
#event_name ⇒ Symbol, WhopSDK::Models::EventCreateParams::EventName
The type of conversion or engagement event
20 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 20 required :event_name, enum: -> { WhopSDK::EventCreateParams::EventName } |
#event_time ⇒ Time?
When the event occurred. Defaults to now.
62 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 62 optional :event_time, Time, nil?: true |
#plan_id ⇒ String?
The plan associated with the event.
68 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 68 optional :plan_id, String, nil?: true |
#product_id ⇒ String?
The product associated with the event.
74 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 74 optional :product_id, String, nil?: true |
#referrer_url ⇒ String?
The referring URL.
80 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 80 optional :referrer_url, String, nil?: true |
#resumed ⇒ Boolean?
For 'page' events: true when the page was restored from the back/forward cache.
86 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 86 optional :resumed, WhopSDK::Internal::Type::Boolean, nil?: true |
#source ⇒ String?
For 'identify' events: where the identity was captured (url, form, manual, iframe).
93 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 93 optional :source, String, nil?: true |
#title ⇒ String?
For 'page' events: the document title.
99 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 99 optional :title, String, nil?: true |
#url ⇒ String?
The URL where the event occurred.
105 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 105 optional :url, String, nil?: true |
#user ⇒ WhopSDK::Models::EventCreateParams::User?
User identity and profile data.
111 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 111 optional :user, -> { WhopSDK::EventCreateParams::User }, nil?: true |
#value ⇒ Float?
Monetary value associated with the event.
117 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 117 optional :value, Float, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/event_create_params.rb', line 175
|
Instance Method Details
#to_hash ⇒ {
88 |
# File 'sig/whop_sdk/models/event_create_params.rbs', line 88
def to_hash: -> {
|