Class: WhopSDK::Models::EventCreateParams::User
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::EventCreateParams::User
- Defined in:
- lib/whop_sdk/models/event_create_params.rb,
sig/whop_sdk/models/event_create_params.rbs
Defined Under Namespace
Modules: Gender
Instance Attribute Summary collapse
-
#anonymous_id ⇒ String?
An anonymous identifier for the user.
-
#birthdate ⇒ String?
Date of birth (YYYY-MM-DD).
-
#city ⇒ String?
City.
-
#country ⇒ String?
Country.
-
#email ⇒ String?
Email address.
-
#external_id ⇒ String?
An external identifier for the user.
-
#first_name ⇒ String?
First name.
-
#gender ⇒ Symbol, ...
Gender.
-
#last_name ⇒ String?
Last name.
-
#linked_anonymous_id ⇒ String?
A second anonymous identifier to link to this user (e.g. captured across an iframe boundary).
-
#linked_wuid ⇒ String?
A wuid from a linked frame, captured across an iframe boundary.
-
#member_id ⇒ String?
The Whop member ID.
-
#membership_id ⇒ String?
The Whop membership ID.
-
#name ⇒ String?
Full display name.
-
#phone ⇒ String?
Phone number.
-
#postal_code ⇒ String?
Postal code.
-
#state ⇒ String?
State or region.
-
#user_id ⇒ String?
The Whop user ID.
-
#username ⇒ String?
Username.
Instance Method Summary collapse
-
#initialize(anonymous_id: nil, birthdate: nil, city: nil, country: nil, email: nil, external_id: nil, first_name: nil, gender: nil, last_name: nil, linked_anonymous_id: nil, linked_wuid: nil, member_id: nil, membership_id: nil, name: nil, phone: nil, postal_code: nil, state: nil, user_id: nil, username: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see User for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(anonymous_id: nil, birthdate: nil, city: nil, country: nil, email: nil, external_id: nil, first_name: nil, gender: nil, last_name: nil, linked_anonymous_id: nil, linked_wuid: nil, member_id: nil, membership_id: nil, name: nil, phone: nil, postal_code: nil, state: nil, user_id: nil, username: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::EventCreateParams::User for more details.
User identity and profile data.
|
|
# File 'lib/whop_sdk/models/event_create_params.rb', line 665
|
Instance Attribute Details
#anonymous_id ⇒ String?
An anonymous identifier for the user.
554 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 554 optional :anonymous_id, String, nil?: true |
#birthdate ⇒ String?
Date of birth (YYYY-MM-DD).
560 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 560 optional :birthdate, String, nil?: true |
#city ⇒ String?
City.
566 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 566 optional :city, String, nil?: true |
#country ⇒ String?
Country.
572 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 572 optional :country, String, nil?: true |
#email ⇒ String?
Email address.
578 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 578 optional :email, String, nil?: true |
#external_id ⇒ String?
An external identifier for the user.
584 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 584 optional :external_id, String, nil?: true |
#first_name ⇒ String?
First name.
590 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 590 optional :first_name, String, nil?: true |
#gender ⇒ Symbol, ...
Gender
596 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 596 optional :gender, enum: -> { WhopSDK::EventCreateParams::User::Gender }, nil?: true |
#last_name ⇒ String?
Last name.
602 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 602 optional :last_name, String, nil?: true |
#linked_anonymous_id ⇒ String?
A second anonymous identifier to link to this user (e.g. captured across an iframe boundary).
609 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 609 optional :linked_anonymous_id, String, nil?: true |
#linked_wuid ⇒ String?
A wuid from a linked frame, captured across an iframe boundary.
615 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 615 optional :linked_wuid, String, nil?: true |
#member_id ⇒ String?
The Whop member ID.
621 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 621 optional :member_id, String, nil?: true |
#membership_id ⇒ String?
The Whop membership ID.
627 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 627 optional :membership_id, String, nil?: true |
#name ⇒ String?
Full display name.
633 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 633 optional :name, String, nil?: true |
#phone ⇒ String?
Phone number.
639 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 639 optional :phone, String, nil?: true |
#postal_code ⇒ String?
Postal code.
645 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 645 optional :postal_code, String, nil?: true |
#state ⇒ String?
State or region.
651 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 651 optional :state, String, nil?: true |
#user_id ⇒ String?
The Whop user ID.
657 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 657 optional :user_id, String, nil?: true |
#username ⇒ String?
Username.
663 |
# File 'lib/whop_sdk/models/event_create_params.rb', line 663 optional :username, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
604 |
# File 'sig/whop_sdk/models/event_create_params.rbs', line 604
def to_hash: -> {
|