Class: WhopSDK::Models::EventListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::EventListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/event_list_params.rb,
sig/whop_sdk/models/event_list_params.rbs
Overview
Instance Attribute Summary collapse
-
#account_id ⇒ String?
The ID of the account, which will look like biz_*.
-
#after ⇒ String?
A cursor for fetching events after a previous page.
-
#before ⇒ String?
A cursor for fetching events before a later page.
-
#first ⇒ Integer?
The number of events to return.
-
#from ⇒ Integer?
Start of the time range as a Unix timestamp.
-
#person_id ⇒ String
The ID of the person.
-
#to ⇒ Integer?
End of the time range as a Unix timestamp.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(person_id:, account_id: nil, after: nil, before: nil, first: nil, from: nil, to: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EventListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(person_id:, account_id: nil, after: nil, before: nil, first: nil, from: nil, to: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::EventListParams for more details.
acco
|
|
# File 'lib/whop_sdk/models/event_list_params.rb', line 53
|
Instance Attribute Details
#account_id ⇒ String?
The ID of the account, which will look like biz_*. Optional for account API keys; required for credentials that can access multiple accounts.
21 |
# File 'lib/whop_sdk/models/event_list_params.rb', line 21 optional :account_id, String |
#after ⇒ String?
A cursor for fetching events after a previous page.
27 |
# File 'lib/whop_sdk/models/event_list_params.rb', line 27 optional :after, String |
#before ⇒ String?
A cursor for fetching events before a later page.
33 |
# File 'lib/whop_sdk/models/event_list_params.rb', line 33 optional :before, String |
#first ⇒ Integer?
The number of events to return.
39 |
# File 'lib/whop_sdk/models/event_list_params.rb', line 39 optional :first, Integer |
#from ⇒ Integer?
Start of the time range as a Unix timestamp.
45 |
# File 'lib/whop_sdk/models/event_list_params.rb', line 45 optional :from, Integer |
#person_id ⇒ String
The ID of the person.
14 |
# File 'lib/whop_sdk/models/event_list_params.rb', line 14 required :person_id, String |
#to ⇒ Integer?
End of the time range as a Unix timestamp. Defaults to now.
51 |
# File 'lib/whop_sdk/models/event_list_params.rb', line 51 optional :to, Integer |
Instance Method Details
#to_hash ⇒ {
56 |
# File 'sig/whop_sdk/models/event_list_params.rbs', line 56
def to_hash: -> {
|