Class: WhopSDK::Models::Experience::App

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/experience.rb

Overview

See Also:

Defined Under Namespace

Classes: Icon

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, icon:, name:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::Experience::App for more details.

The app that powers this experience, defining its interface and behavior.

Parameters:

  • id (String)

    The unique identifier for the app.

  • icon (WhopSDK::Models::Experience::App::Icon, nil)

    The icon image for this app, displayed on the app store, product pages, checkout

  • name (String)

    The display name of this app shown on the app store and in experience navigation



# File 'lib/whop_sdk/models/experience.rb', line 113

Instance Attribute Details

#iconWhopSDK::Models::Experience::App::Icon?

The icon image for this app, displayed on the app store, product pages, checkout, and as the default icon for experiences using this app.



104
# File 'lib/whop_sdk/models/experience.rb', line 104

required :icon, -> { WhopSDK::Experience::App::Icon }, nil?: true

#idString

The unique identifier for the app.

Returns:

  • (String)


97
# File 'lib/whop_sdk/models/experience.rb', line 97

required :id, String

#nameString

The display name of this app shown on the app store and in experience navigation. Maximum 30 characters.

Returns:

  • (String)


111
# File 'lib/whop_sdk/models/experience.rb', line 111

required :name, String