Class: WhopSDK::Models::Experience::Product

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/experience.rb,
sig/whop_sdk/models/experience.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, route:, title:) ⇒ Product

Some parameter documentations has been truncated, see WhopSDK::Models::Experience::Product for more details.

A product is a digital good or service sold on Whop. Products contain plans for pricing and experiences for content delivery.

Parameters:

  • id (String)

    The unique identifier for the product.

  • route (String)

    URL slug in the product's public link, e.g. pickaxe-analytics in whop.com/comp

  • title (String)

    The display name of the product shown to customers on the product page and in se

  • id: (String)
  • route: (String)
  • title: (String)


# File 'lib/whop_sdk/models/experience.rb', line 215

Instance Attribute Details

#idString

The unique identifier for the product.

Parameters:

  • value (String)

Returns:

  • (String)


199
# File 'lib/whop_sdk/models/experience.rb', line 199

required :id, String

#routeString

URL slug in the product's public link, e.g. pickaxe-analytics in whop.com/company/pickaxe-analytics.

Parameters:

  • value (String)

Returns:

  • (String)


206
# File 'lib/whop_sdk/models/experience.rb', line 206

required :route, String

#titleString

The display name of the product shown to customers on the product page and in search results.

Parameters:

  • value (String)

Returns:

  • (String)


213
# File 'lib/whop_sdk/models/experience.rb', line 213

required :title, String

Instance Method Details

#to_hash{ id: String, route: String, title: String }

Returns:

  • ({ id: String, route: String, title: String })


127
# File 'sig/whop_sdk/models/experience.rbs', line 127

def to_hash: -> { id: String, route: String, title: String }