Class: WhopSDK::Models::ExperienceCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ExperienceCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/experience_create_params.rb
Overview
Defined Under Namespace
Classes: Logo
Instance Attribute Summary collapse
-
#app_id ⇒ String
The unique identifier of the app that powers this experience.
-
#company_id ⇒ String
The unique identifier of the company to create this experience for.
-
#is_public ⇒ Boolean?
Whether the experience is publicly accessible without a membership.
-
#logo ⇒ WhopSDK::Models::ExperienceCreateParams::Logo?
A logo image displayed alongside the experience name.
-
#name ⇒ String?
The display name of the experience.
-
#section_id ⇒ String?
The unique identifier of the section to place the experience in.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#app_id ⇒ String
The unique identifier of the app that powers this experience.
14 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 14 required :app_id, String |
#company_id ⇒ String
The unique identifier of the company to create this experience for.
20 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 20 required :company_id, String |
#is_public ⇒ Boolean?
Whether the experience is publicly accessible without a membership.
26 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 26 optional :is_public, WhopSDK::Internal::Type::Boolean, nil?: true |
#logo ⇒ WhopSDK::Models::ExperienceCreateParams::Logo?
A logo image displayed alongside the experience name.
32 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 32 optional :logo, -> { WhopSDK::ExperienceCreateParams::Logo }, nil?: true |
#name ⇒ String?
The display name of the experience. Defaults to the app’s name if not provided.
38 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 38 optional :name, String, nil?: true |
#section_id ⇒ String?
The unique identifier of the section to place the experience in.
44 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 44 optional :section_id, String, nil?: true |