Class: WhopSDK::Models::ExperienceListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/experience_list_response.rb

Overview

Defined Under Namespace

Classes: App, Company, Image

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, route:, title:) ⇒ Object

Some parameter documentations has been truncated, see Company for more details.

The company that owns this experience.

Parameters:

  • id (String)

    The unique identifier for the company.

  • route (String)

    The URL slug for the company’s store page (e.g., ‘pickaxe’ in whop.com/pickaxe).

  • title (String)

    The display name of the company shown to customers.



# File 'lib/whop_sdk/models/experience_list_response.rb', line 59

Instance Attribute Details

#appWhopSDK::Models::ExperienceListResponse::App

The app that powers this experience, defining its interface and behavior.



17
# File 'lib/whop_sdk/models/experience_list_response.rb', line 17

required :app, -> { WhopSDK::Models::ExperienceListResponse::App }

#companyWhopSDK::Models::ExperienceListResponse::Company

The company that owns this experience.



23
# File 'lib/whop_sdk/models/experience_list_response.rb', line 23

required :company, -> { WhopSDK::Models::ExperienceListResponse::Company }

#created_atTime

The datetime the experience was created.

Returns:

  • (Time)


29
# File 'lib/whop_sdk/models/experience_list_response.rb', line 29

required :created_at, Time

#idString

The unique identifier for the experience.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/experience_list_response.rb', line 11

required :id, String

#imageWhopSDK::Models::ExperienceListResponse::Image?

The custom logo image for this experience. Null if no custom logo has been uploaded.



36
# File 'lib/whop_sdk/models/experience_list_response.rb', line 36

required :image, -> { WhopSDK::Models::ExperienceListResponse::Image }, nil?: true

#is_publicBoolean

Whether this experience is publicly visible to all users, including those without a membership.

Returns:

  • (Boolean)


43
# File 'lib/whop_sdk/models/experience_list_response.rb', line 43

required :is_public, WhopSDK::Internal::Type::Boolean

#nameString

The display name of this experience shown to users in the product navigation. Maximum 255 characters.

Returns:

  • (String)


50
# File 'lib/whop_sdk/models/experience_list_response.rb', line 50

required :name, String

#orderString?

The sort position of this experience within its section. Lower values appear first. Null if no position has been set.

Returns:

  • (String, nil)


57
# File 'lib/whop_sdk/models/experience_list_response.rb', line 57

required :order, String, nil?: true