Class: WhopSDK::Models::ExperienceListResponse::App
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ExperienceListResponse::App
- Defined in:
- lib/whop_sdk/models/experience_list_response.rb
Overview
Defined Under Namespace
Classes: Icon
Instance Attribute Summary collapse
-
#icon ⇒ WhopSDK::Models::ExperienceListResponse::App::Icon?
The icon image for this app, displayed on the app store, product pages, checkout, and as the default icon for experiences using this app.
-
#id ⇒ String
The unique identifier for the app.
-
#name ⇒ String
The display name of this app shown on the app store and in experience navigation.
Instance Method Summary collapse
-
#initialize(id:, icon:, name:) ⇒ Object
constructor
Some parameter documentations has been truncated, see App for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, icon:, name:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ExperienceListResponse::App for more details.
The app that powers this experience, defining its interface and behavior.
|
|
# File 'lib/whop_sdk/models/experience_list_response.rb', line 104
|
Instance Attribute Details
#icon ⇒ WhopSDK::Models::ExperienceListResponse::App::Icon?
The icon image for this app, displayed on the app store, product pages, checkout, and as the default icon for experiences using this app.
95 |
# File 'lib/whop_sdk/models/experience_list_response.rb', line 95 required :icon, -> { WhopSDK::Models::ExperienceListResponse::App::Icon }, nil?: true |
#id ⇒ String
The unique identifier for the app.
88 |
# File 'lib/whop_sdk/models/experience_list_response.rb', line 88 required :id, String |
#name ⇒ String
The display name of this app shown on the app store and in experience navigation. Maximum 30 characters.
102 |
# File 'lib/whop_sdk/models/experience_list_response.rb', line 102 required :name, String |