Class: WhopSDK::Models::ExperienceListResponse::Company
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ExperienceListResponse::Company
- Defined in:
- lib/whop_sdk/models/experience_list_response.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the company.
-
#route ⇒ String
The URL slug for the company’s store page (e.g., ‘pickaxe’ in whop.com/pickaxe).
-
#title ⇒ String
The display name of the company shown to customers.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#id ⇒ String
The unique identifier for the company.
142 |
# File 'lib/whop_sdk/models/experience_list_response.rb', line 142 required :id, String |
#route ⇒ String
The URL slug for the company’s store page (e.g., ‘pickaxe’ in whop.com/pickaxe).
148 |
# File 'lib/whop_sdk/models/experience_list_response.rb', line 148 required :route, String |
#title ⇒ String
The display name of the company shown to customers.
154 |
# File 'lib/whop_sdk/models/experience_list_response.rb', line 154 required :title, String |