Class: WhopSDK::Models::ExperienceUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/experience_update_params.rb

Overview

Defined Under Namespace

Modules: AccessLevel Classes: Logo

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, access_level: nil, is_public: nil, logo: nil, name: nil, order: nil, section_id: nil, request_options: {}) ⇒ Object

Parameters:

  • id (String)
  • access_level (Symbol, WhopSDK::Models::ExperienceUpdateParams::AccessLevel, nil) (defaults to: nil)

    The different access levels for experiences (PUBLIC IS NEVER USED ANYMORE).

  • is_public (Boolean, nil) (defaults to: nil)

    Whether the experience is publicly accessible without a membership.

  • logo (WhopSDK::Models::ExperienceUpdateParams::Logo, nil) (defaults to: nil)

    A logo image displayed alongside the experience name.

  • name (String, nil) (defaults to: nil)

    The display name of the experience.

  • order (String, nil) (defaults to: nil)

    The position of the experience within its section for display ordering.

  • section_id (String, nil) (defaults to: nil)

    The unique identifier of the section to move the experience into.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/experience_update_params.rb', line 51

Instance Attribute Details

#access_levelSymbol, ...

The different access levels for experiences (PUBLIC IS NEVER USED ANYMORE).



19
# File 'lib/whop_sdk/models/experience_update_params.rb', line 19

optional :access_level, enum: -> { WhopSDK::ExperienceUpdateParams::AccessLevel }, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/experience_update_params.rb', line 13

required :id, String

#is_publicBoolean?

Whether the experience is publicly accessible without a membership.

Returns:

  • (Boolean, nil)


25
# File 'lib/whop_sdk/models/experience_update_params.rb', line 25

optional :is_public, WhopSDK::Internal::Type::Boolean, nil?: true

#logoWhopSDK::Models::ExperienceUpdateParams::Logo?

A logo image displayed alongside the experience name.



31
# File 'lib/whop_sdk/models/experience_update_params.rb', line 31

optional :logo, -> { WhopSDK::ExperienceUpdateParams::Logo }, nil?: true

#nameString?

The display name of the experience.

Returns:

  • (String, nil)


37
# File 'lib/whop_sdk/models/experience_update_params.rb', line 37

optional :name, String, nil?: true

#orderString?

The position of the experience within its section for display ordering.

Returns:

  • (String, nil)


43
# File 'lib/whop_sdk/models/experience_update_params.rb', line 43

optional :order, String, nil?: true

#section_idString?

The unique identifier of the section to move the experience into.

Returns:

  • (String, nil)


49
# File 'lib/whop_sdk/models/experience_update_params.rb', line 49

optional :section_id, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/experience_update_params.rb', line 75