Class: WhopSDK::Models::FeeMarkupCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/fee_markup_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id:, fee_type:, fixed_fee_usd: nil, metadata: nil, notes: nil, percentage_fee: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::FeeMarkupCreateParams for more details.

Parameters:

  • company_id (String)

    The unique identifier of the company to create or update the fee markup for.

  • fee_type (Symbol, WhopSDK::Models::FeeMarkupType)

    The type of fee this markup applies to, such as processing or platform fees.

  • fixed_fee_usd (Float, nil) (defaults to: nil)

    The fixed fee amount in USD to charge per transaction. Must be between 0 and 50.

  • metadata (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Custom key-value metadata to attach to this fee markup.

  • notes (String, nil) (defaults to: nil)

    Internal notes about this fee markup for record-keeping purposes.

  • percentage_fee (Float, nil) (defaults to: nil)

    The percentage fee to charge per transaction. Must be between 0 and 25.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 46

Instance Attribute Details

#company_idString

The unique identifier of the company to create or update the fee markup for.

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 14

required :company_id, String

#fee_typeSymbol, WhopSDK::Models::FeeMarkupType

The type of fee this markup applies to, such as processing or platform fees.

Returns:



20
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 20

required :fee_type, enum: -> { WhopSDK::FeeMarkupType }

#fixed_fee_usdFloat?

The fixed fee amount in USD to charge per transaction. Must be between 0 and 50.

Returns:

  • (Float, nil)


26
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 26

optional :fixed_fee_usd, Float, nil?: true

#metadataHash{Symbol=>Object}?

Custom key-value metadata to attach to this fee markup.

Returns:

  • (Hash{Symbol=>Object}, nil)


32
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 32

optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#notesString?

Internal notes about this fee markup for record-keeping purposes.

Returns:

  • (String, nil)


38
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 38

optional :notes, String, nil?: true

#percentage_feeFloat?

The percentage fee to charge per transaction. Must be between 0 and 25.

Returns:

  • (Float, nil)


44
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 44

optional :percentage_fee, Float, nil?: true