Class: WhopSDK::Models::FeeMarkupCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/fee_markup_create_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, fee_type:, fixed_fee_usd:, notes:, percentage_fee:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::FeeMarkupCreateResponse for more details.

A fee markup configuration that defines additional charges applied to transactions for a platform’s connected accounts.

Parameters:

  • id (String)

    The unique identifier for the fee markup.

  • created_at (Time)

    The datetime the fee markup was created.

  • fee_type (Symbol, WhopSDK::Models::FeeMarkupType)

    The category of fee this markup applies to.

  • fixed_fee_usd (Float, nil)

    A flat fee charged per transaction, in USD. Ranges from 0 to 50. Null if no fixe

  • notes (String, nil)

    Internal notes about this fee markup, visible only to administrators. Null if no

  • percentage_fee (Float, nil)

    A percentage-based fee charged per transaction. Ranges from 0 to 25. Null if no

  • updated_at (Time)

    The datetime the fee markup was last updated.



# File 'lib/whop_sdk/models/fee_markup_create_response.rb', line 52

Instance Attribute Details

#created_atTime

The datetime the fee markup was created.

Returns:

  • (Time)


17
# File 'lib/whop_sdk/models/fee_markup_create_response.rb', line 17

required :created_at, Time

#fee_typeSymbol, WhopSDK::Models::FeeMarkupType

The category of fee this markup applies to.

Returns:



23
# File 'lib/whop_sdk/models/fee_markup_create_response.rb', line 23

required :fee_type, enum: -> { WhopSDK::FeeMarkupType }

#fixed_fee_usdFloat?

A flat fee charged per transaction, in USD. Ranges from 0 to 50. Null if no fixed fee is configured.

Returns:

  • (Float, nil)


30
# File 'lib/whop_sdk/models/fee_markup_create_response.rb', line 30

required :fixed_fee_usd, Float, nil?: true

#idString

The unique identifier for the fee markup.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/fee_markup_create_response.rb', line 11

required :id, String

#notesString?

Internal notes about this fee markup, visible only to administrators. Null if no notes have been added.

Returns:

  • (String, nil)


37
# File 'lib/whop_sdk/models/fee_markup_create_response.rb', line 37

required :notes, String, nil?: true

#percentage_feeFloat?

A percentage-based fee charged per transaction. Ranges from 0 to 25. Null if no percentage fee is configured.

Returns:

  • (Float, nil)


44
# File 'lib/whop_sdk/models/fee_markup_create_response.rb', line 44

required :percentage_fee, Float, nil?: true

#updated_atTime

The datetime the fee markup was last updated.

Returns:

  • (Time)


50
# File 'lib/whop_sdk/models/fee_markup_create_response.rb', line 50

required :updated_at, Time