Class: WhopSDK::Models::FileCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::FileCreateResponse
- Defined in:
- lib/whop_sdk/models/file_create_response.rb
Overview
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
-
#filename ⇒ String?
The original filename of the uploaded file, including its file extension.
-
#id ⇒ String
The unique identifier for the file.
-
#size ⇒ String?
The file size in bytes.
-
#upload_headers ⇒ Hash{Symbol=>Object}?
Headers to include in the upload request.
-
#upload_status ⇒ Symbol, WhopSDK::Models::UploadStatus
The current upload status of the file (e.g., pending, ready).
-
#upload_url ⇒ String?
The presigned URL to upload the file contents to.
-
#url ⇒ String?
The CDN URL for accessing the file.
Instance Method Summary collapse
-
#initialize(id:, content_type:, filename:, size:, upload_headers:, upload_status:, upload_url:, url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see FileCreateResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, content_type:, filename:, size:, upload_headers:, upload_status:, upload_url:, url:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::FileCreateResponse for more details.
A file that has been uploaded or is pending upload.
|
|
# File 'lib/whop_sdk/models/file_create_response.rb', line 57
|
Instance Attribute Details
#content_type ⇒ String?
The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
17 |
# File 'lib/whop_sdk/models/file_create_response.rb', line 17 required :content_type, String, nil?: true |
#filename ⇒ String?
The original filename of the uploaded file, including its file extension.
23 |
# File 'lib/whop_sdk/models/file_create_response.rb', line 23 required :filename, String, nil?: true |
#id ⇒ String
The unique identifier for the file.
11 |
# File 'lib/whop_sdk/models/file_create_response.rb', line 11 required :id, String |
#size ⇒ String?
The file size in bytes. Null if the file has not finished uploading.
29 |
# File 'lib/whop_sdk/models/file_create_response.rb', line 29 required :size, String, nil?: true |
#upload_headers ⇒ Hash{Symbol=>Object}?
Headers to include in the upload request. Only present in the response from the create mutation.
36 |
# File 'lib/whop_sdk/models/file_create_response.rb', line 36 required :upload_headers, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#upload_status ⇒ Symbol, WhopSDK::Models::UploadStatus
The current upload status of the file (e.g., pending, ready).
42 |
# File 'lib/whop_sdk/models/file_create_response.rb', line 42 required :upload_status, enum: -> { WhopSDK::UploadStatus } |
#upload_url ⇒ String?
The presigned URL to upload the file contents to. Only present in the response from the create mutation.
49 |
# File 'lib/whop_sdk/models/file_create_response.rb', line 49 required :upload_url, String, nil?: true |
#url ⇒ String?
The CDN URL for accessing the file. Null if the file has not finished uploading.
55 |
# File 'lib/whop_sdk/models/file_create_response.rb', line 55 required :url, String, nil?: true |