Class: WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/financial_activity_list_response.rb,
sig/whop_sdk/models/financial_activity_list_response.rbs

Defined Under Namespace

Modules: Object

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, authorized_at:, card_id:, cashback_usd:, declined_reason:, local_amount:, local_currency:, merchant_category:, merchant_icon_url:, merchant_name:, object:, posted_at:, status:, usd_amount:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6 for more details.

Parameters:

  • id (String)

    Card transaction ID.

  • authorized_at (Time, nil)

    ISO 8601 timestamp the transaction was authorized.

  • card_id (String, nil)

    Identifier of the card that the transaction was charged to.

  • cashback_usd (String, nil)

    Cashback earned on this transaction as a USD decimal string. Zero for declined o

  • declined_reason (String, nil)

    Reason the transaction was declined (when status is declined).

  • local_amount (String, nil)

    Amount the merchant charged in their local currency, as a decimal string. Pair w

  • local_currency (String, nil)

    ISO 4217 currency code of the merchant-charged amount in local_amount.

  • merchant_category (String, nil)

    Merchant category.

  • merchant_icon_url (String, nil)

    Merchant icon URL.

  • merchant_name (String, nil)

    Merchant display name.

  • object (Symbol, WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6::Object)
  • posted_at (Time, nil)

    ISO 8601 timestamp the transaction was settled by the card network.

  • status (String, nil)

    Current card transaction status.

  • usd_amount (String, nil)

    The processor-settled USD amount as a decimal string. The ledger's USDT leg is p



# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 793

Instance Attribute Details

#authorized_atTime?

ISO 8601 timestamp the transaction was authorized.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


716
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 716

required :authorized_at, Time, nil?: true

#card_idString?

Identifier of the card that the transaction was charged to.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


722
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 722

required :card_id, String, nil?: true

#cashback_usdString?

Cashback earned on this transaction as a USD decimal string. Zero for declined or ineligible transactions; null when cashback has not been computed yet.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


729
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 729

required :cashback_usd, String, nil?: true

#declined_reasonString?

Reason the transaction was declined (when status is declined).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


735
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 735

required :declined_reason, String, nil?: true

#idString

Card transaction ID.

Parameters:

  • value (String)

Returns:

  • (String)


710
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 710

required :id, String

#local_amountString?

Amount the merchant charged in their local currency, as a decimal string. Pair with local_currency.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


742
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 742

required :local_amount, String, nil?: true

#local_currencyString?

ISO 4217 currency code of the merchant-charged amount in local_amount.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


748
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 748

required :local_currency, String, nil?: true

#merchant_categoryString?

Merchant category.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


754
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 754

required :merchant_category, String, nil?: true

#merchant_icon_urlString?

Merchant icon URL.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


760
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 760

required :merchant_icon_url, String, nil?: true

#merchant_nameString?

Merchant display name.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


766
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 766

required :merchant_name, String, nil?: true

#objectSymbol, WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6::Object

Parameters:

  • value (WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6::object)

Returns:



771
772
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 771

required :object,
enum: -> { WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6::Object }

#posted_atTime?

ISO 8601 timestamp the transaction was settled by the card network.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


778
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 778

required :posted_at, Time, nil?: true

#statusString?

Current card transaction status.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


784
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 784

required :status, String, nil?: true

#usd_amountString?

The processor-settled USD amount as a decimal string. The ledger's USDT leg is posted 1:1 from this value.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


791
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 791

required :usd_amount, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


652
# File 'sig/whop_sdk/models/financial_activity_list_response.rbs', line 652

def to_hash: -> {