Class: WhopSDK::Models::FinancialActivityListResponse::Data::Source

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/financial_activity_list_response.rb,
sig/whop_sdk/models/financial_activity_list_response.rbs

Overview

See Also:

  • WhopSDK::Models::FinancialActivityListResponse::Data#source

Defined Under Namespace

Classes: PayoutDestination

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, object:, amount_float: nil, chain: nil, claim_url: nil, created_at: nil, estimated_arrival: nil, from_amount: nil, from_currency: nil, payer_name: nil, payout_destination: nil, payout_token_nickname: nil, reason: nil, sender_address: nil, status: nil, to_amount: nil, to_currency: nil, tx_hash: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::FinancialActivityListResponse::Data::Source for more details.

Source of this ledger activity.

Parameters:

  • id (String)
  • object (String)
  • amount_float (Float, nil) (defaults to: nil)

    Withdrawal amount as a decimal number in the destination currency (withdrawal so

  • chain (String, nil) (defaults to: nil)

    Chain the deposit landed on, for example plasma (onchain_transaction sources onl

  • claim_url (String, nil) (defaults to: nil)

    Public claim URL for the airdrop link (airdrop_link sources only).

  • created_at (Time, nil) (defaults to: nil)

    Withdrawal creation time as an ISO 8601 timestamp (withdrawal sources only; requ

  • estimated_arrival (Time, nil) (defaults to: nil)

    Estimated arrival as an ISO 8601 timestamp (withdrawal sources only; requires pa

  • from_amount (String, nil) (defaults to: nil)

    Amount converted out of from_currency as a decimal string (swap sources only).

  • from_currency (String, nil) (defaults to: nil)

    Lowercase currency code converted from (swap sources only).

  • payer_name (String, nil) (defaults to: nil)

    Name of the entity processing the payout (withdrawal sources only; requires payo

  • payout_destination (WhopSDK::Models::FinancialActivityListResponse::Data::Source::PayoutDestination, nil) (defaults to: nil)

    Payout destination display info (withdrawal sources only).

  • payout_token_nickname (String, nil) (defaults to: nil)

    Saved payout destination nickname (withdrawal sources only).

  • reason (String, nil) (defaults to: nil)

    Transfer reason on transfer sources, for example pool_top_up or bounty_return.

  • sender_address (String, nil) (defaults to: nil)

    Sender wallet address or onramp provider identifier (onchain_transaction sources

  • status (String, nil) (defaults to: nil)

    Lifecycle status. On withdrawal sources this is the withdrawal status (requires

  • to_amount (String, nil) (defaults to: nil)

    Amount received in to_currency as a decimal string (swap sources only).

  • to_currency (String, nil) (defaults to: nil)

    Lowercase currency code converted to (swap sources only).

  • tx_hash (String, nil) (defaults to: nil)

    On-chain transaction hash (onchain_transaction and swap sources only).



# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 960

Instance Attribute Details

#amount_floatFloat?

Withdrawal amount as a decimal number in the destination currency (withdrawal sources only; requires payout:withdrawal:read).

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


858
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 858

optional :amount_float, Float, nil?: true

#chainString?

Chain the deposit landed on, for example plasma (onchain_transaction sources only).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


865
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 865

optional :chain, String, nil?: true

#claim_urlString?

Public claim URL for the airdrop link (airdrop_link sources only).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


871
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 871

optional :claim_url, String, nil?: true

#created_atTime?

Withdrawal creation time as an ISO 8601 timestamp (withdrawal sources only; requires payout:withdrawal:read).

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


878
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 878

optional :created_at, Time, nil?: true

#estimated_arrivalTime?

Estimated arrival as an ISO 8601 timestamp (withdrawal sources only; requires payout:withdrawal:read).

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


885
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 885

optional :estimated_arrival, Time, nil?: true

#from_amountString?

Amount converted out of from_currency as a decimal string (swap sources only).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


891
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 891

optional :from_amount, String, nil?: true

#from_currencyString?

Lowercase currency code converted from (swap sources only).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


897
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 897

optional :from_currency, String, nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


846
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 846

required :id, String

#objectString

Parameters:

  • value (String)

Returns:

  • (String)


851
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 851

required :object, String

#payer_nameString?

Name of the entity processing the payout (withdrawal sources only; requires payout:withdrawal:read).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


904
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 904

optional :payer_name, String, nil?: true

#payout_destinationWhopSDK::Models::FinancialActivityListResponse::Data::Source::PayoutDestination?

Payout destination display info (withdrawal sources only).



910
911
912
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 910

optional :payout_destination,
-> { WhopSDK::Models::FinancialActivityListResponse::Data::Source::PayoutDestination },
nil?: true

#payout_token_nicknameString?

Saved payout destination nickname (withdrawal sources only).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


918
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 918

optional :payout_token_nickname, String, nil?: true

#reasonString?

Transfer reason on transfer sources, for example pool_top_up or bounty_return.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


924
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 924

optional :reason, String, nil?: true

#sender_addressString?

Sender wallet address or onramp provider identifier (onchain_transaction sources only).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


931
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 931

optional :sender_address, String, nil?: true

#statusString?

Lifecycle status. On withdrawal sources this is the withdrawal status (requires payout:withdrawal:read); on airdrop_link sources it is the claim-link status (ungated); on payment and top-up sources it is the friendly payment status such as succeeded/pending/failed (ungated).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


940
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 940

optional :status, String, nil?: true

#to_amountString?

Amount received in to_currency as a decimal string (swap sources only).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


946
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 946

optional :to_amount, String, nil?: true

#to_currencyString?

Lowercase currency code converted to (swap sources only).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


952
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 952

optional :to_currency, String, nil?: true

#tx_hashString?

On-chain transaction hash (onchain_transaction and swap sources only).

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


958
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 958

optional :tx_hash, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


763
# File 'sig/whop_sdk/models/financial_activity_list_response.rbs', line 763

def to_hash: -> {