Class: WhopSDK::Models::Forum
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Forum
- Defined in:
- lib/whop_sdk/models/forum.rb
Defined Under Namespace
Classes: Experience
Instance Attribute Summary collapse
-
#email_notification_preference ⇒ Symbol, WhopSDK::Models::EmailNotificationPreferences
The email notification setting that controls which posts trigger email alerts.
-
#experience ⇒ WhopSDK::Models::Forum::Experience
The parent experience that this forum belongs to.
-
#id ⇒ String
The unique identifier for the entity.
-
#who_can_comment ⇒ Symbol, WhopSDK::Models::WhoCanCommentTypes
The permission level controlling who can comment on posts.
-
#who_can_post ⇒ Symbol, WhopSDK::Models::WhoCanPostTypes
The permission level controlling who can create new posts.
Instance Method Summary collapse
-
#initialize(id:, email_notification_preference:, experience:, who_can_comment:, who_can_post:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Forum for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, email_notification_preference:, experience:, who_can_comment:, who_can_post:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Forum for more details.
A discussion forum where members can create posts, comment, and react, belonging to an experience.
|
|
# File 'lib/whop_sdk/models/forum.rb', line 39
|
Instance Attribute Details
#email_notification_preference ⇒ Symbol, WhopSDK::Models::EmailNotificationPreferences
The email notification setting that controls which posts trigger email alerts. One of: all_admin_posts, only_weekly_summary, none.
17 |
# File 'lib/whop_sdk/models/forum.rb', line 17 required :email_notification_preference, enum: -> { WhopSDK::EmailNotificationPreferences } |
#experience ⇒ WhopSDK::Models::Forum::Experience
The parent experience that this forum belongs to.
23 |
# File 'lib/whop_sdk/models/forum.rb', line 23 required :experience, -> { WhopSDK::Forum::Experience } |
#id ⇒ String
The unique identifier for the entity
10 |
# File 'lib/whop_sdk/models/forum.rb', line 10 required :id, String |
#who_can_comment ⇒ Symbol, WhopSDK::Models::WhoCanCommentTypes
The permission level controlling who can comment on posts. One of: everyone, admins.
30 |
# File 'lib/whop_sdk/models/forum.rb', line 30 required :who_can_comment, enum: -> { WhopSDK::WhoCanCommentTypes } |
#who_can_post ⇒ Symbol, WhopSDK::Models::WhoCanPostTypes
The permission level controlling who can create new posts. One of: everyone, admins.
37 |
# File 'lib/whop_sdk/models/forum.rb', line 37 required :who_can_post, enum: -> { WhopSDK::WhoCanPostTypes } |