Class: WhopSDK::Models::ForumListResponse::Experience
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ForumListResponse::Experience
- Defined in:
- lib/whop_sdk/models/forum_list_response.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the experience.
-
#name ⇒ String
The display name of this experience shown to users in the product navigation.
Instance Method Summary collapse
-
#initialize(id:, name:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Experience for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ForumListResponse::Experience for more details.
The parent experience that this forum belongs to.
|
|
# File 'lib/whop_sdk/models/forum_list_response.rb', line 72
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the experience.
63 |
# File 'lib/whop_sdk/models/forum_list_response.rb', line 63 required :id, String |
#name ⇒ String
The display name of this experience shown to users in the product navigation. Maximum 255 characters.
70 |
# File 'lib/whop_sdk/models/forum_list_response.rb', line 70 required :name, String |