Class: WhopSDK::Models::ForumPostCreateParams::Attachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/forum_post_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(experience_id: , attachments: nil, content: nil, is_mention: nil, parent_id: nil, paywall_amount: nil, paywall_currency: nil, pinned: nil, poll: nil, title: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ForumPostCreateParams for more details.

Parameters:

  • experience_id (String) (defaults to: )

    The experience to create this post in

  • attachments (Array<WhopSDK::Models::ForumPostCreateParams::Attachment>, nil) (defaults to: nil)

    The attachments for this post

  • content (String, nil) (defaults to: nil)

    This is the main body of the post in Markdown format. Hidden if paywalled and us

  • is_mention (Boolean, nil) (defaults to: nil)

    This is used to determine if the post should be sent as a ‘mention’ notification

  • parent_id (String, nil) (defaults to: nil)

    The ID of the parent post. Set it to the ID of the post you want to comment on o

  • paywall_amount (Float, nil) (defaults to: nil)

    The amount to paywall this post by. A paywalled post requires the user to purcha

  • paywall_currency (Symbol, WhopSDK::Models::Currency, nil) (defaults to: nil)

    The available currencies on the platform

  • pinned (Boolean, nil) (defaults to: nil)

    Whether the post should be pinned

  • poll (WhopSDK::Models::ForumPostCreateParams::Poll, nil) (defaults to: nil)

    The poll for this post

  • title (String, nil) (defaults to: nil)

    The title of the post. Only visible if paywalled.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 103

class Attachment < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing attachment object. Use this when updating a resource and
  #   keeping a subset of the attachments. Don't use this unless you know what you're
  #   doing.
  #
  #   @return [String, nil]
  optional :id, String, nil?: true

  # @!attribute direct_upload_id
  #   This ID should be used the first time you upload an attachment. It is the ID of
  #   the direct upload that was created when uploading the file to S3 via the
  #   mediaDirectUpload mutation.
  #
  #   @return [String, nil]
  optional :direct_upload_id, String, nil?: true

  # @!method initialize(id: nil, direct_upload_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::ForumPostCreateParams::Attachment} for more details.
  #
  #   Input for an attachment
  #
  #   @param id [String, nil] The ID of an existing attachment object. Use this when updating a resource and k
  #
  #   @param direct_upload_id [String, nil] This ID should be used the first time you upload an attachment. It is the ID of
end

Instance Attribute Details

#direct_upload_idString?

This ID should be used the first time you upload an attachment. It is the ID of the direct upload that was created when uploading the file to S3 via the mediaDirectUpload mutation.

Returns:

  • (String, nil)


118
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 118

optional :direct_upload_id, String, nil?: true

#idString?

The ID of an existing attachment object. Use this when updating a resource and keeping a subset of the attachments. Don’t use this unless you know what you’re doing.

Returns:

  • (String, nil)


110
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 110

optional :id, String, nil?: true