Class: WhopSDK::Models::ForumPostListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/forum_post_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(experience_id: , after: nil, before: nil, first: nil, last: nil, parent_id: nil, pinned: nil, request_options: {}) ⇒ Object

Parameters:

  • experience_id (String) (defaults to: )

    The ID of the experience to list forum posts for

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • parent_id (String, nil) (defaults to: nil)

    The ID of the parent post to list forum post comments for

  • pinned (Boolean, nil) (defaults to: nil)

    Set to true to only return pinned posts

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/forum_post_list_params.rb', line 52

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/forum_post_list_params.rb', line 20

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/forum_post_list_params.rb', line 26

optional :before, String, nil?: true

#experience_idString

The ID of the experience to list forum posts for

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/forum_post_list_params.rb', line 14

required :experience_id, String

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


32
# File 'lib/whop_sdk/models/forum_post_list_params.rb', line 32

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


38
# File 'lib/whop_sdk/models/forum_post_list_params.rb', line 38

optional :last, Integer, nil?: true

#parent_idString?

The ID of the parent post to list forum post comments for

Returns:

  • (String, nil)


44
# File 'lib/whop_sdk/models/forum_post_list_params.rb', line 44

optional :parent_id, String, nil?: true

#pinnedBoolean?

Set to true to only return pinned posts

Returns:

  • (Boolean, nil)


50
# File 'lib/whop_sdk/models/forum_post_list_params.rb', line 50

optional :pinned, WhopSDK::Internal::Type::Boolean, nil?: true