Class: WhopSDK::Models::ForumPostListResponse::Attachment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ForumPostListResponse::Attachment
- Defined in:
- lib/whop_sdk/models/forum_post_list_response.rb
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
-
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client.
Instance Method Summary collapse
-
#initialize(id:, attachments:, comment_count:, content:, created_at:, is_edited:, is_pinned:, is_poster_admin:, like_count:, parent_id:, title:, updated_at:, user:, view_count:) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhopSDK::Models::ForumPostListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, attachments:, comment_count:, content:, created_at:, is_edited:, is_pinned:, is_poster_admin:, like_count:, parent_id:, title:, updated_at:, user:, view_count:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ForumPostListResponse for more details.
A post or comment in a forum feed, supporting rich text, attachments, polls, and reactions.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 132 class Attachment < WhopSDK::Internal::Type::BaseModel # @!attribute id # Represents a unique identifier that is Base64 obfuscated. It is often used to # refetch an object or as key for a cache. The ID type appears in a JSON response # as a String; however, it is not intended to be human-readable. When expected as # an input type, any string (such as `"VXNlci0xMA=="`) or integer (such as `4`) # input value will be accepted as an ID. # # @return [String] required :id, String # @!attribute content_type # The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg). # # @return [String, nil] required :content_type, String, nil?: true # @!attribute filename # The original filename of the uploaded attachment, including its file extension. # # @return [String, nil] required :filename, String, nil?: true # @!attribute url # A pre-optimized URL for rendering this attachment on the client. This should be # used for displaying attachments in apps. # # @return [String, nil] required :url, String, nil?: true # @!method initialize(id:, content_type:, filename:, url:) # Some parameter documentations has been truncated, see # {WhopSDK::Models::ForumPostListResponse::Attachment} for more details. # # Represents an image attachment # # @param id [String] Represents a unique identifier that is Base64 obfuscated. It is often used to re # # @param content_type [String, nil] The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg). # # @param filename [String, nil] The original filename of the uploaded attachment, including its file extension. # # @param url [String, nil] A pre-optimized URL for rendering this attachment on the client. This should be end |
Instance Attribute Details
#content_type ⇒ String?
The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
147 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 147 required :content_type, String, nil?: true |
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
153 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 153 required :filename, String, nil?: true |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.
141 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 141 required :id, String |
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client. This should be used for displaying attachments in apps.
160 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 160 required :url, String, nil?: true |