Class: WhopSDK::Models::ForumPostUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/forum_post_update_params.rb

Overview

Defined Under Namespace

Classes: Attachment

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#attachmentsArray<WhopSDK::Models::ForumPostUpdateParams::Attachment>?

A replacement list of file attachments for this post, such as images or videos.



19
20
21
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 19

optional :attachments,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::ForumPostUpdateParams::Attachment] },
nil?: true

#contentString?

The updated body of the post in Markdown format. For example, ‘Check out this update’. Hidden if the post is paywalled and the viewer has not purchased access.

Returns:

  • (String, nil)


29
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 29

optional :content, String, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 13

required :id, String

#is_pinnedBoolean?

Whether this post should be pinned to the top of the forum. Only top-level posts can be pinned, not comments.

Returns:

  • (Boolean, nil)


36
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 36

optional :is_pinned, WhopSDK::Internal::Type::Boolean, nil?: true

#titleString?

The updated title of the post, displayed prominently at the top. Required for paywalled posts as it remains visible to non-purchasers.

Returns:

  • (String, nil)


43
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 43

optional :title, String, nil?: true

#visibilitySymbol, ...

The visibility types for forum posts



49
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 49

optional :visibility, enum: -> { WhopSDK::ForumPostVisibilityType }, nil?: true