Class: WhopSDK::Models::ForumPostUpdateParams::Attachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/forum_post_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, direct_upload_id: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ForumPostUpdateParams::Attachment for more details.

Input for an attachment

Parameters:

  • id (String, nil) (defaults to: nil)

    The ID of an existing attachment object. Use this when updating a resource and k

  • direct_upload_id (String, nil) (defaults to: nil)

    This ID should be used the first time you upload an attachment. It is the ID of



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 51

class Attachment < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing attachment object. Use this when updating a resource and
  #   keeping a subset of the attachments. Don't use this unless you know what you're
  #   doing.
  #
  #   @return [String, nil]
  optional :id, String, nil?: true

  # @!attribute direct_upload_id
  #   This ID should be used the first time you upload an attachment. It is the ID of
  #   the direct upload that was created when uploading the file to S3 via the
  #   mediaDirectUpload mutation.
  #
  #   @return [String, nil]
  optional :direct_upload_id, String, nil?: true

  # @!method initialize(id: nil, direct_upload_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::ForumPostUpdateParams::Attachment} for more details.
  #
  #   Input for an attachment
  #
  #   @param id [String, nil] The ID of an existing attachment object. Use this when updating a resource and k
  #
  #   @param direct_upload_id [String, nil] This ID should be used the first time you upload an attachment. It is the ID of
end

Instance Attribute Details

#direct_upload_idString?

This ID should be used the first time you upload an attachment. It is the ID of the direct upload that was created when uploading the file to S3 via the mediaDirectUpload mutation.

Returns:

  • (String, nil)


66
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 66

optional :direct_upload_id, String, nil?: true

#idString?

The ID of an existing attachment object. Use this when updating a resource and keeping a subset of the attachments. Don’t use this unless you know what you’re doing.

Returns:

  • (String, nil)


58
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 58

optional :id, String, nil?: true