Module: WhopSDK::Models::FriendlyReceiptStatus

Extended by:
Internal::Type::Enum
Defined in:
lib/whop_sdk/models/friendly_receipt_status.rb

Overview

The friendly status of a payment. This is a derived status that provides a human-readable summary of the payment state, combining the underlying status and substatus fields.

Constant Summary collapse

SUCCEEDED =
:succeeded
PENDING =
:pending
FAILED =
:failed
PAST_DUE =
:past_due
CANCELED =
:canceled
PRICE_TOO_LOW =
:price_too_low
UNCOLLECTIBLE =
:uncollectible
REFUNDED =
:refunded
AUTO_REFUNDED =
:auto_refunded
PARTIALLY_REFUNDED =
:partially_refunded
DISPUTE_WARNING =
:dispute_warning
DISPUTE_NEEDS_RESPONSE =
:dispute_needs_response
DISPUTE_WARNING_NEEDS_RESPONSE =
:dispute_warning_needs_response
RESOLUTION_NEEDS_RESPONSE =
:resolution_needs_response
DISPUTE_UNDER_REVIEW =
:dispute_under_review
DISPUTE_WARNING_UNDER_REVIEW =
:dispute_warning_under_review
RESOLUTION_UNDER_REVIEW =
:resolution_under_review
DISPUTE_WON =
:dispute_won
DISPUTE_WARNING_CLOSED =
:dispute_warning_closed
RESOLUTION_WON =
:resolution_won
DISPUTE_LOST =
:dispute_lost
DISPUTE_CLOSED =
:dispute_closed
RESOLUTION_LOST =
:resolution_lost
DRAFTED =
:drafted
INCOMPLETE =
:incomplete
UNRESOLVED =
:unresolved
OPEN_DISPUTE =
:open_dispute
OPEN_RESOLUTION =
:open_resolution

Class Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/friendly_receipt_status.rb', line 40