Class: WhopSDK::Models::IdentityProfileNeedsActionWebhookEvent::Data::Verification
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::IdentityProfileNeedsActionWebhookEvent::Data::Verification
- Defined in:
- lib/whop_sdk/models/identity_profile_needs_action_webhook_event.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Time
When the verification record was created.
-
#id ⇒ String
The numeric id of the verification record.
-
#last_error_code ⇒ Symbol, ...
An error code for a verification attempt.
-
#last_error_reason ⇒ String?
A human-readable explanation of the most recent verification error.
-
#session_url ⇒ String?
A URL the user can visit to complete the verification process.
-
#status ⇒ Symbol, WhopSDK::Models::VerificationStatus
The current status of this verification session.
Instance Method Summary collapse
-
#initialize(id:, created_at:, last_error_code:, last_error_reason:, session_url:, status:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Verification for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, last_error_code:, last_error_reason:, session_url:, status:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::IdentityProfileNeedsActionWebhookEvent::Data::Verification for more details.
An identity verification session used to confirm a person or entity’s identity for payout account eligibility.
|
|
# File 'lib/whop_sdk/models/identity_profile_needs_action_webhook_event.rb', line 409
|
Instance Attribute Details
#created_at ⇒ Time
When the verification record was created.
381 |
# File 'lib/whop_sdk/models/identity_profile_needs_action_webhook_event.rb', line 381 required :created_at, Time |
#id ⇒ String
The numeric id of the verification record.
375 |
# File 'lib/whop_sdk/models/identity_profile_needs_action_webhook_event.rb', line 375 required :id, String |
#last_error_code ⇒ Symbol, ...
An error code for a verification attempt.
387 |
# File 'lib/whop_sdk/models/identity_profile_needs_action_webhook_event.rb', line 387 required :last_error_code, enum: -> { WhopSDK::VerificationErrorCode }, nil?: true |
#last_error_reason ⇒ String?
A human-readable explanation of the most recent verification error. Null if no error has occurred.
394 |
# File 'lib/whop_sdk/models/identity_profile_needs_action_webhook_event.rb', line 394 required :last_error_reason, String, nil?: true |
#session_url ⇒ String?
A URL the user can visit to complete the verification process. Null if the session does not require user interaction.
401 |
# File 'lib/whop_sdk/models/identity_profile_needs_action_webhook_event.rb', line 401 required :session_url, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::VerificationStatus
The current status of this verification session.
407 |
# File 'lib/whop_sdk/models/identity_profile_needs_action_webhook_event.rb', line 407 required :status, enum: -> { WhopSDK::VerificationStatus } |