Class: WhopSDK::Models::Invoice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Invoice
- Defined in:
- lib/whop_sdk/models/invoice.rb
Defined Under Namespace
Classes: CurrentPlan, User
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The datetime the invoice was created.
-
#current_plan ⇒ WhopSDK::Models::Invoice::CurrentPlan
The plan that this invoice charges for.
-
#due_date ⇒ Time?
The deadline by which payment is expected.
-
#email_address ⇒ String?
The email address of the customer this invoice is addressed to.
-
#fetch_invoice_token ⇒ String
A signed token that allows fetching invoice data publicly without authentication.
-
#id ⇒ String
The unique identifier for the invoice.
-
#number ⇒ String
The sequential invoice number for display purposes.
-
#status ⇒ Symbol, WhopSDK::Models::InvoiceStatus
The current payment status of the invoice, such as draft, open, paid, or void.
-
#user ⇒ WhopSDK::Models::Invoice::User?
The user this invoice is addressed to.
Instance Method Summary collapse
-
#initialize(id:, currency:, formatted_price:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CurrentPlan for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, currency:, formatted_price:) ⇒ Object
Some parameter documentations has been truncated, see CurrentPlan for more details.
The plan that this invoice charges for.
|
|
# File 'lib/whop_sdk/models/invoice.rb', line 64
|
Instance Attribute Details
#created_at ⇒ Time
The datetime the invoice was created.
16 |
# File 'lib/whop_sdk/models/invoice.rb', line 16 required :created_at, Time |
#current_plan ⇒ WhopSDK::Models::Invoice::CurrentPlan
The plan that this invoice charges for.
22 |
# File 'lib/whop_sdk/models/invoice.rb', line 22 required :current_plan, -> { WhopSDK::Invoice::CurrentPlan } |
#due_date ⇒ Time?
The deadline by which payment is expected. Null if the invoice is collected automatically.
29 |
# File 'lib/whop_sdk/models/invoice.rb', line 29 required :due_date, Time, nil?: true |
#email_address ⇒ String?
The email address of the customer this invoice is addressed to. Null if no email is on file.
36 |
# File 'lib/whop_sdk/models/invoice.rb', line 36 required :email_address, String, nil?: true |
#fetch_invoice_token ⇒ String
A signed token that allows fetching invoice data publicly without authentication.
43 |
# File 'lib/whop_sdk/models/invoice.rb', line 43 required :fetch_invoice_token, String |
#id ⇒ String
The unique identifier for the invoice.
10 |
# File 'lib/whop_sdk/models/invoice.rb', line 10 required :id, String |
#number ⇒ String
The sequential invoice number for display purposes.
49 |
# File 'lib/whop_sdk/models/invoice.rb', line 49 required :number, String |
#status ⇒ Symbol, WhopSDK::Models::InvoiceStatus
The current payment status of the invoice, such as draft, open, paid, or void.
55 |
# File 'lib/whop_sdk/models/invoice.rb', line 55 required :status, enum: -> { WhopSDK::InvoiceStatus } |
#user ⇒ WhopSDK::Models::Invoice::User?
The user this invoice is addressed to. Null if the user account has been removed.
62 |
# File 'lib/whop_sdk/models/invoice.rb', line 62 required :user, -> { WhopSDK::Invoice::User }, nil?: true |