Class: WhopSDK::Models::Invoice::CurrentPlan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Invoice::CurrentPlan
- Defined in:
- lib/whop_sdk/models/invoice.rb,
sig/whop_sdk/models/invoice.rbs
Overview
Instance Attribute Summary collapse
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency used for all prices on this plan (e.g., 'usd', 'eur').
-
#formatted_price ⇒ String
The formatted price (including currency) for the plan.
-
#id ⇒ String
The unique identifier for the plan.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
73 |
# File 'sig/whop_sdk/models/invoice.rbs', line 73
def initialize: (
|
Instance Attribute Details
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency used for all prices on this plan (e.g., 'usd', 'eur'). All monetary amounts on the plan are denominated in this currency.
103 |
# File 'lib/whop_sdk/models/invoice.rb', line 103 required :currency, enum: -> { WhopSDK::Currency } |
#formatted_price ⇒ String
The formatted price (including currency) for the plan.
109 |
# File 'lib/whop_sdk/models/invoice.rb', line 109 required :formatted_price, String |
#id ⇒ String
The unique identifier for the plan.
96 |
# File 'lib/whop_sdk/models/invoice.rb', line 96 required :id, String |
Instance Method Details
#to_hash ⇒ {
79 |
# File 'sig/whop_sdk/models/invoice.rbs', line 79
def to_hash: -> {
|