Class: WhopSDK::Models::InvoiceCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/invoice_create_params.rb

Overview

Defined Under Namespace

Classes: Plan, Product

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object

Parameters:

  • name (String) (defaults to: )

    The name of the custom field.

  • id (String, nil) (defaults to: nil)

    The ID of the custom field (if being updated)

  • order (Integer, nil) (defaults to: nil)

    The order of the field.

  • placeholder (String, nil) (defaults to: nil)

    The placeholder value of the field.

  • required (Boolean, nil) (defaults to: nil)

    Whether or not the field is required.

  • field_type (Symbol, :text) (defaults to: :text)

    The type of the custom field.



# File 'lib/whop_sdk/models/invoice_create_params.rb', line 275

Instance Attribute Details

#charge_buyer_feeBoolean?

Whether or not to charge the customer a buyer fee.

Returns:

  • (Boolean, nil)


54
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 54

optional :charge_buyer_fee, WhopSDK::Internal::Type::Boolean, nil?: true

#collection_methodSymbol, WhopSDK::Models::CollectionMethod

The method of collection for this invoice. If using charge_automatically, you must provide a payment_token.



15
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 15

required :collection_method, enum: -> { WhopSDK::CollectionMethod }

#company_idString

The company ID to create this invoice for.

Returns:

  • (String)


21
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 21

required :company_id, String

#customer_nameString?

The name of the customer to create this invoice for. This is required if you want to create an invoice for a customer who does not have a member of your company yet.

Returns:

  • (String, nil)


62
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 62

optional :customer_name, String, nil?: true

#due_dateTime

The date the invoice is due, if applicable.

Returns:

  • (Time)


27
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 27

required :due_date, Time

#email_addressString

The email address to create this invoice for. This is required if you want to create an invoice for a user who does not have a member of your company yet.

Returns:

  • (String)


83
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 83

required :email_address, String

#member_idString

The member ID to create this invoice for. Include this if you want to create an invoice for an existing member. If you do not have a member ID, you must provide an email_address and customer_name.

Returns:

  • (String)


35
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 35

required :member_id, String

#payment_method_idString?

The payment method ID to use for this invoice. If using charge_automatically, you must provide a payment_method_id.

Returns:

  • (String, nil)


69
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 69

optional :payment_method_id, String, nil?: true

#payment_token_idString?

The payment token ID to use for this invoice. If using charge_automatically, you must provide a payment_token.

Returns:

  • (String, nil)


76
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 76

optional :payment_token_id, String, nil?: true

#planWhopSDK::Models::InvoiceCreateParams::Plan

The properties of the plan to create for this invoice.



41
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 41

required :plan, -> { WhopSDK::InvoiceCreateParams::Plan }

#productWhopSDK::Models::InvoiceCreateParams::Product

The properties of the product to create for this invoice. Include this if you want to create an invoice for a new product.



48
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 48

required :product, -> { WhopSDK::InvoiceCreateParams::Product }

#product_idString

The product ID to create this invoice for. Include this if you want to create an invoice for an existing product.

Returns:

  • (String)


90
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 90

required :product_id, String