Class: WhopSDK::Models::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Product
- Defined in:
- lib/whop_sdk/models/invoice_create_params.rb,
sig/whop_sdk/models/invoice_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
-
#title ⇒ String
The title of the product.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
299 |
# File 'sig/whop_sdk/models/invoice_create_params.rbs', line 299
def initialize: (
|
Instance Attribute Details
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
463 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 463 optional :product_tax_code_id, String, nil?: true |
#title ⇒ String
The title of the product.
457 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 457 required :title, String |
Instance Method Details
#to_hash ⇒ { title: String, product_tax_code_id: String? }
304 |
# File 'sig/whop_sdk/models/invoice_create_params.rbs', line 304
def to_hash: -> { title: String, product_tax_code_id: String? }
|