Class: WhopSDK::Models::InvoiceCreateParams::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::InvoiceCreateParams::Product
- Defined in:
- lib/whop_sdk/models/invoice_create_params.rb
Instance Attribute Summary collapse
-
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
-
#title ⇒ String
The title of the product.
Instance Method Summary collapse
-
#initialize(title: , product_tax_code_id: nil) ⇒ Object
constructor
The properties of the product to create for this invoice.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(title: , product_tax_code_id: nil) ⇒ Object
The properties of the product to create for this invoice. Include this if you want to create an invoice for a new product.
|
|
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 294
|
Instance Attribute Details
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
292 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 292 optional :product_tax_code_id, String, nil?: true |
#title ⇒ String
The title of the product.
286 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 286 required :title, String |