Class: WhopSDK::Models::InvoiceCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/invoice_create_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(checkout_job_id: , invoice: ) ⇒ Object

Autogenerated return type of CreateInvoice.

Parameters:

  • checkout_job_id (String, nil) (defaults to: )

    The ID of the checkout job that was created for this invoice.

  • invoice (WhopSDK::Models::Invoice) (defaults to: )

    The invoice that was created for this invoice.



# File 'lib/whop_sdk/models/invoice_create_response.rb', line 19

Instance Attribute Details

#checkout_job_idString?

The ID of the checkout job that was created for this invoice.

Returns:

  • (String, nil)


11
# File 'lib/whop_sdk/models/invoice_create_response.rb', line 11

required :checkout_job_id, String, nil?: true

#invoiceWhopSDK::Models::Invoice

The invoice that was created for this invoice.



17
# File 'lib/whop_sdk/models/invoice_create_response.rb', line 17

required :invoice, -> { WhopSDK::Invoice }