Class: WhopSDK::Models::InvoiceListItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/invoice_list_item.rb

Defined Under Namespace

Classes: CurrentPlan, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, currency:, formatted_price:) ⇒ Object

Some parameter documentations has been truncated, see CurrentPlan for more details.

The plan that this invoice charges for.

Parameters:

  • id (String)

    The unique identifier for the plan.

  • currency (Symbol, WhopSDK::Models::Currency)

    The currency used for all prices on this plan (e.g., ‘usd’, ‘eur’). All monetary

  • formatted_price (String)

    The formatted price (including currency) for the plan.



# File 'lib/whop_sdk/models/invoice_list_item.rb', line 64

Instance Attribute Details

#created_atTime

The datetime the invoice was created.

Returns:

  • (Time)


16
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 16

required :created_at, Time

#current_planWhopSDK::Models::InvoiceListItem::CurrentPlan

The plan that this invoice charges for.



22
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 22

required :current_plan, -> { WhopSDK::InvoiceListItem::CurrentPlan }

#due_dateTime?

The deadline by which payment is expected. Null if the invoice is collected automatically.

Returns:

  • (Time, nil)


29
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 29

required :due_date, Time, nil?: true

#email_addressString?

The email address of the customer this invoice is addressed to. Null if no email is on file.

Returns:

  • (String, nil)


36
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 36

required :email_address, String, nil?: true

#fetch_invoice_tokenString

A signed token that allows fetching invoice data publicly without authentication.

Returns:

  • (String)


43
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 43

required :fetch_invoice_token, String

#idString

The unique identifier for the invoice.

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 10

required :id, String

#numberString

The sequential invoice number for display purposes.

Returns:

  • (String)


49
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 49

required :number, String

#statusSymbol, WhopSDK::Models::InvoiceStatus

The current payment status of the invoice, such as draft, open, paid, or void.

Returns:



55
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 55

required :status, enum: -> { WhopSDK::InvoiceStatus }

#userWhopSDK::Models::InvoiceListItem::User?

The user this invoice is addressed to. Null if the user account has been removed.



62
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 62

required :user, -> { WhopSDK::InvoiceListItem::User }, nil?: true