Class: WhopSDK::Models::InvoiceListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::InvoiceListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/invoice_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#collection_methods ⇒ Array<Symbol, WhopSDK::Models::CollectionMethod>?
Filter invoices by their collection method.
-
#company_id ⇒ String
The ID of the company to list invoices for.
-
#created_after ⇒ Time?
The minimum creation date to filter by.
-
#created_before ⇒ Time?
The maximum creation date to filter by.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#order ⇒ Symbol, ...
Which columns can be used to sort.
-
#product_ids ⇒ Array<String>?
Return only invoices created for these specific product ids.
-
#statuses ⇒ Array<Symbol, WhopSDK::Models::InvoiceStatus>?
The statuses to filter the invoices by.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id: , after: nil, before: nil, collection_methods: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, product_ids: nil, statuses: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 84
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
20 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 20 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
26 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 26 optional :before, String, nil?: true |
#collection_methods ⇒ Array<Symbol, WhopSDK::Models::CollectionMethod>?
Filter invoices by their collection method
32 33 34 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 32 optional :collection_methods, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::CollectionMethod] }, nil?: true |
#company_id ⇒ String
The ID of the company to list invoices for
14 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 14 required :company_id, String |
#created_after ⇒ Time?
The minimum creation date to filter by
40 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 40 optional :created_after, Time, nil?: true |
#created_before ⇒ Time?
The maximum creation date to filter by
46 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 46 optional :created_before, Time, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
52 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 52 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
58 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 58 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
64 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 64 optional :last, Integer, nil?: true |
#order ⇒ Symbol, ...
Which columns can be used to sort.
70 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 70 optional :order, enum: -> { WhopSDK::InvoiceListParams::Order }, nil?: true |
#product_ids ⇒ Array<String>?
Return only invoices created for these specific product ids
76 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 76 optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#statuses ⇒ Array<Symbol, WhopSDK::Models::InvoiceStatus>?
The statuses to filter the invoices by
82 |
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 82 optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::InvoiceStatus] }, nil?: true |