Class: WhopSDK::Models::InvoicePastDueWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::InvoicePastDueWebhookEvent
- Defined in:
- lib/whop_sdk/models/invoice_past_due_webhook_event.rb
Instance Attribute Summary collapse
-
#api_version ⇒ Symbol, :v1
The API version for this webhook.
-
#company_id ⇒ String?
The company ID that this webhook event is associated with.
-
#data ⇒ WhopSDK::Models::Invoice
An invoice represents an itemized bill sent by a company to a customer for a specific product and plan, tracking the amount owed, due date, and payment status.
-
#id ⇒ String
A unique ID for every single webhook request.
-
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server.
-
#type ⇒ Symbol, :"invoice.past_due"
The webhook event type.
Instance Method Summary collapse
-
#initialize(id:, data:, timestamp:, company_id: nil, api_version: :v1, type: :"invoice.past_due") ⇒ Object
constructor
Some parameter documentations has been truncated, see InvoicePastDueWebhookEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, data:, timestamp:, company_id: nil, api_version: :v1, type: :"invoice.past_due") ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::InvoicePastDueWebhookEvent for more details.
|
|
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 44
|
Instance Attribute Details
#api_version ⇒ Symbol, :v1
The API version for this webhook
16 |
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 16 required :api_version, const: :v1 |
#company_id ⇒ String?
The company ID that this webhook event is associated with
42 |
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 42 optional :company_id, String, nil?: true |
#data ⇒ WhopSDK::Models::Invoice
An invoice represents an itemized bill sent by a company to a customer for a specific product and plan, tracking the amount owed, due date, and payment status.
24 |
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 24 required :data, -> { WhopSDK::Invoice } |
#id ⇒ String
A unique ID for every single webhook request
10 |
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 10 required :id, String |
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server
30 |
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 30 required :timestamp, Time |
#type ⇒ Symbol, :"invoice.past_due"
The webhook event type
36 |
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 36 required :type, const: :"invoice.past_due" |