Class: WhopSDK::Models::InvoiceUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/invoice_update_params.rb

Overview

Defined Under Namespace

Classes: BillingAddress, LineItem, Plan

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(label:, unit_price:, quantity: nil) ⇒ Object

Some parameter documentations has been truncated, see LineItem for more details.

A single line item to include on the invoice, with a label, quantity, and unit price.

Parameters:

  • label (String)

    The label or description for this line item.

  • unit_price (Float)

    The unit price for this line item. Provided as a number in the specified currenc

  • quantity (Float, nil) (defaults to: nil)

    The quantity of this line item. Defaults to 1.



# File 'lib/whop_sdk/models/invoice_update_params.rb', line 192

Instance Attribute Details

#automatically_finalizes_atTime?

The date and time when the invoice will be automatically finalized. For charge_automatically, triggers an automatic charge. For send_invoice, sends the invoice email at the specified time.

Returns:

  • (Time, nil)


21
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 21

optional :automatically_finalizes_at, Time, nil?: true

#billing_addressWhopSDK::Models::InvoiceUpdateParams::BillingAddress?

Inline billing address to create or update a mailing address for this invoice.



27
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 27

optional :billing_address, -> { WhopSDK::InvoiceUpdateParams::BillingAddress }, nil?: true

#charge_buyer_feeBoolean?

Whether to charge the customer a buyer fee on this invoice.

Returns:

  • (Boolean, nil)


33
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 33

optional :charge_buyer_fee, WhopSDK::Internal::Type::Boolean, nil?: true

#collection_methodSymbol, ...

The method of collection for an invoice.

Returns:



39
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 39

optional :collection_method, enum: -> { WhopSDK::CollectionMethod }, nil?: true

#customer_nameString?

The name of the customer.

Returns:

  • (String, nil)


45
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 45

optional :customer_name, String, nil?: true

#due_dateTime?

The date by which the invoice must be paid.

Returns:

  • (Time, nil)


51
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 51

optional :due_date, Time, nil?: true

#email_addressString?

The email address of the customer.

Returns:

  • (String, nil)


57
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 57

optional :email_address, String, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 13

required :id, String

#line_itemsArray<WhopSDK::Models::InvoiceUpdateParams::LineItem>?

Line items that break down the invoice total.



63
64
65
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 63

optional :line_items,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::InvoiceUpdateParams::LineItem] },
nil?: true

#mailing_address_idString?

The unique identifier of an existing mailing address to attach.

Returns:

  • (String, nil)


71
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 71

optional :mailing_address_id, String, nil?: true

#member_idString?

The unique identifier of a member to assign as the customer.

Returns:

  • (String, nil)


77
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 77

optional :member_id, String, nil?: true

#payment_method_idString?

The unique identifier of the payment method to charge.

Returns:

  • (String, nil)


83
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 83

optional :payment_method_id, String, nil?: true

#planWhopSDK::Models::InvoiceUpdateParams::Plan?

Updated plan attributes.



89
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 89

optional :plan, -> { WhopSDK::InvoiceUpdateParams::Plan }, nil?: true

#subscription_billing_anchor_atTime?

The date that defines when the subscription billing cycle should start.

Returns:

  • (Time, nil)


95
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 95

optional :subscription_billing_anchor_at, Time, nil?: true