Class: WhopSDK::Models::InvoiceUpdateParams::BillingAddress

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/invoice_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, automatically_finalizes_at: nil, billing_address: nil, charge_buyer_fee: nil, collection_method: nil, customer_name: nil, due_date: nil, email_address: nil, line_items: nil, mailing_address_id: nil, member_id: nil, payment_method_id: nil, plan: nil, subscription_billing_anchor_at: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::InvoiceUpdateParams for more details.

Parameters:

  • id (String)
  • automatically_finalizes_at (Time, nil) (defaults to: nil)

    The date and time when the invoice will be automatically finalized. For charge_a

  • billing_address (WhopSDK::Models::InvoiceUpdateParams::BillingAddress, nil) (defaults to: nil)

    Inline billing address to create or update a mailing address for this invoice.

  • charge_buyer_fee (Boolean, nil) (defaults to: nil)

    Whether to charge the customer a buyer fee on this invoice.

  • collection_method (Symbol, WhopSDK::Models::CollectionMethod, nil) (defaults to: nil)

    The method of collection for an invoice.

  • customer_name (String, nil) (defaults to: nil)

    The name of the customer.

  • due_date (Time, nil) (defaults to: nil)

    The date by which the invoice must be paid.

  • email_address (String, nil) (defaults to: nil)

    The email address of the customer.

  • line_items (Array<WhopSDK::Models::InvoiceUpdateParams::LineItem>, nil) (defaults to: nil)

    Line items that break down the invoice total.

  • mailing_address_id (String, nil) (defaults to: nil)

    The unique identifier of an existing mailing address to attach.

  • member_id (String, nil) (defaults to: nil)

    The unique identifier of a member to assign as the customer.

  • payment_method_id (String, nil) (defaults to: nil)

    The unique identifier of the payment method to charge.

  • plan (WhopSDK::Models::InvoiceUpdateParams::Plan, nil) (defaults to: nil)

    Updated plan attributes.

  • subscription_billing_anchor_at (Time, nil) (defaults to: nil)

    The date that defines when the subscription billing cycle should start.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 131

class BillingAddress < WhopSDK::Internal::Type::BaseModel
  # @!attribute city
  #   The city of the address.
  #
  #   @return [String, nil]
  optional :city, String, nil?: true

  # @!attribute country
  #   The country of the address.
  #
  #   @return [String, nil]
  optional :country, String, nil?: true

  # @!attribute line1
  #   The line 1 of the address.
  #
  #   @return [String, nil]
  optional :line1, String, nil?: true

  # @!attribute line2
  #   The line 2 of the address.
  #
  #   @return [String, nil]
  optional :line2, String, nil?: true

  # @!attribute name
  #   The name of the customer.
  #
  #   @return [String, nil]
  optional :name, String, nil?: true

  # @!attribute phone
  #   The phone number of the customer.
  #
  #   @return [String, nil]
  optional :phone, String, nil?: true

  # @!attribute postal_code
  #   The postal code of the address.
  #
  #   @return [String, nil]
  optional :postal_code, String, nil?: true

  # @!attribute state
  #   The state of the address.
  #
  #   @return [String, nil]
  optional :state, String, nil?: true

  # @!attribute tax_id_type
  #   The type of tax identifier
  #
  #   @return [Symbol, WhopSDK::Models::TaxIdentifierType, nil]
  optional :tax_id_type, enum: -> { WhopSDK::TaxIdentifierType }, nil?: true

  # @!attribute tax_id_value
  #   The value of the tax identifier.
  #
  #   @return [String, nil]
  optional :tax_id_value, String, nil?: true

  # @!method initialize(city: nil, country: nil, line1: nil, line2: nil, name: nil, phone: nil, postal_code: nil, state: nil, tax_id_type: nil, tax_id_value: nil)
  #   Inline billing address to create or update a mailing address for this invoice.
  #
  #   @param city [String, nil] The city of the address.
  #
  #   @param country [String, nil] The country of the address.
  #
  #   @param line1 [String, nil] The line 1 of the address.
  #
  #   @param line2 [String, nil] The line 2 of the address.
  #
  #   @param name [String, nil] The name of the customer.
  #
  #   @param phone [String, nil] The phone number of the customer.
  #
  #   @param postal_code [String, nil] The postal code of the address.
  #
  #   @param state [String, nil] The state of the address.
  #
  #   @param tax_id_type [Symbol, WhopSDK::Models::TaxIdentifierType, nil] The type of tax identifier
  #
  #   @param tax_id_value [String, nil] The value of the tax identifier.
end

Instance Attribute Details

#cityString?

The city of the address.

Returns:

  • (String, nil)


136
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 136

optional :city, String, nil?: true

#countryString?

The country of the address.

Returns:

  • (String, nil)


142
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 142

optional :country, String, nil?: true

#line1String?

The line 1 of the address.

Returns:

  • (String, nil)


148
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 148

optional :line1, String, nil?: true

#line2String?

The line 2 of the address.

Returns:

  • (String, nil)


154
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 154

optional :line2, String, nil?: true

#nameString?

The name of the customer.

Returns:

  • (String, nil)


160
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 160

optional :name, String, nil?: true

#phoneString?

The phone number of the customer.

Returns:

  • (String, nil)


166
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 166

optional :phone, String, nil?: true

#postal_codeString?

The postal code of the address.

Returns:

  • (String, nil)


172
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 172

optional :postal_code, String, nil?: true

#stateString?

The state of the address.

Returns:

  • (String, nil)


178
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 178

optional :state, String, nil?: true

#tax_id_typeSymbol, ...

The type of tax identifier

Returns:



184
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 184

optional :tax_id_type, enum: -> { WhopSDK::TaxIdentifierType }, nil?: true

#tax_id_valueString?

The value of the tax identifier.

Returns:

  • (String, nil)


190
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 190

optional :tax_id_value, String, nil?: true