Class: WhopSDK::Models::Lead

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/lead.rb

Overview

Defined Under Namespace

Classes: Member, Product, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, title:) ⇒ Object

Some parameter documentations has been truncated, see Product for more details.

The product the lead expressed interest in. Null if the lead is not associated with a specific product.

Parameters:

  • id (String)

    The unique identifier for the product.

  • title (String)

    The display name of the product shown to customers on the product page and in se



# File 'lib/whop_sdk/models/lead.rb', line 58

Instance Attribute Details

#created_atTime

The datetime the lead was created.

Returns:

  • (Time)


17
# File 'lib/whop_sdk/models/lead.rb', line 17

required :created_at, Time

#idString

The unique identifier for the lead.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/lead.rb', line 11

required :id, String

#memberWhopSDK::Models::Lead::Member?

The company member record if this lead has converted into a paying customer. Null if the lead has not converted.



24
# File 'lib/whop_sdk/models/lead.rb', line 24

required :member, -> { WhopSDK::Lead::Member }, nil?: true

#metadataHash{Symbol=>Object}?

Custom key-value pairs attached to this lead. Null if no metadata was provided.

Returns:

  • (Hash{Symbol=>Object}, nil)


30
# File 'lib/whop_sdk/models/lead.rb', line 30

required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#productWhopSDK::Models::Lead::Product?

The product the lead expressed interest in. Null if the lead is not associated with a specific product.



37
# File 'lib/whop_sdk/models/lead.rb', line 37

required :product, -> { WhopSDK::Lead::Product }, nil?: true

#referrerString?

The URL of the page that referred this lead to the company. Null if no referrer was captured.

Returns:

  • (String, nil)


44
# File 'lib/whop_sdk/models/lead.rb', line 44

required :referrer, String, nil?: true

#updated_atTime

The datetime the lead was last updated.

Returns:

  • (Time)


50
# File 'lib/whop_sdk/models/lead.rb', line 50

required :updated_at, Time

#userWhopSDK::Models::Lead::User

The user account associated with this lead.



56
# File 'lib/whop_sdk/models/lead.rb', line 56

required :user, -> { WhopSDK::Lead::User }