Class: WhopSDK::Models::LeadCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/lead_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id:, metadata: nil, product_id: nil, referrer: nil, user_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::LeadCreateParams for more details.

‘biz_

Parameters:

  • company_id (String)

    The unique identifier of the company to create the lead for, starting with

  • metadata (Hash{Symbol=>Object}, nil) (defaults to: nil)

    A JSON object of custom metadata to attach to the lead for tracking purposes.

  • product_id (String, nil) (defaults to: nil)

    The unique identifier of the product the lead is interested in, starting with ‘p

  • referrer (String, nil) (defaults to: nil)

    The referral URL that brought the lead to the company, such as ‘example.

  • user_id (String, nil) (defaults to: nil)

    The unique identifier of the user to record as the lead. If authenticated as a u

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/lead_create_params.rb', line 44

Instance Attribute Details

#company_idString

The unique identifier of the company to create the lead for, starting with ‘biz_’.

Returns:

  • (String)


15
# File 'lib/whop_sdk/models/lead_create_params.rb', line 15

required :company_id, String

#metadataHash{Symbol=>Object}?

A JSON object of custom metadata to attach to the lead for tracking purposes.

Returns:

  • (Hash{Symbol=>Object}, nil)


21
# File 'lib/whop_sdk/models/lead_create_params.rb', line 21

optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#product_idString?

The unique identifier of the product the lead is interested in, starting with ‘prod_’.

Returns:

  • (String, nil)


28
# File 'lib/whop_sdk/models/lead_create_params.rb', line 28

optional :product_id, String, nil?: true

#referrerString?

The referral URL that brought the lead to the company, such as ‘example.com/landing’.

Returns:

  • (String, nil)


35
# File 'lib/whop_sdk/models/lead_create_params.rb', line 35

optional :referrer, String, nil?: true

#user_idString?

The unique identifier of the user to record as the lead. If authenticated as a user, that user is used automatically.

Returns:

  • (String, nil)


42
# File 'lib/whop_sdk/models/lead_create_params.rb', line 42

optional :user_id, String, nil?: true