Class: WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data
- Defined in:
- lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb,
sig/whop_sdk/models/ledger_account_funds_available_webhook_event.rbs
Overview
Defined Under Namespace
Modules: LedgerType, Owner, PaymentsApprovalStatus Classes: Balance, PayoutAccountDetails, TreasuryBalance
Instance Attribute Summary collapse
-
#balances ⇒ Array<WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::Balance>
The balances associated with the account.
-
#id ⇒ String
The unique identifier for the ledger account.
-
#ledger_type ⇒ Symbol, WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::LedgerType
The type of ledger account.
-
#owner ⇒ WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::Owner::User, ...
The owner of the ledger account.
-
#payments_approval_status ⇒ Symbol, ...
The different approval statuses an account can have.
-
#payout_account_details ⇒ WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::PayoutAccountDetails?
The payout account associated with the LedgerAccount, if any.
-
#transfer_fee ⇒ Float?
The fee for transfers, if applicable.
-
#treasury_balance ⇒ WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::TreasuryBalance?
The balance cache associated with the account by currency.
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::Owner::User, WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::Owner::Company)
Instance Method Summary collapse
-
#initialize(id:, last_error_code:, last_error_reason:, status:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PayoutAccountDetails::LatestVerification for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, last_error_code:, last_error_reason:, status:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::PayoutAccountDetails::LatestVerification for more details.
The latest verification for the connected account.
|
|
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 161
|
Instance Attribute Details
#balances ⇒ Array<WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::Balance>
The balances associated with the account.
71 72 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 71 required :balances, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::LedgerAccountFundsAvailableWebhookEvent::Data::Balance] } |
#id ⇒ String
The unique identifier for the ledger account.
65 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 65 required :id, String |
#ledger_type ⇒ Symbol, WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::LedgerType
The type of ledger account.
78 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 78 required :ledger_type, enum: -> { WhopSDK::LedgerAccountFundsAvailableWebhookEvent::Data::LedgerType } |
#owner ⇒ WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::Owner::User, ...
The owner of the ledger account.
84 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 84 required :owner, union: -> { WhopSDK::LedgerAccountFundsAvailableWebhookEvent::Data::Owner } |
#payments_approval_status ⇒ Symbol, ...
The different approval statuses an account can have.
90 91 92 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 90 required :payments_approval_status, enum: -> { WhopSDK::LedgerAccountFundsAvailableWebhookEvent::Data::PaymentsApprovalStatus }, nil?: true |
#payout_account_details ⇒ WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::PayoutAccountDetails?
The payout account associated with the LedgerAccount, if any.
98 99 100 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 98 required :payout_account_details, -> { WhopSDK::LedgerAccountFundsAvailableWebhookEvent::Data::PayoutAccountDetails }, nil?: true |
#transfer_fee ⇒ Float?
The fee for transfers, if applicable.
106 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 106 required :transfer_fee, Float, nil?: true |
#treasury_balance ⇒ WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::TreasuryBalance?
The balance cache associated with the account by currency.
112 113 114 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 112 required :treasury_balance, -> { WhopSDK::LedgerAccountFundsAvailableWebhookEvent::Data::TreasuryBalance }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 182
|
.variants ⇒ Array(WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::Owner::User, WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::Owner::Company)
|
|
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 276
|
Instance Method Details
#to_hash ⇒ {
84 |
# File 'sig/whop_sdk/models/ledger_account_funds_available_webhook_event.rbs', line 84
def to_hash: -> {
|