Class: WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::TreasuryBalance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::LedgerAccountFundsAvailableWebhookEvent::Data::TreasuryBalance
- Defined in:
- lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb,
sig/whop_sdk/models/ledger_account_funds_available_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#balance ⇒ Float
The amount of the balance.
-
#balance_usd ⇒ Float
The balance converted to USD.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the balance.
-
#pending_balance ⇒ Float
The amount of the balance that is pending.
-
#reserve_balance ⇒ Float
The amount of the balance that is reserved.
-
#total_withdrawable_balance ⇒ Float
The amount of the balance that is withdrawable.
Instance Method Summary collapse
-
#initialize(balance:, balance_usd:, currency:, pending_balance:, reserve_balance:, total_withdrawable_balance:) ⇒ Object
constructor
The balance cache associated with the account by currency.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balance:, balance_usd:, currency:, pending_balance:, reserve_balance:, total_withdrawable_balance:) ⇒ Object
The balance cache associated with the account by currency.
|
|
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 560
|
Instance Attribute Details
#balance ⇒ Float
The amount of the balance.
528 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 528 required :balance, Float |
#balance_usd ⇒ Float
The balance converted to USD.
534 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 534 required :balance_usd, Float |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the balance.
540 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 540 required :currency, enum: -> { WhopSDK::Currency } |
#pending_balance ⇒ Float
The amount of the balance that is pending.
546 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 546 required :pending_balance, Float |
#reserve_balance ⇒ Float
The amount of the balance that is reserved.
552 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 552 required :reserve_balance, Float |
#total_withdrawable_balance ⇒ Float
The amount of the balance that is withdrawable.
558 |
# File 'lib/whop_sdk/models/ledger_account_funds_available_webhook_event.rb', line 558 required :total_withdrawable_balance, Float |
Instance Method Details
#to_hash ⇒ {
406 |
# File 'sig/whop_sdk/models/ledger_account_funds_available_webhook_event.rbs', line 406
def to_hash: -> {
|