Class: WhopSDK::Models::LedgerAccountRetrieveResponse::Owner::Company
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::LedgerAccountRetrieveResponse::Owner::Company
- Defined in:
- lib/whop_sdk/models/ledger_account_retrieve_response.rb,
sig/whop_sdk/models/ledger_account_retrieve_response.rbs
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the company.
-
#route ⇒ String
URL slug for the account's store page, e.g.
-
#title ⇒ String
The display name of the company shown to customers.
-
#typename ⇒ Symbol, :Company
The typename of this object.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
143 |
# File 'sig/whop_sdk/models/ledger_account_retrieve_response.rbs', line 143
def initialize: (
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the company.
189 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 189 required :id, String |
#route ⇒ String
URL slug for the account's store page, e.g. pickaxe in whop.com/pickaxe.
195 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 195 required :route, String |
#title ⇒ String
The display name of the company shown to customers.
201 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 201 required :title, String |
#typename ⇒ Symbol, :Company
The typename of this object
207 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 207 required :typename, const: :Company |
Instance Method Details
#to_hash ⇒ {
150 |
# File 'sig/whop_sdk/models/ledger_account_retrieve_response.rbs', line 150
def to_hash: -> {
|