Class: WhopSDK::Models::LedgerAccountRetrieveResponse::Owner::User

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/ledger_account_retrieve_response.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#idString

The internal ID of the user.

Returns:

  • (String)


162
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 162

required :id, String

#nameString?

The name of the user from their Whop account.

Returns:

  • (String, nil)


168
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 168

required :name, String, nil?: true

#typenameSymbol, :User

The typename of this object

Returns:

  • (Symbol, :User)


174
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 174

required :typename, const: :User

#usernameString

The username of the user from their Whop account.

Returns:

  • (String)


180
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 180

required :username, String