Class: WhopSDK::Models::LedgerAccountRetrieveResponse::TreasuryBalance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::LedgerAccountRetrieveResponse::TreasuryBalance
- Defined in:
- lib/whop_sdk/models/ledger_account_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#balance ⇒ Float
The amount of the balance.
-
#balance_usd ⇒ Float
The balance converted to USD.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the balance.
-
#pending_balance ⇒ Float
The amount of the balance that is pending.
-
#reserve_balance ⇒ Float
The amount of the balance that is reserved.
-
#total_withdrawable_balance ⇒ Float
The amount of the balance that is withdrawable.
Instance Method Summary collapse
-
#initialize(balance:, balance_usd:, currency:, pending_balance:, reserve_balance:, total_withdrawable_balance:) ⇒ Object
constructor
The balance cache associated with the account by currency.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(balance:, balance_usd:, currency:, pending_balance:, reserve_balance:, total_withdrawable_balance:) ⇒ Object
The balance cache associated with the account by currency.
|
|
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 504
|
Instance Attribute Details
#balance ⇒ Float
The amount of the balance.
472 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 472 required :balance, Float |
#balance_usd ⇒ Float
The balance converted to USD.
478 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 478 required :balance_usd, Float |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the balance.
484 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 484 required :currency, enum: -> { WhopSDK::Currency } |
#pending_balance ⇒ Float
The amount of the balance that is pending.
490 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 490 required :pending_balance, Float |
#reserve_balance ⇒ Float
The amount of the balance that is reserved.
496 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 496 required :reserve_balance, Float |
#total_withdrawable_balance ⇒ Float
The amount of the balance that is withdrawable.
502 |
# File 'lib/whop_sdk/models/ledger_account_retrieve_response.rb', line 502 required :total_withdrawable_balance, Float |