Class: WhopSDK::Models::Lesson::AssessmentQuestion::Image
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Lesson::AssessmentQuestion::Image
- Defined in:
- lib/whop_sdk/models/lesson.rb,
sig/whop_sdk/models/lesson.rbs
Overview
Instance Attribute Summary collapse
-
#content_type ⇒ String?
Uploaded file MIME type, such as image/jpeg, video/mp4, or audio/mpeg.
-
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
152 |
# File 'sig/whop_sdk/models/lesson.rbs', line 152
def initialize: (
|
Instance Attribute Details
#content_type ⇒ String?
Uploaded file MIME type, such as image/jpeg, video/mp4, or audio/mpeg.
232 |
# File 'lib/whop_sdk/models/lesson.rb', line 232 required :content_type, String, nil?: true |
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
238 |
# File 'lib/whop_sdk/models/lesson.rb', line 238 required :filename, String, nil?: true |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to
refetch an object or as key for a cache. The ID type appears in a JSON response
as a String; however, it is not intended to be human-readable. When expected as
an input type, any string (such as "VXNlci0xMA==") or integer (such as 4)
input value will be accepted as an ID.
226 |
# File 'lib/whop_sdk/models/lesson.rb', line 226 required :id, String |
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client. This should be used for displaying attachments in apps.
245 |
# File 'lib/whop_sdk/models/lesson.rb', line 245 required :url, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
159 |
# File 'sig/whop_sdk/models/lesson.rbs', line 159
def to_hash: -> {
|