Class: WhopSDK::Models::Lesson::Attachment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Lesson::Attachment
- Defined in:
- lib/whop_sdk/models/lesson.rb
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The attachment’s content type (e.g., image/jpg, video/mp4).
-
#filename ⇒ String?
The name of the file.
-
#id ⇒ String
The ID of the attachment.
-
#url ⇒ String?
This is the URL you use to render optimized attachments on the client.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#content_type ⇒ String?
The attachment’s content type (e.g., image/jpg, video/mp4)
294 |
# File 'lib/whop_sdk/models/lesson.rb', line 294 required :content_type, String, nil?: true |
#filename ⇒ String?
The name of the file
300 |
# File 'lib/whop_sdk/models/lesson.rb', line 300 required :filename, String, nil?: true |
#id ⇒ String
The ID of the attachment
288 |
# File 'lib/whop_sdk/models/lesson.rb', line 288 required :id, String |
#url ⇒ String?
This is the URL you use to render optimized attachments on the client. This should be used for apps.
307 |
# File 'lib/whop_sdk/models/lesson.rb', line 307 required :url, String, nil?: true |