Class: WhopSDK::Models::Lesson::MainPdf

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/lesson.rb,
sig/whop_sdk/models/lesson.rbs

Overview

See Also:

  • WhopSDK::Models::Lesson#main_pdf

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



234
# File 'sig/whop_sdk/models/lesson.rbs', line 234

def initialize: (

Instance Attribute Details

#content_typeString?

Uploaded file MIME type, such as image/jpeg, video/mp4, or audio/mpeg.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


365
# File 'lib/whop_sdk/models/lesson.rb', line 365

required :content_type, String, nil?: true

#filenameString?

The original filename of the uploaded attachment, including its file extension.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


371
# File 'lib/whop_sdk/models/lesson.rb', line 371

required :filename, String, nil?: true

#idString

Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as "VXNlci0xMA==") or integer (such as 4) input value will be accepted as an ID.

Parameters:

  • value (String)

Returns:

  • (String)


359
# File 'lib/whop_sdk/models/lesson.rb', line 359

required :id, String

#urlString?

A pre-optimized URL for rendering this attachment on the client. This should be used for displaying attachments in apps.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


378
# File 'lib/whop_sdk/models/lesson.rb', line 378

required :url, String, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


241
# File 'sig/whop_sdk/models/lesson.rbs', line 241

def to_hash: -> {