Class: WhopSDK::Models::Lesson::VideoAsset

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/lesson.rb

Overview

See Also:

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, asset_id:, audio_only:, created_at:, duration_seconds:, finished_uploading_at:, playback_id:, signed_playback_id:, signed_storyboard_playback_token:, signed_thumbnail_playback_token:, signed_video_playback_token:, status:, updated_at:) ⇒ Object

The Mux video asset for video-type lessons, used for streaming playback. Null if this lesson has no hosted video.

Parameters:

  • id (String)

    The unique identifier for the mux asset.

  • asset_id (String, nil)

    The Mux-provided ID of the asset

  • audio_only (Boolean)

    Whether this asset contains only audio

  • created_at (Time)

    The datetime the mux asset was created.

  • duration_seconds (Integer, nil)

    The duration of the video in seconds

  • finished_uploading_at (Time, nil)

    The time at which the video finished uploading

  • playback_id (String, nil)

    The public playback ID of the Mux asset

  • signed_playback_id (String, nil)

    The signed playback ID of the Mux asset

  • signed_storyboard_playback_token (String, nil)

    The signed storyboard playback token of the Mux asset

  • signed_thumbnail_playback_token (String, nil)

    The signed thumbnail playback token of the Mux asset

  • signed_video_playback_token (String, nil)

    The signed video playback token of the Mux asset

  • status (Symbol, WhopSDK::Models::Lesson::VideoAsset::Status)

    The status of the Mux asset

  • updated_at (Time)

    The datetime the mux asset was last updated.



# File 'lib/whop_sdk/models/lesson.rb', line 495

Instance Attribute Details

#asset_idString?

The Mux-provided ID of the asset

Returns:

  • (String, nil)


427
# File 'lib/whop_sdk/models/lesson.rb', line 427

required :asset_id, String, nil?: true

#audio_onlyBoolean

Whether this asset contains only audio

Returns:

  • (Boolean)


433
# File 'lib/whop_sdk/models/lesson.rb', line 433

required :audio_only, WhopSDK::Internal::Type::Boolean

#created_atTime

The datetime the mux asset was created.

Returns:

  • (Time)


439
# File 'lib/whop_sdk/models/lesson.rb', line 439

required :created_at, Time

#duration_secondsInteger?

The duration of the video in seconds

Returns:

  • (Integer, nil)


445
# File 'lib/whop_sdk/models/lesson.rb', line 445

required :duration_seconds, Integer, nil?: true

#finished_uploading_atTime?

The time at which the video finished uploading

Returns:

  • (Time, nil)


451
# File 'lib/whop_sdk/models/lesson.rb', line 451

required :finished_uploading_at, Time, nil?: true

#idString

The unique identifier for the mux asset.

Returns:

  • (String)


421
# File 'lib/whop_sdk/models/lesson.rb', line 421

required :id, String

#playback_idString?

The public playback ID of the Mux asset

Returns:

  • (String, nil)


457
# File 'lib/whop_sdk/models/lesson.rb', line 457

required :playback_id, String, nil?: true

#signed_playback_idString?

The signed playback ID of the Mux asset

Returns:

  • (String, nil)


463
# File 'lib/whop_sdk/models/lesson.rb', line 463

required :signed_playback_id, String, nil?: true

#signed_storyboard_playback_tokenString?

The signed storyboard playback token of the Mux asset

Returns:

  • (String, nil)


469
# File 'lib/whop_sdk/models/lesson.rb', line 469

required :signed_storyboard_playback_token, String, nil?: true

#signed_thumbnail_playback_tokenString?

The signed thumbnail playback token of the Mux asset

Returns:

  • (String, nil)


475
# File 'lib/whop_sdk/models/lesson.rb', line 475

required :signed_thumbnail_playback_token, String, nil?: true

#signed_video_playback_tokenString?

The signed video playback token of the Mux asset

Returns:

  • (String, nil)


481
# File 'lib/whop_sdk/models/lesson.rb', line 481

required :signed_video_playback_token, String, nil?: true

#statusSymbol, WhopSDK::Models::Lesson::VideoAsset::Status

The status of the Mux asset



487
# File 'lib/whop_sdk/models/lesson.rb', line 487

required :status, enum: -> { WhopSDK::Lesson::VideoAsset::Status }

#updated_atTime

The datetime the mux asset was last updated.

Returns:

  • (Time)


493
# File 'lib/whop_sdk/models/lesson.rb', line 493

required :updated_at, Time