Module: WhopSDK::Models::MediaAsset::Status
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/whop_sdk/models/media_asset.rb,
sig/whop_sdk/models/media_asset.rbs
Overview
Lifecycle state: processing while generation runs, ready when the file is
available, failed when generation failed and the charge was refunded.
Constant Summary collapse
- PROCESSING =
:processing- READY =
:ready- FAILED =
:failed
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/media_asset.rb', line 219
|
Instance Method Details
#self?.values ⇒ ::Array[WhopSDK::Models::MediaAsset::status]
156 |
# File 'sig/whop_sdk/models/media_asset.rbs', line 156
def self?.values: -> ::Array[WhopSDK::Models::MediaAsset::status]
|