Class: WhopSDK::Models::MemberListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MemberListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/member_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#access_level ⇒ Symbol, ...
The access level a given user (or company) has to a product or company.
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#company_id ⇒ String?
The unique identifier of the company to list members for.
-
#created_after ⇒ Time?
Only return members created after this timestamp.
-
#created_before ⇒ Time?
Only return members created before this timestamp.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#most_recent_actions ⇒ Array<Symbol, WhopSDK::Models::MemberMostRecentActions>?
Filter members by their most recent activity type.
-
#order ⇒ Symbol, ...
Which columns can be used to sort.
-
#plan_ids ⇒ Array<String>?
Filter members to only those subscribed to these specific plans.
-
#product_ids ⇒ Array<String>?
Filter members to only those belonging to these specific products.
-
#promo_code_ids ⇒ Array<String>?
Filter members to only those who used these specific promo codes.
-
#query ⇒ String?
Search members by name, username, or email.
-
#statuses ⇒ Array<Symbol, WhopSDK::Models::MemberStatuses>?
Filter members by their current subscription status.
-
#user_ids ⇒ Array<String>?
Filter members to only those matching these specific user identifiers.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(access_level: nil, after: nil, before: nil, company_id: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, most_recent_actions: nil, order: nil, plan_ids: nil, product_ids: nil, promo_code_ids: nil, query: nil, statuses: nil, user_ids: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MemberListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access_level: nil, after: nil, before: nil, company_id: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, most_recent_actions: nil, order: nil, plan_ids: nil, product_ids: nil, promo_code_ids: nil, query: nil, statuses: nil, user_ids: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::MemberListParams for more details.
|
|
# File 'lib/whop_sdk/models/member_list_params.rb', line 115
|
Instance Attribute Details
#access_level ⇒ Symbol, ...
The access level a given user (or company) has to a product or company.
14 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 14 optional :access_level, enum: -> { WhopSDK::AccessLevel }, nil?: true |
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
20 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 20 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
26 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 26 optional :before, String, nil?: true |
#company_id ⇒ String?
The unique identifier of the company to list members for.
32 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 32 optional :company_id, String, nil?: true |
#created_after ⇒ Time?
Only return members created after this timestamp.
38 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 38 optional :created_after, Time, nil?: true |
#created_before ⇒ Time?
Only return members created before this timestamp.
44 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 44 optional :created_before, Time, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
50 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 50 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
56 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 56 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
62 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 62 optional :last, Integer, nil?: true |
#most_recent_actions ⇒ Array<Symbol, WhopSDK::Models::MemberMostRecentActions>?
Filter members by their most recent activity type.
68 69 70 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 68 optional :most_recent_actions, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MemberMostRecentActions] }, nil?: true |
#order ⇒ Symbol, ...
Which columns can be used to sort.
76 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 76 optional :order, enum: -> { WhopSDK::MemberListParams::Order }, nil?: true |
#plan_ids ⇒ Array<String>?
Filter members to only those subscribed to these specific plans.
82 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 82 optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#product_ids ⇒ Array<String>?
Filter members to only those belonging to these specific products.
88 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 88 optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#promo_code_ids ⇒ Array<String>?
Filter members to only those who used these specific promo codes.
94 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 94 optional :promo_code_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#query ⇒ String?
Search members by name, username, or email. Email filtering requires the member:email:read permission.
101 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 101 optional :query, String, nil?: true |
#statuses ⇒ Array<Symbol, WhopSDK::Models::MemberStatuses>?
Filter members by their current subscription status.
107 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 107 optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MemberStatuses] }, nil?: true |