Class: WhopSDK::Models::MemberListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/member_list_response.rb

Overview

Defined Under Namespace

Classes: User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , access_level: , created_at: , joined_at: , most_recent_action: , most_recent_action_at: , phone: , status: , updated_at: , usd_total_spent: , user: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::MemberListResponse for more details.

An object representing a connection between a creator and a user/company_buyer. This type should only be made visible to the user/company_buyer who is a part of the connection.

Parameters:

  • id (String) (defaults to: )

    The ID of the member

  • access_level (Symbol, WhopSDK::Models::AccessLevel) (defaults to: )

    The access level of the product member. If its admin, the member is an authorize

  • created_at (Time) (defaults to: )

    When the member was created

  • joined_at (Time) (defaults to: )

    When the member joined the company

  • most_recent_action (Symbol, WhopSDK::Models::MemberMostRecentActions, nil) (defaults to: )

    The different most recent actions a member can have.

  • most_recent_action_at (Time, nil) (defaults to: )

    The time for the most recent action, if applicable.

  • phone (String, nil) (defaults to: )

    The phone number for the member, if available.

  • status (Symbol, WhopSDK::Models::MemberStatuses) (defaults to: )

    The status of the member

  • updated_at (Time) (defaults to: )

    The timestamp of when this member was last updated

  • usd_total_spent (Float) (defaults to: )

    How much money this customer has spent on the company’s products and plans

  • user (WhopSDK::Models::MemberListResponse::User, nil) (defaults to: )

    The user for this member, if any.



# File 'lib/whop_sdk/models/member_list_response.rb', line 76

Instance Attribute Details

#access_levelSymbol, WhopSDK::Models::AccessLevel

The access level of the product member. If its admin, the member is an authorized user of the company. If its customer, the member has a valid membership to any product on the company. If its no_access, the member does not have access to the product.

Returns:



20
# File 'lib/whop_sdk/models/member_list_response.rb', line 20

required :access_level, enum: -> { WhopSDK::AccessLevel }

#created_atTime

When the member was created

Returns:

  • (Time)


26
# File 'lib/whop_sdk/models/member_list_response.rb', line 26

required :created_at, Time

#idString

The ID of the member

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/member_list_response.rb', line 11

required :id, String

#joined_atTime

When the member joined the company

Returns:

  • (Time)


32
# File 'lib/whop_sdk/models/member_list_response.rb', line 32

required :joined_at, Time

#most_recent_actionSymbol, ...

The different most recent actions a member can have.



38
# File 'lib/whop_sdk/models/member_list_response.rb', line 38

required :most_recent_action, enum: -> { WhopSDK::MemberMostRecentActions }, nil?: true

#most_recent_action_atTime?

The time for the most recent action, if applicable.

Returns:

  • (Time, nil)


44
# File 'lib/whop_sdk/models/member_list_response.rb', line 44

required :most_recent_action_at, Time, nil?: true

#phoneString?

The phone number for the member, if available.

Returns:

  • (String, nil)


50
# File 'lib/whop_sdk/models/member_list_response.rb', line 50

required :phone, String, nil?: true

#statusSymbol, WhopSDK::Models::MemberStatuses

The status of the member

Returns:



56
# File 'lib/whop_sdk/models/member_list_response.rb', line 56

required :status, enum: -> { WhopSDK::MemberStatuses }

#updated_atTime

The timestamp of when this member was last updated

Returns:

  • (Time)


62
# File 'lib/whop_sdk/models/member_list_response.rb', line 62

required :updated_at, Time

#usd_total_spentFloat

How much money this customer has spent on the company’s products and plans

Returns:

  • (Float)


68
# File 'lib/whop_sdk/models/member_list_response.rb', line 68

required :usd_total_spent, Float

#userWhopSDK::Models::MemberListResponse::User?

The user for this member, if any.



74
# File 'lib/whop_sdk/models/member_list_response.rb', line 74

required :user, -> { WhopSDK::Models::MemberListResponse::User }, nil?: true