Class: WhopSDK::Models::Membership::CustomFieldResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Membership::CustomFieldResponse
- Defined in:
- lib/whop_sdk/models/membership.rb,
sig/whop_sdk/models/membership.rbs
Instance Attribute Summary collapse
-
#answer ⇒ String
The response a user gave to the specific question or field.
-
#id ⇒ String
The unique identifier for the custom field response.
-
#question ⇒ String
The question asked by the custom field.
Instance Method Summary collapse
-
#initialize ⇒ CustomFieldResponse
constructor
A new instance of CustomFieldResponse.
- #to_hash ⇒ { id: String, answer: String, question: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ CustomFieldResponse
Returns a new instance of CustomFieldResponse.
156 |
# File 'sig/whop_sdk/models/membership.rbs', line 156
def initialize: (id: String, answer: String, question: String) -> void
|
Instance Attribute Details
#answer ⇒ String
The response a user gave to the specific question or field.
256 |
# File 'lib/whop_sdk/models/membership.rb', line 256 required :answer, String |
#id ⇒ String
The unique identifier for the custom field response.
250 |
# File 'lib/whop_sdk/models/membership.rb', line 250 required :id, String |
#question ⇒ String
The question asked by the custom field
262 |
# File 'lib/whop_sdk/models/membership.rb', line 262 required :question, String |
Instance Method Details
#to_hash ⇒ { id: String, answer: String, question: String }
158 |
# File 'sig/whop_sdk/models/membership.rbs', line 158
def to_hash: -> { id: String, answer: String, question: String }
|