Class: WhopSDK::Models::Membership::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Membership::Product
- Defined in:
- lib/whop_sdk/models/membership.rb,
sig/whop_sdk/models/membership.rbs
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the product.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs stored on the product and included in payment and membership webhook payloads.
-
#title ⇒ String
The display name of the product shown to customers on the product page and in search results.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
193 |
# File 'sig/whop_sdk/models/membership.rbs', line 193
def initialize: (
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the product.
322 |
# File 'lib/whop_sdk/models/membership.rb', line 322 required :id, String |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs stored on the product and included in payment and membership webhook payloads. Max 50 keys, 100 characters per key, 500 characters per string value.
330 |
# File 'lib/whop_sdk/models/membership.rb', line 330 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#title ⇒ String
The display name of the product shown to customers on the product page and in search results.
337 |
# File 'lib/whop_sdk/models/membership.rb', line 337 required :title, String |
Instance Method Details
#to_hash ⇒ {
199 |
# File 'sig/whop_sdk/models/membership.rbs', line 199
def to_hash: -> {
|