Class: WhopSDK::Models::Membership::User
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Membership::User
- Defined in:
- lib/whop_sdk/models/membership.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The internal ID of the user.
-
#name ⇒ String?
The name of the user from their Whop account.
-
#username ⇒ String
The username of the user from their Whop account.
Instance Method Summary collapse
-
#initialize(id: , name: , username: ) ⇒ Object
constructor
The user this membership belongs to.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , name: , username: ) ⇒ Object
The user this membership belongs to
|
|
# File 'lib/whop_sdk/models/membership.rb', line 283
|
Instance Attribute Details
#id ⇒ String
The internal ID of the user.
269 |
# File 'lib/whop_sdk/models/membership.rb', line 269 required :id, String |
#name ⇒ String?
The name of the user from their Whop account.
275 |
# File 'lib/whop_sdk/models/membership.rb', line 275 required :name, String, nil?: true |
#username ⇒ String
The username of the user from their Whop account.
281 |
# File 'lib/whop_sdk/models/membership.rb', line 281 required :username, String |