Class: WhopSDK::Models::MembershipDeactivatedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MembershipDeactivatedWebhookEvent
- Defined in:
- lib/whop_sdk/models/membership_deactivated_webhook_event.rb
Instance Attribute Summary collapse
-
#api_version ⇒ Symbol, :v1
The API version for this webhook.
-
#data ⇒ WhopSDK::Models::Membership
A membership represents a purchase between a User and a Company for a specific Product.
-
#id ⇒ String
A unique ID for every single webhook request.
-
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server.
-
#type ⇒ Symbol, :"membership.deactivated"
The webhook event type.
Instance Method Summary collapse
-
#initialize(id: , data: , timestamp: , api_version: :v1, type: :"membership.deactivated") ⇒ Object
constructor
Some parameter documentations has been truncated, see MembershipDeactivatedWebhookEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , data: , timestamp: , api_version: :v1, type: :"membership.deactivated") ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::MembershipDeactivatedWebhookEvent for more details.
|
|
# File 'lib/whop_sdk/models/membership_deactivated_webhook_event.rb', line 37
|
Instance Attribute Details
#api_version ⇒ Symbol, :v1
The API version for this webhook
16 |
# File 'lib/whop_sdk/models/membership_deactivated_webhook_event.rb', line 16 required :api_version, const: :v1 |
#data ⇒ WhopSDK::Models::Membership
A membership represents a purchase between a User and a Company for a specific Product.
23 |
# File 'lib/whop_sdk/models/membership_deactivated_webhook_event.rb', line 23 required :data, -> { WhopSDK::Membership } |
#id ⇒ String
A unique ID for every single webhook request
10 |
# File 'lib/whop_sdk/models/membership_deactivated_webhook_event.rb', line 10 required :id, String |
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server
29 |
# File 'lib/whop_sdk/models/membership_deactivated_webhook_event.rb', line 29 required :timestamp, Time |
#type ⇒ Symbol, :"membership.deactivated"
The webhook event type
35 |
# File 'lib/whop_sdk/models/membership_deactivated_webhook_event.rb', line 35 required :type, const: :"membership.deactivated" |