Class: WhopSDK::Models::MembershipListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/membership_list_params.rb

Overview

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, cancel_options: nil, company_id: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, plan_ids: nil, product_ids: nil, promo_code_ids: nil, statuses: nil, user_ids: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::MembershipListParams for more details.

Parameters:

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • cancel_options (Array<Symbol, WhopSDK::Models::CancelOptions>, nil) (defaults to: nil)

    Filter to only memberships matching these cancellation reasons.

  • company_id (String, nil) (defaults to: nil)

    The unique identifier of the company to list memberships for. Required when usin

  • created_after (Time, nil) (defaults to: nil)

    Only return memberships created after this timestamp.

  • created_before (Time, nil) (defaults to: nil)

    Only return memberships created before this timestamp.

  • direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • order (Symbol, WhopSDK::Models::MembershipListParams::Order, nil) (defaults to: nil)

    Which columns can be used to sort.

  • plan_ids (Array<String>, nil) (defaults to: nil)

    Filter to only memberships belonging to these plan identifiers.

  • product_ids (Array<String>, nil) (defaults to: nil)

    Filter to only memberships belonging to these product identifiers.

  • promo_code_ids (Array<String>, nil) (defaults to: nil)

    Filter to only memberships that used these promo code identifiers.

  • statuses (Array<Symbol, WhopSDK::Models::MembershipStatus>, nil) (defaults to: nil)

    Filter to only memberships matching these statuses.

  • user_ids (Array<String>, nil) (defaults to: nil)

    Filter to only memberships belonging to these user identifiers.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/membership_list_params.rb', line 103

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


14
# File 'lib/whop_sdk/models/membership_list_params.rb', line 14

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/membership_list_params.rb', line 20

optional :before, String, nil?: true

#cancel_optionsArray<Symbol, WhopSDK::Models::CancelOptions>?

Filter to only memberships matching these cancellation reasons.

Returns:



26
27
28
# File 'lib/whop_sdk/models/membership_list_params.rb', line 26

optional :cancel_options,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::CancelOptions] },
nil?: true

#company_idString?

The unique identifier of the company to list memberships for. Required when using an API key.

Returns:

  • (String, nil)


35
# File 'lib/whop_sdk/models/membership_list_params.rb', line 35

optional :company_id, String, nil?: true

#created_afterTime?

Only return memberships created after this timestamp.

Returns:

  • (Time, nil)


41
# File 'lib/whop_sdk/models/membership_list_params.rb', line 41

optional :created_after, Time, nil?: true

#created_beforeTime?

Only return memberships created before this timestamp.

Returns:

  • (Time, nil)


47
# File 'lib/whop_sdk/models/membership_list_params.rb', line 47

optional :created_before, Time, nil?: true

#directionSymbol, ...

The direction of the sort.

Returns:



53
# File 'lib/whop_sdk/models/membership_list_params.rb', line 53

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


59
# File 'lib/whop_sdk/models/membership_list_params.rb', line 59

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


65
# File 'lib/whop_sdk/models/membership_list_params.rb', line 65

optional :last, Integer, nil?: true

#orderSymbol, ...

Which columns can be used to sort.



71
# File 'lib/whop_sdk/models/membership_list_params.rb', line 71

optional :order, enum: -> { WhopSDK::MembershipListParams::Order }, nil?: true

#plan_idsArray<String>?

Filter to only memberships belonging to these plan identifiers.

Returns:

  • (Array<String>, nil)


77
# File 'lib/whop_sdk/models/membership_list_params.rb', line 77

optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#product_idsArray<String>?

Filter to only memberships belonging to these product identifiers.

Returns:

  • (Array<String>, nil)


83
# File 'lib/whop_sdk/models/membership_list_params.rb', line 83

optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#promo_code_idsArray<String>?

Filter to only memberships that used these promo code identifiers.

Returns:

  • (Array<String>, nil)


89
# File 'lib/whop_sdk/models/membership_list_params.rb', line 89

optional :promo_code_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#statusesArray<Symbol, WhopSDK::Models::MembershipStatus>?

Filter to only memberships matching these statuses.

Returns:



95
# File 'lib/whop_sdk/models/membership_list_params.rb', line 95

optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MembershipStatus] }, nil?: true

#user_idsArray<String>?

Filter to only memberships belonging to these user identifiers.

Returns:

  • (Array<String>, nil)


101
# File 'lib/whop_sdk/models/membership_list_params.rb', line 101

optional :user_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true