Class: WhopSDK::Models::MessageCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/message_create_params.rb

Overview

Defined Under Namespace

Classes: Attachment, Poll

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

Input for an attachment

Parameters:

  • id (String)

    The ID of an existing file object.



# File 'lib/whop_sdk/models/message_create_params.rb', line 76

Instance Attribute Details

#attachmentsArray<WhopSDK::Models::MessageCreateParams::Attachment>?

A list of file attachments to include with the message, such as images or videos.



28
29
30
# File 'lib/whop_sdk/models/message_create_params.rb', line 28

optional :attachments,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::MessageCreateParams::Attachment] },
nil?: true

Automatically detect URLs in the message and generate link previews.

Returns:

  • (Boolean, nil)


36
# File 'lib/whop_sdk/models/message_create_params.rb', line 36

optional :auto_detect_links, WhopSDK::Internal::Type::Boolean, nil?: true

#channel_idString

The unique identifier of the channel or experience to send the message in. For example, ‘exp_xxxxx’ or ‘feed_xxxxx’.

Returns:

  • (String)


15
# File 'lib/whop_sdk/models/message_create_params.rb', line 15

required :channel_id, String

#contentString

The body of the message in Markdown format. For example, ‘Hello world’.

Returns:

  • (String)


21
# File 'lib/whop_sdk/models/message_create_params.rb', line 21

required :content, String

#pollWhopSDK::Models::MessageCreateParams::Poll?

A poll to attach to this message, allowing recipients to vote on options.



42
# File 'lib/whop_sdk/models/message_create_params.rb', line 42

optional :poll, -> { WhopSDK::MessageCreateParams::Poll }, nil?: true

#replying_to_message_idString?

The unique identifier of the message this is replying to, creating a threaded reply.

Returns:

  • (String, nil)


49
# File 'lib/whop_sdk/models/message_create_params.rb', line 49

optional :replying_to_message_id, String, nil?: true