Class: WhopSDK::Models::MessageCreateParams::Attachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/message_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(channel_id:, content:, attachments: nil, auto_detect_links: nil, poll: nil, replying_to_message_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::MessageCreateParams for more details.

Parameters:

  • channel_id (String)

    The unique identifier of the channel or experience to send the message in. For e

  • content (String)

    The body of the message in Markdown format. For example, ‘Hello world’.

  • attachments (Array<WhopSDK::Models::MessageCreateParams::Attachment>, nil) (defaults to: nil)

    A list of file attachments to include with the message, such as images or videos

  • auto_detect_links (Boolean, nil) (defaults to: nil)

    Automatically detect URLs in the message and generate link previews.

  • poll (WhopSDK::Models::MessageCreateParams::Poll, nil) (defaults to: nil)

    A poll to attach to this message, allowing recipients to vote on options.

  • replying_to_message_id (String, nil) (defaults to: nil)

    The unique identifier of the message this is replying to, creating a threaded re

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/whop_sdk/models/message_create_params.rb', line 69

class Attachment < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing file object.
  #
  #   @return [String]
  required :id, String

  # @!method initialize(id:)
  #   Input for an attachment
  #
  #   @param id [String] The ID of an existing file object.
end

Instance Attribute Details

#idString

The ID of an existing file object.

Returns:

  • (String)


74
# File 'lib/whop_sdk/models/message_create_params.rb', line 74

required :id, String