Class: WhopSDK::Models::MessageListResponse::ReactionCount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MessageListResponse::ReactionCount
- Defined in:
- lib/whop_sdk/models/message_list_response.rb,
sig/whop_sdk/models/message_list_response.rbs
Instance Attribute Summary collapse
-
#count ⇒ Integer
The number of users who reacted.
-
#emoji ⇒ String?
The emoji that was used in shortcode format (:heart:).
Instance Method Summary collapse
-
#initialize ⇒ ReactionCount
constructor
A new instance of ReactionCount.
- #to_hash ⇒ { count: Integer, emoji: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ ReactionCount
Returns a new instance of ReactionCount.
137 |
# File 'sig/whop_sdk/models/message_list_response.rbs', line 137
def initialize: (count: Integer, emoji: String?) -> void
|
Instance Attribute Details
#count ⇒ Integer
The number of users who reacted
208 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 208 required :count, Integer |
#emoji ⇒ String?
The emoji that was used in shortcode format (:heart:)
214 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 214 required :emoji, String, nil?: true |
Instance Method Details
#to_hash ⇒ { count: Integer, emoji: String? }
139 |
# File 'sig/whop_sdk/models/message_list_response.rbs', line 139
def to_hash: -> { count: Integer, emoji: String? }
|