Class: WhopSDK::Models::NotificationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/notification_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id: , content: , title: , experience_id: , icon_user_id: nil, rest_path: nil, subtitle: nil, user_ids: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::NotificationCreateParams for more details.

Parameters:

  • company_id (String) (defaults to: )

    The id of the company to target. Only team members of this company will receive

  • content (String) (defaults to: )

    The content of the notification

  • title (String) (defaults to: )

    The title of the notification

  • experience_id (String) (defaults to: )

    The id of the experience to target. All users with access to this experience (cu

  • icon_user_id (String, nil) (defaults to: nil)

    Optional: ID of a Whop user whose profile picture will be used as the notificati

  • rest_path (String, nil) (defaults to: nil)

    The rest path to append to the generated deep link that opens your app. Use [res

  • subtitle (String, nil) (defaults to: nil)

    The subtitle of the notification

  • user_ids (Array<String>, nil) (defaults to: nil)

    If provided, this will only send to these users if they are also in the main sco

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/notification_create_params.rb', line 65

Instance Attribute Details

#company_idString

The id of the company to target. Only team members of this company will receive the notification. When clicked will take the user to your dashboard app view.

Returns:

  • (String)


15
# File 'lib/whop_sdk/models/notification_create_params.rb', line 15

required :company_id, String

#contentString

The content of the notification

Returns:

  • (String)


21
# File 'lib/whop_sdk/models/notification_create_params.rb', line 21

required :content, String

#experience_idString

The id of the experience to target. All users with access to this experience (customers and admins) will receive the notification. When clicked, open your experience view.

Returns:

  • (String)


63
# File 'lib/whop_sdk/models/notification_create_params.rb', line 63

required :experience_id, String

#icon_user_idString?

Optional: ID of a Whop user whose profile picture will be used as the notification icon. If not provided, defaults to the experience or company avatar.

Returns:

  • (String, nil)


35
# File 'lib/whop_sdk/models/notification_create_params.rb', line 35

optional :icon_user_id, String, nil?: true

#rest_pathString?

The rest path to append to the generated deep link that opens your app. Use

restPath

in your app path in the dashboard to read this parameter.

Returns:

  • (String, nil)


42
# File 'lib/whop_sdk/models/notification_create_params.rb', line 42

optional :rest_path, String, nil?: true

#subtitleString?

The subtitle of the notification

Returns:

  • (String, nil)


48
# File 'lib/whop_sdk/models/notification_create_params.rb', line 48

optional :subtitle, String, nil?: true

#titleString

The title of the notification

Returns:

  • (String)


27
# File 'lib/whop_sdk/models/notification_create_params.rb', line 27

required :title, String

#user_idsArray<String>?

If provided, this will only send to these users if they are also in the main scope (experience or company)

Returns:

  • (Array<String>, nil)


55
# File 'lib/whop_sdk/models/notification_create_params.rb', line 55

optional :user_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true