Module: WhopSDK::Models::NotificationCreateParams::Body

Extended by:
Internal::Type::Union
Defined in:
lib/whop_sdk/models/notification_create_params.rb

Overview

Parameters for SendNotificationV2

Defined Under Namespace

Classes: SendNotificationV2InputWithCompanyID, SendNotificationV2InputWithExperienceID

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(company_id:, content:, title:, icon_user_id: nil, rest_path: nil, subtitle: nil, user_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see SendNotificationV2InputWithCompanyID for more details.

Autogenerated input type of SendNotificationV2

Parameters:

  • company_id (String)

    The unique identifier of the company to target. Only team members of this compan

  • content (String)

    The main body text of the notification displayed to the user.

  • title (String)

    The headline text of the notification, displayed prominently to the user.

  • icon_user_id (String, nil) (defaults to: nil)

    The unique identifier of a user whose profile picture will be used as the notifi

  • rest_path (String, nil) (defaults to: nil)

    A path segment appended to the generated deep link that opens your app. Use [res

  • subtitle (String, nil) (defaults to: nil)

    An optional secondary line of text displayed below the title in the notification

  • user_ids (Array<String>, nil) (defaults to: nil)

    An optional list of user IDs to narrow the audience. When provided, only these u



# File 'lib/whop_sdk/models/notification_create_params.rb', line 83