Class: WhopSDK::Models::NotificationCreateParams::Body::SendNotificationV2InputWithExperienceID

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/notification_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(content:, experience_id:, title:, icon_user_id: nil, rest_path: nil, subtitle: nil, user_ids: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::NotificationCreateParams::Body::SendNotificationV2InputWithExperienceID for more details.

Autogenerated input type of SendNotificationV2

Parameters:

  • content (String)

    The main body text of the notification displayed to the user.

  • experience_id (String)

    The unique identifier of the experience to target. All users with access to this

  • title (String)

    The headline text of the notification, displayed prominently to the user.

  • icon_user_id (String, nil) (defaults to: nil)

    The unique identifier of a user whose profile picture will be used as the notifi

  • rest_path (String, nil) (defaults to: nil)

    A path segment appended to the generated deep link that opens your app. Use [res

  • subtitle (String, nil) (defaults to: nil)

    An optional secondary line of text displayed below the title in the notification

  • user_ids (Array<String>, nil) (defaults to: nil)

    An optional list of user IDs to narrow the audience. When provided, only these u



# File 'lib/whop_sdk/models/notification_create_params.rb', line 157

Instance Attribute Details

#contentString

The main body text of the notification displayed to the user.

Returns:

  • (String)


110
# File 'lib/whop_sdk/models/notification_create_params.rb', line 110

required :content, String

#experience_idString

The unique identifier of the experience to target. All users with access to this experience will receive the notification. Clicking the notification opens the experience view.

Returns:

  • (String)


118
# File 'lib/whop_sdk/models/notification_create_params.rb', line 118

required :experience_id, String

#icon_user_idString?

The unique identifier of a user whose profile picture will be used as the notification icon. Defaults to the experience or company avatar when not provided.

Returns:

  • (String, nil)


132
# File 'lib/whop_sdk/models/notification_create_params.rb', line 132

optional :icon_user_id, String, nil?: true

#rest_pathString?

A path segment appended to the generated deep link that opens your app. Use

restPath

in your app path configuration to read this parameter. For example,

‘/settings/billing’.

Returns:

  • (String, nil)


140
# File 'lib/whop_sdk/models/notification_create_params.rb', line 140

optional :rest_path, String, nil?: true

#subtitleString?

An optional secondary line of text displayed below the title in the notification.

Returns:

  • (String, nil)


147
# File 'lib/whop_sdk/models/notification_create_params.rb', line 147

optional :subtitle, String, nil?: true

#titleString

The headline text of the notification, displayed prominently to the user.

Returns:

  • (String)


124
# File 'lib/whop_sdk/models/notification_create_params.rb', line 124

required :title, String

#user_idsArray<String>?

An optional list of user IDs to narrow the audience. When provided, only these users receive the notification, provided they are in the targeted experience or company.

Returns:

  • (Array<String>, nil)


155
# File 'lib/whop_sdk/models/notification_create_params.rb', line 155

optional :user_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true