Class: WhopSDK::Models::Payment::ApplicationFee

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment.rb,
sig/whop_sdk/models/payment.rbs

Overview

See Also:

  • WhopSDK::Models::Payment#application_fee

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



302
# File 'sig/whop_sdk/models/payment.rbs', line 302

def initialize: (

Instance Attribute Details

#amountFloat

The application fee amount.

Parameters:

  • value (Float)

Returns:

  • (Float)


472
# File 'lib/whop_sdk/models/payment.rb', line 472

required :amount, Float

#amount_capturedFloat

The amount of the application fee that has been captured.

Parameters:

  • value (Float)

Returns:

  • (Float)


478
# File 'lib/whop_sdk/models/payment.rb', line 478

required :amount_captured, Float

#amount_refundedFloat

The amount of the application fee that has been refunded.

Parameters:

  • value (Float)

Returns:

  • (Float)


484
# File 'lib/whop_sdk/models/payment.rb', line 484

required :amount_refunded, Float

#created_atTime

The datetime the application fee was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


490
# File 'lib/whop_sdk/models/payment.rb', line 490

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The currency of the application fee.

Parameters:

  • value (WhopSDK::Models::currency)

Returns:



496
# File 'lib/whop_sdk/models/payment.rb', line 496

required :currency, enum: -> { WhopSDK::Currency }

#idString

The unique identifier for the application fee.

Parameters:

  • value (String)

Returns:

  • (String)


466
# File 'lib/whop_sdk/models/payment.rb', line 466

required :id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


311
# File 'sig/whop_sdk/models/payment.rbs', line 311

def to_hash: -> {