Class: WhopSDK::Models::Payment::FinancingTransaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Payment::FinancingTransaction
- Defined in:
- lib/whop_sdk/models/payment.rb
Defined Under Namespace
Modules: Status, TransactionType
Instance Attribute Summary collapse
-
#amount ⇒ Float
The amount of the payment transaction.
-
#created_at ⇒ Time
The date and time the payment transaction was created.
-
#id ⇒ String
The unique identifier for the payment transaction.
-
#status ⇒ Symbol, WhopSDK::Models::Payment::FinancingTransaction::Status
The status of the payment transaction.
-
#transaction_type ⇒ Symbol, WhopSDK::Models::Payment::FinancingTransaction::TransactionType
The type of the payment transaction.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, amount:, created_at:, status:, transaction_type:) ⇒ Object
constructor
A payment transaction.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, created_at:, status:, transaction_type:) ⇒ Object
A payment transaction.
|
|
# File 'lib/whop_sdk/models/payment.rb', line 634
|
Instance Attribute Details
#amount ⇒ Float
The amount of the payment transaction.
614 |
# File 'lib/whop_sdk/models/payment.rb', line 614 required :amount, Float |
#created_at ⇒ Time
The date and time the payment transaction was created.
620 |
# File 'lib/whop_sdk/models/payment.rb', line 620 required :created_at, Time |
#id ⇒ String
The unique identifier for the payment transaction.
608 |
# File 'lib/whop_sdk/models/payment.rb', line 608 required :id, String |
#status ⇒ Symbol, WhopSDK::Models::Payment::FinancingTransaction::Status
The status of the payment transaction.
626 |
# File 'lib/whop_sdk/models/payment.rb', line 626 required :status, enum: -> { WhopSDK::Payment::FinancingTransaction::Status } |
#transaction_type ⇒ Symbol, WhopSDK::Models::Payment::FinancingTransaction::TransactionType
The type of the payment transaction.
632 |
# File 'lib/whop_sdk/models/payment.rb', line 632 required :transaction_type, enum: -> { WhopSDK::Payment::FinancingTransaction::TransactionType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/payment.rb', line 665
|