Class: WhopSDK::Models::Payment::PaymentMethod::Card
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Payment::PaymentMethod::Card
- Defined in:
- lib/whop_sdk/models/payment.rb
Overview
Instance Attribute Summary collapse
-
#brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#exp_month ⇒ Integer?
Card expiration month, like 03 for March.
-
#exp_year ⇒ Integer?
Card expiration year, like 27 for 2027.
-
#last4 ⇒ String?
Last four digits of the card.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#brand ⇒ Symbol, ...
Possible card brands that a payment token can have
463 |
# File 'lib/whop_sdk/models/payment.rb', line 463 required :brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#exp_month ⇒ Integer?
Card expiration month, like 03 for March.
469 |
# File 'lib/whop_sdk/models/payment.rb', line 469 required :exp_month, Integer, nil?: true |
#exp_year ⇒ Integer?
Card expiration year, like 27 for 2027.
475 |
# File 'lib/whop_sdk/models/payment.rb', line 475 required :exp_year, Integer, nil?: true |
#last4 ⇒ String?
Last four digits of the card.
481 |
# File 'lib/whop_sdk/models/payment.rb', line 481 required :last4, String, nil?: true |