Class: WhopSDK::Models::Payment::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Payment::Product
- Defined in:
- lib/whop_sdk/models/payment.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the product.
-
#route ⇒ String
The URL slug used in the product’s public link (e.g., ‘my-product’ in whop.com/company/my-product).
-
#title ⇒ String
The display name of the product shown to customers on the product page and in search results.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#id ⇒ String
The unique identifier for the product.
849 |
# File 'lib/whop_sdk/models/payment.rb', line 849 required :id, String |
#route ⇒ String
The URL slug used in the product’s public link (e.g., ‘my-product’ in whop.com/company/my-product).
856 |
# File 'lib/whop_sdk/models/payment.rb', line 856 required :route, String |
#title ⇒ String
The display name of the product shown to customers on the product page and in search results.
863 |
# File 'lib/whop_sdk/models/payment.rb', line 863 required :title, String |