Class: WhopSDK::Models::Payment::Refund

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment.rb,
sig/whop_sdk/models/payment.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



755
# File 'sig/whop_sdk/models/payment.rbs', line 755

def initialize: (

Instance Attribute Details

#amountFloat

The refunded amount as a decimal in the specified currency, such as 10.43 for $10.43 USD.

Parameters:

  • value (Float)

Returns:

  • (Float)


1059
# File 'lib/whop_sdk/models/payment.rb', line 1059

required :amount, Float

#created_atTime

The datetime the refund was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


1065
# File 'lib/whop_sdk/models/payment.rb', line 1065

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The three-letter ISO currency code for the refunded amount.

Parameters:

  • value (WhopSDK::Models::currency)

Returns:



1071
# File 'lib/whop_sdk/models/payment.rb', line 1071

required :currency, enum: -> { WhopSDK::Currency }

#idString

The unique identifier for the refund.

Parameters:

  • value (String)

Returns:

  • (String)


1052
# File 'lib/whop_sdk/models/payment.rb', line 1052

required :id, String

#statusSymbol, WhopSDK::Models::RefundStatus

The current processing status of the refund, such as pending, succeeded, or failed.

Parameters:

  • value (WhopSDK::Models::refund_status)

Returns:



1078
# File 'lib/whop_sdk/models/payment.rb', line 1078

required :status, enum: -> { WhopSDK::RefundStatus }

Instance Method Details

#to_hash{

Returns:

  • ({)


763
# File 'sig/whop_sdk/models/payment.rbs', line 763

def to_hash: -> {