Class: WhopSDK::Models::Payment::Resolution

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment.rb,
sig/whop_sdk/models/payment.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



804
# File 'sig/whop_sdk/models/payment.rbs', line 804

def initialize: (

Instance Attribute Details

#customer_appealedBoolean

Whether the customer has filed an appeal after the initial resolution decision.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


1109
# File 'lib/whop_sdk/models/payment.rb', line 1109

required :customer_appealed, WhopSDK::Internal::Type::Boolean

#customer_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCaseCustomerResponse>

The list of actions currently available to the customer.

Parameters:

  • value (::Array[WhopSDK::Models::resolution_center_case_customer_response])

Returns:



1115
1116
# File 'lib/whop_sdk/models/payment.rb', line 1115

required :customer_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseCustomerResponse] }

#due_dateTime?

The deadline by which the next response is required. Null if no deadline is currently active. As a Unix timestamp.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


1123
# File 'lib/whop_sdk/models/payment.rb', line 1123

required :due_date, Time, nil?: true

#idString

The unique identifier for the resolution.

Parameters:

  • value (String)

Returns:

  • (String)


1103
# File 'lib/whop_sdk/models/payment.rb', line 1103

required :id, String

#issueSymbol, WhopSDK::Models::ResolutionCenterCaseIssueType

The category of the dispute.

Parameters:

  • value (WhopSDK::Models::resolution_center_case_issue_type)

Returns:



1129
# File 'lib/whop_sdk/models/payment.rb', line 1129

required :issue, enum: -> { WhopSDK::ResolutionCenterCaseIssueType }

#merchant_appealedBoolean

Whether the merchant has filed an appeal after the initial resolution decision.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


1135
# File 'lib/whop_sdk/models/payment.rb', line 1135

required :merchant_appealed, WhopSDK::Internal::Type::Boolean

#merchant_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCaseMerchantResponse>

The list of actions currently available to the merchant.

Parameters:

  • value (::Array[WhopSDK::Models::resolution_center_case_merchant_response])

Returns:



1141
1142
# File 'lib/whop_sdk/models/payment.rb', line 1141

required :merchant_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseMerchantResponse] }

#platform_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCasePlatformResponse>

The list of actions currently available to the Whop platform for moderating this resolution.

Parameters:

  • value (::Array[WhopSDK::Models::resolution_center_case_platform_response])

Returns:



1149
1150
# File 'lib/whop_sdk/models/payment.rb', line 1149

required :platform_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCasePlatformResponse] }

#statusSymbol, WhopSDK::Models::ResolutionCenterCaseStatus

The current status of the resolution case, indicating which party needs to respond or if the case is closed.

Parameters:

  • value (WhopSDK::Models::resolution_center_case_status)

Returns:



1157
# File 'lib/whop_sdk/models/payment.rb', line 1157

required :status, enum: -> { WhopSDK::ResolutionCenterCaseStatus }

Instance Method Details

#to_hash{

Returns:

  • ({)


816
# File 'sig/whop_sdk/models/payment.rbs', line 816

def to_hash: -> {