Class: WhopSDK::Models::Payment::User
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Payment::User
- Defined in:
- lib/whop_sdk/models/payment.rb
Overview
Instance Attribute Summary collapse
-
#email ⇒ String?
The email of the user.
-
#id ⇒ String
The internal ID of the user.
-
#name ⇒ String?
The name of the user from their Whop account.
-
#username ⇒ String
The username of the user from their Whop account.
Instance Method Summary collapse
-
#initialize(id: , email: , name: , username: ) ⇒ Object
constructor
The user that made this payment.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , email: , name: , username: ) ⇒ Object
The user that made this payment.
|
|
# File 'lib/whop_sdk/models/payment.rb', line 524
|
Instance Attribute Details
#email ⇒ String?
The email of the user
510 |
# File 'lib/whop_sdk/models/payment.rb', line 510 required :email, String, nil?: true |
#id ⇒ String
The internal ID of the user.
504 |
# File 'lib/whop_sdk/models/payment.rb', line 504 required :id, String |
#name ⇒ String?
The name of the user from their Whop account.
516 |
# File 'lib/whop_sdk/models/payment.rb', line 516 required :name, String, nil?: true |
#username ⇒ String
The username of the user from their Whop account.
522 |
# File 'lib/whop_sdk/models/payment.rb', line 522 required :username, String |