Class: WhopSDK::Models::PaymentCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/payment_create_params.rb

Overview

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#company_idString

The ID of the company to create the payment for.

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/payment_create_params.rb', line 14

required :company_id, String

#member_idString

The ID of the member to create the payment for.

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/payment_create_params.rb', line 20

required :member_id, String

#payment_method_idString

The ID of the payment method to use for the payment. It must be connected to the Member being charged.

Returns:

  • (String)


27
# File 'lib/whop_sdk/models/payment_create_params.rb', line 27

required :payment_method_id, String

#planWhopSDK::Models::PaymentCreateParams::Plan

Pass this object to create a new plan for this payment



33
# File 'lib/whop_sdk/models/payment_create_params.rb', line 33

required :plan, -> { WhopSDK::PaymentCreateParams::Plan }

#plan_idString

An ID of an existing plan to use for the payment.

Returns:

  • (String)


39
# File 'lib/whop_sdk/models/payment_create_params.rb', line 39

required :plan_id, String