Module: WhopSDK::Models::PaymentCreateParams::Body

Extended by:
Internal::Type::Union
Defined in:
lib/whop_sdk/models/payment_create_params.rb

Overview

Parameters for CreatePayment

Defined Under Namespace

Classes: CreatePaymentInputWithPlan, CreatePaymentInputWithPlanID

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#initialize(external_identifier:, title:, collect_shipping_address: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan::Plan::Product for more details.

Pass this object to create a new product for this plan. We will use the product external identifier to find or create an existing product.

betwee

Parameters:

  • external_identifier (String)

    A unique ID used to find or create a product. When provided during creation, we

  • title (String)

    The title of the product.

  • collect_shipping_address (Boolean, nil) (defaults to: nil)

    Whether or not to collect shipping information at checkout from the customer.

  • custom_statement_descriptor (String, nil) (defaults to: nil)

    The custom statement descriptor for the product i.e. WHOP*SPORTS, must be

  • description (String, nil) (defaults to: nil)

    A written description of the product.

  • global_affiliate_percentage (Float, nil) (defaults to: nil)

    The percentage of the revenue that goes to the global affiliate program.

  • global_affiliate_status (Symbol, WhopSDK::Models::GlobalAffiliateStatus, nil) (defaults to: nil)

    The different statuses of the global affiliate program for a product.

  • headline (String, nil) (defaults to: nil)

    The headline of the product.

  • product_tax_code_id (String, nil) (defaults to: nil)

    The ID of the product tax code to apply to this product.

  • redirect_purchase_url (String, nil) (defaults to: nil)

    The URL to redirect the customer to after a purchase.

  • route (String, nil) (defaults to: nil)

    The route of the product.

  • visibility (Symbol, WhopSDK::Models::Visibility, nil) (defaults to: nil)

    Visibility of a resource



# File 'lib/whop_sdk/models/payment_create_params.rb', line 298