Class: WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan::Plan::Product

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_create_params.rb,
sig/whop_sdk/models/payment_create_params.rbs

Overview

See Also:

  • WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan::Plan#product

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



198
# File 'sig/whop_sdk/models/payment_create_params.rbs', line 198

def initialize: (

Instance Attribute Details

#collect_shipping_addressBoolean?

Whether or not to collect shipping information at checkout from the customer.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


250
# File 'lib/whop_sdk/models/payment_create_params.rb', line 250

optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true

#custom_statement_descriptorString?

The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ', "

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


258
# File 'lib/whop_sdk/models/payment_create_params.rb', line 258

optional :custom_statement_descriptor, String, nil?: true

#descriptionString?

A written description of the product.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


264
# File 'lib/whop_sdk/models/payment_create_params.rb', line 264

optional :description, String, nil?: true

#external_identifierString

A unique ID used to find or create a product. When provided during creation, we will look for an existing product with this external identifier — if found, it will be updated; otherwise, a new product will be created.

Parameters:

  • value (String)

Returns:

  • (String)


238
# File 'lib/whop_sdk/models/payment_create_params.rb', line 238

required :external_identifier, String

#global_affiliate_percentageFloat?

The percentage of the revenue that goes to the global affiliate program.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


270
# File 'lib/whop_sdk/models/payment_create_params.rb', line 270

optional :global_affiliate_percentage, Float, nil?: true

#global_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for a product.

Parameters:

  • value (WhopSDK::Models::global_affiliate_status, nil)

Returns:



276
# File 'lib/whop_sdk/models/payment_create_params.rb', line 276

optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#headlineString?

The headline of the product.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


282
# File 'lib/whop_sdk/models/payment_create_params.rb', line 282

optional :headline, String, nil?: true

#product_tax_code_idString?

The ID of the product tax code to apply to this product.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


288
# File 'lib/whop_sdk/models/payment_create_params.rb', line 288

optional :product_tax_code_id, String, nil?: true

#redirect_purchase_urlString?

The URL to redirect the customer to after a purchase.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


294
# File 'lib/whop_sdk/models/payment_create_params.rb', line 294

optional :redirect_purchase_url, String, nil?: true

#routeString?

The route of the product.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


300
# File 'lib/whop_sdk/models/payment_create_params.rb', line 300

optional :route, String, nil?: true

#titleString

The title of the product.

Parameters:

  • value (String)

Returns:

  • (String)


244
# File 'lib/whop_sdk/models/payment_create_params.rb', line 244

required :title, String

#visibilitySymbol, ...

Visibility of a resource

Parameters:

  • value (WhopSDK::Models::visibility, nil)

Returns:



306
# File 'lib/whop_sdk/models/payment_create_params.rb', line 306

optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


213
# File 'sig/whop_sdk/models/payment_create_params.rbs', line 213

def to_hash: -> {