Class: WhopSDK::Models::PaymentFailedWebhookEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentFailedWebhookEvent
- Defined in:
- lib/whop_sdk/models/payment_failed_webhook_event.rb
Instance Attribute Summary collapse
-
#api_version ⇒ Symbol, :v1
The API version for this webhook.
-
#company_id ⇒ String?
The company ID that this webhook event is associated with.
-
#data ⇒ WhopSDK::Models::Payment
A payment represents a completed or attempted charge.
-
#id ⇒ String
A unique ID for every single webhook request.
-
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server.
-
#type ⇒ Symbol, :"payment.failed"
The webhook event type.
Instance Method Summary collapse
-
#initialize(id:, data:, timestamp:, company_id: nil, api_version: :v1, type: :"payment.failed") ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentFailedWebhookEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, data:, timestamp:, company_id: nil, api_version: :v1, type: :"payment.failed") ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentFailedWebhookEvent for more details.
|
|
# File 'lib/whop_sdk/models/payment_failed_webhook_event.rb', line 43
|
Instance Attribute Details
#api_version ⇒ Symbol, :v1
The API version for this webhook
16 |
# File 'lib/whop_sdk/models/payment_failed_webhook_event.rb', line 16 required :api_version, const: :v1 |
#company_id ⇒ String?
The company ID that this webhook event is associated with
41 |
# File 'lib/whop_sdk/models/payment_failed_webhook_event.rb', line 41 optional :company_id, String, nil?: true |
#data ⇒ WhopSDK::Models::Payment
A payment represents a completed or attempted charge. Payments track the amount, status, currency, and payment method used.
23 |
# File 'lib/whop_sdk/models/payment_failed_webhook_event.rb', line 23 required :data, -> { WhopSDK::Payment } |
#id ⇒ String
A unique ID for every single webhook request
10 |
# File 'lib/whop_sdk/models/payment_failed_webhook_event.rb', line 10 required :id, String |
#timestamp ⇒ Time
The timestamp in ISO 8601 format that the webhook was sent at on the server
29 |
# File 'lib/whop_sdk/models/payment_failed_webhook_event.rb', line 29 required :timestamp, Time |
#type ⇒ Symbol, :"payment.failed"
The webhook event type
35 |
# File 'lib/whop_sdk/models/payment_failed_webhook_event.rb', line 35 required :type, const: :"payment.failed" |