Class: WhopSDK::Models::PaymentListFeesResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentListFeesResponse
- Defined in:
- lib/whop_sdk/models/payment_list_fees_response.rb
Overview
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ Float
The value or amount to display for the fee.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the fee.
-
#name ⇒ String
The label to display for the fee.
-
#type ⇒ Symbol, WhopSDK::Models::PaymentListFeesResponse::Type
The specific origin of the fee, if applicable.
Instance Method Summary collapse
-
#initialize(amount:, currency:, name:, type:) ⇒ Object
constructor
Represents a fee related to a payment.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:, name:, type:) ⇒ Object
Represents a fee related to a payment
|
|
# File 'lib/whop_sdk/models/payment_list_fees_response.rb', line 31
|
Instance Attribute Details
#amount ⇒ Float
The value or amount to display for the fee.
11 |
# File 'lib/whop_sdk/models/payment_list_fees_response.rb', line 11 required :amount, Float |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the fee.
17 |
# File 'lib/whop_sdk/models/payment_list_fees_response.rb', line 17 required :currency, enum: -> { WhopSDK::Currency } |
#name ⇒ String
The label to display for the fee.
23 |
# File 'lib/whop_sdk/models/payment_list_fees_response.rb', line 23 required :name, String |
#type ⇒ Symbol, WhopSDK::Models::PaymentListFeesResponse::Type
The specific origin of the fee, if applicable.
29 |
# File 'lib/whop_sdk/models/payment_list_fees_response.rb', line 29 required :type, enum: -> { WhopSDK::Models::PaymentListFeesResponse::Type } |