Class: WhopSDK::Models::PaymentListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/payment_list_params.rb

Overview

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, billing_reasons: nil, company_id: nil, created_after: nil, created_before: nil, currencies: nil, direction: nil, first: nil, include_free: nil, last: nil, order: nil, plan_ids: nil, product_ids: nil, query: nil, statuses: nil, substatuses: nil, updated_after: nil, updated_before: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PaymentListParams for more details.

Parameters:

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • billing_reasons (Array<Symbol, WhopSDK::Models::BillingReasons>, nil) (defaults to: nil)

    Filter payments by their billing reason.

  • company_id (String, nil) (defaults to: nil)

    The unique identifier of the company to list payments for.

  • created_after (Time, nil) (defaults to: nil)

    Only return payments created after this timestamp.

  • created_before (Time, nil) (defaults to: nil)

    Only return payments created before this timestamp.

  • currencies (Array<Symbol, WhopSDK::Models::Currency>, nil) (defaults to: nil)

    Filter payments by their currency code.

  • direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • include_free (Boolean, nil) (defaults to: nil)

    Whether to include payments with a zero amount.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • order (Symbol, WhopSDK::Models::PaymentListParams::Order, nil) (defaults to: nil)

    The order to sort the results by.

  • plan_ids (Array<String>, nil) (defaults to: nil)

    Filter payments to only those associated with these specific plan identifiers.

  • product_ids (Array<String>, nil) (defaults to: nil)

    Filter payments to only those associated with these specific product identifiers

  • query (String, nil) (defaults to: nil)

    Search payments by user ID, membership ID, user email, name, or username. Email

  • statuses (Array<Symbol, WhopSDK::Models::ReceiptStatus>, nil) (defaults to: nil)

    Filter payments by their current status.

  • substatuses (Array<Symbol, WhopSDK::Models::FriendlyReceiptStatus>, nil) (defaults to: nil)

    Filter payments by their current substatus for more granular filtering.

  • updated_after (Time, nil) (defaults to: nil)

    Only return payments last updated after this timestamp.

  • updated_before (Time, nil) (defaults to: nil)

    Only return payments last updated before this timestamp.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/payment_list_params.rb', line 130

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


14
# File 'lib/whop_sdk/models/payment_list_params.rb', line 14

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/payment_list_params.rb', line 20

optional :before, String, nil?: true

#billing_reasonsArray<Symbol, WhopSDK::Models::BillingReasons>?

Filter payments by their billing reason.

Returns:



26
27
28
# File 'lib/whop_sdk/models/payment_list_params.rb', line 26

optional :billing_reasons,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::BillingReasons] },
nil?: true

#company_idString?

The unique identifier of the company to list payments for.

Returns:

  • (String, nil)


34
# File 'lib/whop_sdk/models/payment_list_params.rb', line 34

optional :company_id, String, nil?: true

#created_afterTime?

Only return payments created after this timestamp.

Returns:

  • (Time, nil)


40
# File 'lib/whop_sdk/models/payment_list_params.rb', line 40

optional :created_after, Time, nil?: true

#created_beforeTime?

Only return payments created before this timestamp.

Returns:

  • (Time, nil)


46
# File 'lib/whop_sdk/models/payment_list_params.rb', line 46

optional :created_before, Time, nil?: true

#currenciesArray<Symbol, WhopSDK::Models::Currency>?

Filter payments by their currency code.

Returns:



52
# File 'lib/whop_sdk/models/payment_list_params.rb', line 52

optional :currencies, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::Currency] }, nil?: true

#directionSymbol, ...

The direction of the sort.

Returns:



58
# File 'lib/whop_sdk/models/payment_list_params.rb', line 58

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


64
# File 'lib/whop_sdk/models/payment_list_params.rb', line 64

optional :first, Integer, nil?: true

#include_freeBoolean?

Whether to include payments with a zero amount.

Returns:

  • (Boolean, nil)


70
# File 'lib/whop_sdk/models/payment_list_params.rb', line 70

optional :include_free, WhopSDK::Internal::Type::Boolean, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


76
# File 'lib/whop_sdk/models/payment_list_params.rb', line 76

optional :last, Integer, nil?: true

#orderSymbol, ...

The order to sort the results by.



82
# File 'lib/whop_sdk/models/payment_list_params.rb', line 82

optional :order, enum: -> { WhopSDK::PaymentListParams::Order }, nil?: true

#plan_idsArray<String>?

Filter payments to only those associated with these specific plan identifiers.

Returns:

  • (Array<String>, nil)


88
# File 'lib/whop_sdk/models/payment_list_params.rb', line 88

optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#product_idsArray<String>?

Filter payments to only those associated with these specific product identifiers.

Returns:

  • (Array<String>, nil)


95
# File 'lib/whop_sdk/models/payment_list_params.rb', line 95

optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#queryString?

Search payments by user ID, membership ID, user email, name, or username. Email filtering requires the member:email:read permission.

Returns:

  • (String, nil)


102
# File 'lib/whop_sdk/models/payment_list_params.rb', line 102

optional :query, String, nil?: true

#statusesArray<Symbol, WhopSDK::Models::ReceiptStatus>?

Filter payments by their current status.

Returns:



108
# File 'lib/whop_sdk/models/payment_list_params.rb', line 108

optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ReceiptStatus] }, nil?: true

#substatusesArray<Symbol, WhopSDK::Models::FriendlyReceiptStatus>?

Filter payments by their current substatus for more granular filtering.

Returns:



114
115
116
# File 'lib/whop_sdk/models/payment_list_params.rb', line 114

optional :substatuses,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::FriendlyReceiptStatus] },
nil?: true

#updated_afterTime?

Only return payments last updated after this timestamp.

Returns:

  • (Time, nil)


122
# File 'lib/whop_sdk/models/payment_list_params.rb', line 122

optional :updated_after, Time, nil?: true

#updated_beforeTime?

Only return payments last updated before this timestamp.

Returns:

  • (Time, nil)


128
# File 'lib/whop_sdk/models/payment_list_params.rb', line 128

optional :updated_before, Time, nil?: true