Class: WhopSDK::Models::PaymentListResponse::ApplicationFee

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_list_response.rb,
sig/whop_sdk/models/payment_list_response.rbs

Overview

See Also:

  • WhopSDK::Models::PaymentListResponse#application_fee

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



247
# File 'sig/whop_sdk/models/payment_list_response.rbs', line 247

def initialize: (

Instance Attribute Details

#amountFloat

The application fee amount.

Parameters:

  • value (Float)

Returns:

  • (Float)


373
# File 'lib/whop_sdk/models/payment_list_response.rb', line 373

required :amount, Float

#amount_capturedFloat

The amount of the application fee that has been captured.

Parameters:

  • value (Float)

Returns:

  • (Float)


379
# File 'lib/whop_sdk/models/payment_list_response.rb', line 379

required :amount_captured, Float

#amount_refundedFloat

The amount of the application fee that has been refunded.

Parameters:

  • value (Float)

Returns:

  • (Float)


385
# File 'lib/whop_sdk/models/payment_list_response.rb', line 385

required :amount_refunded, Float

#created_atTime

The datetime the application fee was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


391
# File 'lib/whop_sdk/models/payment_list_response.rb', line 391

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The currency of the application fee.

Parameters:

  • value (WhopSDK::Models::currency)

Returns:



397
# File 'lib/whop_sdk/models/payment_list_response.rb', line 397

required :currency, enum: -> { WhopSDK::Currency }

#idString

The unique identifier for the application fee.

Parameters:

  • value (String)

Returns:

  • (String)


367
# File 'lib/whop_sdk/models/payment_list_response.rb', line 367

required :id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


256
# File 'sig/whop_sdk/models/payment_list_response.rbs', line 256

def to_hash: -> {