Class: WhopSDK::Models::PaymentListResponse::PaymentMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_list_response.rb,
sig/whop_sdk/models/payment_list_response.rbs

Overview

See Also:

  • WhopSDK::Models::PaymentListResponse#payment_method

Defined Under Namespace

Classes: Card

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, card:, created_at:, payment_method_type:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PaymentListResponse::PaymentMethod for more details.

The tokenized payment method reference used for this payment. Null if no token was used.

Parameters:



# File 'lib/whop_sdk/models/payment_list_response.rb', line 585

Instance Attribute Details

#cardWhopSDK::Models::PaymentListResponse::PaymentMethod::Card?

The card data associated with the payment method, if its a debit or credit card.



571
# File 'lib/whop_sdk/models/payment_list_response.rb', line 571

required :card, -> { WhopSDK::Models::PaymentListResponse::PaymentMethod::Card }, nil?: true

#created_atTime

The datetime the payment token was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


577
# File 'lib/whop_sdk/models/payment_list_response.rb', line 577

required :created_at, Time

#idString

The unique identifier for the payment token.

Parameters:

  • value (String)

Returns:

  • (String)


565
# File 'lib/whop_sdk/models/payment_list_response.rb', line 565

required :id, String

#payment_method_typeSymbol, WhopSDK::Models::PaymentMethodTypes

The payment method type of the payment method

Parameters:

  • value (WhopSDK::Models::payment_method_types)

Returns:



583
# File 'lib/whop_sdk/models/payment_list_response.rb', line 583

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }

Instance Method Details

#to_hash{

Returns:

  • ({)


390
# File 'sig/whop_sdk/models/payment_list_response.rbs', line 390

def to_hash: -> {