Class: WhopSDK::Models::PaymentListResponse::Product

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_list_response.rb,
sig/whop_sdk/models/payment_list_response.rbs

Overview

See Also:

  • WhopSDK::Models::PaymentListResponse#product

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



470
# File 'sig/whop_sdk/models/payment_list_response.rbs', line 470

def initialize: (

Instance Attribute Details

#idString

The unique identifier for the product.

Parameters:

  • value (String)

Returns:

  • (String)


684
# File 'lib/whop_sdk/models/payment_list_response.rb', line 684

required :id, String

#metadataHash{Symbol=>Object}?

Custom key-value pairs stored on the product and included in payment and membership webhook payloads. Max 50 keys, 100 characters per key, 500 characters per string value.

Parameters:

  • value (::Hash[Symbol, top], nil)

Returns:

  • (Hash{Symbol=>Object}, nil)


692
# File 'lib/whop_sdk/models/payment_list_response.rb', line 692

required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#routeString

URL slug in the product's public link, e.g. pickaxe-analytics in whop.com/company/pickaxe-analytics.

Parameters:

  • value (String)

Returns:

  • (String)


699
# File 'lib/whop_sdk/models/payment_list_response.rb', line 699

required :route, String

#titleString

The display name of the product shown to customers on the product page and in search results.

Parameters:

  • value (String)

Returns:

  • (String)


706
# File 'lib/whop_sdk/models/payment_list_response.rb', line 706

required :title, String

Instance Method Details

#to_hash{

Returns:

  • ({)


477
# File 'sig/whop_sdk/models/payment_list_response.rbs', line 477

def to_hash: -> {