Class: WhopSDK::Models::PaymentMethodListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentMethodListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/payment_method_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#company_id ⇒ String?
The unique identifier of the company.
-
#created_after ⇒ Time?
Only return payment methods created after this timestamp.
-
#created_before ⇒ Time?
Only return payment methods created before this timestamp.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#member_id ⇒ String?
The unique identifier of the member to list payment methods for.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, before: nil, company_id: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, member_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethodListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, company_id: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, member_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentMethodListParams for more details.
|
|
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 65
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
14 |
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 14 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
20 |
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 20 optional :before, String, nil?: true |
#company_id ⇒ String?
The unique identifier of the company. Provide either this or member_id, not both.
27 |
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 27 optional :company_id, String, nil?: true |
#created_after ⇒ Time?
Only return payment methods created after this timestamp.
33 |
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 33 optional :created_after, Time, nil?: true |
#created_before ⇒ Time?
Only return payment methods created before this timestamp.
39 |
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 39 optional :created_before, Time, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
45 |
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 45 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
51 |
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 51 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
57 |
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 57 optional :last, Integer, nil?: true |
#member_id ⇒ String?
The unique identifier of the member to list payment methods for.
63 |
# File 'lib/whop_sdk/models/payment_method_list_params.rb', line 63 optional :member_id, String, nil?: true |