Class: WhopSDK::Models::PaymentMethodListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentMethodListResponse
- Defined in:
- lib/whop_sdk/models/payment_method_list_response.rb
Overview
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ WhopSDK::Models::PaymentMethodListResponse::Card?
The card data associated with the payment method, if its a debit or credit card.
-
#created_at ⇒ Time
The date and time the payment method was created.
-
#id ⇒ String
The ID of the payment method.
-
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The payment method type of the payment method.
Instance Method Summary collapse
-
#initialize(id: , card: , created_at: , payment_method_type: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethodListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , card: , created_at: , payment_method_type: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentMethodListResponse for more details.
A stored payment method used to process payments. This could be a credit/debit card, bank account, PayPal wallet, etc.
|
|
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 31
|
Instance Attribute Details
#card ⇒ WhopSDK::Models::PaymentMethodListResponse::Card?
The card data associated with the payment method, if its a debit or credit card.
17 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 17 required :card, -> { WhopSDK::Models::PaymentMethodListResponse::Card }, nil?: true |
#created_at ⇒ Time
The date and time the payment method was created
23 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 23 required :created_at, Time |
#id ⇒ String
The ID of the payment method
11 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 11 required :id, String |
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The payment method type of the payment method
29 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 29 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes } |