Class: WhopSDK::Models::PaymentMethodListResponse::BasePaymentMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_method_list_response.rb,
sig/whop_sdk/models/payment_method_list_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



31
# File 'sig/whop_sdk/models/payment_method_list_response.rbs', line 31

def initialize: (

Instance Attribute Details

#created_atTime

The time of the event in ISO 8601 UTC format with millisecond precision

Parameters:

  • value (Time)

Returns:

  • (Time)


47
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 47

required :created_at, Time

#idString

Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as "VXNlci0xMA==") or integer (such as 4) input value will be accepted as an ID.

Parameters:

  • value (String)

Returns:

  • (String)


41
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 41

required :id, String

#payment_method_typeSymbol, WhopSDK::Models::PaymentMethodTypes

The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).

Parameters:

  • value (WhopSDK::Models::payment_method_types)

Returns:



54
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 54

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }

#typenameSymbol, :BasePaymentMethod

The typename of this object

Parameters:

  • value (:BasePaymentMethod)

Returns:

  • (Symbol, :BasePaymentMethod)


60
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 60

required :typename, const: :BasePaymentMethod

Instance Method Details

#to_hash{

Returns:

  • ({)


38
# File 'sig/whop_sdk/models/payment_method_list_response.rbs', line 38

def to_hash: -> {