Class: WhopSDK::Models::PaymentMethodListResponse::CardPaymentMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_method_list_response.rb

Defined Under Namespace

Classes: Card

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, card:, created_at:, payment_method_type:, typename: :CardPaymentMethod) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PaymentMethodListResponse::CardPaymentMethod for more details.

A saved card payment method, including brand, last four digits, and expiration details.

Parameters:

  • id (String)

    Represents a unique identifier that is Base64 obfuscated. It is often used to re

  • card (WhopSDK::Models::PaymentMethodListResponse::CardPaymentMethod::Card)

    The card-specific details for this payment method, including brand, last four di

  • created_at (Time)

    The time of the event in ISO 8601 UTC format with millisecond precision

  • payment_method_type (Symbol, WhopSDK::Models::PaymentMethodTypes)

    The type of payment instrument stored on file (e.g., card, us_bank_account, cash

  • typename (Symbol, :CardPaymentMethod) (defaults to: :CardPaymentMethod)

    The typename of this object



# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 115

Instance Attribute Details

#cardWhopSDK::Models::PaymentMethodListResponse::CardPaymentMethod::Card

The card-specific details for this payment method, including brand, last four digits, and expiration.



94
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 94

required :card, -> { WhopSDK::Models::PaymentMethodListResponse::CardPaymentMethod::Card }

#created_atTime

The time of the event in ISO 8601 UTC format with millisecond precision

Returns:

  • (Time)


100
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 100

required :created_at, Time

#idString

Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.

Returns:

  • (String)


87
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 87

required :id, String

#payment_method_typeSymbol, WhopSDK::Models::PaymentMethodTypes

The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).



107
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 107

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }

#typenameSymbol, :CardPaymentMethod

The typename of this object

Returns:

  • (Symbol, :CardPaymentMethod)


113
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 113

required :typename, const: :CardPaymentMethod