Class: WhopSDK::Models::PaymentMethodListResponse::CashappPaymentMethod
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentMethodListResponse::CashappPaymentMethod
- Defined in:
- lib/whop_sdk/models/payment_method_list_response.rb
Defined Under Namespace
Classes: Cashapp
Instance Attribute Summary collapse
-
#cashapp ⇒ WhopSDK::Models::PaymentMethodListResponse::CashappPaymentMethod::Cashapp
The Cash App-specific details for this payment method, including cashtag and buyer ID.
-
#created_at ⇒ Time
The time of the event in ISO 8601 UTC format with millisecond precision.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).
-
#typename ⇒ Symbol, :CashappPaymentMethod
The typename of this object.
Instance Method Summary collapse
-
#initialize(id:, cashapp:, created_at:, payment_method_type:, typename: :CashappPaymentMethod) ⇒ Object
constructor
Some parameter documentations has been truncated, see CashappPaymentMethod for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, cashapp:, created_at:, payment_method_type:, typename: :CashappPaymentMethod) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentMethodListResponse::CashappPaymentMethod for more details.
A saved Cash App payment method, including the buyer’s cashtag and unique identifier.
|
|
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 303
|
Instance Attribute Details
#cashapp ⇒ WhopSDK::Models::PaymentMethodListResponse::CashappPaymentMethod::Cashapp
The Cash App-specific details for this payment method, including cashtag and buyer ID.
282 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 282 required :cashapp, -> { WhopSDK::Models::PaymentMethodListResponse::CashappPaymentMethod::Cashapp } |
#created_at ⇒ Time
The time of the event in ISO 8601 UTC format with millisecond precision
288 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 288 required :created_at, Time |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.
275 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 275 required :id, String |
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).
295 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 295 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes } |
#typename ⇒ Symbol, :CashappPaymentMethod
The typename of this object
301 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 301 required :typename, const: :CashappPaymentMethod |