Class: WhopSDK::Models::PaymentMethodListResponse::CashappPaymentMethod::Cashapp

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_method_list_response.rb,
sig/whop_sdk/models/payment_method_list_response.rbs

Overview

See Also:

  • WhopSDK::Models::PaymentMethodListResponse::CashappPaymentMethod#cashapp

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeCashapp

Returns a new instance of Cashapp.

Parameters:

  • buyer_id: (String, nil)
  • cashtag: (String, nil)


218
# File 'sig/whop_sdk/models/payment_method_list_response.rbs', line 218

def initialize: (buyer_id: String?, cashtag: String?) -> void

Instance Attribute Details

#buyer_idString?

The unique and immutable identifier assigned by Cash App to the buyer. Null if not available.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


328
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 328

required :buyer_id, String, nil?: true

#cashtagString?

The public cashtag handle of the buyer on Cash App. Null if not available.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


334
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 334

required :cashtag, String, nil?: true

Instance Method Details

#to_hash{ buyer_id: String?, cashtag: String? }

Returns:

  • ({ buyer_id: String?, cashtag: String? })


220
# File 'sig/whop_sdk/models/payment_method_list_response.rbs', line 220

def to_hash: -> { buyer_id: String?, cashtag: String? }