Class: WhopSDK::Models::PaymentMethodListResponse::IdealPaymentMethod
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentMethodListResponse::IdealPaymentMethod
- Defined in:
- lib/whop_sdk/models/payment_method_list_response.rb
Defined Under Namespace
Classes: Ideal
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time of the event in ISO 8601 UTC format with millisecond precision.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#ideal ⇒ WhopSDK::Models::PaymentMethodListResponse::IdealPaymentMethod::Ideal
The iDEAL-specific details for this payment method, including bank name and BIC.
-
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).
-
#typename ⇒ Symbol, :IdealPaymentMethod
The typename of this object.
Instance Method Summary collapse
-
#initialize(id:, created_at:, ideal:, payment_method_type:, typename: :IdealPaymentMethod) ⇒ Object
constructor
Some parameter documentations has been truncated, see IdealPaymentMethod for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, ideal:, payment_method_type:, typename: :IdealPaymentMethod) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentMethodListResponse::IdealPaymentMethod for more details.
A saved iDEAL payment method, including the customer’s bank name and BIC code.
|
|
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 386
|
Instance Attribute Details
#created_at ⇒ Time
The time of the event in ISO 8601 UTC format with millisecond precision
365 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 365 required :created_at, Time |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.
359 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 359 required :id, String |
#ideal ⇒ WhopSDK::Models::PaymentMethodListResponse::IdealPaymentMethod::Ideal
The iDEAL-specific details for this payment method, including bank name and BIC.
371 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 371 required :ideal, -> { WhopSDK::Models::PaymentMethodListResponse::IdealPaymentMethod::Ideal } |
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).
378 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 378 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes } |
#typename ⇒ Symbol, :IdealPaymentMethod
The typename of this object
384 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 384 required :typename, const: :IdealPaymentMethod |