Class: WhopSDK::Models::PaymentMethodListResponse::SepaDebitPaymentMethod::SepaDebit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_method_list_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(bank_code:, branch_code:, country:, last4:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PaymentMethodListResponse::SepaDebitPaymentMethod::SepaDebit for more details.

The SEPA Direct Debit-specific details for this payment method, including bank code and last four IBAN digits.

Parameters:

  • bank_code (String, nil)

    The bank code of the financial institution associated with this SEPA account. Nu

  • branch_code (String, nil)

    The branch code of the financial institution associated with this SEPA account.

  • country (String, nil)

    The two-letter ISO country code where the bank account is located. Null if not a

  • last4 (String, nil)

    The last four digits of the IBAN associated with this SEPA account. Null if not



# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 517

Instance Attribute Details

#bank_codeString?

The bank code of the financial institution associated with this SEPA account. Null if not available.

Returns:

  • (String, nil)


494
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 494

required :bank_code, String, nil?: true

#branch_codeString?

The branch code of the financial institution associated with this SEPA account. Null if not available.

Returns:

  • (String, nil)


501
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 501

required :branch_code, String, nil?: true

#countryString?

The two-letter ISO country code where the bank account is located. Null if not available.

Returns:

  • (String, nil)


508
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 508

required :country, String, nil?: true

#last4String?

The last four digits of the IBAN associated with this SEPA account. Null if not available.

Returns:

  • (String, nil)


515
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 515

required :last4, String, nil?: true