Class: WhopSDK::Models::PaymentMethodListResponse::UsBankAccountPaymentMethod::UsBankAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentMethodListResponse::UsBankAccountPaymentMethod::UsBankAccount
- Defined in:
- lib/whop_sdk/models/payment_method_list_response.rb
Overview
Instance Attribute Summary collapse
-
#account_type ⇒ String
The type of bank account (e.g., checking, savings).
-
#bank_name ⇒ String
The name of the financial institution holding the account.
-
#last4 ⇒ String
The last four digits of the bank account number.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#account_type ⇒ String
The type of bank account (e.g., checking, savings).
240 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 240 required :account_type, String |
#bank_name ⇒ String
The name of the financial institution holding the account.
246 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 246 required :bank_name, String |
#last4 ⇒ String
The last four digits of the bank account number.
252 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 252 required :last4, String |