Class: WhopSDK::Models::PaymentMethodRetrieveResponse::BasePaymentMethod
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentMethodRetrieveResponse::BasePaymentMethod
- Defined in:
- lib/whop_sdk/models/payment_method_retrieve_response.rb,
sig/whop_sdk/models/payment_method_retrieve_response.rbs
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time of the event in ISO 8601 UTC format with millisecond precision.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).
-
#typename ⇒ Symbol, :BasePaymentMethod
The typename of this object.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
31 |
# File 'sig/whop_sdk/models/payment_method_retrieve_response.rbs', line 31
def initialize: (
|
Instance Attribute Details
#created_at ⇒ Time
The time of the event in ISO 8601 UTC format with millisecond precision
48 |
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 48 required :created_at, Time |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to
refetch an object or as key for a cache. The ID type appears in a JSON response
as a String; however, it is not intended to be human-readable. When expected as
an input type, any string (such as "VXNlci0xMA==") or integer (such as 4)
input value will be accepted as an ID.
42 |
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 42 required :id, String |
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).
55 |
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 55 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes } |
#typename ⇒ Symbol, :BasePaymentMethod
The typename of this object
61 |
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 61 required :typename, const: :BasePaymentMethod |
Instance Method Details
#to_hash ⇒ {
38 |
# File 'sig/whop_sdk/models/payment_method_retrieve_response.rbs', line 38
def to_hash: -> {
|