Class: WhopSDK::Models::PaymentMethodRetrieveResponse::SepaDebitPaymentMethod::SepaDebit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentMethodRetrieveResponse::SepaDebitPaymentMethod::SepaDebit
- Defined in:
- lib/whop_sdk/models/payment_method_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#bank_code ⇒ String?
The bank code of the financial institution associated with this SEPA account.
-
#branch_code ⇒ String?
The branch code of the financial institution associated with this SEPA account.
-
#country ⇒ String?
The two-letter ISO country code where the bank account is located.
-
#last4 ⇒ String?
The last four digits of the IBAN associated with this SEPA account.
Instance Method Summary collapse
-
#initialize(bank_code:, branch_code:, country:, last4:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SepaDebit for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(bank_code:, branch_code:, country:, last4:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentMethodRetrieveResponse::SepaDebitPaymentMethod::SepaDebit for more details.
The SEPA Direct Debit-specific details for this payment method, including bank code and last four IBAN digits.
|
|
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 519
|
Instance Attribute Details
#bank_code ⇒ String?
The bank code of the financial institution associated with this SEPA account. Null if not available.
496 |
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 496 required :bank_code, String, nil?: true |
#branch_code ⇒ String?
The branch code of the financial institution associated with this SEPA account. Null if not available.
503 |
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 503 required :branch_code, String, nil?: true |
#country ⇒ String?
The two-letter ISO country code where the bank account is located. Null if not available.
510 |
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 510 required :country, String, nil?: true |
#last4 ⇒ String?
The last four digits of the IBAN associated with this SEPA account. Null if not available.
517 |
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 517 required :last4, String, nil?: true |