Class: WhopSDK::Models::PaymentMethodRetrieveResponse::UsBankAccountPaymentMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_method_retrieve_response.rb

Defined Under Namespace

Classes: UsBankAccount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, payment_method_type:, us_bank_account:, typename: :UsBankAccountPaymentMethod) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PaymentMethodRetrieveResponse::UsBankAccountPaymentMethod for more details.

A saved US bank account payment method, including bank name, last four digits, and account type.

Parameters:

  • id (String)

    Represents a unique identifier that is Base64 obfuscated. It is often used to re

  • created_at (Time)

    The time of the event in ISO 8601 UTC format with millisecond precision

  • payment_method_type (Symbol, WhopSDK::Models::PaymentMethodTypes)

    The type of payment instrument stored on file (e.g., card, us_bank_account, cash

  • us_bank_account (WhopSDK::Models::PaymentMethodRetrieveResponse::UsBankAccountPaymentMethod::UsBankAccount)

    The bank account-specific details for this payment method, including bank name a

  • typename (Symbol, :UsBankAccountPaymentMethod) (defaults to: :UsBankAccountPaymentMethod)

    The typename of this object



# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 217

Instance Attribute Details

#created_atTime

The time of the event in ISO 8601 UTC format with millisecond precision

Returns:

  • (Time)


194
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 194

required :created_at, Time

#idString

Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.

Returns:

  • (String)


188
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 188

required :id, String

#payment_method_typeSymbol, WhopSDK::Models::PaymentMethodTypes

The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).



201
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 201

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }

#typenameSymbol, :UsBankAccountPaymentMethod

The typename of this object

Returns:

  • (Symbol, :UsBankAccountPaymentMethod)


207
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 207

required :typename, const: :UsBankAccountPaymentMethod

#us_bank_accountWhopSDK::Models::PaymentMethodRetrieveResponse::UsBankAccountPaymentMethod::UsBankAccount

The bank account-specific details for this payment method, including bank name and last four digits.



214
215
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 214

required :us_bank_account,
-> { WhopSDK::Models::PaymentMethodRetrieveResponse::UsBankAccountPaymentMethod::UsBankAccount }