Class: WhopSDK::Models::PaymentMethodRetrieveResponse::UsBankAccountPaymentMethod::UsBankAccount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_method_retrieve_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#account_typeString

The type of bank account (e.g., checking, savings).

Returns:

  • (String)


241
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 241

required :account_type, String

#bank_nameString

The name of the financial institution holding the account.

Returns:

  • (String)


247
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 247

required :bank_name, String

#last4String

The last four digits of the bank account number.

Returns:

  • (String)


253
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 253

required :last4, String