Class: WhopSDK::Models::PayoutAccountRetrieveResponse::BusinessRepresentative
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PayoutAccountRetrieveResponse::BusinessRepresentative
- Defined in:
- lib/whop_sdk/models/payout_account_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#date_of_birth ⇒ String?
The date of birth of the business representative in ISO 8601 format (YYYY-MM-DD).
-
#first_name ⇒ String?
The first name of the business representative.
-
#last_name ⇒ String?
The last name of the business representative.
-
#middle_name ⇒ String?
The middle name of the business representative.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#date_of_birth ⇒ String?
The date of birth of the business representative in ISO 8601 format (YYYY-MM-DD).
143 |
# File 'lib/whop_sdk/models/payout_account_retrieve_response.rb', line 143 required :date_of_birth, String, nil?: true |
#first_name ⇒ String?
The first name of the business representative.
149 |
# File 'lib/whop_sdk/models/payout_account_retrieve_response.rb', line 149 required :first_name, String, nil?: true |
#last_name ⇒ String?
The last name of the business representative.
155 |
# File 'lib/whop_sdk/models/payout_account_retrieve_response.rb', line 155 required :last_name, String, nil?: true |
#middle_name ⇒ String?
The middle name of the business representative.
161 |
# File 'lib/whop_sdk/models/payout_account_retrieve_response.rb', line 161 required :middle_name, String, nil?: true |