Class: WhopSDK::Models::PayoutAccountStatusUpdatedWebhookEvent::Data::BusinessRepresentative
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PayoutAccountStatusUpdatedWebhookEvent::Data::BusinessRepresentative
- Defined in:
- lib/whop_sdk/models/payout_account_status_updated_webhook_event.rb,
sig/whop_sdk/models/payout_account_status_updated_webhook_event.rbs
Overview
Instance Attribute Summary collapse
-
#date_of_birth ⇒ String?
The date of birth of the business representative in ISO 8601 format (YYYY-MM-DD).
-
#first_name ⇒ String?
The first name of the business representative.
-
#last_name ⇒ String?
The last name of the business representative.
-
#middle_name ⇒ String?
The middle name of the business representative.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
154 |
# File 'sig/whop_sdk/models/payout_account_status_updated_webhook_event.rbs', line 154
def initialize: (
|
Instance Attribute Details
#date_of_birth ⇒ String?
The date of birth of the business representative in ISO 8601 format (YYYY-MM-DD).
194 |
# File 'lib/whop_sdk/models/payout_account_status_updated_webhook_event.rb', line 194 required :date_of_birth, String, nil?: true |
#first_name ⇒ String?
The first name of the business representative.
200 |
# File 'lib/whop_sdk/models/payout_account_status_updated_webhook_event.rb', line 200 required :first_name, String, nil?: true |
#last_name ⇒ String?
The last name of the business representative.
206 |
# File 'lib/whop_sdk/models/payout_account_status_updated_webhook_event.rb', line 206 required :last_name, String, nil?: true |
#middle_name ⇒ String?
The middle name of the business representative.
212 |
# File 'lib/whop_sdk/models/payout_account_status_updated_webhook_event.rb', line 212 required :middle_name, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
161 |
# File 'sig/whop_sdk/models/payout_account_status_updated_webhook_event.rbs', line 161
def to_hash: -> {
|