Class: WhopSDK::Models::PayoutCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/payout_create_params.rb,
sig/whop_sdk/models/payout_create_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Payouts#create

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, amount:, payout_method_id:, currency: nil, idempotency_key: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PayoutCreateParams for more details.

Parameters:

  • account_id (String)

    The account to pay out from (a biz_ identifier).

  • amount (Float)

    The amount to pay out in the specified currency.

  • payout_method_id (String)

    The saved payout method to deliver to (a potk_ identifier).

  • currency (String) (defaults to: nil)

    The payout currency. Defaults to usd.

  • idempotency_key (String) (defaults to: nil)

    A client-generated key that makes retries safe. Retrying with the same key retur

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/payout_create_params.rb', line 41

Instance Attribute Details

#account_idString

The account to pay out from (a biz_ identifier).

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/payout_create_params.rb', line 14

required :account_id, String

#amountFloat

The amount to pay out in the specified currency.

Parameters:

  • value (Float)

Returns:

  • (Float)


20
# File 'lib/whop_sdk/models/payout_create_params.rb', line 20

required :amount, Float

#currencyString?

The payout currency. Defaults to usd.

Parameters:

  • (String)

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/payout_create_params.rb', line 32

optional :currency, String

#idempotency_keyString?

A client-generated key that makes retries safe. Retrying with the same key returns the original payout instead of creating a second one.

Parameters:

  • (String)

Returns:

  • (String, nil)


39
# File 'lib/whop_sdk/models/payout_create_params.rb', line 39

optional :idempotency_key, String

#payout_method_idString

The saved payout method to deliver to (a potk_ identifier).

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/whop_sdk/models/payout_create_params.rb', line 26

required :payout_method_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


40
# File 'sig/whop_sdk/models/payout_create_params.rbs', line 40

def to_hash: -> {