Class: WhopSDK::Models::PayoutCreateResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payout_create_response.rb,
sig/whop_sdk/models/payout_create_response.rbs

Overview

See Also:

  • WhopSDK::Resources::Payouts#create

Defined Under Namespace

Modules: Object, Speed, Status Classes: PayoutToken

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(icon_url:, payer_name:) ⇒ Object

Payout destination display details.

Parameters:

  • icon_url (String, nil)

    Payout destination icon URL.

  • payer_name (String, nil)

    Payout destination display name.



# File 'lib/whop_sdk/models/payout_create_response.rb', line 73

Instance Attribute Details

#amountFloat

The payout amount in whole currency units.

Parameters:

  • value (Float)

Returns:

  • (Float)


17
# File 'lib/whop_sdk/models/payout_create_response.rb', line 17

required :amount, Float

#created_atTime

When the payout was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/payout_create_response.rb', line 23

required :created_at, Time

#currencyString

Payout currency.

Parameters:

  • value (String)

Returns:

  • (String)


29
# File 'lib/whop_sdk/models/payout_create_response.rb', line 29

required :currency, String

#estimated_arrivalTime?

Estimated time the funds become available in the destination account. Null until the payout settles.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


36
# File 'lib/whop_sdk/models/payout_create_response.rb', line 36

required :estimated_arrival, Time, nil?: true

#fee_amountFloat

The fee charged for the payout, in the payout currency.

Parameters:

  • value (Float)

Returns:

  • (Float)


42
# File 'lib/whop_sdk/models/payout_create_response.rb', line 42

required :fee_amount, Float

#idString

Payout ID.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/payout_create_response.rb', line 11

required :id, String

#objectSymbol, WhopSDK::Models::PayoutCreateResponse::Object

Parameters:

  • value (WhopSDK::Models::PayoutCreateResponse::object)

Returns:



47
# File 'lib/whop_sdk/models/payout_create_response.rb', line 47

required :object, enum: -> { WhopSDK::Models::PayoutCreateResponse::Object }

#payer_nameString?

Name of the entity processing the payout. Null until the payout settles.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


53
# File 'lib/whop_sdk/models/payout_create_response.rb', line 53

required :payer_name, String, nil?: true

#payout_tokenWhopSDK::Models::PayoutCreateResponse::PayoutToken?

The saved payout method used. Requires payout:destination:read; null without it.



59
# File 'lib/whop_sdk/models/payout_create_response.rb', line 59

required :payout_token, -> { WhopSDK::Models::PayoutCreateResponse::PayoutToken }, nil?: true

#speedSymbol, WhopSDK::Models::PayoutCreateResponse::Speed

Payout delivery speed.

Parameters:

  • value (WhopSDK::Models::PayoutCreateResponse::speed)

Returns:



65
# File 'lib/whop_sdk/models/payout_create_response.rb', line 65

required :speed, enum: -> { WhopSDK::Models::PayoutCreateResponse::Speed }

#statusSymbol, WhopSDK::Models::PayoutCreateResponse::Status

Current payout status, in the same vocabulary as GET /payouts.

Parameters:

  • value (WhopSDK::Models::PayoutCreateResponse::status)

Returns:



71
# File 'lib/whop_sdk/models/payout_create_response.rb', line 71

required :status, enum: -> { WhopSDK::Models::PayoutCreateResponse::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/payout_create_response.rb', line 105

Instance Method Details

#to_hash{

Returns:

  • ({)


55
# File 'sig/whop_sdk/models/payout_create_response.rbs', line 55

def to_hash: -> {