Class: WhopSDK::Models::PayoutListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PayoutListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/payout_list_params.rb,
sig/whop_sdk/models/payout_list_params.rbs
Overview
Instance Attribute Summary collapse
-
#account_id ⇒ String?
The owning account ID (a biz_ identifier).
-
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
-
#before ⇒ String?
Cursor to fetch the page before (from page_info.start_cursor).
-
#currency ⇒ String?
Optional currency code filter, for example
usd. -
#first ⇒ Integer?
Number of payouts to return from the start of the window.
-
#last ⇒ Integer?
Number of payouts to return from the end of the window.
-
#user_id ⇒ String?
The owning user ID (a user_ identifier).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(account_id: nil, after: nil, before: nil, currency: nil, first: nil, last: nil, user_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id: nil, after: nil, before: nil, currency: nil, first: nil, last: nil, user_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/payout_list_params.rb', line 52
|
Instance Attribute Details
#account_id ⇒ String?
The owning account ID (a biz_ identifier). Provide this or user_id.
14 |
# File 'lib/whop_sdk/models/payout_list_params.rb', line 14 optional :account_id, String |
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
20 |
# File 'lib/whop_sdk/models/payout_list_params.rb', line 20 optional :after, String |
#before ⇒ String?
Cursor to fetch the page before (from page_info.start_cursor).
26 |
# File 'lib/whop_sdk/models/payout_list_params.rb', line 26 optional :before, String |
#currency ⇒ String?
Optional currency code filter, for example usd.
32 |
# File 'lib/whop_sdk/models/payout_list_params.rb', line 32 optional :currency, String |
#first ⇒ Integer?
Number of payouts to return from the start of the window.
38 |
# File 'lib/whop_sdk/models/payout_list_params.rb', line 38 optional :first, Integer |
#last ⇒ Integer?
Number of payouts to return from the end of the window.
44 |
# File 'lib/whop_sdk/models/payout_list_params.rb', line 44 optional :last, Integer |
#user_id ⇒ String?
The owning user ID (a user_ identifier). Provide this or account_id.
50 |
# File 'lib/whop_sdk/models/payout_list_params.rb', line 50 optional :user_id, String |
Instance Method Details
#to_hash ⇒ {
58 |
# File 'sig/whop_sdk/models/payout_list_params.rbs', line 58
def to_hash: -> {
|