Class: WhopSDK::Models::PayoutMethodCreatedWebhookEvent::Data::Destination

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payout_method_created_webhook_event.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(category:, country_code:, name:) ⇒ Object

The payout destination configuration linked to this token. Null if not yet configured.

Parameters:

  • category (Symbol, WhopSDK::Models::PayoutDestinationCategory)

    The category of the payout destination

  • country_code (String)

    The country code of the payout destination

  • name (String)

    The name of the payer associated with the payout destination



# File 'lib/whop_sdk/models/payout_method_created_webhook_event.rb', line 182

Instance Attribute Details

#categorySymbol, WhopSDK::Models::PayoutDestinationCategory

The category of the payout destination



168
# File 'lib/whop_sdk/models/payout_method_created_webhook_event.rb', line 168

required :category, enum: -> { WhopSDK::PayoutDestinationCategory }

#country_codeString

The country code of the payout destination

Returns:

  • (String)


174
# File 'lib/whop_sdk/models/payout_method_created_webhook_event.rb', line 174

required :country_code, String

#nameString

The name of the payer associated with the payout destination

Returns:

  • (String)


180
# File 'lib/whop_sdk/models/payout_method_created_webhook_event.rb', line 180

required :name, String