Class: WhopSDK::Models::PayoutMethodListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payout_method_list_response.rb

Overview

Defined Under Namespace

Classes: Company, Destination

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

The company associated with this payout destination. Null if not linked to a specific company.

Parameters:

  • id (String)

    The unique identifier for the company.



# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 68

Instance Attribute Details

#account_referenceString?

A masked identifier for the payout destination, such as the last four digits of a bank account or an email address. Null if no reference is available.

Returns:

  • (String, nil)


18
# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 18

required :account_reference, String, nil?: true

#companyWhopSDK::Models::PayoutMethodListResponse::Company?

The company associated with this payout destination. Null if not linked to a specific company.



25
# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 25

required :company, -> { WhopSDK::Models::PayoutMethodListResponse::Company }, nil?: true

#created_atTime

The datetime the payout token was created.

Returns:

  • (Time)


31
# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 31

required :created_at, Time

#currencyString

The three-letter ISO currency code that payouts are delivered in for this destination.

Returns:

  • (String)


38
# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 38

required :currency, String

#destinationWhopSDK::Models::PayoutMethodListResponse::Destination?

The payout destination configuration linked to this token. Null if not yet configured.



45
# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 45

required :destination, -> { WhopSDK::Models::PayoutMethodListResponse::Destination }, nil?: true

#idString

The unique identifier for the payout token.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 11

required :id, String

#institution_nameString?

The name of the bank or financial institution receiving payouts. Null if not applicable or not provided.

Returns:

  • (String, nil)


52
# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 52

required :institution_name, String, nil?: true

#is_defaultBoolean

Whether this is the default payout destination for the associated payout account.

Returns:

  • (Boolean)


59
# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 59

required :is_default, WhopSDK::Internal::Type::Boolean

#nicknameString?

A user-defined label to help identify this payout destination. Not sent to the provider. Null if no nickname has been set.

Returns:

  • (String, nil)


66
# File 'lib/whop_sdk/models/payout_method_list_response.rb', line 66

required :nickname, String, nil?: true