Module: WhopSDK::Models::Payouts::MethodListParams::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/whop_sdk/models/payouts/method_list_params.rb,
sig/whop_sdk/models/payouts/method_list_params.rbs

Overview

Optional status filter. created means saved but unused, active means a payout through it succeeded, broken means the last payout failed and the method needs fixing.

Constant Summary collapse

CREATED =

Returns:

  • (:created)
:created
ACTIVE =

Returns:

  • (:active)
:active
BROKEN =

Returns:

  • (:broken)
:broken

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/payouts/method_list_params.rb', line 114

Instance Method Details

#self?.values::Array[WhopSDK::Models::Payouts::MethodListParams::status]

Returns:

  • (::Array[WhopSDK::Models::Payouts::MethodListParams::status])


102
# File 'sig/whop_sdk/models/payouts/method_list_params.rbs', line 102

def self?.values: -> ::Array[WhopSDK::Models::Payouts::MethodListParams::status]