Class: WhopSDK::Models::Payouts::MethodListResponse::Quote

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payouts/method_list_response.rb,
sig/whop_sdk/models/payouts/method_list_response.rbs

Overview

See Also:

  • WhopSDK::Models::Payouts::MethodListResponse#quote

Defined Under Namespace

Classes: Instant, Standard

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(estimated_arrival:, fee:, total_received:) ⇒ Object

Instant-delivery estimate. Null if the method does not support instant delivery, instant delivery is unavailable for the account, or the amount does not cover the fee.

Parameters:

  • estimated_arrival (Time)

    Estimated time the funds become available.

  • fee (Float)

    Total fee charged, in the withdrawal currency.

  • total_received (Float)

    Amount delivered after fees, in the withdrawal currency.



# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 213

Instance Attribute Details

#amountFloat

The withdrawal amount the quote is for.

Parameters:

  • value (Float)

Returns:

  • (Float)


172
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 172

required :amount, Float

#currencyString

Currency of the quoted amount.

Parameters:

  • value (String)

Returns:

  • (String)


178
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 178

required :currency, String

#exchange_rateFloat

Exchange rate from the withdrawal currency to the destination currency.

Parameters:

  • value (Float)

Returns:

  • (Float)


184
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 184

required :exchange_rate, Float

#instantWhopSDK::Models::Payouts::MethodListResponse::Quote::Instant?

Instant-delivery estimate. Null if the method does not support instant delivery, instant delivery is unavailable for the account, or the amount does not cover the fee.



192
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 192

required :instant, -> { WhopSDK::Models::Payouts::MethodListResponse::Quote::Instant }, nil?: true

#max_limitFloat?

Maximum withdrawal amount for this method, in the withdrawal currency.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


198
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 198

required :max_limit, Float, nil?: true

#min_limitFloat

Minimum withdrawal amount for this method, in the withdrawal currency.

Parameters:

  • value (Float)

Returns:

  • (Float)


204
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 204

required :min_limit, Float

#standardWhopSDK::Models::Payouts::MethodListResponse::Quote::Standard?

Standard-delivery estimate. Null if the method does not support standard delivery, or the amount does not cover the fee.



211
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 211

required :standard, -> { WhopSDK::Models::Payouts::MethodListResponse::Quote::Standard }, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


158
# File 'sig/whop_sdk/models/payouts/method_list_response.rbs', line 158

def to_hash: -> {