Class: WhopSDK::Models::PersonListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/person_list_params.rb,
sig/whop_sdk/models/person_list_params.rbs

Overview

See Also:

  • WhopSDK::Resources::People#list

Defined Under Namespace

Modules: Direction

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id: nil, after: nil, before: nil, direction: nil, filters: nil, first: nil, from: nil, sort: nil, to: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PersonListParams for more details.

acco

Parameters:

  • account_id (String) (defaults to: nil)

    The ID of the account, which will look like biz_*. Optional for

  • after (String) (defaults to: nil)

    A cursor for fetching people after a previous page.

  • before (String) (defaults to: nil)

    A cursor for fetching people before a later page.

  • direction (Symbol, WhopSDK::Models::PersonListParams::Direction) (defaults to: nil)

    Sort direction. Defaults to desc.

  • filters (String) (defaults to: nil)

    A JSON-encoded array of filters, each with field, operator, and value keys.

  • first (Integer) (defaults to: nil)

    The number of people to return (default 100, max 100).

  • from (Integer) (defaults to: nil)

    Start of the time range as a Unix timestamp. Defaults to 366 days before to.

  • sort (String) (defaults to: nil)

    Column to sort by (e.g. last_seen_at, ltv, purchase_count). Defaults to last_see

  • to (Integer) (defaults to: nil)

    End of the time range as a Unix timestamp. Defaults to now.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/person_list_params.rb', line 66

Instance Attribute Details

#account_idString?

The ID of the account, which will look like biz_*. Optional for account API keys; required for credentials that can access multiple accounts.

Parameters:

  • (String)

Returns:

  • (String, nil)


15
# File 'lib/whop_sdk/models/person_list_params.rb', line 15

optional :account_id, String

#afterString?

A cursor for fetching people after a previous page.

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/whop_sdk/models/person_list_params.rb', line 21

optional :after, String

#beforeString?

A cursor for fetching people before a later page.

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/whop_sdk/models/person_list_params.rb', line 27

optional :before, String

#directionSymbol, ...

Sort direction. Defaults to desc.



33
# File 'lib/whop_sdk/models/person_list_params.rb', line 33

optional :direction, enum: -> { WhopSDK::PersonListParams::Direction }

#filtersString?

A JSON-encoded array of filters, each with field, operator, and value keys.

Parameters:

  • (String)

Returns:

  • (String, nil)


39
# File 'lib/whop_sdk/models/person_list_params.rb', line 39

optional :filters, String

#firstInteger?

The number of people to return (default 100, max 100).

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


45
# File 'lib/whop_sdk/models/person_list_params.rb', line 45

optional :first, Integer

#fromInteger?

Start of the time range as a Unix timestamp. Defaults to 366 days before to.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


51
# File 'lib/whop_sdk/models/person_list_params.rb', line 51

optional :from, Integer

#sortString?

Column to sort by (e.g. last_seen_at, ltv, purchase_count). Defaults to last_seen_at.

Parameters:

  • (String)

Returns:

  • (String, nil)


58
# File 'lib/whop_sdk/models/person_list_params.rb', line 58

optional :sort, String

#toInteger?

End of the time range as a Unix timestamp. Defaults to now.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


64
# File 'lib/whop_sdk/models/person_list_params.rb', line 64

optional :to, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


72
# File 'sig/whop_sdk/models/person_list_params.rbs', line 72

def to_hash: -> {