Class: WhopSDK::Models::PersonRetrieveParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/person_retrieve_params.rb,
sig/whop_sdk/models/person_retrieve_params.rbs

Overview

See Also:

  • WhopSDK::Resources::People#retrieve

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(person_id:, account_id: nil, from: nil, to: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PersonRetrieveParams for more details.

acco

Parameters:

  • person_id (String)
  • account_id (String) (defaults to: nil)

    The ID of the account, which will look like biz_*. Optional for

  • from (Integer) (defaults to: nil)

    Start of the time range as a Unix timestamp.

  • to (Integer) (defaults to: nil)

    End of the time range as a Unix timestamp. Defaults to now.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/person_retrieve_params.rb', line 34

Instance Attribute Details

#account_idString?

The ID of the account, which will look like biz_*. Optional for account API keys; required for credentials that can access multiple accounts.

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/person_retrieve_params.rb', line 20

optional :account_id, String

#fromInteger?

Start of the time range as a Unix timestamp.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


26
# File 'lib/whop_sdk/models/person_retrieve_params.rb', line 26

optional :from, Integer

#person_idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/person_retrieve_params.rb', line 13

required :person_id, String

#toInteger?

End of the time range as a Unix timestamp. Defaults to now.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


32
# File 'lib/whop_sdk/models/person_retrieve_params.rb', line 32

optional :to, Integer

Instance Method Details

#to_hash{

Returns:

  • ({)


33
# File 'sig/whop_sdk/models/person_retrieve_params.rbs', line 33

def to_hash: -> {