Module: WhopSDK::Models::PlanCalculateTaxResponse::TaxBehavior
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/whop_sdk/models/plan_calculate_tax_response.rb,
sig/whop_sdk/models/plan_calculate_tax_response.rbs
Overview
Whether tax is added on top of the plan price or already included in it for this buyer's location.
Constant Summary collapse
- EXCLUSIVE =
:exclusive- INCLUSIVE =
:inclusive
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/plan_calculate_tax_response.rb', line 89
|
Instance Method Details
#self?.values ⇒ ::Array[WhopSDK::Models::PlanCalculateTaxResponse::tax_behavior]
63 |
# File 'sig/whop_sdk/models/plan_calculate_tax_response.rbs', line 63
def self?.values: -> ::Array[WhopSDK::Models::PlanCalculateTaxResponse::tax_behavior]
|