Class: WhopSDK::Models::PlanCreateParams::PaymentMethodConfiguration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/plan_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PlanCreateParams::PaymentMethodConfiguration for more details.

The explicit payment method configuration for the plan. If not provided, the platform or company’s defaults will apply.

Parameters:

  • disabled (Array<Symbol, WhopSDK::Models::PaymentMethodTypes>) (defaults to: )

    An array of payment method identifiers that are explicitly disabled. Only applie

  • enabled (Array<Symbol, WhopSDK::Models::PaymentMethodTypes>) (defaults to: )

    An array of payment method identifiers that are explicitly enabled. This means t

  • include_platform_defaults (Boolean) (defaults to: )

    Whether Whop’s platform default payment method enablement settings are included



# File 'lib/whop_sdk/models/plan_create_params.rb', line 331

Instance Attribute Details

#disabledArray<Symbol, WhopSDK::Models::PaymentMethodTypes>

An array of payment method identifiers that are explicitly disabled. Only applies if the include_platform_defaults is true.

Returns:



312
# File 'lib/whop_sdk/models/plan_create_params.rb', line 312

required :disabled, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::PaymentMethodTypes] }

#enabledArray<Symbol, WhopSDK::Models::PaymentMethodTypes>

An array of payment method identifiers that are explicitly enabled. This means these payment methods will be shown on checkout. Example use case is to only enable a specific payment method like cashapp, or extending the platform defaults with additional methods.

Returns:



321
# File 'lib/whop_sdk/models/plan_create_params.rb', line 321

required :enabled, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::PaymentMethodTypes] }

#include_platform_defaultsBoolean

Whether Whop’s platform default payment method enablement settings are included in this configuration. The full list of default payment methods can be found in the documentation at docs.whop.com/payments.

Returns:

  • (Boolean)


329
# File 'lib/whop_sdk/models/plan_create_params.rb', line 329

required :include_platform_defaults, WhopSDK::Internal::Type::Boolean