Class: WhopSDK::Models::PlanListResponse::PaymentMethodConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanListResponse::PaymentMethodConfiguration
- Defined in:
- lib/whop_sdk/models/plan_list_response.rb
Overview
Instance Attribute Summary collapse
-
#disabled ⇒ Array<Symbol, WhopSDK::Models::PaymentMethodTypes>
An array of payment method identifiers that are explicitly disabled.
-
#enabled ⇒ Array<Symbol, WhopSDK::Models::PaymentMethodTypes>
An array of payment method identifiers that are explicitly enabled.
-
#include_platform_defaults ⇒ Boolean
Whether Whop’s platform default payment method enablement settings are included in this configuration.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#disabled ⇒ Array<Symbol, WhopSDK::Models::PaymentMethodTypes>
An array of payment method identifiers that are explicitly disabled. Only applies if the include_platform_defaults is true.
241 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 241 required :disabled, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::PaymentMethodTypes] } |
#enabled ⇒ Array<Symbol, WhopSDK::Models::PaymentMethodTypes>
An array of payment method identifiers that are explicitly enabled. This means these payment methods will be shown on checkout. Example use case is to only enable a specific payment method like cashapp, or extending the platform defaults with additional methods.
250 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 250 required :enabled, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::PaymentMethodTypes] } |
#include_platform_defaults ⇒ Boolean
Whether Whop’s platform default payment method enablement settings are included in this configuration. The full list of default payment methods can be found in the documentation at docs.whop.com/payments.
258 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 258 required :include_platform_defaults, WhopSDK::Internal::Type::Boolean |