Class: WhopSDK::Models::PlanUpdateParams::CheckoutStyling

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/plan_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, adaptive_pricing_enabled: nil, billing_period: nil, checkout_styling: nil, currency: nil, custom_fields: nil, description: nil, expiration_days: nil, image: nil, initial_price: nil, internal_notes: nil, legacy_payment_method_controls: nil, metadata: nil, offer_cancel_discount: nil, override_tax_type: nil, payment_method_configuration: nil, renewal_price: nil, stock: nil, strike_through_initial_price: nil, strike_through_renewal_price: nil, three_ds_level: nil, title: nil, trial_period_days: nil, unlimited_stock: nil, visibility: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PlanUpdateParams for more details.

Parameters:

  • id (String)
  • adaptive_pricing_enabled (Boolean, nil) (defaults to: nil)

    Whether this plan accepts local currency payments via adaptive pricing.

  • billing_period (Integer, nil) (defaults to: nil)

    The number of days between recurring charges. For example, 30 for monthly or 365

  • checkout_styling (WhopSDK::Models::PlanUpdateParams::CheckoutStyling, nil) (defaults to: nil)

    Checkout styling overrides for this plan. Pass null to remove all overrides and

  • currency (Symbol, WhopSDK::Models::Currency, nil) (defaults to: nil)

    The available currencies on the platform

  • custom_fields (Array<WhopSDK::Models::PlanUpdateParams::CustomField>, nil) (defaults to: nil)

    An array of custom field definitions to collect from customers at checkout.

  • description (String, nil) (defaults to: nil)

    A text description of the plan displayed to customers on the product page.

  • expiration_days (Integer, nil) (defaults to: nil)

    The number of days until the membership expires and access is revoked. For examp

  • image (WhopSDK::Models::PlanUpdateParams::Image, nil) (defaults to: nil)

    An image displayed on the product page to represent this plan.

  • initial_price (Float, nil) (defaults to: nil)

    The amount charged on the first purchase. Provided in the plan’s currency (e.g.,

  • internal_notes (String, nil) (defaults to: nil)

    Private notes visible only to the business owner. Not shown to customers.

  • legacy_payment_method_controls (Boolean, nil) (defaults to: nil)

    Whether this plan uses legacy payment method controls.

  • metadata (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Custom key-value pairs to store on the plan. Included in webhook payloads for pa

  • offer_cancel_discount (Boolean, nil) (defaults to: nil)

    Whether to offer a retention discount when a customer attempts to cancel.

  • override_tax_type (Symbol, WhopSDK::Models::TaxType, nil) (defaults to: nil)

    Whether or not the tax is included in a plan’s price (or if it hasn’t been set u

  • payment_method_configuration (WhopSDK::Models::PlanUpdateParams::PaymentMethodConfiguration, nil) (defaults to: nil)

    Explicit payment method configuration for the plan. Sending null removes any cus

  • renewal_price (Float, nil) (defaults to: nil)

    The amount charged each billing period for recurring plans. Provided in the plan

  • stock (Integer, nil) (defaults to: nil)

    The maximum number of units available for purchase. Ignored when unlimited_stock

  • strike_through_initial_price (Float, nil) (defaults to: nil)

    A comparison price displayed with a strikethrough for the initial price. Provide

  • strike_through_renewal_price (Float, nil) (defaults to: nil)

    A comparison price displayed with a strikethrough for the renewal price. Provide

  • three_ds_level (Symbol, WhopSDK::Models::PlanUpdateParams::ThreeDSLevel, nil) (defaults to: nil)

    The 3D Secure behavior for a plan.

  • title (String, nil) (defaults to: nil)

    The display name of the plan shown to customers on the product page.

  • trial_period_days (Integer, nil) (defaults to: nil)

    The number of free trial days before the first charge on a recurring plan.

  • unlimited_stock (Boolean, nil) (defaults to: nil)

    Whether the plan has unlimited stock. When true, the stock field is ignored.

  • visibility (Symbol, WhopSDK::Models::Visibility, nil) (defaults to: nil)

    Visibility of a resource

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/whop_sdk/models/plan_update_params.rb', line 231

class CheckoutStyling < WhopSDK::Internal::Type::BaseModel
  # @!attribute background_color
  #   A hex color code for the checkout page background, applied to the order summary
  #   panel (e.g. #F4F4F5).
  #
  #   @return [String, nil]
  optional :background_color, String, nil?: true

  # @!attribute border_style
  #   The different border-radius styles available for checkout pages.
  #
  #   @return [Symbol, WhopSDK::Models::CheckoutShape, nil]
  optional :border_style, enum: -> { WhopSDK::CheckoutShape }, nil?: true

  # @!attribute button_color
  #   A hex color code for the button color (e.g. #FF5733).
  #
  #   @return [String, nil]
  optional :button_color, String, nil?: true

  # @!attribute font_family
  #   The different font families available for checkout pages.
  #
  #   @return [Symbol, WhopSDK::Models::CheckoutFont, nil]
  optional :font_family, enum: -> { WhopSDK::CheckoutFont }, nil?: true

  # @!method initialize(background_color: nil, border_style: nil, button_color: nil, font_family: nil)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::PlanUpdateParams::CheckoutStyling} for more details.
  #
  #   Checkout styling overrides for this plan. Pass null to remove all overrides and
  #   inherit from the company default.
  #
  #   @param background_color [String, nil] A hex color code for the checkout page background, applied to the order summary
  #
  #   @param border_style [Symbol, WhopSDK::Models::CheckoutShape, nil] The different border-radius styles available for checkout pages.
  #
  #   @param button_color [String, nil] A hex color code for the button color (e.g. #FF5733).
  #
  #   @param font_family [Symbol, WhopSDK::Models::CheckoutFont, nil] The different font families available for checkout pages.
end

Instance Attribute Details

#background_colorString?

A hex color code for the checkout page background, applied to the order summary panel (e.g. #F4F4F5).

Returns:

  • (String, nil)


237
# File 'lib/whop_sdk/models/plan_update_params.rb', line 237

optional :background_color, String, nil?: true

#border_styleSymbol, ...

The different border-radius styles available for checkout pages.

Returns:



243
# File 'lib/whop_sdk/models/plan_update_params.rb', line 243

optional :border_style, enum: -> { WhopSDK::CheckoutShape }, nil?: true

#button_colorString?

A hex color code for the button color (e.g. #FF5733).

Returns:

  • (String, nil)


249
# File 'lib/whop_sdk/models/plan_update_params.rb', line 249

optional :button_color, String, nil?: true

#font_familySymbol, ...

The different font families available for checkout pages.

Returns:



255
# File 'lib/whop_sdk/models/plan_update_params.rb', line 255

optional :font_family, enum: -> { WhopSDK::CheckoutFont }, nil?: true