Class: WhopSDK::Models::ProductCreateParams::BannerImage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductCreateParams::BannerImage
- Defined in:
- lib/whop_sdk/models/product_create_params.rb
Instance Attribute Summary collapse
-
#direct_upload_id ⇒ String?
This ID should be used the first time you upload an attachment.
-
#id ⇒ String?
The ID of an existing attachment object.
Instance Method Summary collapse
-
#initialize(company_id: , title: , access_pass_type: nil, banner_image: nil, business_type: nil, collect_shipping_address: nil, custom_cta: nil, custom_cta_url: nil, custom_statement_descriptor: nil, description: nil, experience_ids: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, industry_type: nil, member_affiliate_percentage: nil, member_affiliate_status: nil, plan_options: nil, product_highlights: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhopSDK::Models::ProductCreateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id: , title: , access_pass_type: nil, banner_image: nil, business_type: nil, collect_shipping_address: nil, custom_cta: nil, custom_cta_url: nil, custom_statement_descriptor: nil, description: nil, experience_ids: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, industry_type: nil, member_affiliate_percentage: nil, member_affiliate_status: nil, plan_options: nil, product_highlights: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ProductCreateParams for more details.
betwee
205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 205 class BannerImage < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of an existing attachment object. Use this when updating a resource and # keeping a subset of the attachments. Don't use this unless you know what you're # doing. # # @return [String, nil] optional :id, String, nil?: true # @!attribute direct_upload_id # This ID should be used the first time you upload an attachment. It is the ID of # the direct upload that was created when uploading the file to S3 via the # mediaDirectUpload mutation. # # @return [String, nil] optional :direct_upload_id, String, nil?: true # @!method initialize(id: nil, direct_upload_id: nil) # Some parameter documentations has been truncated, see # {WhopSDK::Models::ProductCreateParams::BannerImage} for more details. # # A banner image for the product in png, jpeg format # # @param id [String, nil] The ID of an existing attachment object. Use this when updating a resource and k # # @param direct_upload_id [String, nil] This ID should be used the first time you upload an attachment. It is the ID of end |
Instance Attribute Details
#direct_upload_id ⇒ String?
This ID should be used the first time you upload an attachment. It is the ID of the direct upload that was created when uploading the file to S3 via the mediaDirectUpload mutation.
220 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 220 optional :direct_upload_id, String, nil?: true |
#id ⇒ String?
The ID of an existing attachment object. Use this when updating a resource and keeping a subset of the attachments. Don’t use this unless you know what you’re doing.
212 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 212 optional :id, String, nil?: true |