Class: WhopSDK::Models::ProductListItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductListItem
- Defined in:
- lib/whop_sdk/models/product_list_item.rb,
sig/whop_sdk/models/product_list_item.rbs
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The datetime the product was created.
-
#external_identifier ⇒ String?
External identifier for the product.
-
#headline ⇒ String?
A short marketing headline displayed prominently on the product's product page.
-
#id ⇒ String
The unique identifier for the product.
-
#member_count ⇒ Integer
Active memberships for this product.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs stored on the product and included in payment and membership webhook payloads.
-
#published_reviews_count ⇒ Integer
The total number of published customer reviews for this product's company.
-
#route ⇒ String
URL slug in the product's public link, e.g.
-
#title ⇒ String
The display name of the product shown to customers on the product page and in search results.
-
#updated_at ⇒ Time
The datetime the product was last updated.
-
#verified ⇒ Boolean
Whether this company has been verified by Whop's trust and safety team.
-
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Controls whether the product is visible to customers.
Instance Method Summary collapse
-
#initialize(id:, created_at:, external_identifier:, headline:, member_count:, metadata:, published_reviews_count:, route:, title:, updated_at:, verified:, visibility:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProductListItem for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, external_identifier:, headline:, member_count:, metadata:, published_reviews_count:, route:, title:, updated_at:, verified:, visibility:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ProductListItem for more details.
A product is a digital good or service sold on Whop. Products contain plans for pricing and experiences for content delivery.
|
|
# File 'lib/whop_sdk/models/product_list_item.rb', line 85
|
Instance Attribute Details
#created_at ⇒ Time
The datetime the product was created.
16 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 16 required :created_at, Time |
#external_identifier ⇒ String?
External identifier for the product. Providing it on a product creation endpoint updates the existing product with this identifier instead of creating a new one.
23 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 23 required :external_identifier, String, nil?: true |
#headline ⇒ String?
A short marketing headline displayed prominently on the product's product page.
29 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 29 required :headline, String, nil?: true |
#id ⇒ String
The unique identifier for the product.
10 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 10 required :id, String |
#member_count ⇒ Integer
Active memberships for this product. Returns 0 if the account has disabled
public member counts.
36 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 36 required :member_count, Integer |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs stored on the product and included in payment and membership webhook payloads. Max 50 keys, 100 characters per key, 500 characters per string value.
44 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 44 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#published_reviews_count ⇒ Integer
The total number of published customer reviews for this product's company.
50 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 50 required :published_reviews_count, Integer |
#route ⇒ String
URL slug in the product's public link, e.g. pickaxe-analytics in
whop.com/company/pickaxe-analytics.
57 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 57 required :route, String |
#title ⇒ String
The display name of the product shown to customers on the product page and in search results.
64 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 64 required :title, String |
#updated_at ⇒ Time
The datetime the product was last updated.
70 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 70 required :updated_at, Time |
#verified ⇒ Boolean
Whether this company has been verified by Whop's trust and safety team.
76 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 76 required :verified, WhopSDK::Internal::Type::Boolean |
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Controls whether the product is visible to customers. When set to 'hidden', the product is only accessible via direct link.
83 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 83 required :visibility, enum: -> { WhopSDK::Visibility } |
Instance Method Details
#to_hash ⇒ {
59 |
# File 'sig/whop_sdk/models/product_list_item.rbs', line 59
def to_hash: -> {
|