Class: WhopSDK::Models::ProductUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/product_update_params.rb,
sig/whop_sdk/models/product_update_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Products#update

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, description: nil, headline: nil, metadata: nil, product_tax_code_id: nil, send_welcome_message: nil, title: nil, visibility: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ProductUpdateParams for more details.

Parameters:

  • id (String)
  • description (String, nil) (defaults to: nil)

    A written description displayed on the product page.

  • headline (String, nil) (defaults to: nil)

    A short marketing headline for the product page.

  • metadata (Object, nil) (defaults to: nil)

    Custom key-value pairs to store on the product.

  • product_tax_code_id (String, nil) (defaults to: nil)

    The unique identifier of the tax classification code. See the available [product

  • send_welcome_message (Boolean, nil) (defaults to: nil)

    Whether to send an automated welcome message via support chat when a user joins

  • title (String) (defaults to: nil)

    The display name of the product.

  • visibility (String) (defaults to: nil)

    Whether the product is visible to customers.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/product_update_params.rb', line 59

Instance Attribute Details

#descriptionString?

A written description displayed on the product page.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


19
# File 'lib/whop_sdk/models/product_update_params.rb', line 19

optional :description, String, nil?: true

#headlineString?

A short marketing headline for the product page.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


25
# File 'lib/whop_sdk/models/product_update_params.rb', line 25

optional :headline, String, nil?: true

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/product_update_params.rb', line 13

required :id, String

#metadataObject?

Custom key-value pairs to store on the product.

Parameters:

  • value (top, nil)

Returns:

  • (Object, nil)


31
# File 'lib/whop_sdk/models/product_update_params.rb', line 31

optional :metadata, WhopSDK::Internal::Type::Unknown, nil?: true

#product_tax_code_idString?

The unique identifier of the tax classification code. See the available product categories.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


38
# File 'lib/whop_sdk/models/product_update_params.rb', line 38

optional :product_tax_code_id, String, nil?: true

#send_welcome_messageBoolean?

Whether to send an automated welcome message via support chat when a user joins this product.

Parameters:

  • value (Boolean, nil)

Returns:

  • (Boolean, nil)


45
# File 'lib/whop_sdk/models/product_update_params.rb', line 45

optional :send_welcome_message, WhopSDK::Internal::Type::Boolean, nil?: true

#titleString?

The display name of the product.

Parameters:

  • (String)

Returns:

  • (String, nil)


51
# File 'lib/whop_sdk/models/product_update_params.rb', line 51

optional :title, String

#visibilityString?

Whether the product is visible to customers.

Parameters:

  • (String)

Returns:

  • (String, nil)


57
# File 'lib/whop_sdk/models/product_update_params.rb', line 57

optional :visibility, String

Instance Method Details

#to_hash{

Returns:

  • ({)


52
# File 'sig/whop_sdk/models/product_update_params.rbs', line 52

def to_hash: -> {