Class: WhopSDK::Models::ProductUpdateParams::BannerImage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(banner_image: nil, business_type: nil, collect_shipping_address: nil, custom_cta: nil, custom_cta_url: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, industry_type: nil, member_affiliate_percentage: nil, member_affiliate_status: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, store_page_config: nil, title: nil, visibility: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ProductUpdateParams for more details.

betwee

Parameters:

  • banner_image (WhopSDK::Models::ProductUpdateParams::BannerImage, nil) (defaults to: nil)

    A banner image for the product in png, jpeg format

  • business_type (Symbol, WhopSDK::Models::BusinessTypes, nil) (defaults to: nil)

    The different business types a company can be.

  • collect_shipping_address (Boolean, nil) (defaults to: nil)

    Whether or not to collect shipping information at checkout from the customer.

  • custom_cta (Symbol, WhopSDK::Models::CustomCta, nil) (defaults to: nil)

    The different types of custom CTAs that can be selected.

  • custom_cta_url (String, nil) (defaults to: nil)

    The custom call to action URL for the product.

  • custom_statement_descriptor (String, nil) (defaults to: nil)

    The custom statement descriptor for the product i.e. WHOP*SPORTS, must be

  • description (String, nil) (defaults to: nil)

    A written description of the product.

  • global_affiliate_percentage (Float, nil) (defaults to: nil)

    The percentage of the revenue that goes to the global affiliate program.

  • global_affiliate_status (Symbol, WhopSDK::Models::GlobalAffiliateStatus, nil) (defaults to: nil)

    The different statuses of the global affiliate program for an access pass.

  • headline (String, nil) (defaults to: nil)

    The headline of the product.

  • industry_type (Symbol, WhopSDK::Models::IndustryTypes, nil) (defaults to: nil)

    The different industry types a company can be in.

  • member_affiliate_percentage (Float, nil) (defaults to: nil)

    The percentage of the revenue that goes to the member affiliate program.

  • member_affiliate_status (Symbol, WhopSDK::Models::GlobalAffiliateStatus, nil) (defaults to: nil)

    The different statuses of the global affiliate program for an access pass.

  • product_tax_code_id (String, nil) (defaults to: nil)

    The ID of the product tax code to apply to this product.

  • redirect_purchase_url (String, nil) (defaults to: nil)

    The URL to redirect the customer to after a purchase.

  • route (String, nil) (defaults to: nil)

    The route of the product.

  • store_page_config (WhopSDK::Models::ProductUpdateParams::StorePageConfig, nil) (defaults to: nil)

    Configuration for a product on the company’s store page.

  • title (String, nil) (defaults to: nil)

    The title of the product.

  • visibility (Symbol, WhopSDK::Models::Visibility, nil) (defaults to: nil)

    Visibility of a resource

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/whop_sdk/models/product_update_params.rb', line 171

class BannerImage < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing attachment object. Use this when updating a resource and
  #   keeping a subset of the attachments. Don't use this unless you know what you're
  #   doing.
  #
  #   @return [String, nil]
  optional :id, String, nil?: true

  # @!attribute direct_upload_id
  #   This ID should be used the first time you upload an attachment. It is the ID of
  #   the direct upload that was created when uploading the file to S3 via the
  #   mediaDirectUpload mutation.
  #
  #   @return [String, nil]
  optional :direct_upload_id, String, nil?: true

  # @!method initialize(id: nil, direct_upload_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::ProductUpdateParams::BannerImage} for more details.
  #
  #   A banner image for the product in png, jpeg format
  #
  #   @param id [String, nil] The ID of an existing attachment object. Use this when updating a resource and k
  #
  #   @param direct_upload_id [String, nil] This ID should be used the first time you upload an attachment. It is the ID of
end

Instance Attribute Details

#direct_upload_idString?

This ID should be used the first time you upload an attachment. It is the ID of the direct upload that was created when uploading the file to S3 via the mediaDirectUpload mutation.

Returns:

  • (String, nil)


186
# File 'lib/whop_sdk/models/product_update_params.rb', line 186

optional :direct_upload_id, String, nil?: true

#idString?

The ID of an existing attachment object. Use this when updating a resource and keeping a subset of the attachments. Don’t use this unless you know what you’re doing.

Returns:

  • (String, nil)


178
# File 'lib/whop_sdk/models/product_update_params.rb', line 178

optional :id, String, nil?: true