Class: WhopSDK::Models::ProductUpdateParams::GalleryImage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, collect_shipping_address: nil, custom_cta: nil, custom_cta_url: nil, custom_statement_descriptor: nil, description: nil, gallery_images: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, member_affiliate_percentage: nil, member_affiliate_status: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, send_welcome_message: nil, store_page_config: nil, title: nil, visibility: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ProductUpdateParams for more details.

Parameters:

  • id (String)
  • collect_shipping_address (Boolean, nil) (defaults to: nil)

    Whether the checkout flow collects a shipping address from the customer.

  • custom_cta (Symbol, WhopSDK::Models::CustomCta, nil) (defaults to: nil)

    The different types of custom CTAs that can be selected.

  • custom_cta_url (String, nil) (defaults to: nil)

    A URL that the call-to-action button links to instead of the default checkout fl

  • custom_statement_descriptor (String, nil) (defaults to: nil)

    A custom text label that appears on the customer’s bank statement. Must be 5-22

  • description (String, nil) (defaults to: nil)

    A written description of the product displayed on its product page.

  • gallery_images (Array<WhopSDK::Models::ProductUpdateParams::GalleryImage>, nil) (defaults to: nil)

    The gallery images for the product.

  • global_affiliate_percentage (Float, nil) (defaults to: nil)

    The commission rate as a percentage that affiliates earn through the global affi

  • global_affiliate_status (Symbol, WhopSDK::Models::GlobalAffiliateStatus, nil) (defaults to: nil)

    The different statuses of the global affiliate program for a product.

  • headline (String, nil) (defaults to: nil)

    A short marketing headline displayed prominently on the product page.

  • member_affiliate_percentage (Float, nil) (defaults to: nil)

    The commission rate as a percentage that members earn through the member affilia

  • member_affiliate_status (Symbol, WhopSDK::Models::GlobalAffiliateStatus, nil) (defaults to: nil)

    The different statuses of the global affiliate program for a product.

  • product_tax_code_id (String, nil) (defaults to: nil)

    The unique identifier of the tax classification code to apply to this product.

  • redirect_purchase_url (String, nil) (defaults to: nil)

    A URL to redirect the customer to after completing a purchase.

  • route (String, nil) (defaults to: nil)

    The URL slug for the product’s public link.

  • send_welcome_message (Boolean, nil) (defaults to: nil)

    Whether to send an automated welcome message via support chat when a user joins

  • store_page_config (WhopSDK::Models::ProductUpdateParams::StorePageConfig, nil) (defaults to: nil)

    Layout and display configuration for this product on the company’s store page.

  • title (String, nil) (defaults to: nil)

    The display name of the product. Maximum 80 characters.

  • visibility (Symbol, WhopSDK::Models::Visibility, nil) (defaults to: nil)

    Visibility of a resource

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/whop_sdk/models/product_update_params.rb', line 175

class GalleryImage < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing file object.
  #
  #   @return [String]
  required :id, String

  # @!method initialize(id:)
  #   Input for an attachment
  #
  #   @param id [String] The ID of an existing file object.
end

Instance Attribute Details

#idString

The ID of an existing file object.

Returns:

  • (String)


180
# File 'lib/whop_sdk/models/product_update_params.rb', line 180

required :id, String