Class: WhopSDK::Models::ProductUpdateParams::StorePageConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(custom_cta: nil, show_price: nil) ⇒ Object

Configuration for a product on the company’s store page.

Parameters:

  • custom_cta (String, nil) (defaults to: nil)

    Custom call-to-action text for the product’s store page.

  • show_price (Boolean, nil) (defaults to: nil)

    Whether or not to show the price on the product’s store page.



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/whop_sdk/models/product_update_params.rb', line 163

class StorePageConfig < WhopSDK::Internal::Type::BaseModel
  # @!attribute custom_cta
  #   Custom call-to-action text for the product's store page.
  #
  #   @return [String, nil]
  optional :custom_cta, String, nil?: true

  # @!attribute show_price
  #   Whether or not to show the price on the product's store page.
  #
  #   @return [Boolean, nil]
  optional :show_price, WhopSDK::Internal::Type::Boolean, nil?: true

  # @!method initialize(custom_cta: nil, show_price: nil)
  #   Configuration for a product on the company's store page.
  #
  #   @param custom_cta [String, nil] Custom call-to-action text for the product's store page.
  #
  #   @param show_price [Boolean, nil] Whether or not to show the price on the product's store page.
end

Instance Attribute Details

#custom_ctaString?

Custom call-to-action text for the product’s store page.

Returns:

  • (String, nil)


168
# File 'lib/whop_sdk/models/product_update_params.rb', line 168

optional :custom_cta, String, nil?: true

#show_priceBoolean?

Whether or not to show the price on the product’s store page.

Returns:

  • (Boolean, nil)


174
# File 'lib/whop_sdk/models/product_update_params.rb', line 174

optional :show_price, WhopSDK::Internal::Type::Boolean, nil?: true