Class: WhopSDK::Models::Reaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Reaction
- Defined in:
- lib/whop_sdk/models/reaction.rb
Defined Under Namespace
Classes: User
Instance Attribute Summary collapse
-
#emoji ⇒ String?
The emoji used for this reaction in shortcode format.
-
#id ⇒ String
The unique identifier for the entity.
-
#resource_id ⇒ String
The unique identifier of the post this reaction was left on.
-
#user ⇒ WhopSDK::Models::Reaction::User
The user who left this reaction on the post.
Instance Method Summary collapse
-
#initialize(id:, emoji:, resource_id:, user:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Reaction for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, emoji:, resource_id:, user:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Reaction for more details.
A single reaction left by a user on a feed post, such as a like or emoji.
|
|
# File 'lib/whop_sdk/models/reaction.rb', line 31
|
Instance Attribute Details
#emoji ⇒ String?
The emoji used for this reaction in shortcode format. Null if the reaction type is not emoji.
17 |
# File 'lib/whop_sdk/models/reaction.rb', line 17 required :emoji, String, nil?: true |
#id ⇒ String
The unique identifier for the entity
10 |
# File 'lib/whop_sdk/models/reaction.rb', line 10 required :id, String |
#resource_id ⇒ String
The unique identifier of the post this reaction was left on.
23 |
# File 'lib/whop_sdk/models/reaction.rb', line 23 required :resource_id, String |
#user ⇒ WhopSDK::Models::Reaction::User
The user who left this reaction on the post.
29 |
# File 'lib/whop_sdk/models/reaction.rb', line 29 required :user, -> { WhopSDK::Reaction::User } |