Class: WhopSDK::Models::ReactionCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/reaction_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(resource_id:, emoji: nil, poll_option_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ReactionCreateParams for more details.

Parameters:

  • resource_id (String)

    The unique identifier of the message or forum post to react to.

  • emoji (String, nil) (defaults to: nil)

    The emoji to react with, in shortcode or unicode format. For example, ‘:heart:’

  • poll_option_id (String, nil) (defaults to: nil)

    The unique identifier of a poll option to vote for. Only valid when the target m

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/reaction_create_params.rb', line 30

Instance Attribute Details

#emojiString?

The emoji to react with, in shortcode or unicode format. For example, ‘:heart:’ or a unicode emoji. Ignored in forums where reactions are always likes.

Returns:

  • (String, nil)


21
# File 'lib/whop_sdk/models/reaction_create_params.rb', line 21

optional :emoji, String, nil?: true

#poll_option_idString?

The unique identifier of a poll option to vote for. Only valid when the target message or post contains a poll.

Returns:

  • (String, nil)


28
# File 'lib/whop_sdk/models/reaction_create_params.rb', line 28

optional :poll_option_id, String, nil?: true

#resource_idString

The unique identifier of the message or forum post to react to.

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/reaction_create_params.rb', line 14

required :resource_id, String