Class: WhopSDK::Models::ReactionListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/reaction_list_response.rb

Overview

Defined Under Namespace

Classes: User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, emoji:, resource_id:, user:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ReactionListResponse for more details.

A single reaction left by a user on a feed post, such as a like or emoji.

Parameters:

  • id (String)

    The unique identifier for the entity

  • emoji (String, nil)

    The emoji used for this reaction in shortcode format. Null if the reaction type

  • resource_id (String)

    The unique identifier of the post this reaction was left on.

  • user (WhopSDK::Models::ReactionListResponse::User)

    The user who left this reaction on the post.



# File 'lib/whop_sdk/models/reaction_list_response.rb', line 32

Instance Attribute Details

#emojiString?

The emoji used for this reaction in shortcode format. Null if the reaction type is not emoji.

Returns:

  • (String, nil)


18
# File 'lib/whop_sdk/models/reaction_list_response.rb', line 18

required :emoji, String, nil?: true

#idString

The unique identifier for the entity

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/reaction_list_response.rb', line 11

required :id, String

#resource_idString

The unique identifier of the post this reaction was left on.

Returns:

  • (String)


24
# File 'lib/whop_sdk/models/reaction_list_response.rb', line 24

required :resource_id, String

#userWhopSDK::Models::ReactionListResponse::User

The user who left this reaction on the post.



30
# File 'lib/whop_sdk/models/reaction_list_response.rb', line 30

required :user, -> { WhopSDK::Models::ReactionListResponse::User }