Class: WhopSDK::Models::Referrals::BusinessLeaderboardParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/referrals/business_leaderboard_params.rb,
sig/whop_sdk/models/referrals/business_leaderboard_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Referrals::Businesses#leaderboard

Defined Under Namespace

Modules: Period

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(period: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::Referrals::BusinessLeaderboardParams for more details.

Parameters:



# File 'lib/whop_sdk/models/referrals/business_leaderboard_params.rb', line 19

Instance Attribute Details

#periodSymbol, ...

Time window for the rankings. day, month, and year count earnings since the start of the current calendar day, month, or year; last_30_days counts earnings over the trailing 30 days; all_time ranks lifetime earnings.



17
# File 'lib/whop_sdk/models/referrals/business_leaderboard_params.rb', line 17

optional :period, enum: -> { WhopSDK::Referrals::BusinessLeaderboardParams::Period }

Instance Method Details

#to_hash{

Returns:

  • ({)


25
# File 'sig/whop_sdk/models/referrals/business_leaderboard_params.rbs', line 25

def to_hash: -> {