Module: WhopSDK::Models::Referrals::BusinessLeaderboardParams::Period

Extended by:
Internal::Type::Enum
Defined in:
lib/whop_sdk/models/referrals/business_leaderboard_params.rb,
sig/whop_sdk/models/referrals/business_leaderboard_params.rbs

Overview

Time window for the rankings. day, month, and year count earnings since the start of the current calendar day, month, or year; last_30_days counts earnings over the trailing 30 days; all_time ranks lifetime earnings.

Constant Summary collapse

DAY =

Returns:

  • (:day)
:day
MONTH =

Returns:

  • (:month)
:month
YEAR =

Returns:

  • (:year)
:year
LAST_30_DAYS =

Returns:

  • (:last_30_days)
:last_30_days
ALL_TIME =

Returns:

  • (:all_time)
:all_time

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/referrals/business_leaderboard_params.rb', line 39

Instance Method Details

#self?.values::Array[WhopSDK::Models::Referrals::BusinessLeaderboardParams::period]

Returns:

  • (::Array[WhopSDK::Models::Referrals::BusinessLeaderboardParams::period])


41
# File 'sig/whop_sdk/models/referrals/business_leaderboard_params.rbs', line 41

def self?.values: -> ::Array[WhopSDK::Models::Referrals::BusinessLeaderboardParams::period]