Class: WhopSDK::Models::Referrals::BusinessLeaderboardResponse::Me::User
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Referrals::BusinessLeaderboardResponse::Me::User
- Defined in:
- lib/whop_sdk/models/referrals/business_leaderboard_response.rb,
sig/whop_sdk/models/referrals/business_leaderboard_response.rbs
Overview
Defined Under Namespace
Classes: ProfilePicture
Instance Attribute Summary collapse
-
#city ⇒ String?
The city where the referrer is located, derived from their IP address.
-
#country ⇒ String?
The country where the referrer is located, derived from their IP address.
-
#id ⇒ String?
User ID, prefixed
user_. -
#name ⇒ String?
The user's display name.
-
#profile_picture ⇒ WhopSDK::Models::Referrals::BusinessLeaderboardResponse::Me::User::ProfilePicture?
The user's profile picture.
-
#username ⇒ String?
The user's unique username.
Instance Method Summary collapse
-
#initialize(city:, country:, id: nil, name: nil, profile_picture: nil, username: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see User for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country:, id: nil, name: nil, profile_picture: nil, username: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Referrals::BusinessLeaderboardResponse::Me::User for more details.
The ranked referrer. Identity fields (id, name, username, profile_picture) are returned only on the caller's own entry; other referrers expose coarse location only.
|
|
# File 'lib/whop_sdk/models/referrals/business_leaderboard_response.rb', line 245
|
Instance Attribute Details
#city ⇒ String?
The city where the referrer is located, derived from their IP address. Null if location sharing is disabled.
211 |
# File 'lib/whop_sdk/models/referrals/business_leaderboard_response.rb', line 211 required :city, String, nil?: true |
#country ⇒ String?
The country where the referrer is located, derived from their IP address. Null if location sharing is disabled.
218 |
# File 'lib/whop_sdk/models/referrals/business_leaderboard_response.rb', line 218 required :country, String, nil?: true |
#id ⇒ String?
User ID, prefixed user_. Present only on the caller's own entry.
224 |
# File 'lib/whop_sdk/models/referrals/business_leaderboard_response.rb', line 224 optional :id, String |
#name ⇒ String?
The user's display name. Present only on the caller's own entry.
230 |
# File 'lib/whop_sdk/models/referrals/business_leaderboard_response.rb', line 230 optional :name, String, nil?: true |
#profile_picture ⇒ WhopSDK::Models::Referrals::BusinessLeaderboardResponse::Me::User::ProfilePicture?
The user's profile picture. Present only on the caller's own entry.
236 237 |
# File 'lib/whop_sdk/models/referrals/business_leaderboard_response.rb', line 236 optional :profile_picture, -> { WhopSDK::Models::Referrals::BusinessLeaderboardResponse::Me::User::ProfilePicture } |
#username ⇒ String?
The user's unique username. Present only on the caller's own entry.
243 |
# File 'lib/whop_sdk/models/referrals/business_leaderboard_response.rb', line 243 optional :username, String |
Instance Method Details
#to_hash ⇒ {
198 |
# File 'sig/whop_sdk/models/referrals/business_leaderboard_response.rbs', line 198
def to_hash: -> {
|