Class: WhopSDK::Models::Referrals::BusinessListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Referrals::BusinessListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/referrals/business_list_params.rb,
sig/whop_sdk/models/referrals/business_list_params.rbs
Overview
Defined Under Namespace
Modules: Direction, Order, Status, Tier
Instance Attribute Summary collapse
-
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
-
#before ⇒ String?
Cursor to fetch the page before (from page_info.start_cursor).
-
#created_after ⇒ String?
Only return business referrals created after this timestamp.
-
#created_before ⇒ String?
Only return business referrals created before this timestamp.
-
#direction ⇒ Symbol, ...
Sort direction.
-
#first ⇒ Integer?
Number of business referrals to return from the start of the window.
-
#has_earnings ⇒ Boolean?
When true, only businesses with pending or completed earnings paid to the caller.
-
#last ⇒ Integer?
Number of business referrals to return from the end of the window.
-
#order ⇒ Symbol, ...
The field to sort business referrals by.
-
#referred_user_id ⇒ String?
Filter to referrals attributed to this user.
-
#referred_username ⇒ String?
Filter by the referred user's exact username.
-
#status ⇒ Symbol, ...
Filter by referral status.
-
#tier ⇒ Symbol, ...
Filter to only first-tier referrals or only second-tier referrals.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, has_earnings: nil, last: nil, order: nil, referred_user_id: nil, referred_username: nil, status: nil, tier: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BusinessListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, has_earnings: nil, last: nil, order: nil, referred_user_id: nil, referred_username: nil, status: nil, tier: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Referrals::BusinessListParams for more details.
|
|
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 93
|
Instance Attribute Details
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
15 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 15 optional :after, String |
#before ⇒ String?
Cursor to fetch the page before (from page_info.start_cursor).
21 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 21 optional :before, String |
#created_after ⇒ String?
Only return business referrals created after this timestamp.
27 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 27 optional :created_after, String |
#created_before ⇒ String?
Only return business referrals created before this timestamp.
33 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 33 optional :created_before, String |
#direction ⇒ Symbol, ...
Sort direction.
39 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 39 optional :direction, enum: -> { WhopSDK::Referrals::BusinessListParams::Direction } |
#first ⇒ Integer?
Number of business referrals to return from the start of the window.
45 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 45 optional :first, Integer |
#has_earnings ⇒ Boolean?
When true, only businesses with pending or completed earnings paid to the caller.
52 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 52 optional :has_earnings, WhopSDK::Internal::Type::Boolean |
#last ⇒ Integer?
Number of business referrals to return from the end of the window.
58 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 58 optional :last, Integer |
#order ⇒ Symbol, ...
The field to sort business referrals by.
64 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 64 optional :order, enum: -> { WhopSDK::Referrals::BusinessListParams::Order } |
#referred_user_id ⇒ String?
Filter to referrals attributed to this user. For first-tier referrals, this is the referred account owner; for second-tier referrals, this is the partner you recruited.
72 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 72 optional :referred_user_id, String |
#referred_username ⇒ String?
Filter by the referred user's exact username. Ignored when referred_user_id is
present.
79 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 79 optional :referred_username, String |
#status ⇒ Symbol, ...
Filter by referral status.
85 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 85 optional :status, enum: -> { WhopSDK::Referrals::BusinessListParams::Status } |
#tier ⇒ Symbol, ...
Filter to only first-tier referrals or only second-tier referrals.
91 |
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 91 optional :tier, enum: -> { WhopSDK::Referrals::BusinessListParams::Tier } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/referrals/business_list_params.rb', line 132
|
Instance Method Details
#to_hash ⇒ {
103 |
# File 'sig/whop_sdk/models/referrals/business_list_params.rbs', line 103
def to_hash: -> {
|