Class: WhopSDK::Models::Referrals::Businesses::EarningListResponse::FinancialActivity
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Referrals::Businesses::EarningListResponse::FinancialActivity
- Defined in:
- lib/whop_sdk/models/referrals/businesses/earning_list_response.rb,
sig/whop_sdk/models/referrals/businesses/earning_list_response.rbs
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#amount ⇒ String
Line amount in its native currency.
-
#amount_usd ⇒ String
Line amount in USD.
-
#category ⇒ String?
Fee or cost category of the line.
- #created_at ⇒ Time?
-
#currency ⇒ String
Currency of the native amount.
-
#type ⇒ Symbol, WhopSDK::Models::Referrals::Businesses::EarningListResponse::FinancialActivity::Type
Whether the line is income Whop collected or a cost Whop paid.
Instance Method Summary collapse
- #initialize(amount:, amount_usd:, category:, created_at:, currency:, type:) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, amount_usd:, category:, created_at:, currency:, type:) ⇒ Object
|
|
# File 'lib/whop_sdk/models/referrals/businesses/earning_list_response.rb', line 201
|
Instance Attribute Details
#amount ⇒ String
Line amount in its native currency.
169 |
# File 'lib/whop_sdk/models/referrals/businesses/earning_list_response.rb', line 169 required :amount, String |
#amount_usd ⇒ String
Line amount in USD.
175 |
# File 'lib/whop_sdk/models/referrals/businesses/earning_list_response.rb', line 175 required :amount_usd, String |
#category ⇒ String?
Fee or cost category of the line.
181 |
# File 'lib/whop_sdk/models/referrals/businesses/earning_list_response.rb', line 181 required :category, String, nil?: true |
#created_at ⇒ Time?
186 |
# File 'lib/whop_sdk/models/referrals/businesses/earning_list_response.rb', line 186 required :created_at, Time, nil?: true |
#currency ⇒ String
Currency of the native amount.
192 |
# File 'lib/whop_sdk/models/referrals/businesses/earning_list_response.rb', line 192 required :currency, String |
#type ⇒ Symbol, WhopSDK::Models::Referrals::Businesses::EarningListResponse::FinancialActivity::Type
Whether the line is income Whop collected or a cost Whop paid.
198 199 |
# File 'lib/whop_sdk/models/referrals/businesses/earning_list_response.rb', line 198 required :type, enum: -> { WhopSDK::Models::Referrals::Businesses::EarningListResponse::FinancialActivity::Type } |
Instance Method Details
#to_hash ⇒ {
145 |
# File 'sig/whop_sdk/models/referrals/businesses/earning_list_response.rbs', line 145
def to_hash: -> {
|