Class: WhopSDK::Models::RefundCreatedWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/refund_created_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Classes: Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , amount: , created_at: , currency: , payment: , provider: , provider_created_at: , reference_status: , reference_type: , reference_value: , status: ) ⇒ Object

An object representing a refund made on a payment.

Parameters:



# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 115

Instance Attribute Details

#amountFloat

The amount of the refund.

Returns:

  • (Float)


59
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 59

required :amount, Float

#created_atTime

The time the refund was created.

Returns:

  • (Time)


65
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 65

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The currency of the refund.

Returns:



71
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 71

required :currency, enum: -> { WhopSDK::Currency }

#idString

The ID of the refund.

Returns:

  • (String)


53
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 53

required :id, String

#paymentWhopSDK::Models::RefundCreatedWebhookEvent::Data::Payment?

The payment associated with the refund.



77
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 77

required :payment, -> { WhopSDK::RefundCreatedWebhookEvent::Data::Payment }, nil?: true

#providerSymbol, WhopSDK::Models::PaymentProvider

The provider of the refund.



83
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 83

required :provider, enum: -> { WhopSDK::PaymentProvider }

#provider_created_atTime?

The time the refund was created by the provider.

Returns:

  • (Time, nil)


89
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 89

required :provider_created_at, Time, nil?: true

#reference_statusSymbol, ...

The status of the refund reference.

Returns:



95
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 95

required :reference_status, enum: -> { WhopSDK::RefundReferenceStatus }, nil?: true

#reference_typeSymbol, ...

The type of refund reference that was made available by the payment provider.

Returns:



101
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 101

required :reference_type, enum: -> { WhopSDK::RefundReferenceType }, nil?: true

#reference_valueString?

The value of the reference.

Returns:

  • (String, nil)


107
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 107

required :reference_value, String, nil?: true

#statusSymbol, WhopSDK::Models::RefundStatus

The status of the refund.

Returns:



113
# File 'lib/whop_sdk/models/refund_created_webhook_event.rb', line 113

required :status, enum: -> { WhopSDK::RefundStatus }