Class: WhopSDK::Models::RefundListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/refund_list_response.rb

Overview

Defined Under Namespace

Classes: Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, currency:, payment:, provider:, provider_created_at:, reference_status:, reference_type:, reference_value:, status:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::RefundListResponse for more details.

A refund represents a full or partial reversal of a payment, including the amount, status, and payment provider.

Parameters:

  • id (String)

    The unique identifier for the refund.

  • amount (Float)

    The refunded amount as a decimal in the specified currency, such as 10.43 for $1

  • created_at (Time)

    The datetime the refund was created.

  • currency (Symbol, WhopSDK::Models::Currency)

    The three-letter ISO currency code for the refunded amount.

  • payment (WhopSDK::Models::RefundListResponse::Payment, nil)

    The original payment that this refund was issued against. Null if the payment is

  • provider (Symbol, WhopSDK::Models::PaymentProvider)

    The payment provider that processed the refund.

  • provider_created_at (Time, nil)

    The timestamp when the refund was created in the payment provider’s system. Null

  • reference_status (Symbol, WhopSDK::Models::RefundReferenceStatus, nil)

    The status of the refund reference.

  • reference_type (Symbol, WhopSDK::Models::RefundReferenceType, nil)

    The type of refund reference that was made available by the payment provider.

  • reference_value (String, nil)

    The tracking reference value from the payment processor, used to trace the refun

  • status (Symbol, WhopSDK::Models::RefundStatus)

    The current processing status of the refund, such as pending, succeeded, or fail



# File 'lib/whop_sdk/models/refund_list_response.rb', line 78

Instance Attribute Details

#amountFloat

The refunded amount as a decimal in the specified currency, such as 10.43 for $10.43 USD.

Returns:

  • (Float)


18
# File 'lib/whop_sdk/models/refund_list_response.rb', line 18

required :amount, Float

#created_atTime

The datetime the refund was created.

Returns:

  • (Time)


24
# File 'lib/whop_sdk/models/refund_list_response.rb', line 24

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The three-letter ISO currency code for the refunded amount.

Returns:



30
# File 'lib/whop_sdk/models/refund_list_response.rb', line 30

required :currency, enum: -> { WhopSDK::Currency }

#idString

The unique identifier for the refund.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/refund_list_response.rb', line 11

required :id, String

#paymentWhopSDK::Models::RefundListResponse::Payment?

The original payment that this refund was issued against. Null if the payment is no longer available.



37
# File 'lib/whop_sdk/models/refund_list_response.rb', line 37

required :payment, -> { WhopSDK::Models::RefundListResponse::Payment }, nil?: true

#providerSymbol, WhopSDK::Models::PaymentProvider

The payment provider that processed the refund.



43
# File 'lib/whop_sdk/models/refund_list_response.rb', line 43

required :provider, enum: -> { WhopSDK::PaymentProvider }

#provider_created_atTime?

The timestamp when the refund was created in the payment provider’s system. Null if not available from the provider.

Returns:

  • (Time, nil)


50
# File 'lib/whop_sdk/models/refund_list_response.rb', line 50

required :provider_created_at, Time, nil?: true

#reference_statusSymbol, ...

The status of the refund reference.

Returns:



56
# File 'lib/whop_sdk/models/refund_list_response.rb', line 56

required :reference_status, enum: -> { WhopSDK::RefundReferenceStatus }, nil?: true

#reference_typeSymbol, ...

The type of refund reference that was made available by the payment provider.

Returns:



62
# File 'lib/whop_sdk/models/refund_list_response.rb', line 62

required :reference_type, enum: -> { WhopSDK::RefundReferenceType }, nil?: true

#reference_valueString?

The tracking reference value from the payment processor, used to trace the refund through banking networks. Null if no reference was provided.

Returns:

  • (String, nil)


69
# File 'lib/whop_sdk/models/refund_list_response.rb', line 69

required :reference_value, String, nil?: true

#statusSymbol, WhopSDK::Models::RefundStatus

The current processing status of the refund, such as pending, succeeded, or failed.

Returns:



76
# File 'lib/whop_sdk/models/refund_list_response.rb', line 76

required :status, enum: -> { WhopSDK::RefundStatus }