Class: WhopSDK::Models::RefundRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::RefundRetrieveResponse
- Defined in:
- lib/whop_sdk/models/refund_retrieve_response.rb
Overview
Defined Under Namespace
Classes: Payment
Instance Attribute Summary collapse
-
#amount ⇒ Float
The refunded amount as a decimal in the specified currency, such as 10.43 for $10.43 USD.
-
#created_at ⇒ Time
The datetime the refund was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The three-letter ISO currency code for the refunded amount.
-
#id ⇒ String
The unique identifier for the refund.
-
#payment ⇒ WhopSDK::Models::RefundRetrieveResponse::Payment?
The original payment that this refund was issued against.
-
#provider ⇒ Symbol, WhopSDK::Models::PaymentProvider
The payment provider that processed the refund.
-
#provider_created_at ⇒ Time?
The timestamp when the refund was created in the payment provider’s system.
-
#reference_status ⇒ Symbol, ...
The status of the refund reference.
-
#reference_type ⇒ Symbol, ...
The type of refund reference that was made available by the payment provider.
-
#reference_value ⇒ String?
The tracking reference value from the payment processor, used to trace the refund through banking networks.
-
#status ⇒ Symbol, WhopSDK::Models::RefundStatus
The current processing status of the refund, such as pending, succeeded, or failed.
Instance Method Summary collapse
-
#initialize(id:, amount:, created_at:, currency:, payment:, provider:, provider_created_at:, reference_status:, reference_type:, reference_value:, status:) ⇒ Object
constructor
Some parameter documentations has been truncated, see RefundRetrieveResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, created_at:, currency:, payment:, provider:, provider_created_at:, reference_status:, reference_type:, reference_value:, status:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::RefundRetrieveResponse for more details.
A refund represents a full or partial reversal of a payment, including the amount, status, and payment provider.
|
|
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 78
|
Instance Attribute Details
#amount ⇒ Float
The refunded amount as a decimal in the specified currency, such as 10.43 for $10.43 USD.
18 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 18 required :amount, Float |
#created_at ⇒ Time
The datetime the refund was created.
24 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 24 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The three-letter ISO currency code for the refunded amount.
30 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 30 required :currency, enum: -> { WhopSDK::Currency } |
#id ⇒ String
The unique identifier for the refund.
11 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 11 required :id, String |
#payment ⇒ WhopSDK::Models::RefundRetrieveResponse::Payment?
The original payment that this refund was issued against. Null if the payment is no longer available.
37 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 37 required :payment, -> { WhopSDK::Models::RefundRetrieveResponse::Payment }, nil?: true |
#provider ⇒ Symbol, WhopSDK::Models::PaymentProvider
The payment provider that processed the refund.
43 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 43 required :provider, enum: -> { WhopSDK::PaymentProvider } |
#provider_created_at ⇒ Time?
The timestamp when the refund was created in the payment provider’s system. Null if not available from the provider.
50 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 50 required :provider_created_at, Time, nil?: true |
#reference_status ⇒ Symbol, ...
The status of the refund reference.
56 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 56 required :reference_status, enum: -> { WhopSDK::RefundReferenceStatus }, nil?: true |
#reference_type ⇒ Symbol, ...
The type of refund reference that was made available by the payment provider.
62 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 62 required :reference_type, enum: -> { WhopSDK::RefundReferenceType }, nil?: true |
#reference_value ⇒ String?
The tracking reference value from the payment processor, used to trace the refund through banking networks. Null if no reference was provided.
69 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 69 required :reference_value, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::RefundStatus
The current processing status of the refund, such as pending, succeeded, or failed.
76 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 76 required :status, enum: -> { WhopSDK::RefundStatus } |