Class: WhopSDK::Models::RefundRetrieveResponse::Payment::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::RefundRetrieveResponse::Payment::Product
- Defined in:
- lib/whop_sdk/models/refund_retrieve_response.rb,
sig/whop_sdk/models/refund_retrieve_response.rbs
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the product.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs stored on the product and included in payment and membership webhook payloads.
Instance Method Summary collapse
-
#initialize ⇒ Product
constructor
A new instance of Product.
- #to_hash ⇒ { id: String, metadata: ::Hash[Symbol, top]? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Product
Returns a new instance of Product.
235 |
# File 'sig/whop_sdk/models/refund_retrieve_response.rbs', line 235
def initialize: (id: String, metadata: ::Hash[Symbol, top]?) -> void
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the product.
365 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 365 required :id, String |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs stored on the product and included in payment and membership webhook payloads. Max 50 keys, 100 characters per key, 500 characters per string value.
373 |
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 373 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
Instance Method Details
#to_hash ⇒ { id: String, metadata: ::Hash[Symbol, top]? }
237 |
# File 'sig/whop_sdk/models/refund_retrieve_response.rbs', line 237
def to_hash: -> { id: String, metadata: ::Hash[Symbol, top]? }
|