Class: WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment
- Defined in:
- lib/whop_sdk/models/refund_updated_webhook_event.rb
Overview
Defined Under Namespace
Classes: Member, Membership, Plan, Product, User
Instance Attribute Summary collapse
-
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed.
-
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#card_last4 ⇒ String?
The last four digits of the card used to make this payment.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The three-letter ISO currency code for this payment (e.g., ‘usd’, ‘eur’).
-
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed.
-
#id ⇒ String
The unique identifier for the payment.
-
#member ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Member?
The member attached to this payment.
-
#membership ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Membership?
The membership attached to this payment.
-
#metadata ⇒ Hash{Symbol=>Object}?
The custom metadata stored on this payment.
-
#paid_at ⇒ Time?
The time at which this payment was successfully collected.
-
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
-
#plan ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Plan?
The plan attached to this payment.
-
#product ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Product?
The product this payment was made for.
-
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
-
#tax_amount ⇒ Float?
The calculated amount of the sales/VAT tax (if applicable).
-
#tax_behavior ⇒ Symbol, ...
The type of tax inclusivity applied to the receipt, for determining whether the tax is included in the final price, or paid on top.
-
#tax_refunded_amount ⇒ Float?
The amount of tax that has been refunded (if applicable).
-
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
-
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
-
#user ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::User?
The user that made this payment.
Instance Method Summary collapse
-
#initialize(id:, metadata:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Product for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, metadata:) ⇒ Object
Some parameter documentations has been truncated, see Product for more details.
The product this payment was made for
|
|
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 297
|
Instance Attribute Details
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed
173 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 173 required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true |
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have
179 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 179 required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#card_last4 ⇒ String?
The last four digits of the card used to make this payment. Null if the payment was not made with a card.
186 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 186 required :card_last4, String, nil?: true |
#created_at ⇒ Time
The datetime the payment was created.
192 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 192 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The three-letter ISO currency code for this payment (e.g., ‘usd’, ‘eur’).
198 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 198 required :currency, enum: -> { WhopSDK::Currency } |
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed
204 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 204 required :dispute_alerted_at, Time, nil?: true |
#id ⇒ String
The unique identifier for the payment.
167 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 167 required :id, String |
#member ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Member?
The member attached to this payment.
210 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 210 required :member, -> { WhopSDK::RefundUpdatedWebhookEvent::Data::Payment::Member }, nil?: true |
#membership ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Membership?
The membership attached to this payment.
216 217 218 219 220 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 216 required :membership, -> { WhopSDK::RefundUpdatedWebhookEvent::Data::Payment::Membership }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
The custom metadata stored on this payment. This will be copied over to the checkout configuration for which this payment was made
227 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 227 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#paid_at ⇒ Time?
The time at which this payment was successfully collected. Null if the payment has not yet succeeded. As a Unix timestamp.
234 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 234 required :paid_at, Time, nil?: true |
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
240 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 240 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true |
#plan ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Plan?
The plan attached to this payment.
246 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 246 required :plan, -> { WhopSDK::RefundUpdatedWebhookEvent::Data::Payment::Plan }, nil?: true |
#product ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Product?
The product this payment was made for
252 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 252 required :product, -> { WhopSDK::RefundUpdatedWebhookEvent::Data::Payment::Product }, nil?: true |
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
258 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 258 required :subtotal, Float, nil?: true |
#tax_amount ⇒ Float?
The calculated amount of the sales/VAT tax (if applicable).
264 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 264 required :tax_amount, Float, nil?: true |
#tax_behavior ⇒ Symbol, ...
The type of tax inclusivity applied to the receipt, for determining whether the tax is included in the final price, or paid on top.
271 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 271 required :tax_behavior, enum: -> { WhopSDK::ReceiptTaxBehavior }, nil?: true |
#tax_refunded_amount ⇒ Float?
The amount of tax that has been refunded (if applicable).
277 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 277 required :tax_refunded_amount, Float, nil?: true |
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
283 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 283 required :total, Float, nil?: true |
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
289 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 289 required :usd_total, Float, nil?: true |
#user ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::User?
The user that made this payment.
295 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 295 required :user, -> { WhopSDK::RefundUpdatedWebhookEvent::Data::Payment::User }, nil?: true |