Class: WhopSDK::Models::ResolutionCenterCaseCreatedWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Classes: Company, Member, Payment, ResolutionEvent, User

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, currency:, paid_at:, subtotal:, total:) ⇒ Object

Some parameter documentations has been truncated, see Payment for more details.

The payment record that is the subject of this resolution case.

Parameters:

  • id (String)

    The unique identifier for the payment.

  • created_at (Time)

    The datetime the payment was created.

  • currency (Symbol, WhopSDK::Models::Currency, nil)

    The available currencies on the platform

  • paid_at (Time, nil)

    The time at which this payment was successfully collected. Null if the payment h

  • subtotal (Float, nil)

    The payment amount before taxes and discounts are applied. In the currency speci

  • total (Float)

    The total amount charged to the customer for this payment, including taxes and a



# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 167

Instance Attribute Details

#companyWhopSDK::Models::ResolutionCenterCaseCreatedWebhookEvent::Data::Company?

The company involved in this resolution case. Null if the company no longer exists.



72
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 72

required :company, -> { WhopSDK::ResolutionCenterCaseCreatedWebhookEvent::Data::Company }, nil?: true

#created_atTime

The datetime the resolution was created.

Returns:

  • (Time)


78
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 78

required :created_at, Time

#customer_appealedBoolean

Whether the customer has filed an appeal after the initial resolution decision.

Returns:

  • (Boolean)


84
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 84

required :customer_appealed, WhopSDK::Internal::Type::Boolean

#customer_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCaseCustomerResponse>

The list of actions currently available to the customer.



90
91
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 90

required :customer_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseCustomerResponse] }

#due_dateTime?

The deadline by which the next response is required. Null if no deadline is currently active. As a Unix timestamp.

Returns:

  • (Time, nil)


98
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 98

required :due_date, Time, nil?: true

#idString

The unique identifier for the resolution.

Returns:

  • (String)


65
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 65

required :id, String

#issueSymbol, WhopSDK::Models::ResolutionCenterCaseIssueType

The category of the dispute.



104
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 104

required :issue, enum: -> { WhopSDK::ResolutionCenterCaseIssueType }

#memberWhopSDK::Models::ResolutionCenterCaseCreatedWebhookEvent::Data::Member?

The membership record associated with the disputed payment. Null if the membership no longer exists.



111
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 111

required :member, -> { WhopSDK::ResolutionCenterCaseCreatedWebhookEvent::Data::Member }, nil?: true

#merchant_appealedBoolean

Whether the merchant has filed an appeal after the initial resolution decision.

Returns:

  • (Boolean)


117
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 117

required :merchant_appealed, WhopSDK::Internal::Type::Boolean

#merchant_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCaseMerchantResponse>

The list of actions currently available to the merchant.



123
124
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 123

required :merchant_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseMerchantResponse] }

#paymentWhopSDK::Models::ResolutionCenterCaseCreatedWebhookEvent::Data::Payment

The payment record that is the subject of this resolution case.



130
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 130

required :payment, -> { WhopSDK::ResolutionCenterCaseCreatedWebhookEvent::Data::Payment }

#platform_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCasePlatformResponse>

The list of actions currently available to the Whop platform for moderating this resolution.



137
138
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 137

required :platform_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCasePlatformResponse] }

#resolution_eventsArray<WhopSDK::Models::ResolutionCenterCaseCreatedWebhookEvent::Data::ResolutionEvent>

The most recent 50 messages, actions, and status changes that have occurred during this resolution case.



145
146
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 145

required :resolution_events,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::ResolutionCenterCaseCreatedWebhookEvent::Data::ResolutionEvent] }

#statusSymbol, WhopSDK::Models::ResolutionCenterCaseStatus

The current status of the resolution case, indicating which party needs to respond or if the case is closed.



153
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 153

required :status, enum: -> { WhopSDK::ResolutionCenterCaseStatus }

#updated_atTime

The datetime the resolution was last updated.

Returns:

  • (Time)


159
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 159

required :updated_at, Time

#userWhopSDK::Models::ResolutionCenterCaseCreatedWebhookEvent::Data::User

The customer (buyer) who filed this resolution case.



165
# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 165

required :user, -> { WhopSDK::ResolutionCenterCaseCreatedWebhookEvent::Data::User }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/resolution_center_case_created_webhook_event.rb', line 391