Class: WhopSDK::Models::ResolutionCenterCaseListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/resolution_center_case_list_response.rb

Overview

Defined Under Namespace

Classes: Company, Payment, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

The payment record that is the subject of this resolution case.

Parameters:

  • id (String)

    The unique identifier for the payment.



# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 90

Instance Attribute Details

#companyWhopSDK::Models::ResolutionCenterCaseListResponse::Company?

The company involved in this resolution case. Null if the company no longer exists.



18
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 18

required :company, -> { WhopSDK::Models::ResolutionCenterCaseListResponse::Company }, nil?: true

#created_atTime

The datetime the resolution was created.

Returns:

  • (Time)


24
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 24

required :created_at, Time

#customer_appealedBoolean

Whether the customer has filed an appeal after the initial resolution decision.

Returns:

  • (Boolean)


30
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 30

required :customer_appealed, WhopSDK::Internal::Type::Boolean

#customer_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCaseCustomerResponse>

The list of actions currently available to the customer.



36
37
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 36

required :customer_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseCustomerResponse] }

#due_dateTime?

The deadline by which the next response is required. Null if no deadline is currently active. As a Unix timestamp.

Returns:

  • (Time, nil)


44
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 44

required :due_date, Time, nil?: true

#idString

The unique identifier for the resolution.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 11

required :id, String

#issueSymbol, WhopSDK::Models::ResolutionCenterCaseIssueType

The category of the dispute.



50
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 50

required :issue, enum: -> { WhopSDK::ResolutionCenterCaseIssueType }

#merchant_appealedBoolean

Whether the merchant has filed an appeal after the initial resolution decision.

Returns:

  • (Boolean)


56
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 56

required :merchant_appealed, WhopSDK::Internal::Type::Boolean

#merchant_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCaseMerchantResponse>

The list of actions currently available to the merchant.



62
63
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 62

required :merchant_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseMerchantResponse] }

#paymentWhopSDK::Models::ResolutionCenterCaseListResponse::Payment

The payment record that is the subject of this resolution case.



69
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 69

required :payment, -> { WhopSDK::Models::ResolutionCenterCaseListResponse::Payment }

#statusSymbol, WhopSDK::Models::ResolutionCenterCaseStatus

The current status of the resolution case, indicating which party needs to respond or if the case is closed.



76
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 76

required :status, enum: -> { WhopSDK::ResolutionCenterCaseStatus }

#updated_atTime

The datetime the resolution was last updated.

Returns:

  • (Time)


82
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 82

required :updated_at, Time

#userWhopSDK::Models::ResolutionCenterCaseListResponse::User

The customer (buyer) who filed this resolution case.



88
# File 'lib/whop_sdk/models/resolution_center_case_list_response.rb', line 88

required :user, -> { WhopSDK::Models::ResolutionCenterCaseListResponse::User }