Class: WhopSDK::Models::ResolutionCenterCaseRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ResolutionCenterCaseRetrieveResponse
- Defined in:
- lib/whop_sdk/models/resolution_center_case_retrieve_response.rb
Overview
Defined Under Namespace
Classes: Company, Member, Payment, ResolutionEvent, User
Instance Attribute Summary collapse
-
#company ⇒ WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Company?
The company involved in this resolution case.
-
#created_at ⇒ Time
The datetime the resolution was created.
-
#customer_appealed ⇒ Boolean
Whether the customer has filed an appeal after the initial resolution decision.
-
#customer_response_actions ⇒ Array<Symbol, WhopSDK::Models::ResolutionCenterCaseCustomerResponse>
The list of actions currently available to the customer.
-
#due_date ⇒ Time?
The deadline by which the next response is required.
-
#id ⇒ String
The unique identifier for the resolution.
-
#issue ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseIssueType
The category of the dispute.
-
#member ⇒ WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Member?
The membership record associated with the disputed payment.
-
#merchant_appealed ⇒ Boolean
Whether the merchant has filed an appeal after the initial resolution decision.
-
#merchant_response_actions ⇒ Array<Symbol, WhopSDK::Models::ResolutionCenterCaseMerchantResponse>
The list of actions currently available to the merchant.
-
#payment ⇒ WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Payment
The payment record that is the subject of this resolution case.
-
#platform_response_actions ⇒ Array<Symbol, WhopSDK::Models::ResolutionCenterCasePlatformResponse>
The list of actions currently available to the Whop platform for moderating this resolution.
-
#resolution_events ⇒ Array<WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent>
The most recent 50 messages, actions, and status changes that have occurred during this resolution case.
-
#status ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseStatus
The current status of the resolution case, indicating which party needs to respond or if the case is closed.
-
#updated_at ⇒ Time
The datetime the resolution was last updated.
-
#user ⇒ WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::User
The customer (buyer) who filed this resolution case.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, currency:, paid_at:, subtotal:, total:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Payment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, currency:, paid_at:, subtotal:, total:) ⇒ Object
Some parameter documentations has been truncated, see Payment for more details.
The payment record that is the subject of this resolution case.
|
|
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 113
|
Instance Attribute Details
#company ⇒ WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Company?
The company involved in this resolution case. Null if the company no longer exists.
18 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 18 required :company, -> { WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Company }, nil?: true |
#created_at ⇒ Time
The datetime the resolution was created.
24 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 24 required :created_at, Time |
#customer_appealed ⇒ Boolean
Whether the customer has filed an appeal after the initial resolution decision.
30 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 30 required :customer_appealed, WhopSDK::Internal::Type::Boolean |
#customer_response_actions ⇒ Array<Symbol, WhopSDK::Models::ResolutionCenterCaseCustomerResponse>
The list of actions currently available to the customer.
36 37 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 36 required :customer_response_actions, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseCustomerResponse] } |
#due_date ⇒ Time?
The deadline by which the next response is required. Null if no deadline is currently active. As a Unix timestamp.
44 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 44 required :due_date, Time, nil?: true |
#id ⇒ String
The unique identifier for the resolution.
11 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 11 required :id, String |
#issue ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseIssueType
The category of the dispute.
50 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 50 required :issue, enum: -> { WhopSDK::ResolutionCenterCaseIssueType } |
#member ⇒ WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Member?
The membership record associated with the disputed payment. Null if the membership no longer exists.
57 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 57 required :member, -> { WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Member }, nil?: true |
#merchant_appealed ⇒ Boolean
Whether the merchant has filed an appeal after the initial resolution decision.
63 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 63 required :merchant_appealed, WhopSDK::Internal::Type::Boolean |
#merchant_response_actions ⇒ Array<Symbol, WhopSDK::Models::ResolutionCenterCaseMerchantResponse>
The list of actions currently available to the merchant.
69 70 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 69 required :merchant_response_actions, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseMerchantResponse] } |
#payment ⇒ WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Payment
The payment record that is the subject of this resolution case.
76 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 76 required :payment, -> { WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Payment } |
#platform_response_actions ⇒ Array<Symbol, WhopSDK::Models::ResolutionCenterCasePlatformResponse>
The list of actions currently available to the Whop platform for moderating this resolution.
83 84 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 83 required :platform_response_actions, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCasePlatformResponse] } |
#resolution_events ⇒ Array<WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent>
The most recent 50 messages, actions, and status changes that have occurred during this resolution case.
91 92 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 91 required :resolution_events, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent] } |
#status ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseStatus
The current status of the resolution case, indicating which party needs to respond or if the case is closed.
99 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 99 required :status, enum: -> { WhopSDK::ResolutionCenterCaseStatus } |
#updated_at ⇒ Time
The datetime the resolution was last updated.
105 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 105 required :updated_at, Time |
#user ⇒ WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::User
The customer (buyer) who filed this resolution case.
111 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 111 required :user, -> { WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::User } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 336
|