Class: WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Payment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/resolution_center_case_retrieve_response.rb,
sig/whop_sdk/models/resolution_center_case_retrieve_response.rbs

Overview

See Also:

  • WhopSDK::Models::ResolutionCenterCaseRetrieveResponse#payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



139
# File 'sig/whop_sdk/models/resolution_center_case_retrieve_response.rbs', line 139

def initialize: (

Instance Attribute Details

#created_atTime

The datetime the payment was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


202
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 202

required :created_at, Time

#currencySymbol, ...

The available currencies on the platform

Parameters:

  • value (WhopSDK::Models::currency, nil)

Returns:



208
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 208

required :currency, enum: -> { WhopSDK::Currency }, nil?: true

#idString

The unique identifier for the payment.

Parameters:

  • value (String)

Returns:

  • (String)


196
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 196

required :id, String

The time at which this payment was successfully collected. Null if the payment has not yet succeeded. As a Unix timestamp.

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


215
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 215

required :paid_at, Time, nil?: true

#subtotalFloat?

The payment amount before taxes and discounts are applied. In the currency specified by the currency field.

Parameters:

  • value (Float, nil)

Returns:

  • (Float, nil)


222
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 222

required :subtotal, Float, nil?: true

#totalFloat

The total amount charged to the customer for this payment, including taxes and after any discounts. In the currency specified by the currency field.

Parameters:

  • value (Float)

Returns:

  • (Float)


229
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 229

required :total, Float

Instance Method Details

#to_hash{

Returns:

  • ({)


148
# File 'sig/whop_sdk/models/resolution_center_case_retrieve_response.rbs', line 148

def to_hash: -> {