Class: WhopSDK::Models::ReviewListResponse::Attachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/review_list_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, attachments:, created_at:, description:, joined_at:, paid_for_product:, published_at:, stars:, status:, title:, updated_at:, user:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ReviewListResponse for more details.

A user-submitted review of a company, including a star rating and optional text feedback.

Parameters:

  • id (String)

    The unique identifier for the review.

  • attachments (Array<WhopSDK::Models::ReviewListResponse::Attachment>)

    A list of files and media attached to the review.

  • created_at (Time)

    The datetime the review was created.

  • description (String, nil)

    The body text of the review containing the user’s detailed feedback. Returns an

  • joined_at (Time, nil)

    The timestamp of when the reviewer first joined the product. Null if unknown.

  • paid_for_product (Boolean, nil)

    Whether the reviewer paid for the product. Null if the payment status is unknown

  • published_at (Time, nil)

    The timestamp of when the review was published. Null if the review has not been

  • stars (Integer)

    The star rating given by the reviewer, from 1 to 5.

  • status (Symbol, WhopSDK::Models::ReviewStatus)

    The current moderation status of the review.

  • title (String, nil)

    A short summary title for the review. Null if the reviewer did not provide one.

  • updated_at (Time)

    The datetime the review was last updated.

  • user (WhopSDK::Models::ReviewListResponse::User)

    The user account of the person who wrote this review.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/whop_sdk/models/review_list_response.rb', line 114

class Attachment < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   Represents a unique identifier that is Base64 obfuscated. It is often used to
  #   refetch an object or as key for a cache. The ID type appears in a JSON response
  #   as a String; however, it is not intended to be human-readable. When expected as
  #   an input type, any string (such as `"VXNlci0xMA=="`) or integer (such as `4`)
  #   input value will be accepted as an ID.
  #
  #   @return [String]
  required :id, String

  # @!attribute content_type
  #   The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
  #
  #   @return [String, nil]
  required :content_type, String, nil?: true

  # @!attribute filename
  #   The original filename of the uploaded attachment, including its file extension.
  #
  #   @return [String, nil]
  required :filename, String, nil?: true

  # @!attribute url
  #   A pre-optimized URL for rendering this attachment on the client. This should be
  #   used for displaying attachments in apps.
  #
  #   @return [String, nil]
  required :url, String, nil?: true

  # @!method initialize(id:, content_type:, filename:, url:)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::ReviewListResponse::Attachment} for more details.
  #
  #   Represents an image attachment
  #
  #   @param id [String] Represents a unique identifier that is Base64 obfuscated. It is often used to re
  #
  #   @param content_type [String, nil] The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
  #
  #   @param filename [String, nil] The original filename of the uploaded attachment, including its file extension.
  #
  #   @param url [String, nil] A pre-optimized URL for rendering this attachment on the client. This should be
end

Instance Attribute Details

#content_typeString?

The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).

Returns:

  • (String, nil)


129
# File 'lib/whop_sdk/models/review_list_response.rb', line 129

required :content_type, String, nil?: true

#filenameString?

The original filename of the uploaded attachment, including its file extension.

Returns:

  • (String, nil)


135
# File 'lib/whop_sdk/models/review_list_response.rb', line 135

required :filename, String, nil?: true

#idString

Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.

Returns:

  • (String)


123
# File 'lib/whop_sdk/models/review_list_response.rb', line 123

required :id, String

#urlString?

A pre-optimized URL for rendering this attachment on the client. This should be used for displaying attachments in apps.

Returns:

  • (String, nil)


142
# File 'lib/whop_sdk/models/review_list_response.rb', line 142

required :url, String, nil?: true