Class: WhopSDK::Models::SetupIntent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/setup_intent.rb

Overview

Defined Under Namespace

Classes: CheckoutConfiguration, Company, Member, PaymentMethod

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, email:, name:, username:) ⇒ Object

The user for this member, if any.

Parameters:

  • id (String)

    The unique identifier for the company member user.

  • email (String, nil)

    The digital mailing address of the user.

  • name (String, nil)

    The user’s full name.

  • username (String)

    The whop username.



# File 'lib/whop_sdk/models/setup_intent.rb', line 67

Instance Attribute Details

#checkout_configurationWhopSDK::Models::SetupIntent::CheckoutConfiguration?

The checkout session configuration associated with this setup intent. Null if no checkout session was used.



18
# File 'lib/whop_sdk/models/setup_intent.rb', line 18

required :checkout_configuration, -> { WhopSDK::SetupIntent::CheckoutConfiguration }, nil?: true

#companyWhopSDK::Models::SetupIntent::Company?

The company that initiated this setup intent. Null if the company has been deleted.



25
# File 'lib/whop_sdk/models/setup_intent.rb', line 25

required :company, -> { WhopSDK::SetupIntent::Company }, nil?: true

#created_atTime

The datetime the setup intent was created.

Returns:

  • (Time)


31
# File 'lib/whop_sdk/models/setup_intent.rb', line 31

required :created_at, Time

#error_messageString?

A human-readable error message explaining why the setup intent failed. Null if no error occurred.

Returns:

  • (String, nil)


38
# File 'lib/whop_sdk/models/setup_intent.rb', line 38

required :error_message, String, nil?: true

#idString

The unique identifier for the setup intent.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/setup_intent.rb', line 11

required :id, String

#memberWhopSDK::Models::SetupIntent::Member?

The company member associated with this setup intent. Null if the user is not a member.



45
# File 'lib/whop_sdk/models/setup_intent.rb', line 45

required :member, -> { WhopSDK::SetupIntent::Member }, nil?: true

#metadataHash{Symbol=>Object}?

Custom key-value pairs attached to this setup intent. Null if no metadata was provided.

Returns:

  • (Hash{Symbol=>Object}, nil)


52
# File 'lib/whop_sdk/models/setup_intent.rb', line 52

required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#payment_methodWhopSDK::Models::SetupIntent::PaymentMethod?

The saved payment method created by this setup intent. Null if the setup has not completed successfully.



59
# File 'lib/whop_sdk/models/setup_intent.rb', line 59

required :payment_method, -> { WhopSDK::SetupIntent::PaymentMethod }, nil?: true

#statusSymbol, WhopSDK::Models::SetupIntentStatus

The current status of the setup intent.



65
# File 'lib/whop_sdk/models/setup_intent.rb', line 65

required :status, enum: -> { WhopSDK::SetupIntentStatus }