Class: WhopSDK::Models::SetupIntent::PaymentMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/setup_intent.rb,
sig/whop_sdk/models/setup_intent.rbs

Overview

See Also:

  • WhopSDK::Models::SetupIntent#payment_method

Defined Under Namespace

Classes: Card, MailingAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand:, exp_month:, exp_year:, last4:) ⇒ Object

Some parameter documentations has been truncated, see Card for more details.

The card data associated with the payment method, if its a debit or credit card.

Parameters:

  • brand (Symbol, WhopSDK::Models::CardBrands, nil)

    Possible card brands that a payment token can have

  • exp_month (Integer, nil)

    The two-digit expiration month of the card (1-12). Null if not available.

  • exp_year (Integer, nil)

    The two-digit expiration year of the card (e.g., 27 for 2027). Null if not avail

  • last4 (String, nil)

    The last four digits of the card number. Null if not available.



# File 'lib/whop_sdk/models/setup_intent.rb', line 224

Instance Attribute Details

#cardWhopSDK::Models::SetupIntent::PaymentMethod::Card?

The card data associated with the payment method, if its a debit or credit card.

Parameters:

  • value (WhopSDK::SetupIntent::PaymentMethod::Card, nil)

Returns:



204
# File 'lib/whop_sdk/models/setup_intent.rb', line 204

required :card, -> { WhopSDK::SetupIntent::PaymentMethod::Card }, nil?: true

#created_atTime

The datetime the payment token was created.

Parameters:

  • value (Time)

Returns:

  • (Time)


210
# File 'lib/whop_sdk/models/setup_intent.rb', line 210

required :created_at, Time

#idString

The unique identifier for the payment token.

Parameters:

  • value (String)

Returns:

  • (String)


198
# File 'lib/whop_sdk/models/setup_intent.rb', line 198

required :id, String

#mailing_addressWhopSDK::Models::SetupIntent::PaymentMethod::MailingAddress?

The mailing address associated with the payment method's user

Parameters:

  • value (WhopSDK::SetupIntent::PaymentMethod::MailingAddress, nil)

Returns:



216
# File 'lib/whop_sdk/models/setup_intent.rb', line 216

required :mailing_address, -> { WhopSDK::SetupIntent::PaymentMethod::MailingAddress }, nil?: true

#payment_method_typeSymbol, WhopSDK::Models::PaymentMethodTypes

The payment method type of the payment method

Parameters:

  • value (WhopSDK::Models::payment_method_types)

Returns:



222
# File 'lib/whop_sdk/models/setup_intent.rb', line 222

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }

Instance Method Details

#to_hash{

Returns:

  • ({)


157
# File 'sig/whop_sdk/models/setup_intent.rbs', line 157

def to_hash: -> {