Class: WhopSDK::Models::SetupIntent::PaymentMethod::Card
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SetupIntent::PaymentMethod::Card
- Defined in:
- lib/whop_sdk/models/setup_intent.rb,
sig/whop_sdk/models/setup_intent.rbs
Overview
Instance Attribute Summary collapse
-
#brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#exp_month ⇒ Integer?
The two-digit expiration month of the card (1-12).
-
#exp_year ⇒ Integer?
The two-digit expiration year of the card (e.g., 27 for 2027).
-
#last4 ⇒ String?
The last four digits of the card number.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
182 |
# File 'sig/whop_sdk/models/setup_intent.rbs', line 182
def initialize: (
|
Instance Attribute Details
#brand ⇒ Symbol, ...
Possible card brands that a payment token can have
247 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 247 required :brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#exp_month ⇒ Integer?
The two-digit expiration month of the card (1-12). Null if not available.
253 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 253 required :exp_month, Integer, nil?: true |
#exp_year ⇒ Integer?
The two-digit expiration year of the card (e.g., 27 for 2027). Null if not available.
260 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 260 required :exp_year, Integer, nil?: true |
#last4 ⇒ String?
The last four digits of the card number. Null if not available.
266 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 266 required :last4, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
189 |
# File 'sig/whop_sdk/models/setup_intent.rbs', line 189
def to_hash: -> {
|