Class: WhopSDK::Models::SetupIntentCanceledWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/setup_intent_canceled_webhook_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , data: , timestamp: , api_version: :v1, type: :"setup_intent.canceled") ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::SetupIntentCanceledWebhookEvent for more details.

Parameters:

  • id (String) (defaults to: )

    A unique ID for every single webhook request

  • data (WhopSDK::Models::SetupIntent) (defaults to: )

    An object representing a setup intent, which is a flow for allowing a customer t

  • timestamp (Time) (defaults to: )

    The timestamp in ISO 8601 format that the webhook was sent at on the server

  • api_version (Symbol, :v1) (defaults to: :v1)

    The API version for this webhook

  • type (Symbol, :"setup_intent.canceled") (defaults to: :"setup_intent.canceled")

    The webhook event type



# File 'lib/whop_sdk/models/setup_intent_canceled_webhook_event.rb', line 37

Instance Attribute Details

#api_versionSymbol, :v1

The API version for this webhook

Returns:

  • (Symbol, :v1)


16
# File 'lib/whop_sdk/models/setup_intent_canceled_webhook_event.rb', line 16

required :api_version, const: :v1

#dataWhopSDK::Models::SetupIntent

An object representing a setup intent, which is a flow for allowing a customer to add a payment method to their account without making a purchase.



23
# File 'lib/whop_sdk/models/setup_intent_canceled_webhook_event.rb', line 23

required :data, -> { WhopSDK::SetupIntent }

#idString

A unique ID for every single webhook request

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/setup_intent_canceled_webhook_event.rb', line 10

required :id, String

#timestampTime

The timestamp in ISO 8601 format that the webhook was sent at on the server

Returns:

  • (Time)


29
# File 'lib/whop_sdk/models/setup_intent_canceled_webhook_event.rb', line 29

required :timestamp, Time

#typeSymbol, :"setup_intent.canceled"

The webhook event type

Returns:

  • (Symbol, :"setup_intent.canceled")


35
# File 'lib/whop_sdk/models/setup_intent_canceled_webhook_event.rb', line 35

required :type, const: :"setup_intent.canceled"