Class: WhopSDK::Models::SetupIntentListResponse::PaymentMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/setup_intent_list_response.rb

Overview

See Also:

Defined Under Namespace

Classes: Card, MailingAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand:, exp_month:, exp_year:, last4:) ⇒ Object

Some parameter documentations has been truncated, see Card for more details.

The card data associated with the payment method, if its a debit or credit card.

Parameters:

  • brand (Symbol, WhopSDK::Models::CardBrands, nil)

    Possible card brands that a payment token can have

  • exp_month (Integer, nil)

    The two-digit expiration month of the card (1-12). Null if not available.

  • exp_year (Integer, nil)

    The two-digit expiration year of the card (e.g., 27 for 2027). Null if not avail

  • last4 (String, nil)

    The last four digits of the card number. Null if not available.



# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 219

Instance Attribute Details

#cardWhopSDK::Models::SetupIntentListResponse::PaymentMethod::Card?

The card data associated with the payment method, if its a debit or credit card.



197
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 197

required :card, -> { WhopSDK::Models::SetupIntentListResponse::PaymentMethod::Card }, nil?: true

#created_atTime

The datetime the payment token was created.

Returns:

  • (Time)


203
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 203

required :created_at, Time

#idString

The unique identifier for the payment token.

Returns:

  • (String)


191
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 191

required :id, String

#mailing_addressWhopSDK::Models::SetupIntentListResponse::PaymentMethod::MailingAddress?

The mailing address associated with the payment method’s user



209
210
211
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 209

required :mailing_address,
-> { WhopSDK::Models::SetupIntentListResponse::PaymentMethod::MailingAddress },
nil?: true

#payment_method_typeSymbol, WhopSDK::Models::PaymentMethodTypes

The payment method type of the payment method



217
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 217

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }