Class: WhopSDK::Models::Shipment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/shipment.rb

Defined Under Namespace

Classes: Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, carrier:, created_at:, delivery_estimate:, payment:, service:, status:, substatus:, tracking_code:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::Shipment for more details.

A physical shipment associated with a payment, including carrier details and tracking information.

Parameters:

  • id (String)

    The unique identifier for the shipment.

  • carrier (Symbol, WhopSDK::Models::ShipmentCarrier)

    The shipping carrier responsible for delivering this shipment.

  • created_at (Time)

    The datetime the shipment was created.

  • delivery_estimate (Time, nil)

    The estimated delivery date for this shipment. Null if the carrier has not provi

  • payment (WhopSDK::Models::Shipment::Payment, nil)

    The payment associated with this shipment. Null if the payment has been deleted

  • service (String, nil)

    The shipping service level used for this shipment. Null if the carrier does not

  • status (Symbol, WhopSDK::Models::ShipmentStatus)

    The current delivery status of this shipment.

  • substatus (Symbol, WhopSDK::Models::ShipmentSubstatus, nil)

    The substatus of a shipment

  • tracking_code (String)

    The carrier-assigned tracking number used to look up shipment progress.

  • updated_at (Time)

    The datetime the shipment was last updated.



# File 'lib/whop_sdk/models/shipment.rb', line 69

Instance Attribute Details

#carrierSymbol, WhopSDK::Models::ShipmentCarrier

The shipping carrier responsible for delivering this shipment.



16
# File 'lib/whop_sdk/models/shipment.rb', line 16

required :carrier, enum: -> { WhopSDK::ShipmentCarrier }

#created_atTime

The datetime the shipment was created.

Returns:

  • (Time)


22
# File 'lib/whop_sdk/models/shipment.rb', line 22

required :created_at, Time

#delivery_estimateTime?

The estimated delivery date for this shipment. Null if the carrier has not provided an estimate.

Returns:

  • (Time, nil)


29
# File 'lib/whop_sdk/models/shipment.rb', line 29

required :delivery_estimate, Time, nil?: true

#idString

The unique identifier for the shipment.

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/shipment.rb', line 10

required :id, String

#paymentWhopSDK::Models::Shipment::Payment?

The payment associated with this shipment. Null if the payment has been deleted or is inaccessible.



36
# File 'lib/whop_sdk/models/shipment.rb', line 36

required :payment, -> { WhopSDK::Shipment::Payment }, nil?: true

#serviceString?

The shipping service level used for this shipment. Null if the carrier does not specify a service tier.

Returns:

  • (String, nil)


43
# File 'lib/whop_sdk/models/shipment.rb', line 43

required :service, String, nil?: true

#statusSymbol, WhopSDK::Models::ShipmentStatus

The current delivery status of this shipment.

Returns:



49
# File 'lib/whop_sdk/models/shipment.rb', line 49

required :status, enum: -> { WhopSDK::ShipmentStatus }

#substatusSymbol, ...

The substatus of a shipment

Returns:



55
# File 'lib/whop_sdk/models/shipment.rb', line 55

required :substatus, enum: -> { WhopSDK::ShipmentSubstatus }, nil?: true

#tracking_codeString

The carrier-assigned tracking number used to look up shipment progress.

Returns:

  • (String)


61
# File 'lib/whop_sdk/models/shipment.rb', line 61

required :tracking_code, String

#updated_atTime

The datetime the shipment was last updated.

Returns:

  • (Time)


67
# File 'lib/whop_sdk/models/shipment.rb', line 67

required :updated_at, Time