Class: WhopSDK::Models::ShipmentCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/shipment_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id:, payment_id:, tracking_code:, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ShipmentCreateParams for more details.

Parameters:

  • company_id (String)

    The unique identifier of the company to create the shipment for, starting with ‘

  • payment_id (String)

    The unique identifier of the payment to associate the shipment with.

  • tracking_code (String)

    The carrier tracking code for the shipment, such as a USPS, UPS, or FedEx tracki

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/shipment_create_params.rb', line 30

Instance Attribute Details

#company_idString

The unique identifier of the company to create the shipment for, starting with ‘biz_’.

Returns:

  • (String)


15
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 15

required :company_id, String

#payment_idString

The unique identifier of the payment to associate the shipment with.

Returns:

  • (String)


21
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 21

required :payment_id, String

#tracking_codeString

The carrier tracking code for the shipment, such as a USPS, UPS, or FedEx tracking number.

Returns:

  • (String)


28
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 28

required :tracking_code, String