Class: WhopSDK::Models::ShipmentListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/shipment_list_response.rb

Overview

Defined Under Namespace

Classes: Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, carrier:, created_at:, delivery_estimate:, payment:, service:, status:, substatus:, tracking_code:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ShipmentListResponse for more details.

A physical shipment associated with a payment, including carrier details and tracking information.

Parameters:

  • id (String)

    The unique identifier for the shipment.

  • carrier (Symbol, WhopSDK::Models::ShipmentCarrier)

    The shipping carrier responsible for delivering this shipment.

  • created_at (Time)

    The datetime the shipment was created.

  • delivery_estimate (Time, nil)

    The estimated delivery date for this shipment. Null if the carrier has not provi

  • payment (WhopSDK::Models::ShipmentListResponse::Payment, nil)

    The payment associated with this shipment. Null if the payment has been deleted

  • service (String, nil)

    The shipping service level used for this shipment. Null if the carrier does not

  • status (Symbol, WhopSDK::Models::ShipmentStatus)

    The current delivery status of this shipment.

  • substatus (Symbol, WhopSDK::Models::ShipmentSubstatus, nil)

    The substatus of a shipment

  • tracking_code (String)

    The carrier-assigned tracking number used to look up shipment progress.

  • updated_at (Time)

    The datetime the shipment was last updated.



# File 'lib/whop_sdk/models/shipment_list_response.rb', line 70

Instance Attribute Details

#carrierSymbol, WhopSDK::Models::ShipmentCarrier

The shipping carrier responsible for delivering this shipment.



17
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 17

required :carrier, enum: -> { WhopSDK::ShipmentCarrier }

#created_atTime

The datetime the shipment was created.

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 23

required :created_at, Time

#delivery_estimateTime?

The estimated delivery date for this shipment. Null if the carrier has not provided an estimate.

Returns:

  • (Time, nil)


30
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 30

required :delivery_estimate, Time, nil?: true

#idString

The unique identifier for the shipment.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 11

required :id, String

#paymentWhopSDK::Models::ShipmentListResponse::Payment?

The payment associated with this shipment. Null if the payment has been deleted or is inaccessible.



37
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 37

required :payment, -> { WhopSDK::Models::ShipmentListResponse::Payment }, nil?: true

#serviceString?

The shipping service level used for this shipment. Null if the carrier does not specify a service tier.

Returns:

  • (String, nil)


44
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 44

required :service, String, nil?: true

#statusSymbol, WhopSDK::Models::ShipmentStatus

The current delivery status of this shipment.

Returns:



50
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 50

required :status, enum: -> { WhopSDK::ShipmentStatus }

#substatusSymbol, ...

The substatus of a shipment

Returns:



56
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 56

required :substatus, enum: -> { WhopSDK::ShipmentSubstatus }, nil?: true

#tracking_codeString

The carrier-assigned tracking number used to look up shipment progress.

Returns:

  • (String)


62
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 62

required :tracking_code, String

#updated_atTime

The datetime the shipment was last updated.

Returns:

  • (Time)


68
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 68

required :updated_at, Time