Class: WhopSDK::Models::SocialAccount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/social_account.rb,
sig/whop_sdk/models/social_account.rbs

Overview

See Also:

  • WhopSDK::Resources::SocialAccounts#create

Defined Under Namespace

Modules: Platform

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, external_id:, name:, platform:, profile_picture_url:, scopes:, url:, username:, verified:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::SocialAccount for more details.

Parameters:

  • id (String)

    Unique identifier for the social account.

  • external_id (String, nil)

    The platform-specific ID for this social account.

  • name (String, nil)

    The display name of the social account on the platform.

  • platform (Symbol, WhopSDK::Models::SocialAccount::Platform)

    The platform the social account exists on.

  • profile_picture_url (String, nil)

    The URL where the profile picture of the social account can be accessed.

  • scopes (Array<String>)
  • url (String, nil)

    The URL where the social account can be accessed on the platform. Null while a W

  • username (String, nil)

    The username of the social account on the platform. Null while a Whop-owned page

  • verified (Boolean)

    Whether the social account is verified on the platform.



# File 'lib/whop_sdk/models/social_account.rb', line 62

Instance Attribute Details

#external_idString?

The platform-specific ID for this social account.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


17
# File 'lib/whop_sdk/models/social_account.rb', line 17

required :external_id, String, nil?: true

#idString

Unique identifier for the social account.

Parameters:

  • value (String)

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/social_account.rb', line 11

required :id, String

#nameString?

The display name of the social account on the platform.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


23
# File 'lib/whop_sdk/models/social_account.rb', line 23

required :name, String, nil?: true

#platformSymbol, WhopSDK::Models::SocialAccount::Platform

The platform the social account exists on.

Parameters:

  • value (WhopSDK::Models::SocialAccount::platform)

Returns:



29
# File 'lib/whop_sdk/models/social_account.rb', line 29

required :platform, enum: -> { WhopSDK::SocialAccount::Platform }

#profile_picture_urlString?

The URL where the profile picture of the social account can be accessed.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


35
# File 'lib/whop_sdk/models/social_account.rb', line 35

required :profile_picture_url, String, nil?: true

#scopesArray<String>

Parameters:

  • value (::Array[String])

Returns:

  • (Array<String>)


40
# File 'lib/whop_sdk/models/social_account.rb', line 40

required :scopes, WhopSDK::Internal::Type::ArrayOf[String]

#urlString?

The URL where the social account can be accessed on the platform. Null while a Whop-owned page is still being provisioned.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


47
# File 'lib/whop_sdk/models/social_account.rb', line 47

required :url, String, nil?: true

#usernameString?

The username of the social account on the platform. Null while a Whop-owned page is still being provisioned.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


54
# File 'lib/whop_sdk/models/social_account.rb', line 54

required :username, String, nil?: true

#verifiedBoolean

Whether the social account is verified on the platform.

Parameters:

  • value (Boolean)

Returns:

  • (Boolean)


60
# File 'lib/whop_sdk/models/social_account.rb', line 60

required :verified, WhopSDK::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


47
# File 'sig/whop_sdk/models/social_account.rbs', line 47

def to_hash: -> {