Class: WhopSDK::Models::SocialAccountConnectParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/social_account_connect_params.rb,
sig/whop_sdk/models/social_account_connect_params.rbs

Overview

See Also:

  • WhopSDK::Resources::SocialAccounts#connect

Defined Under Namespace

Modules: Platform, Scope

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(platform:, account_id: nil, redirect_url: nil, scopes: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::SocialAccountConnectParams for more details.

account-scop

Parameters:

  • platform (Symbol, WhopSDK::Models::SocialAccountConnectParams::Platform)

    The platform to connect the social account on. Today, the supported option is `m

  • account_id (String) (defaults to: nil)

    The Account (biz_ identifier) to connect the social account for. An

  • redirect_url (String) (defaults to: nil)

    The Whop URL to redirect the user to after they finish connecting.

  • scopes (Array<Symbol, WhopSDK::Models::SocialAccountConnectParams::Scope>) (defaults to: nil)

    Capabilities to grant for the connected social account. Use advertise when con

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/social_account_connect_params.rb', line 38

Instance Attribute Details

#account_idString?

The Account (biz_ identifier) to connect the social account for. An account-scoped API key may omit this to default to its own account.

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/whop_sdk/models/social_account_connect_params.rb', line 22

optional :account_id, String

#platformSymbol, WhopSDK::Models::SocialAccountConnectParams::Platform

The platform to connect the social account on. Today, the supported option is meta_business.

Parameters:

  • value (WhopSDK::Models::SocialAccountConnectParams::platform)

Returns:



15
# File 'lib/whop_sdk/models/social_account_connect_params.rb', line 15

required :platform, enum: -> { WhopSDK::SocialAccountConnectParams::Platform }

#redirect_urlString?

The Whop URL to redirect the user to after they finish connecting.

Parameters:

  • (String)

Returns:

  • (String, nil)


28
# File 'lib/whop_sdk/models/social_account_connect_params.rb', line 28

optional :redirect_url, String

#scopesArray<Symbol, WhopSDK::Models::SocialAccountConnectParams::Scope>?

Capabilities to grant for the connected social account. Use advertise when connecting a Meta Business account for ads.



35
36
# File 'lib/whop_sdk/models/social_account_connect_params.rb', line 35

optional :scopes,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::SocialAccountConnectParams::Scope] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/social_account_connect_params.rb', line 60

Instance Method Details

#to_hash{

Returns:

  • ({)


40
# File 'sig/whop_sdk/models/social_account_connect_params.rbs', line 40

def to_hash: -> {