Class: WhopSDK::Models::SocialAccountListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/social_account_list_params.rb,
sig/whop_sdk/models/social_account_list_params.rbs

Overview

See Also:

  • WhopSDK::Resources::SocialAccounts#list

Defined Under Namespace

Modules: Direction, Order, Platform, Scope

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id: nil, after: nil, before: nil, direction: nil, first: nil, last: nil, order: nil, platform: nil, scopes: nil, user_id: nil, verified: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::SocialAccountListParams for more details.

Parameters:

  • account_id (String) (defaults to: nil)

    The Account that the social accounts are connected to. Provide either this or us

  • after (String) (defaults to: nil)

    Cursor to fetch the page after (from page_info.end_cursor).

  • before (String) (defaults to: nil)

    Cursor to fetch the page before (from page_info.start_cursor).

  • direction (Symbol, WhopSDK::Models::SocialAccountListParams::Direction) (defaults to: nil)

    Sort direction.

  • first (Integer) (defaults to: nil)

    The number of social accounts to return.

  • last (Integer) (defaults to: nil)

    The number of social accounts to return from the end of the range.

  • order (Symbol, WhopSDK::Models::SocialAccountListParams::Order) (defaults to: nil)

    The field to sort social accounts by.

  • platform (Symbol, WhopSDK::Models::SocialAccountListParams::Platform) (defaults to: nil)

    Only return social accounts for the platform that is specified.

  • scopes (Array<Symbol, WhopSDK::Models::SocialAccountListParams::Scope>) (defaults to: nil)

    Only return social accounts that have these scopes.

  • user_id (String) (defaults to: nil)

    The User that the social accounts are connected to. Provide either this or accou

  • verified (Boolean) (defaults to: nil)

    Only return social accounts that are verified on the platform.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/social_account_list_params.rb', line 78

Instance Attribute Details

#account_idString?

The Account that the social accounts are connected to. Provide either this or user_id.

Parameters:

  • (String)

Returns:

  • (String, nil)


15
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 15

optional :account_id, String

#afterString?

Cursor to fetch the page after (from page_info.end_cursor).

Parameters:

  • (String)

Returns:

  • (String, nil)


21
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 21

optional :after, String

#beforeString?

Cursor to fetch the page before (from page_info.start_cursor).

Parameters:

  • (String)

Returns:

  • (String, nil)


27
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 27

optional :before, String

#directionSymbol, ...

Sort direction.



33
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 33

optional :direction, enum: -> { WhopSDK::SocialAccountListParams::Direction }

#firstInteger?

The number of social accounts to return.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


39
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 39

optional :first, Integer

#lastInteger?

The number of social accounts to return from the end of the range.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


45
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 45

optional :last, Integer

#orderSymbol, ...

The field to sort social accounts by.



51
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 51

optional :order, enum: -> { WhopSDK::SocialAccountListParams::Order }

#platformSymbol, ...

Only return social accounts for the platform that is specified.



57
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 57

optional :platform, enum: -> { WhopSDK::SocialAccountListParams::Platform }

#scopesArray<Symbol, WhopSDK::Models::SocialAccountListParams::Scope>?

Only return social accounts that have these scopes.

Returns:



63
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 63

optional :scopes, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::SocialAccountListParams::Scope] }

#user_idString?

The User that the social accounts are connected to. Provide either this or account_id.

Parameters:

  • (String)

Returns:

  • (String, nil)


70
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 70

optional :user_id, String

#verifiedBoolean?

Only return social accounts that are verified on the platform.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


76
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 76

optional :verified, WhopSDK::Internal::Type::Boolean

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/social_account_list_params.rb', line 113

Instance Method Details

#to_hash{

Returns:

  • ({)


90
# File 'sig/whop_sdk/models/social_account_list_params.rbs', line 90

def to_hash: -> {