Class: WhopSDK::Models::SocialAccountPostsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/social_account_posts_params.rb,
sig/whop_sdk/models/social_account_posts_params.rbs

Overview

See Also:

  • WhopSDK::Resources::SocialAccounts#posts

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, account_id:, after: nil, first: nil, post_id: nil, request_options: {}) ⇒ Object

Parameters:

  • id (String)
  • account_id (String)

    The Account (a biz_ identifier) the social account is connected to.

  • after (String) (defaults to: nil)

    Cursor to fetch the page after (from page_info.end_cursor).

  • first (Integer) (defaults to: nil)

    The number of posts to return.

  • post_id (String) (defaults to: nil)

    Return only the single post with this platform id, instead of the full list.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 39

Instance Attribute Details

#account_idString

The Account (a biz_ identifier) the social account is connected to.

Parameters:

  • value (String)

Returns:

  • (String)


19
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 19

required :account_id, String

#afterString?

Cursor to fetch the page after (from page_info.end_cursor).

Parameters:

  • (String)

Returns:

  • (String, nil)


25
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 25

optional :after, String

#firstInteger?

The number of posts to return.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


31
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 31

optional :first, Integer

#idString

Parameters:

  • value (String)

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 13

required :id, String

#post_idString?

Return only the single post with this platform id, instead of the full list.

Parameters:

  • (String)

Returns:

  • (String, nil)


37
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 37

optional :post_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


42
# File 'sig/whop_sdk/models/social_account_posts_params.rbs', line 42

def to_hash: -> {