Class: WhopSDK::Models::SupportChannel

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/support_channel.rb

Defined Under Namespace

Classes: CustomerUser

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, company_id:, custom_name:, customer_user:, last_message_at:, resolved_at:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::SupportChannel for more details.

A messaging channel that can be a one-on-one DM, group chat, company support conversation, or platform-level direct message.

Parameters:

  • id (String)

    The unique identifier for the entity

  • company_id (String, nil)

    The unique identifier of the company associated with this channel. Null if this

  • custom_name (String, nil)

    A custom display name assigned to this channel by the user. Null if no custom na

  • customer_user (WhopSDK::Models::SupportChannel::CustomerUser, nil)

    The customer who initiated this support conversation. Null if this is not a supp

  • last_message_at (Time, nil)

    The timestamp when the most recent message was sent in this channel. Null if no

  • resolved_at (Time, nil)

    The timestamp when the linked support ticket was marked as resolved. Null if unr



# File 'lib/whop_sdk/models/support_channel.rb', line 47

Instance Attribute Details

#company_idString?

The unique identifier of the company associated with this channel. Null if this is not a support or company-scoped conversation.

Returns:

  • (String, nil)


17
# File 'lib/whop_sdk/models/support_channel.rb', line 17

required :company_id, String, nil?: true

#custom_nameString?

A custom display name assigned to this channel by the user. Null if no custom name has been set.

Returns:

  • (String, nil)


24
# File 'lib/whop_sdk/models/support_channel.rb', line 24

required :custom_name, String, nil?: true

#customer_userWhopSDK::Models::SupportChannel::CustomerUser?

The customer who initiated this support conversation. Null if this is not a support chat.



31
# File 'lib/whop_sdk/models/support_channel.rb', line 31

required :customer_user, -> { WhopSDK::SupportChannel::CustomerUser }, nil?: true

#idString

The unique identifier for the entity

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/support_channel.rb', line 10

required :id, String

#last_message_atTime?

The timestamp when the most recent message was sent in this channel. Null if no messages have been sent.

Returns:

  • (Time, nil)


38
# File 'lib/whop_sdk/models/support_channel.rb', line 38

required :last_message_at, Time, nil?: true

#resolved_atTime?

The timestamp when the linked support ticket was marked as resolved. Null if unresolved or not a support chat.

Returns:

  • (Time, nil)


45
# File 'lib/whop_sdk/models/support_channel.rb', line 45

required :resolved_at, Time, nil?: true