Class: WhopSDK::Models::SupportChannelListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SupportChannelListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/support_channel_list_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#company_id ⇒ String?
The unique identifier of the company to list support channels for.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#open_ ⇒ Boolean?
Whether to filter by open or resolved support channels.
-
#order ⇒ Symbol, ...
Sort options for message channels.
-
#view ⇒ Symbol, ...
The perspective to filter support channels by.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(after: nil, before: nil, company_id: nil, direction: nil, first: nil, last: nil, open_: nil, order: nil, view: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SupportChannelListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, company_id: nil, direction: nil, first: nil, last: nil, open_: nil, order: nil, view: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::SupportChannelListParams for more details.
|
|
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 67
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
14 |
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 14 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
20 |
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 20 optional :before, String, nil?: true |
#company_id ⇒ String?
The unique identifier of the company to list support channels for. Includes channels of child companies. When omitted, returns support channels across all companies the user has access to.
28 |
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 28 optional :company_id, String, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
34 |
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 34 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
40 |
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 40 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
46 |
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 46 optional :last, Integer, nil?: true |
#open_ ⇒ Boolean?
Whether to filter by open or resolved support channels. Set to true to only return channels awaiting a response, or false for resolved channels.
53 |
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 53 optional :open_, WhopSDK::Internal::Type::Boolean, nil?: true |
#order ⇒ Symbol, ...
Sort options for message channels
59 |
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 59 optional :order, enum: -> { WhopSDK::SupportChannelListParams::Order }, nil?: true |
#view ⇒ Symbol, ...
The perspective to filter support channels by.
65 |
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 65 optional :view, enum: -> { WhopSDK::SupportChannelListParams::View }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/support_channel_list_params.rb', line 98
|