Class: WhopSDK::Models::SupportChannelListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SupportChannelListResponse
- Defined in:
- lib/whop_sdk/models/support_channel_list_response.rb
Overview
Defined Under Namespace
Classes: CustomerUser
Instance Attribute Summary collapse
-
#company_id ⇒ String?
The bot ID if this is a support chat.
-
#custom_name ⇒ String?
The custom name of the DM channel, if any.
-
#customer_user ⇒ WhopSDK::Models::SupportChannelListResponse::CustomerUser?
The customer user if this is a support chat.
-
#id ⇒ String
The unique identifier for the entity.
-
#last_message_at ⇒ Time?
When the last message was sent.
-
#resolved_at ⇒ Time?
When the support ticket was resolved (null if unresolved).
Instance Method Summary collapse
-
#initialize(id: , company_id: , custom_name: , customer_user: , last_message_at: , resolved_at: ) ⇒ Object
constructor
Represents a DM channel.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , company_id: , custom_name: , customer_user: , last_message_at: , resolved_at: ) ⇒ Object
Represents a DM channel
|
|
# File 'lib/whop_sdk/models/support_channel_list_response.rb', line 43
|
Instance Attribute Details
#company_id ⇒ String?
The bot ID if this is a support chat
17 |
# File 'lib/whop_sdk/models/support_channel_list_response.rb', line 17 required :company_id, String, nil?: true |
#custom_name ⇒ String?
The custom name of the DM channel, if any
23 |
# File 'lib/whop_sdk/models/support_channel_list_response.rb', line 23 required :custom_name, String, nil?: true |
#customer_user ⇒ WhopSDK::Models::SupportChannelListResponse::CustomerUser?
The customer user if this is a support chat
29 |
# File 'lib/whop_sdk/models/support_channel_list_response.rb', line 29 required :customer_user, -> { WhopSDK::Models::SupportChannelListResponse::CustomerUser }, nil?: true |
#id ⇒ String
The unique identifier for the entity
11 |
# File 'lib/whop_sdk/models/support_channel_list_response.rb', line 11 required :id, String |
#last_message_at ⇒ Time?
When the last message was sent
35 |
# File 'lib/whop_sdk/models/support_channel_list_response.rb', line 35 required :last_message_at, Time, nil?: true |
#resolved_at ⇒ Time?
When the support ticket was resolved (null if unresolved)
41 |
# File 'lib/whop_sdk/models/support_channel_list_response.rb', line 41 required :resolved_at, Time, nil?: true |