Class: WhopSDK::Models::SwapCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/swap_create_params.rb,
sig/whop_sdk/models/swap_create_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Swaps#create

Defined Under Namespace

Modules: FromChain, ToChain

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, amount:, from_token:, to_token:, from_chain: nil, slippage_bps: nil, to_chain: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::SwapCreateParams for more details.

Parameters:

  • account_id (String)

    Business or user account ID (biz* / user*).

  • amount (String)

    Source token amount.

  • from_token (String)

    Source token contract address or ticker symbol, such as "USDT".

  • to_token (String)

    Destination token contract address or ticker symbol, such as "XAUT".

  • from_chain (String, Integer, nil) (defaults to: nil)

    Source chain name or chain ID. Defaults to the source token's chain when omitted

  • slippage_bps (Integer, nil) (defaults to: nil)

    Maximum slippage tolerance in basis points.

  • to_chain (String, Integer, nil) (defaults to: nil)

    Destination chain name or chain ID. Defaults to the destination token's chain wh

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/swap_create_params.rb', line 54

Instance Attribute Details

#account_idString

Business or user account ID (biz* / user*).

Parameters:

  • value (String)

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/swap_create_params.rb', line 14

required :account_id, String

#amountString

Source token amount.

Parameters:

  • value (String)

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/swap_create_params.rb', line 20

required :amount, String

#from_chainString, ...

Source chain name or chain ID. Defaults to the source token's chain when omitted.

Parameters:

  • value (WhopSDK::Models::SwapCreateParams::from_chain, nil)

Returns:

  • (String, Integer, nil)


39
# File 'lib/whop_sdk/models/swap_create_params.rb', line 39

optional :from_chain, union: -> { WhopSDK::SwapCreateParams::FromChain }, nil?: true

#from_tokenString

Source token contract address or ticker symbol, such as "USDT".

Parameters:

  • value (String)

Returns:

  • (String)


26
# File 'lib/whop_sdk/models/swap_create_params.rb', line 26

required :from_token, String

#slippage_bpsInteger?

Maximum slippage tolerance in basis points.

Parameters:

  • value (Integer, nil)

Returns:

  • (Integer, nil)


45
# File 'lib/whop_sdk/models/swap_create_params.rb', line 45

optional :slippage_bps, Integer, nil?: true

#to_chainString, ...

Destination chain name or chain ID. Defaults to the destination token's chain when omitted.

Parameters:

  • value (WhopSDK::Models::SwapCreateParams::to_chain, nil)

Returns:

  • (String, Integer, nil)


52
# File 'lib/whop_sdk/models/swap_create_params.rb', line 52

optional :to_chain, union: -> { WhopSDK::SwapCreateParams::ToChain }, nil?: true

#to_tokenString

Destination token contract address or ticker symbol, such as "XAUT".

Parameters:

  • value (String)

Returns:

  • (String)


32
# File 'lib/whop_sdk/models/swap_create_params.rb', line 32

required :to_token, String

Class Method Details

.variantsArray(String, Integer)

Returns:

  • (Array(String, Integer))


# File 'lib/whop_sdk/models/swap_create_params.rb', line 83

Instance Method Details

#to_hash{

Returns:

  • ({)


44
# File 'sig/whop_sdk/models/swap_create_params.rbs', line 44

def to_hash: -> {