Class: WhopSDK::Models::TopupCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/topup_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, company_id:, currency:, payment_method_id:, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::TopupCreateParams for more details.

Parameters:

  • amount (Float)

    The amount to add to the balance in the specified currency. For example, 50.00 f

  • company_id (String)

    The unique identifier of the company to add funds to, starting with ‘biz_’.

  • currency (Symbol, WhopSDK::Models::Currency)

    The currency for the top-up amount, such as ‘usd’.

  • payment_method_id (String)

    The unique identifier of the stored payment method to charge for the top-up.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/topup_create_params.rb', line 35

Instance Attribute Details

#amountFloat

The amount to add to the balance in the specified currency. For example, 50.00 for $50.00 USD.

Returns:

  • (Float)


15
# File 'lib/whop_sdk/models/topup_create_params.rb', line 15

required :amount, Float

#company_idString

The unique identifier of the company to add funds to, starting with ‘biz_’.

Returns:

  • (String)


21
# File 'lib/whop_sdk/models/topup_create_params.rb', line 21

required :company_id, String

#currencySymbol, WhopSDK::Models::Currency

The currency for the top-up amount, such as ‘usd’.

Returns:



27
# File 'lib/whop_sdk/models/topup_create_params.rb', line 27

required :currency, enum: -> { WhopSDK::Currency }

#payment_method_idString

The unique identifier of the stored payment method to charge for the top-up.

Returns:

  • (String)


33
# File 'lib/whop_sdk/models/topup_create_params.rb', line 33

required :payment_method_id, String