Class: WhopSDK::Models::Transfer::Destination::User
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Transfer::Destination::User
- Defined in:
- lib/whop_sdk/models/transfer.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The internal ID of the user.
-
#name ⇒ String?
The name of the user from their Whop account.
-
#typename ⇒ Symbol, :User
The typename of this object.
-
#username ⇒ String
The username of the user from their Whop account.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#id ⇒ String
The internal ID of the user.
116 |
# File 'lib/whop_sdk/models/transfer.rb', line 116 required :id, String |
#name ⇒ String?
The name of the user from their Whop account.
122 |
# File 'lib/whop_sdk/models/transfer.rb', line 122 required :name, String, nil?: true |
#typename ⇒ Symbol, :User
The typename of this object
128 |
# File 'lib/whop_sdk/models/transfer.rb', line 128 required :typename, const: :User |
#username ⇒ String
The username of the user from their Whop account.
134 |
# File 'lib/whop_sdk/models/transfer.rb', line 134 required :username, String |