Module: WhopSDK::Models::Transfer::Origin

Extended by:
Internal::Type::Union
Defined in:
lib/whop_sdk/models/transfer.rb

Overview

The sender of the credit transaction transfer

See Also:

Defined Under Namespace

Classes: Company, User

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::Union

==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Class Method Details

Instance Method Details

#initialize(id: , name: , username: , typename: :User) ⇒ Object

An object representing a (sanitized) user of the site.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the user.

  • name (String, nil) (defaults to: )

    The name of the user from their Whop account.

  • username (String) (defaults to: )

    The username of the user from their Whop account.

  • typename (Symbol, :User) (defaults to: :User)

    The typename of this object



# File 'lib/whop_sdk/models/transfer.rb', line 220