Class: WhopSDK::Models::TransferListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/transfer_list_params.rb,
sig/whop_sdk/models/transfer_list_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Transfers#list

Defined Under Namespace

Modules: Direction, Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, created_after: nil, created_before: nil, destination_id: nil, direction: nil, first: nil, last: nil, order: nil, origin_id: nil, request_options: {}) ⇒ Object

Parameters:

  • after (String) (defaults to: nil)

    Cursor to fetch the page after (from page_info.end_cursor).

  • before (String) (defaults to: nil)

    Cursor to fetch the page before (from page_info.start_cursor).

  • created_after (String) (defaults to: nil)

    Only transfers created strictly after this ISO 8601 timestamp.

  • created_before (String) (defaults to: nil)

    Only transfers created strictly before this ISO 8601 timestamp.

  • destination_id (String) (defaults to: nil)

    Filter to transfers received by this account.

  • direction (Symbol, WhopSDK::Models::TransferListParams::Direction) (defaults to: nil)

    Sort direction. Defaults to desc.

  • first (Integer) (defaults to: nil)

    Number of transfers to return from the start of the window.

  • last (Integer) (defaults to: nil)

    Number of transfers to return from the end of the window.

  • order (Symbol, WhopSDK::Models::TransferListParams::Order) (defaults to: nil)

    Sort column. Defaults to created_at.

  • origin_id (String) (defaults to: nil)

    Filter to transfers sent from this account.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/transfer_list_params.rb', line 70

Instance Attribute Details

#afterString?

Cursor to fetch the page after (from page_info.end_cursor).

Parameters:

  • (String)

Returns:

  • (String, nil)


14
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 14

optional :after, String

#beforeString?

Cursor to fetch the page before (from page_info.start_cursor).

Parameters:

  • (String)

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 20

optional :before, String

#created_afterString?

Only transfers created strictly after this ISO 8601 timestamp.

Parameters:

  • (String)

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 26

optional :created_after, String

#created_beforeString?

Only transfers created strictly before this ISO 8601 timestamp.

Parameters:

  • (String)

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 32

optional :created_before, String

#destination_idString?

Filter to transfers received by this account.

Parameters:

  • (String)

Returns:

  • (String, nil)


38
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 38

optional :destination_id, String

#directionSymbol, ...

Sort direction. Defaults to desc.



44
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 44

optional :direction, enum: -> { WhopSDK::TransferListParams::Direction }

#firstInteger?

Number of transfers to return from the start of the window.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


50
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 50

optional :first, Integer

#lastInteger?

Number of transfers to return from the end of the window.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


56
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 56

optional :last, Integer

#orderSymbol, ...

Sort column. Defaults to created_at.



62
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 62

optional :order, enum: -> { WhopSDK::TransferListParams::Order }

#origin_idString?

Filter to transfers sent from this account.

Parameters:

  • (String)

Returns:

  • (String, nil)


68
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 68

optional :origin_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/transfer_list_params.rb', line 100

Instance Method Details

#to_hash{

Returns:

  • ({)


80
# File 'sig/whop_sdk/models/transfer_list_params.rbs', line 80

def to_hash: -> {