Class: WhopSDK::Models::TransferListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/transfer_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, currency:, destination_ledger_account_id:, fee_amount:, metadata:, notes:, origin_ledger_account_id:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::TransferListResponse for more details.

A transfer of credit between two ledger accounts.

Parameters:

  • id (String)

    The unique identifier for the credit transaction transfer.

  • amount (Float)

    The transfer amount in the currency specified by the currency field. For example

  • created_at (Time)

    The datetime the credit transaction transfer was created.

  • currency (Symbol, WhopSDK::Models::Currency)

    The currency in which this transfer amount is denominated.

  • destination_ledger_account_id (String)

    The unique identifier of the ledger account receiving the funds.

  • fee_amount (Float, nil)

    The flat fee amount deducted from this transfer, in the transfer’s currency. Nul

  • metadata (Hash{Symbol=>Object}, nil)

    Custom key-value pairs attached to this transfer. Maximum 50 keys, 500 character

  • notes (String, nil)

    A free-text note attached to this transfer by the sender. Null if no note was pr

  • origin_ledger_account_id (String)

    The unique identifier of the ledger account that sent the funds.



# File 'lib/whop_sdk/models/transfer_list_response.rb', line 65

Instance Attribute Details

#amountFloat

The transfer amount in the currency specified by the currency field. For example, 10.43 represents $10.43 USD.

Returns:

  • (Float)


18
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 18

required :amount, Float

#created_atTime

The datetime the credit transaction transfer was created.

Returns:

  • (Time)


24
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 24

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The currency in which this transfer amount is denominated.

Returns:



30
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 30

required :currency, enum: -> { WhopSDK::Currency }

#destination_ledger_account_idString

The unique identifier of the ledger account receiving the funds.

Returns:

  • (String)


36
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 36

required :destination_ledger_account_id, String

#fee_amountFloat?

The flat fee amount deducted from this transfer, in the transfer’s currency. Null if no flat fee was applied.

Returns:

  • (Float, nil)


43
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 43

required :fee_amount, Float, nil?: true

#idString

The unique identifier for the credit transaction transfer.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 11

required :id, String

#metadataHash{Symbol=>Object}?

Custom key-value pairs attached to this transfer. Maximum 50 keys, 500 characters per key, 5000 characters per value.

Returns:

  • (Hash{Symbol=>Object}, nil)


50
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 50

required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#notesString?

A free-text note attached to this transfer by the sender. Null if no note was provided.

Returns:

  • (String, nil)


57
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 57

required :notes, String, nil?: true

#origin_ledger_account_idString

The unique identifier of the ledger account that sent the funds.

Returns:

  • (String)


63
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 63

required :origin_ledger_account_id, String