Class: WhopSDK::Models::User::EarningsUsd

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/user.rb,
sig/whop_sdk/models/user.rbs

Overview

See Also:

  • WhopSDK::Models::User#earnings_usd

Defined Under Namespace

Classes: OwnedAccounts, Personal, Total

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(last_24_hours:, last_30_days:, last_7_days:, lifetime:) ⇒ Object

Gross income from the user's personal wallet.

Parameters:

  • last_24_hours (String)

    Gross income in USD over the last 24 hours.

  • last_30_days (String)

    Gross income in USD over the last 30 days.

  • last_7_days (String)

    Gross income in USD over the last 7 days.

  • lifetime (String)

    All-time gross income in USD.



# File 'lib/whop_sdk/models/user.rb', line 196

Instance Attribute Details

#first_earned_atString?

The first time the user earned gross income, as an ISO 8601 timestamp.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


175
# File 'lib/whop_sdk/models/user.rb', line 175

required :first_earned_at, String, nil?: true

#owned_accountsWhopSDK::Models::User::EarningsUsd::OwnedAccounts

Gross income from accounts the user owns or is owner-authorized on.

Parameters:

  • value (WhopSDK::User::EarningsUsd::OwnedAccounts)

Returns:



181
# File 'lib/whop_sdk/models/user.rb', line 181

required :owned_accounts, -> { WhopSDK::User::EarningsUsd::OwnedAccounts }

#personalWhopSDK::Models::User::EarningsUsd::Personal

Gross income from the user's personal wallet.

Parameters:

  • value (WhopSDK::User::EarningsUsd::Personal)

Returns:



187
# File 'lib/whop_sdk/models/user.rb', line 187

required :personal, -> { WhopSDK::User::EarningsUsd::Personal }

#totalWhopSDK::Models::User::EarningsUsd::Total

Gross income from the user's personal wallet plus accounts they own or are owner-authorized on.

Parameters:

  • value (WhopSDK::User::EarningsUsd::Total)

Returns:



194
# File 'lib/whop_sdk/models/user.rb', line 194

required :total, -> { WhopSDK::User::EarningsUsd::Total }

Instance Method Details

#to_hash{

Returns:

  • ({)


137
# File 'sig/whop_sdk/models/user.rbs', line 137

def to_hash: -> {