Class: WhopSDK::Models::User::EarningsUsd::Total
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::User::EarningsUsd::Total
- Defined in:
- lib/whop_sdk/models/user.rb,
sig/whop_sdk/models/user.rbs
Overview
Instance Attribute Summary collapse
-
#last_24_hours ⇒ String
Gross income in USD over the last 24 hours.
-
#last_30_days ⇒ String
Gross income in USD over the last 30 days.
-
#last_7_days ⇒ String
Gross income in USD over the last 7 days.
-
#lifetime ⇒ String
All-time gross income in USD.
Instance Method Summary collapse
-
#initialize(last_24_hours:, last_30_days:, last_7_days:, lifetime:) ⇒ Object
constructor
Gross income from the user's personal wallet plus accounts they own or are owner-authorized on.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(last_24_hours:, last_30_days:, last_7_days:, lifetime:) ⇒ Object
Gross income from the user's personal wallet plus accounts they own or are owner-authorized on.
|
|
# File 'lib/whop_sdk/models/user.rb', line 313
|
Instance Attribute Details
#last_24_hours ⇒ String
Gross income in USD over the last 24 hours.
293 |
# File 'lib/whop_sdk/models/user.rb', line 293 required :last_24_hours, String |
#last_30_days ⇒ String
Gross income in USD over the last 30 days.
299 |
# File 'lib/whop_sdk/models/user.rb', line 299 required :last_30_days, String |
#last_7_days ⇒ String
Gross income in USD over the last 7 days.
305 |
# File 'lib/whop_sdk/models/user.rb', line 305 required :last_7_days, String |
#lifetime ⇒ String
All-time gross income in USD.
311 |
# File 'lib/whop_sdk/models/user.rb', line 311 required :lifetime, String |
Instance Method Details
#to_hash ⇒ {
232 |
# File 'sig/whop_sdk/models/user.rbs', line 232
def to_hash: -> {
|