Class: WhopSDK::Models::UserCheckAccessResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::UserCheckAccessResponse
- Defined in:
- lib/whop_sdk/models/user_check_access_response.rb
Overview
Instance Attribute Summary collapse
-
#access_level ⇒ Symbol, WhopSDK::Models::AccessLevel
The permission level of the user.
-
#has_access ⇒ Boolean
Whether the user has access to the resource.
Instance Method Summary collapse
-
#initialize(access_level: , has_access: ) ⇒ Object
constructor
The result of a has access check for the developer API.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access_level: , has_access: ) ⇒ Object
The result of a has access check for the developer API
|
|
# File 'lib/whop_sdk/models/user_check_access_response.rb', line 19
|
Instance Attribute Details
#access_level ⇒ Symbol, WhopSDK::Models::AccessLevel
The permission level of the user
11 |
# File 'lib/whop_sdk/models/user_check_access_response.rb', line 11 required :access_level, enum: -> { WhopSDK::AccessLevel } |