Class: WhopSDK::Models::UserListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/user_list_response.rb

Overview

Defined Under Namespace

Classes: ProfilePicture

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, bio:, created_at:, name:, profile_picture:, username:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::UserListResponse for more details.

A user account on Whop. Contains profile information, identity details, and social connections.

Parameters:

  • id (String)

    The unique identifier for the user.

  • bio (String, nil)

    A short biography written by the user, displayed on their public profile.

  • created_at (Time)

    The datetime the user was created.

  • name (String, nil)

    The user’s display name shown on their public profile.

  • profile_picture (WhopSDK::Models::UserListResponse::ProfilePicture, nil)

    The user’s profile picture attachment with URL, content type, and file metadata.

  • username (String)

    The user’s unique username shown on their public profile.



# File 'lib/whop_sdk/models/user_list_response.rb', line 44

Instance Attribute Details

#bioString?

A short biography written by the user, displayed on their public profile.

Returns:

  • (String, nil)


17
# File 'lib/whop_sdk/models/user_list_response.rb', line 17

required :bio, String, nil?: true

#created_atTime

The datetime the user was created.

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/user_list_response.rb', line 23

required :created_at, Time

#idString

The unique identifier for the user.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/user_list_response.rb', line 11

required :id, String

#nameString?

The user’s display name shown on their public profile.

Returns:

  • (String, nil)


29
# File 'lib/whop_sdk/models/user_list_response.rb', line 29

required :name, String, nil?: true

#profile_pictureWhopSDK::Models::UserListResponse::ProfilePicture?

The user’s profile picture attachment with URL, content type, and file metadata. Null if using a legacy profile picture.



36
# File 'lib/whop_sdk/models/user_list_response.rb', line 36

required :profile_picture, -> { WhopSDK::Models::UserListResponse::ProfilePicture }, nil?: true

#usernameString

The user’s unique username shown on their public profile.

Returns:

  • (String)


42
# File 'lib/whop_sdk/models/user_list_response.rb', line 42

required :username, String