Class: WhopSDK::Models::UserRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/user_retrieve_response.rb

Overview

Defined Under Namespace

Classes: ProfilePicture

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , bio: , created_at: , name: , profile_picture: , username: ) ⇒ Object

An object representing a (sanitized) user of the site.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the user.

  • bio (String, nil) (defaults to: )

    The user’s bio

  • created_at (Time) (defaults to: )

    When the user was created.

  • name (String, nil) (defaults to: )

    The name of the user from their Whop account.

  • profile_picture (WhopSDK::Models::UserRetrieveResponse::ProfilePicture, nil) (defaults to: )

    The user’s profile picture

  • username (String) (defaults to: )

    The username of the user from their Whop account.



# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 43

Instance Attribute Details

#bioString?

The user’s bio

Returns:

  • (String, nil)


17
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 17

required :bio, String, nil?: true

#created_atTime

When the user was created.

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 23

required :created_at, Time

#idString

The internal ID of the user.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 11

required :id, String

#nameString?

The name of the user from their Whop account.

Returns:

  • (String, nil)


29
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 29

required :name, String, nil?: true

#profile_pictureWhopSDK::Models::UserRetrieveResponse::ProfilePicture?

The user’s profile picture



35
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 35

required :profile_picture, -> { WhopSDK::Models::UserRetrieveResponse::ProfilePicture }, nil?: true

#usernameString

The username of the user from their Whop account.

Returns:

  • (String)


41
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 41

required :username, String