Class: WhopSDK::Models::VerificationCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/verification_create_params.rb,
sig/whop_sdk/models/verification_create_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Verifications#create

Defined Under Namespace

Modules: Body

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, body:, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::VerificationCreateParams for more details.

Parameters:



# File 'lib/whop_sdk/models/verification_create_params.rb', line 30

Instance Attribute Details

#account_idString

Account or user ID whose identity you want to verify. Use a biz_ account ID for account verifications, or the caller's user_ ID for personal verification.

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/whop_sdk/models/verification_create_params.rb', line 15

required :account_id, String

#bodyWhopSDK::Models::VerificationCreateParams::Body::Individual, WhopSDK::Models::VerificationCreateParams::Body::Business

Request body for an individual (KYC) verification. Omit kind or set it to individual. KYC is required to pay out funds and is a prerequisite for Whop Card access. Accepting payments does not require verification until a business reaches $5000 in payments.

Add business_name, business_structure, and country of incorporation if the individual operates under a business entity. This enables payouts to be received by a business bank account.

Parameters:

  • value (WhopSDK::Models::VerificationCreateParams::body)

Returns:



28
# File 'lib/whop_sdk/models/verification_create_params.rb', line 28

required :body, union: -> { WhopSDK::VerificationCreateParams::Body }

Instance Method Details

#to_hash{

Returns:

  • ({)


24
# File 'sig/whop_sdk/models/verification_create_params.rbs', line 24

def to_hash: -> {