Module: WhopSDK::Models::VerificationCreateParams::Body
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/whop_sdk/models/verification_create_params.rb,
sig/whop_sdk/models/verification_create_params.rbs
Overview
Request body for an individual (KYC) verification. Omit kind or set it to
individual. KYC is required to pay out funds and is a prerequisite for Whop
Card access. Accepting payments does not require verification until a business
reaches $5000 in payments.
Add business_name, business_structure, and country of incorporation if the
individual operates under a business entity. This enables payouts to be received
by a business bank account.
Defined Under Namespace
Classes: Business, Individual
Class Method Summary collapse
- .values ⇒ Array<Symbol>
- .variants ⇒ Array(WhopSDK::Models::VerificationCreateParams::Body::Individual, WhopSDK::Models::VerificationCreateParams::Body::Business)
Instance Method Summary collapse
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/verification_create_params.rb', line 266
|
.variants ⇒ Array(WhopSDK::Models::VerificationCreateParams::Body::Individual, WhopSDK::Models::VerificationCreateParams::Body::Business)
|
|
# File 'lib/whop_sdk/models/verification_create_params.rb', line 409
|
Instance Method Details
#self?.variants ⇒ ::Array[WhopSDK::Models::VerificationCreateParams::body]
360 |
# File 'sig/whop_sdk/models/verification_create_params.rbs', line 360
def self?.variants: -> ::Array[WhopSDK::Models::VerificationCreateParams::body]
|