Class: WhopSDK::Models::VerificationListResponse::Data::RequestedInformation::RequestedFile
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::VerificationListResponse::Data::RequestedInformation::RequestedFile
- Defined in:
- lib/whop_sdk/models/verification_list_response.rb,
sig/whop_sdk/models/verification_list_response.rbs
Instance Attribute Summary collapse
-
#category ⇒ String?
File category to include with the uploaded file so Whop can route the document correctly.
-
#is_optional ⇒ Boolean?
Whether this slot can be left empty.
-
#kind ⇒ String?
Specific document type requested, such as
Bank Statement. -
#label ⇒ String?
Label for this upload slot, such as
Front of ID Document. -
#multiple ⇒ Boolean?
Whether this slot accepts more than one file.
Instance Method Summary collapse
-
#initialize(id: nil, description: nil, error_message: nil, field: nil, label: nil, options: nil, requested_files: nil, type: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhopSDK::Models::VerificationListResponse::Data::RequestedInformation for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, description: nil, error_message: nil, field: nil, label: nil, options: nil, requested_files: nil, type: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::VerificationListResponse::Data::RequestedInformation for more details.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/whop_sdk/models/verification_list_response.rb', line 291 class RequestedFile < WhopSDK::Internal::Type::BaseModel # @!attribute category # File category to include with the uploaded file so Whop can route the document # correctly. `null` for a generic upload. # # @return [String, nil] optional :category, String, nil?: true # @!attribute is_optional # Whether this slot can be left empty. # # @return [Boolean, nil] optional :is_optional, WhopSDK::Internal::Type::Boolean # @!attribute kind # Specific document type requested, such as `Bank Statement`. `null` for standard # identity and business document uploads. # # @return [String, nil] optional :kind, String, nil?: true # @!attribute label # Label for this upload slot, such as `Front of ID Document`. # # @return [String, nil] optional :label, String # @!attribute multiple # Whether this slot accepts more than one file. # # @return [Boolean, nil] optional :multiple, WhopSDK::Internal::Type::Boolean # @!method initialize(category: nil, is_optional: nil, kind: nil, label: nil, multiple: nil) # Some parameter documentations has been truncated, see # {WhopSDK::Models::VerificationListResponse::Data::RequestedInformation::RequestedFile} # for more details. # # @param category [String, nil] File category to include with the uploaded file so Whop can route the document c # # @param is_optional [Boolean] Whether this slot can be left empty. # # @param kind [String, nil] Specific document type requested, such as `Bank Statement`. `null` for standard # # @param label [String] Label for this upload slot, such as `Front of ID Document`. # # @param multiple [Boolean] Whether this slot accepts more than one file. end |
Instance Attribute Details
#category ⇒ String?
File category to include with the uploaded file so Whop can route the document
correctly. null for a generic upload.
297 |
# File 'lib/whop_sdk/models/verification_list_response.rb', line 297 optional :category, String, nil?: true |
#is_optional ⇒ Boolean?
Whether this slot can be left empty.
303 |
# File 'lib/whop_sdk/models/verification_list_response.rb', line 303 optional :is_optional, WhopSDK::Internal::Type::Boolean |
#kind ⇒ String?
Specific document type requested, such as Bank Statement. null for standard
identity and business document uploads.
310 |
# File 'lib/whop_sdk/models/verification_list_response.rb', line 310 optional :kind, String, nil?: true |
#label ⇒ String?
Label for this upload slot, such as Front of ID Document.
316 |
# File 'lib/whop_sdk/models/verification_list_response.rb', line 316 optional :label, String |
#multiple ⇒ Boolean?
Whether this slot accepts more than one file.
322 |
# File 'lib/whop_sdk/models/verification_list_response.rb', line 322 optional :multiple, WhopSDK::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ {
281 |
# File 'sig/whop_sdk/models/verification_list_response.rbs', line 281
def to_hash: -> {
|