Class: WhopSDK::Models::VerificationRetrieveResponse::RequiredDocument

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/verification_retrieve_response.rb,
sig/whop_sdk/models/verification_retrieve_response.rbs

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(document: nil, rejection_reason: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::VerificationRetrieveResponse::RequiredDocument for more details.

Parameters:

  • document (String) (defaults to: nil)

    Document slot key, such as id_card_front, id_card_back, or selfie.

  • rejection_reason (String, nil) (defaults to: nil)

    Why the previous submission was rejected, when the provider requested new docume

  • status (Symbol, WhopSDK::Models::VerificationRetrieveResponse::RequiredDocument::Status) (defaults to: nil)

    pending_upload until the document has been relayed for review; submitted aft



# File 'lib/whop_sdk/models/verification_retrieve_response.rb', line 353

Instance Attribute Details

#documentString?

Document slot key, such as id_card_front, id_card_back, or selfie.

Parameters:

  • (String)

Returns:

  • (String, nil)


337
# File 'lib/whop_sdk/models/verification_retrieve_response.rb', line 337

optional :document, String

#rejection_reasonString?

Why the previous submission was rejected, when the provider requested new documents or declined the verification.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


344
# File 'lib/whop_sdk/models/verification_retrieve_response.rb', line 344

optional :rejection_reason, String, nil?: true

#statusSymbol, ...

pending_upload until the document has been relayed for review; submitted afterwards.



351
# File 'lib/whop_sdk/models/verification_retrieve_response.rb', line 351

optional :status, enum: -> { WhopSDK::Models::VerificationRetrieveResponse::RequiredDocument::Status }

Instance Method Details

#to_hash{

Returns:

  • ({)


299
# File 'sig/whop_sdk/models/verification_retrieve_response.rbs', line 299

def to_hash: -> {