Class: WhopSDK::Models::VerificationSucceededWebhookEvent::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::VerificationSucceededWebhookEvent::Data
- Defined in:
- lib/whop_sdk/models/verification_succeeded_webhook_event.rb
Overview
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the verification.
-
#last_error_code ⇒ Symbol, ...
An error code for a verification attempt.
-
#last_error_reason ⇒ String?
A human-readable explanation of the most recent verification error.
-
#status ⇒ Symbol, WhopSDK::Models::VerificationStatus
The current status of this verification session.
Instance Method Summary collapse
-
#initialize(id:, last_error_code:, last_error_reason:, status:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, last_error_code:, last_error_reason:, status:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::VerificationSucceededWebhookEvent::Data for more details.
An identity verification session used to confirm a person or entity’s identity for payout account eligibility.
|
|
# File 'lib/whop_sdk/models/verification_succeeded_webhook_event.rb', line 86
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the verification.
65 |
# File 'lib/whop_sdk/models/verification_succeeded_webhook_event.rb', line 65 required :id, String |
#last_error_code ⇒ Symbol, ...
An error code for a verification attempt.
71 |
# File 'lib/whop_sdk/models/verification_succeeded_webhook_event.rb', line 71 required :last_error_code, enum: -> { WhopSDK::VerificationErrorCode }, nil?: true |
#last_error_reason ⇒ String?
A human-readable explanation of the most recent verification error. Null if no error has occurred.
78 |
# File 'lib/whop_sdk/models/verification_succeeded_webhook_event.rb', line 78 required :last_error_reason, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::VerificationStatus
The current status of this verification session.
84 |
# File 'lib/whop_sdk/models/verification_succeeded_webhook_event.rb', line 84 required :status, enum: -> { WhopSDK::VerificationStatus } |