Class: WhopSDK::Models::VerificationUpdateParams::Body::UpdateBusinessVerification::RequestedInformation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::VerificationUpdateParams::Body::UpdateBusinessVerification::RequestedInformation
- Defined in:
- lib/whop_sdk/models/verification_update_params.rb,
sig/whop_sdk/models/verification_update_params.rbs
Defined Under Namespace
Modules: ValueType Classes: Address, File
Instance Attribute Summary collapse
-
#address ⇒ WhopSDK::Models::VerificationUpdateParams::Body::UpdateBusinessVerification::RequestedInformation::Address?
Address payload for
addressitems. -
#files ⇒ Array<WhopSDK::Models::VerificationUpdateParams::Body::UpdateBusinessVerification::RequestedInformation::File>?
Uploaded file payloads for
filesitems. -
#id ⇒ String
Requested information item ID, prefixed
inrqi_. -
#value ⇒ String?
Answer value for
text,date, orphoneitems. -
#value_type ⇒ Symbol, ...
Whether
valueis raw input or a vault token.
Instance Method Summary collapse
- #initialize(attachment_id: nil, category: nil, direct_upload_id: nil, kind: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(attachment_id: nil, category: nil, direct_upload_id: nil, kind: nil) ⇒ Object
|
|
# File 'lib/whop_sdk/models/verification_update_params.rb', line 455
|
Instance Attribute Details
#address ⇒ WhopSDK::Models::VerificationUpdateParams::Body::UpdateBusinessVerification::RequestedInformation::Address?
Address payload for address items.
430 431 |
# File 'lib/whop_sdk/models/verification_update_params.rb', line 430 optional :address, -> { WhopSDK::VerificationUpdateParams::Body::UpdateBusinessVerification::RequestedInformation::Address } |
#files ⇒ Array<WhopSDK::Models::VerificationUpdateParams::Body::UpdateBusinessVerification::RequestedInformation::File>?
Uploaded file payloads for files items. Each file should include a
direct_upload_id from the upload flow, plus the requested file category and
kind when provided.
439 440 |
# File 'lib/whop_sdk/models/verification_update_params.rb', line 439 optional :files, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::VerificationUpdateParams::Body::UpdateBusinessVerification::RequestedInformation::File] } |
#id ⇒ String
Requested information item ID, prefixed inrqi_.
424 |
# File 'lib/whop_sdk/models/verification_update_params.rb', line 424 required :id, String |
#value ⇒ String?
Answer value for text, date, or phone items.
446 |
# File 'lib/whop_sdk/models/verification_update_params.rb', line 446 optional :value, String |
#value_type ⇒ Symbol, ...
Whether value is raw input or a vault token.
452 453 |
# File 'lib/whop_sdk/models/verification_update_params.rb', line 452 optional :value_type, enum: -> { WhopSDK::VerificationUpdateParams::Body::UpdateBusinessVerification::RequestedInformation::ValueType } |
Instance Method Details
#to_hash ⇒ {
451 |
# File 'sig/whop_sdk/models/verification_update_params.rbs', line 451
def to_hash: -> {
|