Class: WhopSDK::Models::VerificationUpdateResponse::RequestedInformation::RequestedFile

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/verification_update_response.rb,
sig/whop_sdk/models/verification_update_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, description: nil, error_message: nil, field: nil, label: nil, options: nil, requested_files: nil, type: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::VerificationUpdateResponse::RequestedInformation for more details.

Parameters:

  • id (String) (defaults to: nil)

    Requested information item ID, prefixed inrqi_. Include this ID when submittin

  • description (String, nil) (defaults to: nil)

    Additional instructions for this requested item, or null.

  • error_message (String, nil) (defaults to: nil)

    Reason a previously submitted value was rejected. null if no submitted value h

  • field (String) (defaults to: nil)

    Stable field key, such as ssn or business_description.

  • label (String) (defaults to: nil)

    Human-readable label for the field, such as Social Security Number.

  • options (Array<String>) (defaults to: nil)

    Allowed values for a select field (e.g. account_type, business_structure) — th

  • requested_files (Array<WhopSDK::Models::VerificationUpdateResponse::RequestedInformation::RequestedFile>) (defaults to: nil)

    Document upload slots for this item. Present when type is files; upload one

  • type (String, nil) (defaults to: nil)

    Input type expected for this item: text, date, phone, address, files,



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/whop_sdk/models/verification_update_response.rb', line 282

class RequestedFile < WhopSDK::Internal::Type::BaseModel
  # @!attribute category
  #   File category to include with the uploaded file so Whop can route the document
  #   correctly. `null` for a generic upload.
  #
  #   @return [String, nil]
  optional :category, String, nil?: true

  # @!attribute is_optional
  #   Whether this slot can be left empty.
  #
  #   @return [Boolean, nil]
  optional :is_optional, WhopSDK::Internal::Type::Boolean

  # @!attribute kind
  #   Specific document type requested, such as `Bank Statement`. `null` for standard
  #   identity and business document uploads.
  #
  #   @return [String, nil]
  optional :kind, String, nil?: true

  # @!attribute label
  #   Label for this upload slot, such as `Front of ID Document`.
  #
  #   @return [String, nil]
  optional :label, String

  # @!attribute multiple
  #   Whether this slot accepts more than one file.
  #
  #   @return [Boolean, nil]
  optional :multiple, WhopSDK::Internal::Type::Boolean

  # @!method initialize(category: nil, is_optional: nil, kind: nil, label: nil, multiple: nil)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::VerificationUpdateResponse::RequestedInformation::RequestedFile}
  #   for more details.
  #
  #   @param category [String, nil] File category to include with the uploaded file so Whop can route the document c
  #
  #   @param is_optional [Boolean] Whether this slot can be left empty.
  #
  #   @param kind [String, nil] Specific document type requested, such as `Bank Statement`. `null` for standard
  #
  #   @param label [String] Label for this upload slot, such as `Front of ID Document`.
  #
  #   @param multiple [Boolean] Whether this slot accepts more than one file.
end

Instance Attribute Details

#categoryString?

File category to include with the uploaded file so Whop can route the document correctly. null for a generic upload.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


288
# File 'lib/whop_sdk/models/verification_update_response.rb', line 288

optional :category, String, nil?: true

#is_optionalBoolean?

Whether this slot can be left empty.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


294
# File 'lib/whop_sdk/models/verification_update_response.rb', line 294

optional :is_optional, WhopSDK::Internal::Type::Boolean

#kindString?

Specific document type requested, such as Bank Statement. null for standard identity and business document uploads.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


301
# File 'lib/whop_sdk/models/verification_update_response.rb', line 301

optional :kind, String, nil?: true

#labelString?

Label for this upload slot, such as Front of ID Document.

Parameters:

  • (String)

Returns:

  • (String, nil)


307
# File 'lib/whop_sdk/models/verification_update_response.rb', line 307

optional :label, String

#multipleBoolean?

Whether this slot accepts more than one file.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


313
# File 'lib/whop_sdk/models/verification_update_response.rb', line 313

optional :multiple, WhopSDK::Internal::Type::Boolean

Instance Method Details

#to_hash{

Returns:

  • ({)


263
# File 'sig/whop_sdk/models/verification_update_response.rbs', line 263

def to_hash: -> {