Class: WhopSDK::Models::VerificationUpdateResponse::RequiredDocument
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::VerificationUpdateResponse::RequiredDocument
- Defined in:
- lib/whop_sdk/models/verification_update_response.rb,
sig/whop_sdk/models/verification_update_response.rbs
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#document ⇒ String?
Document slot key, such as
id_card_front,id_card_back, orselfie. -
#rejection_reason ⇒ String?
Why the previous submission was rejected, when the provider requested new documents or declined the verification.
-
#status ⇒ Symbol, ...
pending_uploaduntil the document has been relayed for review;submittedafterwards.
Instance Method Summary collapse
-
#initialize(document: nil, rejection_reason: nil, status: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see RequiredDocument for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(document: nil, rejection_reason: nil, status: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::VerificationUpdateResponse::RequiredDocument for more details.
|
|
# File 'lib/whop_sdk/models/verification_update_response.rb', line 353
|
Instance Attribute Details
#document ⇒ String?
Document slot key, such as id_card_front, id_card_back, or selfie.
337 |
# File 'lib/whop_sdk/models/verification_update_response.rb', line 337 optional :document, String |
#rejection_reason ⇒ String?
Why the previous submission was rejected, when the provider requested new documents or declined the verification.
344 |
# File 'lib/whop_sdk/models/verification_update_response.rb', line 344 optional :rejection_reason, String, nil?: true |
#status ⇒ Symbol, ...
pending_upload until the document has been relayed for review; submitted
afterwards.
351 |
# File 'lib/whop_sdk/models/verification_update_response.rb', line 351 optional :status, enum: -> { WhopSDK::Models::VerificationUpdateResponse::RequiredDocument::Status } |
Instance Method Details
#to_hash ⇒ {
299 |
# File 'sig/whop_sdk/models/verification_update_response.rbs', line 299
def to_hash: -> {
|