Class: WhopSDK::Models::WebhookListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/webhook_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, api_version:, child_resource_events:, created_at:, enabled:, events:, url:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::WebhookListResponse for more details.

A webhook endpoint that receives event notifications for a company via HTTP POST.

Parameters:

  • id (String)

    The unique identifier for the webhook.

  • api_version (Symbol, WhopSDK::Models::APIVersion)

    The API version used to format payloads sent to this webhook endpoint.

  • child_resource_events (Boolean)

    Whether events are sent for child resources. For example, if the webhook is on a

  • created_at (Time)

    The datetime the webhook was created.

  • enabled (Boolean)

    Whether this webhook endpoint is currently active and receiving events.

  • events (Array<Symbol, WhopSDK::Models::WebhookEvent>)

    The list of event types this webhook is subscribed to.

  • url (String)

    The destination URL where webhook payloads are delivered via HTTP POST.



# File 'lib/whop_sdk/models/webhook_list_response.rb', line 51

Instance Attribute Details

#api_versionSymbol, WhopSDK::Models::APIVersion

The API version used to format payloads sent to this webhook endpoint.

Returns:



17
# File 'lib/whop_sdk/models/webhook_list_response.rb', line 17

required :api_version, enum: -> { WhopSDK::APIVersion }

#child_resource_eventsBoolean

Whether events are sent for child resources. For example, if the webhook is on a company, enabling this sends events only from the company’s sub-merchants (child companies).

Returns:

  • (Boolean)


25
# File 'lib/whop_sdk/models/webhook_list_response.rb', line 25

required :child_resource_events, WhopSDK::Internal::Type::Boolean

#created_atTime

The datetime the webhook was created.

Returns:

  • (Time)


31
# File 'lib/whop_sdk/models/webhook_list_response.rb', line 31

required :created_at, Time

#enabledBoolean

Whether this webhook endpoint is currently active and receiving events.

Returns:

  • (Boolean)


37
# File 'lib/whop_sdk/models/webhook_list_response.rb', line 37

required :enabled, WhopSDK::Internal::Type::Boolean

#eventsArray<Symbol, WhopSDK::Models::WebhookEvent>

The list of event types this webhook is subscribed to.

Returns:



43
# File 'lib/whop_sdk/models/webhook_list_response.rb', line 43

required :events, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::WebhookEvent] }

#idString

The unique identifier for the webhook.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/webhook_list_response.rb', line 11

required :id, String

#urlString

The destination URL where webhook payloads are delivered via HTTP POST.

Returns:

  • (String)


49
# File 'lib/whop_sdk/models/webhook_list_response.rb', line 49

required :url, String