Class: WhopSDK::Models::WebhookUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/webhook_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, api_version: nil, child_resource_events: nil, enabled: nil, events: nil, url: nil, request_options: {}) ⇒ Object

Parameters:

  • id (String)
  • api_version (Symbol, WhopSDK::Models::APIVersion, nil) (defaults to: nil)

    The different API versions

  • child_resource_events (Boolean, nil) (defaults to: nil)

    Whether or not to send events for child resources.

  • enabled (Boolean, nil) (defaults to: nil)

    Whether or not the webhook is enabled.

  • events (Array<Symbol, WhopSDK::Models::WebhookEvent>, nil) (defaults to: nil)

    The events to send the webhook for.

  • url (String, nil) (defaults to: nil)

    The URL to send the webhook to.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/webhook_update_params.rb', line 45

Instance Attribute Details

#api_versionSymbol, ...

The different API versions

Returns:



19
# File 'lib/whop_sdk/models/webhook_update_params.rb', line 19

optional :api_version, enum: -> { WhopSDK::APIVersion }, nil?: true

#child_resource_eventsBoolean?

Whether or not to send events for child resources.

Returns:

  • (Boolean, nil)


25
# File 'lib/whop_sdk/models/webhook_update_params.rb', line 25

optional :child_resource_events, WhopSDK::Internal::Type::Boolean, nil?: true

#enabledBoolean?

Whether or not the webhook is enabled.

Returns:

  • (Boolean, nil)


31
# File 'lib/whop_sdk/models/webhook_update_params.rb', line 31

optional :enabled, WhopSDK::Internal::Type::Boolean, nil?: true

#eventsArray<Symbol, WhopSDK::Models::WebhookEvent>?

The events to send the webhook for.

Returns:



37
# File 'lib/whop_sdk/models/webhook_update_params.rb', line 37

optional :events, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::WebhookEvent] }, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/webhook_update_params.rb', line 13

required :id, String

#urlString?

The URL to send the webhook to.

Returns:

  • (String, nil)


43
# File 'lib/whop_sdk/models/webhook_update_params.rb', line 43

optional :url, String, nil?: true