Class: WhopSDK::Models::Withdrawal::LedgerAccount

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/withdrawal.rb,
sig/whop_sdk/models/withdrawal.rbs

Overview

See Also:

  • WhopSDK::Models::Withdrawal#ledger_account

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeLedgerAccount

Returns a new instance of LedgerAccount.

Parameters:

  • id: (String)
  • company_id: (String, nil)


201
# File 'sig/whop_sdk/models/withdrawal.rbs', line 201

def initialize: (id: String, company_id: String?) -> void

Instance Attribute Details

#company_idString?

Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as "VXNlci0xMA==") or integer (such as 4) input value will be accepted as an ID.

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


217
# File 'lib/whop_sdk/models/withdrawal.rb', line 217

required :company_id, String, nil?: true

#idString

The unique identifier for the ledger account.

Parameters:

  • value (String)

Returns:

  • (String)


207
# File 'lib/whop_sdk/models/withdrawal.rb', line 207

required :id, String

Instance Method Details

#to_hash{ id: String, company_id: String? }

Returns:

  • ({ id: String, company_id: String? })


203
# File 'sig/whop_sdk/models/withdrawal.rbs', line 203

def to_hash: -> { id: String, company_id: String? }