Class: WhopSDK::Models::WithdrawalCreatedWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/withdrawal_created_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Modules: ErrorCode Classes: LedgerAccount, PayoutToken

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , company_id: ) ⇒ Object

The ledger account associated with the withdrawal.

Parameters:

  • id (String) (defaults to: )

    The ID of the LedgerAccount.

  • company_id (String, nil) (defaults to: )

    The ID of the company associated with this ledger account.



# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 141

Instance Attribute Details

#amountFloat

How much money was attempted to be withdrawn, in a float type.

Returns:

  • (Float)


59
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 59

required :amount, Float

#created_atTime

When the withdrawal request was created.

Returns:

  • (Time)


65
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 65

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The currency of the withdrawal request.

Returns:



71
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 71

required :currency, enum: -> { WhopSDK::Currency }

#error_codeSymbol, ...

The different error codes a payout can be in.



77
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 77

required :error_code, enum: -> { WhopSDK::WithdrawalCreatedWebhookEvent::Data::ErrorCode }, nil?: true

#error_messageString?

The error message for the withdrawal, if any.

Returns:

  • (String, nil)


83
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 83

required :error_message, String, nil?: true

#estimated_availabilityTime?

The estimated availability date for the withdrawal, if any.

Returns:

  • (Time, nil)


89
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 89

required :estimated_availability, Time, nil?: true

#fee_amountFloat

The fee amount that was charged for the withdrawal. This is in the same currency as the withdrawal amount.

Returns:

  • (Float)


96
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 96

required :fee_amount, Float

#fee_typeSymbol, ...

The different fee types for a withdrawal.

Returns:



102
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 102

required :fee_type, enum: -> { WhopSDK::WithdrawalFeeTypes }, nil?: true

#idString

Internal ID of the withdrawal request.

Returns:

  • (String)


53
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 53

required :id, String

#ledger_accountWhopSDK::Models::WithdrawalCreatedWebhookEvent::Data::LedgerAccount

The ledger account associated with the withdrawal.



108
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 108

required :ledger_account, -> { WhopSDK::WithdrawalCreatedWebhookEvent::Data::LedgerAccount }

#payout_tokenWhopSDK::Models::WithdrawalCreatedWebhookEvent::Data::PayoutToken?

The payout token used for the withdrawal, if applicable.



114
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 114

required :payout_token, -> { WhopSDK::WithdrawalCreatedWebhookEvent::Data::PayoutToken }, nil?: true

#speedSymbol, WhopSDK::Models::WithdrawalSpeeds

The speed of the withdrawal.



120
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 120

required :speed, enum: -> { WhopSDK::WithdrawalSpeeds }

#statusSymbol, WhopSDK::Models::WithdrawalStatus

Status of the withdrawal.



126
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 126

required :status, enum: -> { WhopSDK::WithdrawalStatus }

#trace_codeString?

The trace code for the payout, if applicable. Provided on ACH transactions when available.

Returns:

  • (String, nil)


133
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 133

required :trace_code, String, nil?: true

#withdrawal_typeSymbol, WhopSDK::Models::WithdrawalTypes

The type of withdrawal.



139
# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 139

required :withdrawal_type, enum: -> { WhopSDK::WithdrawalTypes }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/withdrawal_created_webhook_event.rb', line 229