Class: WhopSDK::Models::WithdrawalListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/withdrawal_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, currency:, fee_amount:, fee_type:, markup_fee:, speed:, status:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::WithdrawalListResponse for more details.

A withdrawal represents a request to transfer funds from a ledger account to an external payout method.

Parameters:

  • id (String)

    The unique identifier for the withdrawal.

  • amount (Float)

    The withdrawal amount as a decimal number in the specified currency (e.g., 100.0

  • created_at (Time)

    The datetime the withdrawal was created.

  • currency (Symbol, WhopSDK::Models::Currency)

    The three-letter ISO currency code for this withdrawal (e.g., ‘usd’, ‘eur’).

  • fee_amount (Float)

    The fee charged for processing this withdrawal, in the same currency as the with

  • fee_type (Symbol, WhopSDK::Models::WithdrawalFeeTypes, nil)

    The different fee types for a withdrawal.

  • markup_fee (Float)

    An additional markup fee charged for the withdrawal, in the same currency as the

  • speed (Symbol, WhopSDK::Models::WithdrawalSpeeds)

    The processing speed selected for this withdrawal (‘standard’ or ‘instant’).

  • status (Symbol, WhopSDK::Models::WithdrawalStatus)

    The computed lifecycle status of the withdrawal, accounting for the state of ass



# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 65

Instance Attribute Details

#amountFloat

The withdrawal amount as a decimal number in the specified currency (e.g., 100.00 for $100.00 USD).

Returns:

  • (Float)


18
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 18

required :amount, Float

#created_atTime

The datetime the withdrawal was created.

Returns:

  • (Time)


24
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 24

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The three-letter ISO currency code for this withdrawal (e.g., ‘usd’, ‘eur’).

Returns:



30
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 30

required :currency, enum: -> { WhopSDK::Currency }

#fee_amountFloat

The fee charged for processing this withdrawal, in the same currency as the withdrawal amount.

Returns:

  • (Float)


37
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 37

required :fee_amount, Float

#fee_typeSymbol, ...

The different fee types for a withdrawal.

Returns:



43
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 43

required :fee_type, enum: -> { WhopSDK::WithdrawalFeeTypes }, nil?: true

#idString

The unique identifier for the withdrawal.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 11

required :id, String

#markup_feeFloat

An additional markup fee charged for the withdrawal, in the same currency as the withdrawal amount. Only applies to platform accounts using Whop Rails.

Returns:

  • (Float)


50
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 50

required :markup_fee, Float

#speedSymbol, WhopSDK::Models::WithdrawalSpeeds

The processing speed selected for this withdrawal (‘standard’ or ‘instant’).



56
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 56

required :speed, enum: -> { WhopSDK::WithdrawalSpeeds }

#statusSymbol, WhopSDK::Models::WithdrawalStatus

The computed lifecycle status of the withdrawal, accounting for the state of associated payouts (e.g., ‘requested’, ‘in_transit’, ‘completed’, ‘failed’).



63
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 63

required :status, enum: -> { WhopSDK::WithdrawalStatus }