Class: WhopSDK::Models::WithdrawalRetrieveResponse::LatestPayout

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/withdrawal_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Modules: ErrorCode, Status

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , created_at: , error_code: , error_message: , estimated_availability: , payer_name: , status: , trace_code: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::WithdrawalRetrieveResponse::LatestPayout for more details.

The latest payout associated with this withdrawal, if any.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the payout.

  • created_at (Time) (defaults to: )

    The date and time the payout was created.

  • error_code (Symbol, WhopSDK::Models::WithdrawalRetrieveResponse::LatestPayout::ErrorCode, nil) (defaults to: )

    The different error codes a payout can be in.

  • error_message (String, nil) (defaults to: )

    The error message for the payout.

  • estimated_availability (Time, nil) (defaults to: )

    The estimated availability date of the payout.

  • payer_name (String, nil) (defaults to: )

    The name of the payer for the payout.

  • status (Symbol, WhopSDK::Models::WithdrawalRetrieveResponse::LatestPayout::Status) (defaults to: )

    The status of the payout.

  • trace_code (String, nil) (defaults to: )

    The trace code for the payout, if applicable. Provided on ACH transactions when



# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 155

Instance Attribute Details

#created_atTime

The date and time the payout was created.

Returns:

  • (Time)


114
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 114

required :created_at, Time

#error_codeSymbol, ...

The different error codes a payout can be in.



120
121
122
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 120

required :error_code,
enum: -> { WhopSDK::Models::WithdrawalRetrieveResponse::LatestPayout::ErrorCode },
nil?: true

#error_messageString?

The error message for the payout.

Returns:

  • (String, nil)


128
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 128

required :error_message, String, nil?: true

#estimated_availabilityTime?

The estimated availability date of the payout.

Returns:

  • (Time, nil)


134
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 134

required :estimated_availability, Time, nil?: true

#idString

The internal ID of the payout.

Returns:

  • (String)


108
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 108

required :id, String

#payer_nameString?

The name of the payer for the payout.

Returns:

  • (String, nil)


140
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 140

required :payer_name, String, nil?: true

#statusSymbol, WhopSDK::Models::WithdrawalRetrieveResponse::LatestPayout::Status

The status of the payout.



146
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 146

required :status, enum: -> { WhopSDK::Models::WithdrawalRetrieveResponse::LatestPayout::Status }

#trace_codeString?

The trace code for the payout, if applicable. Provided on ACH transactions when available.

Returns:

  • (String, nil)


153
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 153

required :trace_code, String, nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 229