Class: WhopSDK::Models::WithdrawalUpdatedWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/withdrawal_updated_webhook_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, data:, timestamp:, company_id: nil, api_version: :v1, type: :"withdrawal.updated") ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::WithdrawalUpdatedWebhookEvent for more details.

Parameters:

  • id (String)

    A unique ID for every single webhook request

  • data (WhopSDK::Models::Withdrawal)

    A withdrawal represents a request to transfer funds from a ledger account to an

  • timestamp (Time)

    The timestamp in ISO 8601 format that the webhook was sent at on the server

  • company_id (String, nil) (defaults to: nil)

    The company ID that this webhook event is associated with

  • api_version (Symbol, :v1) (defaults to: :v1)

    The API version for this webhook

  • type (Symbol, :"withdrawal.updated") (defaults to: :"withdrawal.updated")

    The webhook event type



# File 'lib/whop_sdk/models/withdrawal_updated_webhook_event.rb', line 43

Instance Attribute Details

#api_versionSymbol, :v1

The API version for this webhook

Returns:

  • (Symbol, :v1)


16
# File 'lib/whop_sdk/models/withdrawal_updated_webhook_event.rb', line 16

required :api_version, const: :v1

#company_idString?

The company ID that this webhook event is associated with

Returns:

  • (String, nil)


41
# File 'lib/whop_sdk/models/withdrawal_updated_webhook_event.rb', line 41

optional :company_id, String, nil?: true

#dataWhopSDK::Models::Withdrawal

A withdrawal represents a request to transfer funds from a ledger account to an external payout method.



23
# File 'lib/whop_sdk/models/withdrawal_updated_webhook_event.rb', line 23

required :data, -> { WhopSDK::Withdrawal }

#idString

A unique ID for every single webhook request

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/withdrawal_updated_webhook_event.rb', line 10

required :id, String

#timestampTime

The timestamp in ISO 8601 format that the webhook was sent at on the server

Returns:

  • (Time)


29
# File 'lib/whop_sdk/models/withdrawal_updated_webhook_event.rb', line 29

required :timestamp, Time

#typeSymbol, :"withdrawal.updated"

The webhook event type

Returns:

  • (Symbol, :"withdrawal.updated")


35
# File 'lib/whop_sdk/models/withdrawal_updated_webhook_event.rb', line 35

required :type, const: :"withdrawal.updated"