Class: WhopSDK::Models::Workforce::BountyListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/workforce/bounty_list_params.rb,
sig/whop_sdk/models/workforce/bounty_list_params.rbs

Overview

See Also:

  • WhopSDK::Resources::Workforce::Bounties#list

Defined Under Namespace

Modules: Direction, Order, Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id: nil, after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, query: nil, status: nil, user_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::Workforce::BountyListParams for more details.

Parameters:

  • account_id (String) (defaults to: nil)

    Scope the list to this account (biz_ tag). Requires read access to the account

  • after (String) (defaults to: nil)

    Cursor to paginate forwards from.

  • before (String) (defaults to: nil)

    Cursor to paginate backwards from.

  • created_after (String) (defaults to: nil)

    Only bounties created after this ISO 8601 timestamp.

  • created_before (String) (defaults to: nil)

    Only bounties created before this ISO 8601 timestamp.

  • direction (Symbol, WhopSDK::Models::Workforce::BountyListParams::Direction) (defaults to: nil)

    Sort direction.

  • first (Integer) (defaults to: nil)

    Number of bounties to return from the start of the window.

  • last (Integer) (defaults to: nil)

    Number of bounties to return from the end of the window.

  • order (Symbol, WhopSDK::Models::Workforce::BountyListParams::Order) (defaults to: nil)

    Sort field.

  • query (String) (defaults to: nil)

    Substring match on the bounty title or ID.

  • status (Symbol, WhopSDK::Models::Workforce::BountyListParams::Status) (defaults to: nil)

    Filter by lifecycle state.

  • user_id (String) (defaults to: nil)

    List the bounties this user participated in (user_ tag). Must be the authentic

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 85

Instance Attribute Details

#account_idString?

Scope the list to this account (biz_ tag). Requires read access to the account; account API keys may pass their own account or a connected account.

Parameters:

  • (String)

Returns:

  • (String, nil)


16
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 16

optional :account_id, String

#afterString?

Cursor to paginate forwards from.

Parameters:

  • (String)

Returns:

  • (String, nil)


22
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 22

optional :after, String

#beforeString?

Cursor to paginate backwards from.

Parameters:

  • (String)

Returns:

  • (String, nil)


28
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 28

optional :before, String

#created_afterString?

Only bounties created after this ISO 8601 timestamp.

Parameters:

  • (String)

Returns:

  • (String, nil)


34
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 34

optional :created_after, String

#created_beforeString?

Only bounties created before this ISO 8601 timestamp.

Parameters:

  • (String)

Returns:

  • (String, nil)


40
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 40

optional :created_before, String

#directionSymbol, ...

Sort direction.



46
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 46

optional :direction, enum: -> { WhopSDK::Workforce::BountyListParams::Direction }

#firstInteger?

Number of bounties to return from the start of the window.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


52
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 52

optional :first, Integer

#lastInteger?

Number of bounties to return from the end of the window.

Parameters:

  • (Integer)

Returns:

  • (Integer, nil)


58
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 58

optional :last, Integer

#orderSymbol, ...

Sort field.



64
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 64

optional :order, enum: -> { WhopSDK::Workforce::BountyListParams::Order }

#queryString?

Substring match on the bounty title or ID.

Parameters:

  • (String)

Returns:

  • (String, nil)


70
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 70

optional :query, String

#statusSymbol, ...

Filter by lifecycle state.



76
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 76

optional :status, enum: -> { WhopSDK::Workforce::BountyListParams::Status }

#user_idString?

List the bounties this user participated in (user_ tag). Must be the authenticated user.

Parameters:

  • (String)

Returns:

  • (String, nil)


83
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 83

optional :user_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 122

Instance Method Details

#to_hash{

Returns:

  • ({)


95
# File 'sig/whop_sdk/models/workforce/bounty_list_params.rbs', line 95

def to_hash: -> {