Class: WhopSDK::Models::Workforce::WorkforceBounty::Poster
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Workforce::WorkforceBounty::Poster
- Defined in:
- lib/whop_sdk/models/workforce/workforce_bounty.rb,
sig/whop_sdk/models/workforce/workforce_bounty.rbs
Overview
Defined Under Namespace
Classes: ProfilePicture
Instance Attribute Summary collapse
-
#id ⇒ String
User ID, prefixed
user_. -
#name ⇒ String?
Display name.
-
#profile_picture ⇒ WhopSDK::Models::Workforce::WorkforceBounty::Poster::ProfilePicture
Avatar wrapper; its
urlis always present, using a generated placeholder when the user set no picture. -
#username ⇒ String
Public username.
Instance Method Summary collapse
-
#initialize(id:, name:, profile_picture:, username:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Poster for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, profile_picture:, username:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Workforce::WorkforceBounty::Poster for more details.
The user who posted the bounty.
|
|
# File 'lib/whop_sdk/models/workforce/workforce_bounty.rb', line 275
|
Instance Attribute Details
#id ⇒ String
User ID, prefixed user_.
254 |
# File 'lib/whop_sdk/models/workforce/workforce_bounty.rb', line 254 required :id, String |
#name ⇒ String?
Display name.
260 |
# File 'lib/whop_sdk/models/workforce/workforce_bounty.rb', line 260 required :name, String, nil?: true |
#profile_picture ⇒ WhopSDK::Models::Workforce::WorkforceBounty::Poster::ProfilePicture
Avatar wrapper; its url is always present, using a generated placeholder when
the user set no picture.
267 |
# File 'lib/whop_sdk/models/workforce/workforce_bounty.rb', line 267 required :profile_picture, -> { WhopSDK::Workforce::WorkforceBounty::Poster::ProfilePicture } |
#username ⇒ String
Public username.
273 |
# File 'lib/whop_sdk/models/workforce/workforce_bounty.rb', line 273 required :username, String |
Instance Method Details
#to_hash ⇒ {
184 |
# File 'sig/whop_sdk/models/workforce/workforce_bounty.rbs', line 184
def to_hash: -> {
|