Module: WhopSDK::Models::Workforce::WorkforceBounty::Status

Extended by:
Internal::Type::Enum
Defined in:
lib/whop_sdk/models/workforce/workforce_bounty.rb,
sig/whop_sdk/models/workforce/workforce_bounty.rbs

Overview

Lifecycle state. scheduled bounties are unpublished drafts, visible to their poster and the account's authorized managers; open bounties accept new submissions; closed bounties are live but no longer accept new submissions; completed bounties paid out every winner slot; canceled bounties ended before filling their slots.

See Also:

  • WhopSDK::Models::Workforce::WorkforceBounty#status

Constant Summary collapse

SCHEDULED =

Returns:

  • (:scheduled)
:scheduled
OPEN =

Returns:

  • (:open)
:open
CLOSED =

Returns:

  • (:closed)
:closed
COMPLETED =

Returns:

  • (:completed)
:completed
CANCELED =

Returns:

  • (:canceled)
:canceled

Instance Method Summary collapse

Methods included from Internal::Type::Enum

==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#self?.values::Array[WhopSDK::Models::Workforce::WorkforceBounty::status]

Returns:

  • (::Array[WhopSDK::Models::Workforce::WorkforceBounty::status])


227
# File 'sig/whop_sdk/models/workforce/workforce_bounty.rbs', line 227

def self?.values: -> ::Array[WhopSDK::Models::Workforce::WorkforceBounty::status]