Class: WhopSDK::Resources::PaymentTokens

Inherits:
Object
  • Object
show all
Defined in:
lib/whop_sdk/resources/payment_tokens.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ PaymentTokens

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of PaymentTokens.

Parameters:



78
79
80
# File 'lib/whop_sdk/resources/payment_tokens.rb', line 78

def initialize(client:)
  @client = client
end

Instance Method Details

#list(member_id: , after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, request_options: {}) ⇒ WhopSDK::Internal::CursorPage<WhopSDK::Models::PaymentTokenListResponse>

Lists PaymentTokens

Required permissions:

  • ‘member:payment_methods:read`

Parameters:

  • member_id (String)

    The ID of the Member to list payment tokens for

  • after (String, nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil)

    Returns the elements in the list that come before the specified cursor.

  • created_after (Time, nil)

    The minimum creation date to filter by

  • created_before (Time, nil)

    The maximum creation date to filter by

  • direction (Symbol, WhopSDK::Models::Direction, nil)

    The direction of the sort.

  • first (Integer, nil)

    Returns the first n elements from the list.

  • last (Integer, nil)

    Returns the last n elements from the list.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/whop_sdk/resources/payment_tokens.rb', line 63

def list(params)
  parsed, options = WhopSDK::PaymentTokenListParams.dump_request(params)
  @client.request(
    method: :get,
    path: "payment_tokens",
    query: parsed,
    page: WhopSDK::Internal::CursorPage,
    model: WhopSDK::Models::PaymentTokenListResponse,
    options: options
  )
end

#retrieve(id, member_id: , request_options: {}) ⇒ WhopSDK::Models::PaymentTokenRetrieveResponse

Retrieves a PaymentToken by ID

Required permissions:

  • ‘member:payment_methods:read`

Parameters:

  • id (String)

    The ID of the PaymentToken

  • member_id (String)

    The ID of the Member associated with the PaymentToken

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



23
24
25
26
27
28
29
30
31
32
# File 'lib/whop_sdk/resources/payment_tokens.rb', line 23

def retrieve(id, params)
  parsed, options = WhopSDK::PaymentTokenRetrieveParams.dump_request(params)
  @client.request(
    method: :get,
    path: ["payment_tokens/%1$s", id],
    query: parsed,
    model: WhopSDK::Models::PaymentTokenRetrieveResponse,
    options: options
  )
end