Class: Whop_sdk::APIKeys::Types::UpdateAPIKeysRequestPermissions
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Whop_sdk::APIKeys::Types::UpdateAPIKeysRequestPermissions
- Defined in:
- lib/whop_sdk/api_keys/types/update_api_keys_request_permissions.rb
Overview
The permissions policy for the API key: explicit permission statements, or a system role to inherit from.
Statements without a resources array default to the owning account (Account API keys) or every key-addressable
resource (App API keys).
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Whop_sdk::Internal::Types::Model