Class: Whop_sdk::AppBuilds::Types::CreateAppBuildsRequestSourceAttachment

Inherits:
Internal::Types::Model show all
Defined in:
lib/whop_sdk/app_builds/types/create_app_builds_request_source_attachment.rb

Overview

An optional compressed archive (.zip or .gz) of the source code that produced this build, stored alongside the build so it can be downloaded later. Referenced like attachment, and must be a different file.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Whop_sdk::Internal::Types::Model