Class: Whop_sdk::BountySubmissions::Types::CreateBountySubmissionsRequestMetadata
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Whop_sdk::BountySubmissions::Types::CreateBountySubmissionsRequestMetadata
- Defined in:
- lib/whop_sdk/bounty_submissions/types/create_bounty_submissions_request_metadata.rb
Overview
Optional capture metadata describing where and how the footage was recorded. Persisted on the submission. On a
data_capture bounty every field except fov is required whenever metadata is provided.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Whop_sdk::Internal::Types::Model