Class: Whop_sdk::CourseLessonInteractions::Client
- Inherits:
-
Object
- Object
- Whop_sdk::CourseLessonInteractions::Client
- Defined in:
- lib/whop_sdk/course_lesson_interactions/client.rb
Instance Method Summary collapse
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Whop_sdk::CourseLessonInteractions::Types::ListCourseLessonInteractionsResponse
Returns a paginated list of lesson interactions, filtered by lesson, course, user, or completion status.
-
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Types::CourseLessonInteraction
Retrieves the details of an existing course lesson interaction.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/whop_sdk/course_lesson_interactions/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#list(request_options: {}, **params) ⇒ Whop_sdk::CourseLessonInteractions::Types::ListCourseLessonInteractionsResponse
Returns a paginated list of lesson interactions, filtered by lesson, course, user, or completion status.
Required permissions:
courses:readcourse_analytics:read
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/whop_sdk/course_lesson_interactions/client.rb', line 45 def list(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["after"] = params[:after] if params.key?(:after) query_params["before"] = params[:before] if params.key?(:before) query_params["first"] = params[:first] if params.key?(:first) query_params["last"] = params[:last] if params.key?(:last) query_params["user_id"] = params[:user_id] if params.key?(:user_id) query_params["lesson_id"] = params[:lesson_id] if params.key?(:lesson_id) query_params["course_id"] = params[:course_id] if params.key?(:course_id) query_params["completed"] = params[:completed] if params.key?(:completed) Whop_sdk::Internal::CursorItemIterator.new( cursor_field: :end_cursor, item_field: :data, initial_cursor: query_params["after"] ) do |next_cursor| query_params["after"] = next_cursor request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "course_lesson_interactions", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Whop_sdk::CourseLessonInteractions::Types::ListCourseLessonInteractionsResponse.load(response.body) [parsed_response, response] else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Types::CourseLessonInteraction
Retrieves the details of an existing course lesson interaction.
Required permissions:
courses:readcourse_analytics:read
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/whop_sdk/course_lesson_interactions/client.rb', line 105 def retrieve(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "course_lesson_interactions/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Types::CourseLessonInteraction.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |