Class: Whop_sdk::Partners::Businesses::Client
- Inherits:
-
Object
- Object
- Whop_sdk::Partners::Businesses::Client
- Defined in:
- lib/whop_sdk/partners/businesses/client.rb
Instance Method Summary collapse
- #earnings ⇒ Whop_sdk::Earnings::Client
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Whop_sdk::Partners::Businesses::Types::ListBusinessesResponse
Lists the businesses the authenticated user referred onto Whop, most recent first.
-
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Partners::Businesses::Types::RetrieveBusinessesResponse
Retrieves a single referred business and its referral terms.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/whop_sdk/partners/businesses/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#earnings ⇒ Whop_sdk::Earnings::Client
125 126 127 |
# File 'lib/whop_sdk/partners/businesses/client.rb', line 125 def earnings @earnings ||= Whop_sdk::Partners::Businesses::Earnings::Client.new(client: @client) end |
#list(request_options: {}, **params) ⇒ Whop_sdk::Partners::Businesses::Types::ListBusinessesResponse
Lists the businesses the authenticated user referred onto Whop, most recent first.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/whop_sdk/partners/businesses/client.rb', line 41 def list(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["status"] = params[:status] if params.key?(:status) query_params["has_earnings"] = params[:has_earnings] if params.key?(:has_earnings) query_params["first"] = params[:first] if params.key?(:first) query_params["after"] = params[:after] if params.key?(:after) query_params["last"] = params[:last] if params.key?(:last) query_params["before"] = params[:before] if params.key?(:before) query_params["order"] = params[:order] if params.key?(:order) query_params["direction"] = params[:direction] if params.key?(:direction) query_params["created_before"] = params[:created_before] if params.key?(:created_before) query_params["created_after"] = params[:created_after] if params.key?(:created_after) query_params["referred_user_id"] = params[:referred_user_id] if params.key?(:referred_user_id) query_params["referred_username"] = params[:referred_username] if params.key?(:referred_username) query_params["tier"] = params[:tier] if params.key?(:tier) Whop_sdk::Internal::CursorItemIterator.new( cursor_field: :end_cursor, item_field: :data, initial_cursor: query_params["after"] ) do |next_cursor| query_params["after"] = next_cursor request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "partners/businesses", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Whop_sdk::Partners::Businesses::Types::ListBusinessesResponse.load(response.body) [parsed_response, response] else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Partners::Businesses::Types::RetrieveBusinessesResponse
Retrieves a single referred business and its referral terms.
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/whop_sdk/partners/businesses/client.rb', line 102 def retrieve(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "partners/businesses/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Partners::Businesses::Types::RetrieveBusinessesResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |