Class: Whop_sdk::PayoutMethods::Client
- Inherits:
-
Object
- Object
- Whop_sdk::PayoutMethods::Client
- Defined in:
- lib/whop_sdk/payout_methods/client.rb
Instance Method Summary collapse
- #initialize(client:) ⇒ void constructor
-
#list_payout_method(request_options: {}, **params) ⇒ Whop_sdk::PayoutMethods::Types::ListPayoutMethodResponse
Returns a list of active payout methods configured for a company, ordered by most recently created.
-
#retrieve_payout_method(request_options: {}, **params) ⇒ Whop_sdk::Types::PayoutMethod
Retrieves the details of an existing payout method.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/whop_sdk/payout_methods/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#list_payout_method(request_options: {}, **params) ⇒ Whop_sdk::PayoutMethods::Types::ListPayoutMethodResponse
Returns a list of active payout methods configured for a company, ordered by most recently created.
Required permissions:
payout:destination:read
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/whop_sdk/payout_methods/client.rb', line 39 def list_payout_method(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["after"] = params[:after] if params.key?(:after) query_params["before"] = params[:before] if params.key?(:before) query_params["first"] = params[:first] if params.key?(:first) query_params["last"] = params[:last] if params.key?(:last) query_params["company_id"] = params[:company_id] if params.key?(:company_id) Whop_sdk::Internal::CursorItemIterator.new( cursor_field: :end_cursor, item_field: :data, initial_cursor: query_params["after"] ) do |next_cursor| query_params["after"] = next_cursor request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "payout_methods", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Whop_sdk::PayoutMethods::Types::ListPayoutMethodResponse.load(response.body) [parsed_response, response] else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#retrieve_payout_method(request_options: {}, **params) ⇒ Whop_sdk::Types::PayoutMethod
Retrieves the details of an existing payout method.
Required permissions:
payout:destination:read
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/whop_sdk/payout_methods/client.rb', line 95 def retrieve_payout_method(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "payout_methods/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Types::PayoutMethod.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |