Class: Whop_sdk::Payouts::Types::PostPayoutMethodCreatedPayloadDataQuote

Inherits:
Internal::Types::Model show all
Defined in:
lib/whop_sdk/payouts/types/post_payout_method_created_payload_data_quote.rb

Overview

Fee and delivery estimate for paying out the requested amount through this method. Null unless an amount was provided, or when the estimate is unavailable.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Whop_sdk::Internal::Types::Model