Class: Whop_sdk::Payouts::Types::PostPayoutMethodCreatedPayloadDataQuoteInstant

Inherits:
Internal::Types::Model show all
Defined in:
lib/whop_sdk/payouts/types/post_payout_method_created_payload_data_quote_instant.rb

Overview

Instant-delivery estimate. Null if the method does not support instant delivery, instant delivery is unavailable for the account, or the amount does not cover the fee.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Whop_sdk::Internal::Types::Model