Class: Whop_sdk::Plans::Client
- Inherits:
-
Object
- Object
- Whop_sdk::Plans::Client
- Defined in:
- lib/whop_sdk/plans/client.rb
Instance Method Summary collapse
-
#calculate_tax(request_options: {}, **params) ⇒ Whop_sdk::Plans::Types::CalculateTaxPlansResponse
Previews tax for a plan before checkout, based on the buyer's location.
-
#create(request_options: {}, **params) ⇒ Whop_sdk::Types::Plan
Create a new pricing plan for a product.
-
#delete(request_options: {}, **params) ⇒ Whop_sdk::Plans::Types::DeletePlansResponse
Permanently delete a plan from a product.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Whop_sdk::Plans::Types::ListPlansResponse
Returns a paginated list of plans.
-
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Types::Plan
Retrieves the details of an existing plan.
-
#update(request_options: {}, **params) ⇒ Whop_sdk::Types::Plan
Update a plan's pricing, billing interval, visibility, stock, and other settings.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/whop_sdk/plans/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#calculate_tax(request_options: {}, **params) ⇒ Whop_sdk::Plans::Types::CalculateTaxPlansResponse
Previews tax for a plan before checkout, based on the buyer's location.
267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/whop_sdk/plans/client.rb', line 267 def calculate_tax(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request_data = Whop_sdk::Plans::Types::CalculateTaxPlansRequest.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "plans/#{URI.encode_uri_component(params[:id].to_s)}/calculate_tax", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Plans::Types::CalculateTaxPlansResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#create(request_options: {}, **params) ⇒ Whop_sdk::Types::Plan
Create a new pricing plan for a product. The plan defines the billing interval, price, and availability for customers.
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/whop_sdk/plans/client.rb', line 107 def create(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "plans", body: Whop_sdk::Plans::Types::CreatePlansRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Types::Plan.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ Whop_sdk::Plans::Types::DeletePlansResponse
Permanently delete a plan from a product. Existing memberships on this plan will not be affected.
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/whop_sdk/plans/client.rb', line 182 def delete(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "plans/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Plans::Types::DeletePlansResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Whop_sdk::Plans::Types::ListPlansResponse
Returns a paginated list of plans. Omit account_id and pass product_ids to list a product's public buyable
plans.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/whop_sdk/plans/client.rb', line 46 def list(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["account_id"] = params[:account_id] if params.key?(:account_id) query_params["direction"] = params[:direction] if params.key?(:direction) query_params["order"] = params[:order] if params.key?(:order) query_params["release_methods"] = params[:release_methods] if params.key?(:release_methods) query_params["visibilities"] = params[:visibilities] if params.key?(:visibilities) query_params["plan_types"] = params[:plan_types] if params.key?(:plan_types) query_params["product_ids"] = params[:product_ids] if params.key?(:product_ids) query_params["created_before"] = params[:created_before] if params.key?(:created_before) query_params["created_after"] = params[:created_after] if params.key?(:created_after) query_params["first"] = params[:first] if params.key?(:first) query_params["after"] = params[:after] if params.key?(:after) query_params["last"] = params[:last] if params.key?(:last) query_params["before"] = params[:before] if params.key?(:before) Whop_sdk::Internal::CursorItemIterator.new( cursor_field: :end_cursor, item_field: :data, initial_cursor: query_params["after"] ) do |next_cursor| query_params["after"] = next_cursor request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "plans", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Whop_sdk::Plans::Types::ListPlansResponse.load(response.body) [parsed_response, response] else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Types::Plan
Retrieves the details of an existing plan.
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/whop_sdk/plans/client.rb', line 145 def retrieve(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "plans/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Types::Plan.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Whop_sdk::Types::Plan
Update a plan's pricing, billing interval, visibility, stock, and other settings.
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/whop_sdk/plans/client.rb', line 219 def update(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request_data = Whop_sdk::Plans::Types::UpdatePlansRequest.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "plans/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Types::Plan.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |