Class: Whop_sdk::Types::CompanyTokenTransaction

Inherits:
Internal::Types::Model show all
Defined in:
lib/whop_sdk/types/company_token_transaction.rb

Overview

A token transaction records a credit or debit to a member's token balance within a company, including transfers between members.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Whop_sdk::Internal::Types::Model