Class: Whop_sdk::Types::CourseResumeLesson

Inherits:
Internal::Types::Model show all
Defined in:
lib/whop_sdk/types/course_resume_lesson.rb

Overview

The lesson the current user should continue from: their first incomplete lesson, or the first lesson when they have finished the course, have not started it, or can edit it. Null if the course has no lessons.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Whop_sdk::Internal::Types::Model