Class: Whop_sdk::Types::Invoice
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Whop_sdk::Types::Invoice
- Defined in:
- lib/whop_sdk/types/invoice.rb
Overview
An invoice represents an itemized bill sent by a company to a customer for a specific product and plan, tracking the amount owed, due date, and payment status.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Whop_sdk::Internal::Types::Model