Class: Whop_sdk::Types::InvoiceLineItemsItem
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Whop_sdk::Types::InvoiceLineItemsItem
- Defined in:
- lib/whop_sdk/types/invoice_line_items_item.rb
Overview
A line item on an invoice, representing a single charge with a label, quantity, and unit price.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Whop_sdk::Internal::Types::Model