Class: Whop_sdk::Types::InvoicePayment
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Whop_sdk::Types::InvoicePayment
- Defined in:
- lib/whop_sdk/types/invoice_payment.rb
Overview
The payment that settled this invoice. Null while the invoice is unpaid, when the invoice was marked paid manually, and on a subscription renewal invoice, where the settling payment cannot yet be identified.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Whop_sdk::Internal::Types::Model