Class: Whop_sdk::Types::PaymentRuleConditionValue

Inherits:
Internal::Types::Model show all
Extended by:
Internal::Types::Union
Defined in:
lib/whop_sdk/types/payment_rule_condition_value.rb

Overview

The value to compare against. A number for risk_score, a string for the other fields, and an array of strings for the in and not_in operators.

Method Summary

Methods included from Internal::Types::Union

coerce, discriminant, load, member, members, type_member?

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Constructor Details

This class inherits a constructor from Whop_sdk::Internal::Types::Model