Class: Whop_sdk::Types::PayoutMethod
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Whop_sdk::Types::PayoutMethod
- Defined in:
- lib/whop_sdk/types/payout_method.rb
Overview
A configured payout destination where a user receives earned funds, such as a bank account or digital wallet.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Whop_sdk::Internal::Types::Model