Class: Whop_sdk::Types::ResolutionCenterCaseLegacyResolutionEventsItem

Inherits:
Internal::Types::Model show all
Defined in:
lib/whop_sdk/types/resolution_center_case_legacy_resolution_events_item.rb

Overview

A resolution event is a message or action within a resolution case, such as a response, escalation, or status change.

Method Summary

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Constructor Details

This class inherits a constructor from Whop_sdk::Internal::Types::Model