Class: Whop_sdk::Withdrawals::Client
- Inherits:
-
Object
- Object
- Whop_sdk::Withdrawals::Client
- Defined in:
- lib/whop_sdk/withdrawals/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Whop_sdk::Types::Withdrawal
Creates a withdrawal request for a ledger account.
-
#generate_pdf(request_options: {}, **params) ⇒ Whop_sdk::Withdrawals::Types::GeneratePdfWithdrawalsResponse
Generates a withdrawal PDF invoice and returns a temporary download URL.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Whop_sdk::Withdrawals::Types::ListWithdrawalsResponse
Returns a paginated list of withdrawals for a company, with optional sorting and date filtering.
-
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Types::Withdrawal
Retrieves the details of an existing withdrawal.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/whop_sdk/withdrawals/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Whop_sdk::Types::Withdrawal
Creates a withdrawal request for a ledger account
Required permissions:
payout:withdraw_fundspayout:destination:read
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/whop_sdk/withdrawals/client.rb', line 107 def create(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "withdrawals", body: Whop_sdk::Withdrawals::Types::CreateWithdrawalsRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Types::Withdrawal.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#generate_pdf(request_options: {}, **params) ⇒ Whop_sdk::Withdrawals::Types::GeneratePdfWithdrawalsResponse
Generates a withdrawal PDF invoice and returns a temporary download URL.
Required permissions:
payout:withdrawal:read
189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/whop_sdk/withdrawals/client.rb', line 189 def generate_pdf(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "withdrawals/#{URI.encode_uri_component(params[:id].to_s)}/generate_pdf", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Withdrawals::Types::GeneratePdfWithdrawalsResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Whop_sdk::Withdrawals::Types::ListWithdrawalsResponse
Returns a paginated list of withdrawals for a company, with optional sorting and date filtering.
Required permissions:
payout:withdrawal:read
44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/whop_sdk/withdrawals/client.rb', line 44 def list(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["after"] = params[:after] if params.key?(:after) query_params["before"] = params[:before] if params.key?(:before) query_params["first"] = params[:first] if params.key?(:first) query_params["last"] = params[:last] if params.key?(:last) query_params["company_id"] = params[:company_id] if params.key?(:company_id) query_params["direction"] = params[:direction] if params.key?(:direction) query_params["created_before"] = params[:created_before] if params.key?(:created_before) query_params["created_after"] = params[:created_after] if params.key?(:created_after) Whop_sdk::Internal::CursorItemIterator.new( cursor_field: :end_cursor, item_field: :data, initial_cursor: query_params["after"] ) do |next_cursor| query_params["after"] = next_cursor request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "withdrawals", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Whop_sdk::Withdrawals::Types::ListWithdrawalsResponse.load(response.body) [parsed_response, response] else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Types::Withdrawal
Retrieves the details of an existing withdrawal.
Required permissions:
payout:withdrawal:readpayout:destination:read
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/whop_sdk/withdrawals/client.rb', line 149 def retrieve(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "withdrawals/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Types::Withdrawal.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |