Class: WhopSDK::Helpers::VerifyUserToken::UserTokenPayload

Inherits:
Object
  • Object
show all
Defined in:
lib/whop_sdk/helpers/verify_user_token.rb

Overview

User token payload structure

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(user_id:, app_id:) ⇒ UserTokenPayload

Returns a new instance of UserTokenPayload.



25
26
27
28
# File 'lib/whop_sdk/helpers/verify_user_token.rb', line 25

def initialize(user_id:, app_id:)
  @user_id = user_id
  @app_id = app_id
end

Instance Attribute Details

#app_idString (readonly)

Returns The app id of the app that is making the request.

Returns:

  • (String)

    The app id of the app that is making the request



23
24
25
# File 'lib/whop_sdk/helpers/verify_user_token.rb', line 23

def app_id
  @app_id
end

#user_idString (readonly)

Returns The user id of the user who is making the request.

Returns:

  • (String)

    The user id of the user who is making the request



20
21
22
# File 'lib/whop_sdk/helpers/verify_user_token.rb', line 20

def user_id
  @user_id
end