Class: WhopSDK::Models::AIChatCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AIChatCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/ai_chat_create_params.rb
Overview
Defined Under Namespace
Modules: MessageSource Classes: MessageAttachment
Instance Attribute Summary collapse
-
#current_company_id ⇒ String?
The unique identifier of the company to set as context for the AI chat (e.g., “biz_XXXXX”).
-
#message_attachments ⇒ Array<WhopSDK::Models::AIChatCreateParams::MessageAttachment>?
A list of previously uploaded file attachments to include with the first message.
-
#message_source ⇒ Symbol, ...
The source of an AI chat message.
-
#message_text ⇒ String
The text content of the first message to send to the AI agent.
-
#suggestion_type ⇒ String?
The type of suggestion prompt that was clicked, when message_source is ‘suggestion’.
-
#title ⇒ String?
An optional display title for the AI chat thread (e.g., “Help with billing”).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
Input for an attachment.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
Input for an attachment
|
|
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 76
|
Instance Attribute Details
#current_company_id ⇒ String?
The unique identifier of the company to set as context for the AI chat (e.g., “biz_XXXXX”).
21 |
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 21 optional :current_company_id, String, nil?: true |
#message_attachments ⇒ Array<WhopSDK::Models::AIChatCreateParams::MessageAttachment>?
A list of previously uploaded file attachments to include with the first message.
28 29 30 |
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 28 optional :message_attachments, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::AIChatCreateParams::MessageAttachment] }, nil?: true |
#message_source ⇒ Symbol, ...
The source of an AI chat message
36 |
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 36 optional :message_source, enum: -> { WhopSDK::AIChatCreateParams::MessageSource }, nil?: true |
#message_text ⇒ String
The text content of the first message to send to the AI agent.
14 |
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 14 required :message_text, String |
#suggestion_type ⇒ String?
The type of suggestion prompt that was clicked, when message_source is ‘suggestion’.
43 |
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 43 optional :suggestion_type, String, nil?: true |
#title ⇒ String?
An optional display title for the AI chat thread (e.g., “Help with billing”).
49 |
# File 'lib/whop_sdk/models/ai_chat_create_params.rb', line 49 optional :title, String, nil?: true |