Class: WhopSDK::Models::AIChatUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AIChatUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/ai_chat_update_params.rb
Overview
Instance Attribute Summary collapse
-
#current_company_id ⇒ String?
The unique identifier of the company to set as context for the AI chat (e.g., “biz_XXXXX”).
- #id ⇒ String
-
#notification_preference ⇒ Symbol, ...
The notification preference for an AI chat.
-
#title ⇒ String?
The new display title for the AI chat thread (e.g., “Help with billing”).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, current_company_id: nil, notification_preference: nil, title: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AIChatUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, current_company_id: nil, notification_preference: nil, title: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AIChatUpdateParams for more details.
|
|
# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 34
|
Instance Attribute Details
#current_company_id ⇒ String?
The unique identifier of the company to set as context for the AI chat (e.g., “biz_XXXXX”).
20 |
# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 20 optional :current_company_id, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 13 required :id, String |
#notification_preference ⇒ Symbol, ...
The notification preference for an AI chat
26 |
# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 26 optional :notification_preference, enum: -> { WhopSDK::NotificationPreferences }, nil?: true |
#title ⇒ String?
The new display title for the AI chat thread (e.g., “Help with billing”).
32 |
# File 'lib/whop_sdk/models/ai_chat_update_params.rb', line 32 optional :title, String, nil?: true |