Class: WhopSDK::Models::AccessTokenCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AccessTokenCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/access_token_create_params.rb
Overview
Instance Attribute Summary collapse
-
#company_id ⇒ String
The ID of the Company to generate the token for.
-
#expires_at ⇒ Time?
The expiration timestamp for the access token.
-
#scoped_actions ⇒ Array<String>?
Array of desired scoped actions for the access token.
-
#user_id ⇒ String
The ID of the User to generate the token for.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(company_id: , user_id: , expires_at: nil, scoped_actions: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccessTokenCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id: , user_id: , expires_at: nil, scoped_actions: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AccessTokenCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 42
|
Instance Attribute Details
#company_id ⇒ String
The ID of the Company to generate the token for. The API key must have permission to access this Company, such as the being the company the API key belongs to or a sub-merchant of it
16 |
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 16 required :company_id, String |
#expires_at ⇒ Time?
The expiration timestamp for the access token. If not provided, a default expiration time of 1 hour will be used. The expiration can be set to a maximum of 3 hours from the current time.
24 |
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 24 optional :expires_at, Time, nil?: true |
#scoped_actions ⇒ Array<String>?
Array of desired scoped actions for the access token. If sent as an empty array or not provided, all permissions from the API key making the request will be available on the token. If sending an explicit list, they must be a subset of the API keys’s existing permissions. Otherwise, an error will be raised.
33 |
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 33 optional :scoped_actions, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#user_id ⇒ String
The ID of the User to generate the token for. The API key must have permission to access this User.
40 |
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 40 required :user_id, String |