Class: WhopSDK::Models::AccessTokenCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/access_token_create_params.rb

Overview

Defined Under Namespace

Modules: TargetResourceType

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(scoped_actions: , target_resource_id: , target_resource_type: , expires_at: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AccessTokenCreateParams for more details.

Parameters:

  • scoped_actions (Array<String>) (defaults to: )

    Array of desired scoped actions for the access token. This list must be a subset

  • target_resource_id (String) (defaults to: )

    The ID of the target resource (Company, User, etc.) for which the access token i

  • target_resource_type (Symbol, WhopSDK::Models::AccessTokenCreateParams::TargetResourceType) (defaults to: )

    The type of the target resource (company, user, product, experience, etc.).

  • expires_at (Time, nil) (defaults to: nil)

    The expiration timestamp for the access token. If not provided, a default expira

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/access_token_create_params.rb', line 38

Instance Attribute Details

#expires_atTime?

The expiration timestamp for the access token. If not provided, a default expiration time of 1 hour will be used. The expiration can be set to a maximum of 3 hours from the current time.

Returns:

  • (Time, nil)


36
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 36

optional :expires_at, Time, nil?: true

#scoped_actionsArray<String>

Array of desired scoped actions for the access token. This list must be a subset of the API keys’s existing permissions. Otherwise, an error will be raised.

Returns:

  • (Array<String>)


15
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 15

required :scoped_actions, WhopSDK::Internal::Type::ArrayOf[String]

#target_resource_idString

The ID of the target resource (Company, User, etc.) for which the access token is being created.

Returns:

  • (String)


22
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 22

required :target_resource_id, String

#target_resource_typeSymbol, WhopSDK::Models::AccessTokenCreateParams::TargetResourceType

The type of the target resource (company, user, product, experience, etc.).



28
# File 'lib/whop_sdk/models/access_token_create_params.rb', line 28

required :target_resource_type, enum: -> { WhopSDK::AccessTokenCreateParams::TargetResourceType }