Class: WhopSDK::Models::Account

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/account.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, banner_image_url:, business_type:, created_at:, description:, email:, industry_group:, industry_type:, logo_url:, metadata:, parent_account_id:, route:, send_customer_emails:, social_links:, target_audience:, title:, wallet:) ⇒ Object

Parameters:

  • id (String)

    The ID of the account, which will look like biz_*************

  • banner_image_url (String, nil)

    The URL of the account banner image

  • business_type (String, nil)

    The high-level business category for the account

  • created_at (String)

    When the account was created, as an ISO 8601 timestamp

  • description (String, nil)

    A promotional description for the account

  • email (String, nil)

    The email address of the account owner

  • industry_group (String, nil)

    The industry group the account belongs to

  • industry_type (String, nil)

    The specific industry vertical the account operates in

  • logo_url (String, nil)

    The URL of the account logo image

  • metadata (Object)

    Arbitrary key/value metadata supplied when the account was created

  • parent_account_id (String, nil)

    The parent account ID for connected accounts

  • route (String)

    The account’s public route identifier

  • send_customer_emails (Boolean)

    Whether Whop sends transactional emails to customers on behalf of this account

  • social_links (Array<WhopSDK::Models::AccountSocialLink>)
  • target_audience (String, nil)

    The target audience for this account

  • title (String)

    The display name of the account

  • wallet (WhopSDK::Models::AccountWallet, nil)

    The account’s primary crypto wallet, or null if none has been provisioned



# File 'lib/whop_sdk/models/account.rb', line 108

Instance Attribute Details

The URL of the account banner image

Returns:

  • (String, nil)


17
# File 'lib/whop_sdk/models/account.rb', line 17

required :banner_image_url, String, nil?: true

#business_typeString?

The high-level business category for the account

Returns:

  • (String, nil)


23
# File 'lib/whop_sdk/models/account.rb', line 23

required :business_type, String, nil?: true

#created_atString

When the account was created, as an ISO 8601 timestamp

Returns:

  • (String)


29
# File 'lib/whop_sdk/models/account.rb', line 29

required :created_at, String

#descriptionString?

A promotional description for the account

Returns:

  • (String, nil)


35
# File 'lib/whop_sdk/models/account.rb', line 35

required :description, String, nil?: true

#emailString?

The email address of the account owner

Returns:

  • (String, nil)


41
# File 'lib/whop_sdk/models/account.rb', line 41

required :email, String, nil?: true

#idString

The ID of the account, which will look like biz_*************

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/account.rb', line 11

required :id, String

#industry_groupString?

The industry group the account belongs to

Returns:

  • (String, nil)


47
# File 'lib/whop_sdk/models/account.rb', line 47

required :industry_group, String, nil?: true

#industry_typeString?

The specific industry vertical the account operates in

Returns:

  • (String, nil)


53
# File 'lib/whop_sdk/models/account.rb', line 53

required :industry_type, String, nil?: true

#logo_urlString?

The URL of the account logo image

Returns:

  • (String, nil)


59
# File 'lib/whop_sdk/models/account.rb', line 59

required :logo_url, String, nil?: true

#metadataObject

Arbitrary key/value metadata supplied when the account was created

Returns:

  • (Object)


65
# File 'lib/whop_sdk/models/account.rb', line 65

required :metadata, WhopSDK::Internal::Type::Unknown

#parent_account_idString?

The parent account ID for connected accounts

Returns:

  • (String, nil)


71
# File 'lib/whop_sdk/models/account.rb', line 71

required :parent_account_id, String, nil?: true

#routeString

The account’s public route identifier

Returns:

  • (String)


77
# File 'lib/whop_sdk/models/account.rb', line 77

required :route, String

#send_customer_emailsBoolean

Whether Whop sends transactional emails to customers on behalf of this account

Returns:

  • (Boolean)


83
# File 'lib/whop_sdk/models/account.rb', line 83

required :send_customer_emails, WhopSDK::Internal::Type::Boolean


88
# File 'lib/whop_sdk/models/account.rb', line 88

required :social_links, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::AccountSocialLink] }

#target_audienceString?

The target audience for this account

Returns:

  • (String, nil)


94
# File 'lib/whop_sdk/models/account.rb', line 94

required :target_audience, String, nil?: true

#titleString

The display name of the account

Returns:

  • (String)


100
# File 'lib/whop_sdk/models/account.rb', line 100

required :title, String

#walletWhopSDK::Models::AccountWallet?

The account’s primary crypto wallet, or null if none has been provisioned



106
# File 'lib/whop_sdk/models/account.rb', line 106

required :wallet, -> { WhopSDK::AccountWallet }, nil?: true