Class: WhopSDK::Models::Account::Balance
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Account::Balance
- Defined in:
- lib/whop_sdk/models/account.rb,
sig/whop_sdk/models/account.rbs
Instance Attribute Summary collapse
-
#balance ⇒ String
Total amount held in native units, as a decimal string.
-
#breakdown ⇒ Object
Balance split into available, pending, and reserve amounts, as native-unit decimal strings.
-
#icon_url ⇒ String?
Holding icon URL.
-
#name ⇒ String
The holding's display name.
-
#price_usd ⇒ Float?
USD price per unit, or
nullwhen no exchange rate is available. -
#symbol ⇒ String
Holding display symbol, such as
USDT,cbBTC, orEUR. -
#value_usd ⇒ String?
Holding USD value, or
nullwhen no exchange rate is available.
Instance Method Summary collapse
-
#initialize(id:, balances:, banner_image_url:, business_address:, business_type:, capabilities:, country:, created_at:, description:, email:, home_preferences:, industry_group:, industry_type:, invoice_prefix:, logo_url:, metadata:, onboarding_type:, opengraph_image_url:, opengraph_image_variant:, other_business_description:, other_industry_description:, parent_account_id:, product_tax_code:, recommended_actions:, require_2fa:, required_actions:, route:, send_customer_emails:, show_joined_whops:, show_reviews_dtc:, show_user_directory:, social_links:, status:, store_page_config:, target_audience:, tax_identifiers:, tax_remitted_by:, title:, total_earned_usd:, total_usd:, use_logo_as_opengraph_image_fallback:, verification:, wallet:) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhopSDK::Models::Account for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, balances:, banner_image_url:, business_address:, business_type:, capabilities:, country:, created_at:, description:, email:, home_preferences:, industry_group:, industry_type:, invoice_prefix:, logo_url:, metadata:, onboarding_type:, opengraph_image_url:, opengraph_image_variant:, other_business_description:, other_industry_description:, parent_account_id:, product_tax_code:, recommended_actions:, require_2fa:, required_actions:, route:, send_customer_emails:, show_joined_whops:, show_reviews_dtc:, show_user_directory:, social_links:, status:, store_page_config:, target_audience:, tax_identifiers:, tax_remitted_by:, title:, total_earned_usd:, total_usd:, use_logo_as_opengraph_image_fallback:, verification:, wallet:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Account for more details.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/whop_sdk/models/account.rb', line 372 class Balance < WhopSDK::Internal::Type::BaseModel # @!attribute balance # Total amount held in native units, as a decimal string. # # @return [String] required :balance, String # @!attribute breakdown # Balance split into available, pending, and reserve amounts, as native-unit # decimal strings. On-chain crypto is entirely available; good_funds and fiat cash # can have pending or reserve portions. # # @return [Object] required :breakdown, WhopSDK::Internal::Type::Unknown # @!attribute icon_url # Holding icon URL. # # @return [String, nil] required :icon_url, String, nil?: true # @!attribute name # The holding's display name # # @return [String] required :name, String # @!attribute price_usd # USD price per unit, or `null` when no exchange rate is available. # # @return [Float, nil] required :price_usd, Float, nil?: true # @!attribute symbol # Holding display symbol, such as `USDT`, `cbBTC`, or `EUR`. # # @return [String] required :symbol, String # @!attribute value_usd # Holding USD value, or `null` when no exchange rate is available. # # @return [String, nil] required :value_usd, String, nil?: true # @!method initialize(balance:, breakdown:, icon_url:, name:, price_usd:, symbol:, value_usd:) # Some parameter documentations has been truncated, see # {WhopSDK::Models::Account::Balance} for more details. # # Account holdings, each with USD value. Empty when `total_usd` is `null`. # # @param balance [String] Total amount held in native units, as a decimal string. # # @param breakdown [Object] Balance split into available, pending, and reserve amounts, as native-unit decim # # @param icon_url [String, nil] Holding icon URL. # # @param name [String] The holding's display name # # @param price_usd [Float, nil] USD price per unit, or `null` when no exchange rate is available. # # @param symbol [String] Holding display symbol, such as `USDT`, `cbBTC`, or `EUR`. # # @param value_usd [String, nil] Holding USD value, or `null` when no exchange rate is available. end |
Instance Attribute Details
#balance ⇒ String
Total amount held in native units, as a decimal string.
377 |
# File 'lib/whop_sdk/models/account.rb', line 377 required :balance, String |
#breakdown ⇒ Object
Balance split into available, pending, and reserve amounts, as native-unit decimal strings. On-chain crypto is entirely available; good_funds and fiat cash can have pending or reserve portions.
385 |
# File 'lib/whop_sdk/models/account.rb', line 385 required :breakdown, WhopSDK::Internal::Type::Unknown |
#icon_url ⇒ String?
Holding icon URL.
391 |
# File 'lib/whop_sdk/models/account.rb', line 391 required :icon_url, String, nil?: true |
#name ⇒ String
The holding's display name
397 |
# File 'lib/whop_sdk/models/account.rb', line 397 required :name, String |
#price_usd ⇒ Float?
USD price per unit, or null when no exchange rate is available.
403 |
# File 'lib/whop_sdk/models/account.rb', line 403 required :price_usd, Float, nil?: true |
#symbol ⇒ String
Holding display symbol, such as USDT, cbBTC, or EUR.
409 |
# File 'lib/whop_sdk/models/account.rb', line 409 required :symbol, String |
#value_usd ⇒ String?
Holding USD value, or null when no exchange rate is available.
415 |
# File 'lib/whop_sdk/models/account.rb', line 415 required :value_usd, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
265 |
# File 'sig/whop_sdk/models/account.rbs', line 265
def to_hash: -> {
|