Class: WhopSDK::Models::AccountLinkCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AccountLinkCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/account_link_create_params.rb
Overview
Defined Under Namespace
Modules: UseCase
Instance Attribute Summary collapse
-
#company_id ⇒ String
The unique identifier of the company to generate the link for, starting with ‘biz_’.
-
#refresh_url ⇒ String
The URL to redirect the user to if the session expires and needs to be re-authenticated, such as ‘example.com/refresh’.
-
#return_url ⇒ String
The URL to redirect the user to when they want to return to your site, such as ‘example.com/return’.
-
#use_case ⇒ Symbol, WhopSDK::Models::AccountLinkCreateParams::UseCase
The purpose of the account link, such as hosted payouts portal or hosted KYC onboarding.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(company_id:, refresh_url:, return_url:, use_case:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AccountLinkCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, refresh_url:, return_url:, use_case:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AccountLinkCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/account_link_create_params.rb', line 38
|
Instance Attribute Details
#company_id ⇒ String
The unique identifier of the company to generate the link for, starting with ‘biz_’. Must be a sub-merchant of the API key’s company.
15 |
# File 'lib/whop_sdk/models/account_link_create_params.rb', line 15 required :company_id, String |
#refresh_url ⇒ String
The URL to redirect the user to if the session expires and needs to be re-authenticated, such as ‘example.com/refresh’.
22 |
# File 'lib/whop_sdk/models/account_link_create_params.rb', line 22 required :refresh_url, String |
#return_url ⇒ String
The URL to redirect the user to when they want to return to your site, such as ‘example.com/return’.
29 |
# File 'lib/whop_sdk/models/account_link_create_params.rb', line 29 required :return_url, String |
#use_case ⇒ Symbol, WhopSDK::Models::AccountLinkCreateParams::UseCase
The purpose of the account link, such as hosted payouts portal or hosted KYC onboarding.
36 |
# File 'lib/whop_sdk/models/account_link_create_params.rb', line 36 required :use_case, enum: -> { WhopSDK::AccountLinkCreateParams::UseCase } |