Class: WhopSDK::Models::AccountLinkCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/account_link_create_params.rb

Overview

Defined Under Namespace

Modules: UseCase

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id: , refresh_url: , return_url: , use_case: , request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AccountLinkCreateParams for more details.

Parameters:

  • company_id (String) (defaults to: )

    The ID of the Company to generate the url for. The company must be a sub-merchan

  • refresh_url (String) (defaults to: )

    The URL to redirect to if the session expires and needs to be re-authenticated d

  • return_url (String) (defaults to: )

    The URL to redirect to when the customer wants to return to your site.

  • use_case (Symbol, WhopSDK::Models::AccountLinkCreateParams::UseCase) (defaults to: )

    The use case for which the link will be used.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/account_link_create_params.rb', line 36

Instance Attribute Details

#company_idString

The ID of the Company to generate the url for. The company must be a sub-merchant of the API key’s company.

Returns:

  • (String)


15
# File 'lib/whop_sdk/models/account_link_create_params.rb', line 15

required :company_id, String

#refresh_urlString

The URL to redirect to if the session expires and needs to be re-authenticated due to the token expiring.

Returns:

  • (String)


22
# File 'lib/whop_sdk/models/account_link_create_params.rb', line 22

required :refresh_url, String

#return_urlString

The URL to redirect to when the customer wants to return to your site.

Returns:

  • (String)


28
# File 'lib/whop_sdk/models/account_link_create_params.rb', line 28

required :return_url, String

#use_caseSymbol, WhopSDK::Models::AccountLinkCreateParams::UseCase

The use case for which the link will be used.



34
# File 'lib/whop_sdk/models/account_link_create_params.rb', line 34

required :use_case, enum: -> { WhopSDK::AccountLinkCreateParams::UseCase }