Class: WhopSDK::Models::AccountRecommendActionsResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AccountRecommendActionsResponse::Data
- Defined in:
- lib/whop_sdk/models/account_recommend_actions_response.rb,
sig/whop_sdk/models/account_recommend_actions_response.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#action ⇒ Symbol, WhopSDK::Models::AccountRecommendActionsResponse::Data::Action
The recommendation; new values may be added, so handle unknown actions gracefully.
- #blocked_capabilities ⇒ Array<String>
-
#cta ⇒ String
The URL the call-to-action links to.
-
#cta_label ⇒ String
Button label.
-
#description ⇒ String
Supporting copy, or empty.
-
#icon_url ⇒ String?
Illustration icon URL, or
null. -
#impact_score ⇒ Integer?
Estimated revenue impact from 0-100, comparable across accounts, or
nullwhen not ranked. -
#reasoning ⇒ String?
Why this action was recommended for this account, or
null. -
#status ⇒ Symbol, WhopSDK::Models::AccountRecommendActionsResponse::Data::Status
Always optional — never blocking.
-
#title ⇒ String
Headline for the recommendation.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(action:, blocked_capabilities:, cta:, cta_label:, description:, icon_url:, impact_score:, reasoning:, status:, title:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(action:, blocked_capabilities:, cta:, cta_label:, description:, icon_url:, impact_score:, reasoning:, status:, title:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AccountRecommendActionsResponse::Data for more details.
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 16 class Data < WhopSDK::Internal::Type::BaseModel # @!attribute action # The recommendation; new values may be added, so handle unknown actions # gracefully # # @return [Symbol, WhopSDK::Models::AccountRecommendActionsResponse::Data::Action] required :action, enum: -> { WhopSDK::Models::AccountRecommendActionsResponse::Data::Action } # @!attribute blocked_capabilities # # @return [Array<String>] required :blocked_capabilities, WhopSDK::Internal::Type::ArrayOf[String] # @!attribute cta # The URL the call-to-action links to # # @return [String] required :cta, String # @!attribute cta_label # Button label # # @return [String] required :cta_label, String # @!attribute description # Supporting copy, or empty # # @return [String] required :description, String # @!attribute icon_url # Illustration icon URL, or `null` # # @return [String, nil] required :icon_url, String, nil?: true # @!attribute impact_score # Estimated revenue impact from 0-100, comparable across accounts, or `null` when # not ranked # # @return [Integer, nil] required :impact_score, Integer, nil?: true # @!attribute reasoning # Why this action was recommended for this account, or `null` # # @return [String, nil] required :reasoning, String, nil?: true # @!attribute status # Always optional — never blocking # # @return [Symbol, WhopSDK::Models::AccountRecommendActionsResponse::Data::Status] required :status, enum: -> { WhopSDK::Models::AccountRecommendActionsResponse::Data::Status } # @!attribute title # Headline for the recommendation # # @return [String] required :title, String # @!method initialize(action:, blocked_capabilities:, cta:, cta_label:, description:, icon_url:, impact_score:, reasoning:, status:, title:) # Some parameter documentations has been truncated, see # {WhopSDK::Models::AccountRecommendActionsResponse::Data} for more details. # # @param action [Symbol, WhopSDK::Models::AccountRecommendActionsResponse::Data::Action] The recommendation; new values may be added, so handle unknown actions gracefull # # @param blocked_capabilities [Array<String>] # # @param cta [String] The URL the call-to-action links to # # @param cta_label [String] Button label # # @param description [String] Supporting copy, or empty # # @param icon_url [String, nil] Illustration icon URL, or `null` # # @param impact_score [Integer, nil] Estimated revenue impact from 0-100, comparable across accounts, or `null` when # # @param reasoning [String, nil] Why this action was recommended for this account, or `null` # # @param status [Symbol, WhopSDK::Models::AccountRecommendActionsResponse::Data::Status] Always optional — never blocking # # @param title [String] Headline for the recommendation # The recommendation; new values may be added, so handle unknown actions # gracefully # # @see WhopSDK::Models::AccountRecommendActionsResponse::Data#action module Action extend WhopSDK::Internal::Type::Enum THEME_BUSINESS = :theme_business CREATE_PRODUCT = :create_product CREATE_PLAN = :create_plan VERIFY_IDENTITY = :verify_identity CONNECT_AFFILIATE_PROGRAM = :connect_affiliate_program CREATE_PROMOTION = :create_promotion SETUP_TRACKING_PIXEL = :setup_tracking_pixel MIGRATE_FROM_STRIPE = :migrate_from_stripe ACCEPT_FIRST_PAYMENT = :accept_first_payment LAUNCH_FIRST_AD = :launch_first_ad INVITE_TEAM_MEMBER = :invite_team_member ENABLE_TAX_COLLECTION = :enable_tax_collection CREATE_CARD = :create_card JOIN_WHOP_UNIVERSITY = :join_whop_university APPLY_FOR_FINANCING = :apply_for_financing # @!method self.values # @return [Array<Symbol>] end # Always optional — never blocking # # @see WhopSDK::Models::AccountRecommendActionsResponse::Data#status module Status extend WhopSDK::Internal::Type::Enum OPTIONAL = :optional # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#action ⇒ Symbol, WhopSDK::Models::AccountRecommendActionsResponse::Data::Action
The recommendation; new values may be added, so handle unknown actions gracefully
22 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 22 required :action, enum: -> { WhopSDK::Models::AccountRecommendActionsResponse::Data::Action } |
#blocked_capabilities ⇒ Array<String>
27 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 27 required :blocked_capabilities, WhopSDK::Internal::Type::ArrayOf[String] |
#cta ⇒ String
The URL the call-to-action links to
33 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 33 required :cta, String |
#cta_label ⇒ String
Button label
39 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 39 required :cta_label, String |
#description ⇒ String
Supporting copy, or empty
45 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 45 required :description, String |
#icon_url ⇒ String?
Illustration icon URL, or null
51 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 51 required :icon_url, String, nil?: true |
#impact_score ⇒ Integer?
Estimated revenue impact from 0-100, comparable across accounts, or null when
not ranked
58 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 58 required :impact_score, Integer, nil?: true |
#reasoning ⇒ String?
Why this action was recommended for this account, or null
64 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 64 required :reasoning, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::AccountRecommendActionsResponse::Data::Status
Always optional — never blocking
70 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 70 required :status, enum: -> { WhopSDK::Models::AccountRecommendActionsResponse::Data::Status } |
#title ⇒ String
Headline for the recommendation
76 |
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 76 required :title, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/account_recommend_actions_response.rb', line 125
|
Instance Method Details
#to_hash ⇒ {
65 |
# File 'sig/whop_sdk/models/account_recommend_actions_response.rbs', line 65
def to_hash: -> {
|