Class: WhopSDK::Models::AccountUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AccountUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/account_update_params.rb,
sig/whop_sdk/models/account_update_params.rbs
Overview
Defined Under Namespace
Modules: TaxRemittedBy Classes: BusinessAddress, TaxIdentifier
Instance Attribute Summary collapse
- #account_id ⇒ String
-
#affiliate_application_required ⇒ Boolean?
Whether prospective affiliates must submit an application before promoting this account.
-
#affiliate_instructions ⇒ String?
Guidelines shown to affiliates promoting this account.
-
#banner_image ⇒ Hash{Symbol=>Object}?
Attachment input for the account banner image.
-
#business_address ⇒ WhopSDK::Models::AccountUpdateParams::BusinessAddress?
Account business address used to calculate tax.
-
#business_type ⇒ String?
High-level business category for the account.
-
#country ⇒ String?
Country where the account is located.
-
#description ⇒ String?
Account promotional description.
-
#featured_affiliate_product_id ⇒ String?
The ID of the product to feature for affiliates.
-
#home_preferences ⇒ Array<String>?
Public account home page preferences.
-
#industry_group ⇒ String?
Account industry group.
-
#industry_type ⇒ String?
Specific industry vertical for the account.
-
#invoice_prefix ⇒ String?
Prefix used for account invoices.
-
#logo ⇒ Hash{Symbol=>Object}?
Attachment input for the account logo.
-
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key/value metadata to store on the account.
-
#onboarding_type ⇒ String?
The type of onboarding the account has completed.
-
#opengraph_image ⇒ Hash{Symbol=>Object}?
Attachment input for the account Open Graph image.
-
#opengraph_image_variant ⇒ String?
The account Open Graph image variant.
-
#other_business_description ⇒ String?
The description of the business type when business_type is other.
-
#other_industry_description ⇒ String?
The description of the industry type when industry_type is other.
-
#product_tax_code_id ⇒ String?
ID of the tax classification code applied by default to the account's products.
-
#require_2fa ⇒ Boolean?
Whether the account requires authorized users to have two-factor authentication enabled.
-
#route ⇒ String?
The unique URL slug for the account.
-
#send_customer_emails ⇒ Boolean?
Whether Whop sends transactional emails to customers on behalf of this account.
-
#show_joined_whops ⇒ Boolean?
Whether the account appears in joined whops on other accounts.
-
#show_reviews_dtc ⇒ Boolean?
Whether reviews are displayed on direct-to-consumer product pages.
-
#show_user_directory ⇒ Boolean?
Whether the account shows users in the user directory.
-
#social_links ⇒ Array<Hash{Symbol=>Object}>?
The full list of social links to display for the account.
-
#store_page_config ⇒ Hash{Symbol=>Object}?
Account store page display configuration.
-
#target_audience ⇒ String?
The target audience for this account.
-
#tax_identifiers ⇒ Array<WhopSDK::Models::AccountUpdateParams::TaxIdentifier>?
Account tax/VAT registrations to add or update.
-
#tax_remitted_by ⇒ Symbol, ...
Who calculates and remits tax for the account:
whop(Whop calculates and remits),self(Whop calculates; the account collects and remits), ornone(neither; the account is responsible). -
#title ⇒ String?
The display name of the account.
-
#use_logo_as_opengraph_image_fallback ⇒ Boolean?
Whether the account uses its logo as the fallback Open Graph image.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
constructor
Account business address used to calculate tax.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
Account business address used to calculate tax. A complete address in a
supported country is required when tax_remitted_by is self.
|
|
# File 'lib/whop_sdk/models/account_update_params.rb', line 338
|
Instance Attribute Details
#account_id ⇒ String
13 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 13 required :account_id, String |
#affiliate_application_required ⇒ Boolean?
Whether prospective affiliates must submit an application before promoting this account.
20 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 20 optional :affiliate_application_required, WhopSDK::Internal::Type::Boolean |
#affiliate_instructions ⇒ String?
Guidelines shown to affiliates promoting this account.
26 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 26 optional :affiliate_instructions, String, nil?: true |
#banner_image ⇒ Hash{Symbol=>Object}?
Attachment input for the account banner image.
32 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 32 optional :banner_image, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#business_address ⇒ WhopSDK::Models::AccountUpdateParams::BusinessAddress?
Account business address used to calculate tax. A complete address in a
supported country is required when tax_remitted_by is self.
39 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 39 optional :business_address, -> { WhopSDK::AccountUpdateParams::BusinessAddress } |
#business_type ⇒ String?
High-level business category for the account.
45 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 45 optional :business_type, String, nil?: true |
#country ⇒ String?
Country where the account is located.
51 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 51 optional :country, String, nil?: true |
#description ⇒ String?
Account promotional description.
57 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 57 optional :description, String, nil?: true |
#featured_affiliate_product_id ⇒ String?
The ID of the product to feature for affiliates. Pass null to clear.
63 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 63 optional :featured_affiliate_product_id, String, nil?: true |
#home_preferences ⇒ Array<String>?
Public account home page preferences.
69 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 69 optional :home_preferences, WhopSDK::Internal::Type::ArrayOf[String] |
#industry_group ⇒ String?
Account industry group.
75 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 75 optional :industry_group, String, nil?: true |
#industry_type ⇒ String?
Specific industry vertical for the account.
81 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 81 optional :industry_type, String, nil?: true |
#invoice_prefix ⇒ String?
Prefix used for account invoices.
87 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 87 optional :invoice_prefix, String, nil?: true |
#logo ⇒ Hash{Symbol=>Object}?
Attachment input for the account logo.
93 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 93 optional :logo, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Arbitrary key/value metadata to store on the account.
99 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 99 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown] |
#onboarding_type ⇒ String?
The type of onboarding the account has completed.
105 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 105 optional :onboarding_type, String, nil?: true |
#opengraph_image ⇒ Hash{Symbol=>Object}?
Attachment input for the account Open Graph image.
111 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 111 optional :opengraph_image, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#opengraph_image_variant ⇒ String?
The account Open Graph image variant.
117 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 117 optional :opengraph_image_variant, String, nil?: true |
#other_business_description ⇒ String?
The description of the business type when business_type is other.
123 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 123 optional :other_business_description, String, nil?: true |
#other_industry_description ⇒ String?
The description of the industry type when industry_type is other.
129 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 129 optional :other_industry_description, String, nil?: true |
#product_tax_code_id ⇒ String?
ID of the tax classification code applied by default to the account's products. See the available product categories.
137 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 137 optional :product_tax_code_id, String, nil?: true |
#require_2fa ⇒ Boolean?
Whether the account requires authorized users to have two-factor authentication enabled.
144 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 144 optional :require_2fa, WhopSDK::Internal::Type::Boolean |
#route ⇒ String?
The unique URL slug for the account.
150 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 150 optional :route, String, nil?: true |
#send_customer_emails ⇒ Boolean?
Whether Whop sends transactional emails to customers on behalf of this account.
156 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 156 optional :send_customer_emails, WhopSDK::Internal::Type::Boolean |
#show_joined_whops ⇒ Boolean?
Whether the account appears in joined whops on other accounts.
162 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 162 optional :show_joined_whops, WhopSDK::Internal::Type::Boolean |
#show_reviews_dtc ⇒ Boolean?
Whether reviews are displayed on direct-to-consumer product pages.
168 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 168 optional :show_reviews_dtc, WhopSDK::Internal::Type::Boolean |
#show_user_directory ⇒ Boolean?
Whether the account shows users in the user directory.
174 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 174 optional :show_user_directory, WhopSDK::Internal::Type::Boolean |
#social_links ⇒ Array<Hash{Symbol=>Object}>?
The full list of social links to display for the account.
180 181 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 180 optional :social_links, WhopSDK::Internal::Type::ArrayOf[WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown]] |
#store_page_config ⇒ Hash{Symbol=>Object}?
Account store page display configuration.
187 188 189 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 187 optional :store_page_config, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#target_audience ⇒ String?
The target audience for this account.
195 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 195 optional :target_audience, String, nil?: true |
#tax_identifiers ⇒ Array<WhopSDK::Models::AccountUpdateParams::TaxIdentifier>?
Account tax/VAT registrations to add or update. When tax_remitted_by is
self, tax is calculated and collected only in the countries where the account
holds a registration.
203 204 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 203 optional :tax_identifiers, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::AccountUpdateParams::TaxIdentifier] } |
#tax_remitted_by ⇒ Symbol, ...
Who calculates and remits tax for the account: whop (Whop calculates and
remits), self (Whop calculates; the account collects and remits), or none
(neither; the account is responsible). self requires a business_address in a
supported country.
213 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 213 optional :tax_remitted_by, enum: -> { WhopSDK::AccountUpdateParams::TaxRemittedBy } |
#title ⇒ String?
The display name of the account.
219 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 219 optional :title, String, nil?: true |
#use_logo_as_opengraph_image_fallback ⇒ Boolean?
Whether the account uses its logo as the fallback Open Graph image.
225 |
# File 'lib/whop_sdk/models/account_update_params.rb', line 225 optional :use_logo_as_opengraph_image_fallback, WhopSDK::Internal::Type::Boolean |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/account_update_params.rb', line 491
|
Instance Method Details
#to_hash ⇒ {
186 |
# File 'sig/whop_sdk/models/account_update_params.rbs', line 186
def to_hash: -> {
|