Class: WhopSDK::Models::AccountUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/account_update_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(account_id:, affiliate_application_required: nil, affiliate_instructions: nil, banner_image: nil, business_type: nil, description: nil, featured_affiliate_product_id: nil, industry_group: nil, industry_type: nil, logo: nil, metadata: nil, route: nil, send_customer_emails: nil, social_links: nil, target_audience: nil, title: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AccountUpdateParams for more details.

Parameters:

  • account_id (String)
  • affiliate_application_required (Boolean) (defaults to: nil)

    Whether prospective affiliates must submit an application before promoting this

  • affiliate_instructions (String, nil) (defaults to: nil)

    Guidelines shown to affiliates promoting this account.

  • banner_image (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Attachment input for the account banner image.

  • business_type (String, nil) (defaults to: nil)

    The high-level business category for the account.

  • description (String, nil) (defaults to: nil)

    A promotional description for the account.

  • featured_affiliate_product_id (String, nil) (defaults to: nil)

    The ID of the product to feature for affiliates. Pass null to clear.

  • industry_group (String, nil) (defaults to: nil)

    The industry group the account belongs to.

  • industry_type (String, nil) (defaults to: nil)

    The specific industry vertical the account operates in.

  • logo (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Attachment input for the account logo.

  • metadata (Hash{Symbol=>Object}) (defaults to: nil)

    Arbitrary key/value metadata to store on the account.

  • route (String, nil) (defaults to: nil)

    The unique URL slug for the account.

  • send_customer_emails (Boolean) (defaults to: nil)

    Whether Whop sends transactional emails to customers on behalf of this account.

  • social_links (Array<Hash{Symbol=>Object}>) (defaults to: nil)

    The full list of social links to display for the account.

  • target_audience (String, nil) (defaults to: nil)

    The target audience for this account.

  • title (String, nil) (defaults to: nil)

    The display name of the account.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/account_update_params.rb', line 107

Instance Attribute Details

#account_idString

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/account_update_params.rb', line 13

required :account_id, String

#affiliate_application_requiredBoolean?

Whether prospective affiliates must submit an application before promoting this account.

Returns:

  • (Boolean, nil)


20
# File 'lib/whop_sdk/models/account_update_params.rb', line 20

optional :affiliate_application_required, WhopSDK::Internal::Type::Boolean

#affiliate_instructionsString?

Guidelines shown to affiliates promoting this account.

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/account_update_params.rb', line 26

optional :affiliate_instructions, String, nil?: true

Attachment input for the account banner image.

Returns:

  • (Hash{Symbol=>Object}, nil)


32
# File 'lib/whop_sdk/models/account_update_params.rb', line 32

optional :banner_image, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#business_typeString?

The high-level business category for the account.

Returns:

  • (String, nil)


38
# File 'lib/whop_sdk/models/account_update_params.rb', line 38

optional :business_type, String, nil?: true

#descriptionString?

A promotional description for the account.

Returns:

  • (String, nil)


44
# File 'lib/whop_sdk/models/account_update_params.rb', line 44

optional :description, String, nil?: true

The ID of the product to feature for affiliates. Pass null to clear.

Returns:

  • (String, nil)


50
# File 'lib/whop_sdk/models/account_update_params.rb', line 50

optional :featured_affiliate_product_id, String, nil?: true

#industry_groupString?

The industry group the account belongs to.

Returns:

  • (String, nil)


56
# File 'lib/whop_sdk/models/account_update_params.rb', line 56

optional :industry_group, String, nil?: true

#industry_typeString?

The specific industry vertical the account operates in.

Returns:

  • (String, nil)


62
# File 'lib/whop_sdk/models/account_update_params.rb', line 62

optional :industry_type, String, nil?: true

#logoHash{Symbol=>Object}?

Attachment input for the account logo.

Returns:

  • (Hash{Symbol=>Object}, nil)


68
# File 'lib/whop_sdk/models/account_update_params.rb', line 68

optional :logo, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#metadataHash{Symbol=>Object}?

Arbitrary key/value metadata to store on the account.

Returns:

  • (Hash{Symbol=>Object}, nil)


74
# File 'lib/whop_sdk/models/account_update_params.rb', line 74

optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown]

#routeString?

The unique URL slug for the account.

Returns:

  • (String, nil)


80
# File 'lib/whop_sdk/models/account_update_params.rb', line 80

optional :route, String, nil?: true

#send_customer_emailsBoolean?

Whether Whop sends transactional emails to customers on behalf of this account.

Returns:

  • (Boolean, nil)


86
# File 'lib/whop_sdk/models/account_update_params.rb', line 86

optional :send_customer_emails, WhopSDK::Internal::Type::Boolean

The full list of social links to display for the account.

Returns:

  • (Array<Hash{Symbol=>Object}>, nil)


92
93
# File 'lib/whop_sdk/models/account_update_params.rb', line 92

optional :social_links,
WhopSDK::Internal::Type::ArrayOf[WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown]]

#target_audienceString?

The target audience for this account.

Returns:

  • (String, nil)


99
# File 'lib/whop_sdk/models/account_update_params.rb', line 99

optional :target_audience, String, nil?: true

#titleString?

The display name of the account.

Returns:

  • (String, nil)


105
# File 'lib/whop_sdk/models/account_update_params.rb', line 105

optional :title, String, nil?: true