Class: WhopSDK::Models::Ad
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Ad
- Defined in:
- lib/whop_sdk/models/ad.rb
Overview
Defined Under Namespace
Classes: AdCampaign, AdGroup
Instance Attribute Summary collapse
-
#ad_campaign ⇒ WhopSDK::Models::Ad::AdCampaign
The ad campaign this ad belongs to.
-
#ad_group ⇒ WhopSDK::Models::Ad::AdGroup
The parent ad group this ad belongs to.
-
#created_at ⇒ Time
When the ad was created.
-
#id ⇒ String
The unique identifier for this ad.
-
#platform ⇒ Symbol, WhopSDK::Models::AdCampaignPlatform
The external ad platform this ad is running on (e.g., meta, tiktok).
-
#status ⇒ Symbol, WhopSDK::Models::ExternalAdStatus
Current delivery status of the ad.
-
#title ⇒ String?
The display title of the ad.
-
#updated_at ⇒ Time
When the ad was last updated.
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
The ad campaign this ad belongs to.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
The ad campaign this ad belongs to.
|
|
# File 'lib/whop_sdk/models/ad.rb', line 55
|
Instance Attribute Details
#ad_campaign ⇒ WhopSDK::Models::Ad::AdCampaign
The ad campaign this ad belongs to.
17 |
# File 'lib/whop_sdk/models/ad.rb', line 17 required :ad_campaign, -> { WhopSDK::Ad::AdCampaign } |
#ad_group ⇒ WhopSDK::Models::Ad::AdGroup
The parent ad group this ad belongs to.
23 |
# File 'lib/whop_sdk/models/ad.rb', line 23 required :ad_group, -> { WhopSDK::Ad::AdGroup } |
#created_at ⇒ Time
When the ad was created.
29 |
# File 'lib/whop_sdk/models/ad.rb', line 29 required :created_at, Time |
#id ⇒ String
The unique identifier for this ad.
11 |
# File 'lib/whop_sdk/models/ad.rb', line 11 required :id, String |
#platform ⇒ Symbol, WhopSDK::Models::AdCampaignPlatform
The external ad platform this ad is running on (e.g., meta, tiktok).
35 |
# File 'lib/whop_sdk/models/ad.rb', line 35 required :platform, enum: -> { WhopSDK::AdCampaignPlatform } |
#status ⇒ Symbol, WhopSDK::Models::ExternalAdStatus
Current delivery status of the ad.
41 |
# File 'lib/whop_sdk/models/ad.rb', line 41 required :status, enum: -> { WhopSDK::ExternalAdStatus } |
#title ⇒ String?
The display title of the ad. Falls back to the creative set caption when unset.
47 |
# File 'lib/whop_sdk/models/ad.rb', line 47 required :title, String, nil?: true |
#updated_at ⇒ Time
When the ad was last updated.
53 |
# File 'lib/whop_sdk/models/ad.rb', line 53 required :updated_at, Time |