Class: WhopSDK::Models::Ad::Creative
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Ad::Creative
- Defined in:
- lib/whop_sdk/models/ad.rb,
sig/whop_sdk/models/ad.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#crop ⇒ WhopSDK::Models::Ad::Creative::Crop?
The saved crop window for this creative, in source image pixels.
-
#format_ ⇒ Symbol, ...
The placement variant this asset covers, or null for the original asset.
-
#id ⇒ String
The creative attachment's file id.
-
#media_type ⇒ String?
The kind of asset, image or video.
-
#url ⇒ String?
CDN url of the asset.
Instance Method Summary collapse
-
#initialize(height:, width:, x:, y_:) ⇒ Object
constructor
The saved crop window for this creative, in source image pixels.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(height:, width:, x:, y_:) ⇒ Object
The saved crop window for this creative, in source image pixels. Null for the original asset or a format that has not been cropped.
|
|
# File 'lib/whop_sdk/models/ad.rb', line 611
|
Instance Attribute Details
#crop ⇒ WhopSDK::Models::Ad::Creative::Crop?
The saved crop window for this creative, in source image pixels. Null for the original asset or a format that has not been cropped.
591 |
# File 'lib/whop_sdk/models/ad.rb', line 591 required :crop, -> { WhopSDK::Ad::Creative::Crop }, nil?: true |
#format_ ⇒ Symbol, ...
The placement variant this asset covers, or null for the original asset.
597 |
# File 'lib/whop_sdk/models/ad.rb', line 597 required :format_, enum: -> { WhopSDK::Ad::Creative::Format }, api_name: :format, nil?: true |
#id ⇒ String
The creative attachment's file id.
584 |
# File 'lib/whop_sdk/models/ad.rb', line 584 required :id, String |
#media_type ⇒ String?
The kind of asset, image or video.
603 |
# File 'lib/whop_sdk/models/ad.rb', line 603 required :media_type, String, nil?: true |
#url ⇒ String?
CDN url of the asset.
609 |
# File 'lib/whop_sdk/models/ad.rb', line 609 required :url, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
428 |
# File 'sig/whop_sdk/models/ad.rbs', line 428
def to_hash: -> {
|