Class: WhopSDK::Models::Ad::Creative::Crop
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Ad::Creative::Crop
- Defined in:
- lib/whop_sdk/models/ad.rb,
sig/whop_sdk/models/ad.rbs
Overview
Instance Attribute Summary collapse
-
#height ⇒ Float
Height of the crop window in source pixels.
-
#width ⇒ Float
Width of the crop window in source pixels.
-
#x ⇒ Float
Left edge of the crop window in source pixels.
-
#y_ ⇒ Float
Top edge of the crop window in source pixels.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
447 |
# File 'sig/whop_sdk/models/ad.rbs', line 447
def initialize: (
|
Instance Attribute Details
#height ⇒ Float
Height of the crop window in source pixels.
634 |
# File 'lib/whop_sdk/models/ad.rb', line 634 required :height, Float |
#width ⇒ Float
Width of the crop window in source pixels.
640 |
# File 'lib/whop_sdk/models/ad.rb', line 640 required :width, Float |
#x ⇒ Float
Left edge of the crop window in source pixels.
646 |
# File 'lib/whop_sdk/models/ad.rb', line 646 required :x, Float |
#y_ ⇒ Float
Top edge of the crop window in source pixels.
652 |
# File 'lib/whop_sdk/models/ad.rb', line 652 required :y_, Float, api_name: :y |
Instance Method Details
#to_hash ⇒ { height: Float, width: Float, x: Float, y_: Float }
454 |
# File 'sig/whop_sdk/models/ad.rbs', line 454
def to_hash: -> { height: Float, width: Float, x: Float, y_: Float }
|