Class: WhopSDK::Models::AdCampaignListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AdCampaignListResponse
- Defined in:
- lib/whop_sdk/models/ad_campaign_list_response.rb
Overview
Instance Attribute Summary collapse
-
#budget ⇒ Float?
Total budget in dollars.
-
#budget_type ⇒ Symbol, ...
The budget type for an ad campaign or ad group.
-
#created_at ⇒ Time
When the ad campaign was created.
-
#id ⇒ String
The unique identifier for this ad campaign.
-
#platform ⇒ Symbol, WhopSDK::Models::AdCampaignPlatform
The external ad platform this campaign is running on (e.g., meta, tiktok).
-
#status ⇒ Symbol, WhopSDK::Models::AdCampaignStatus
Current status of the campaign (active, paused, or inactive).
-
#title ⇒ String
The campaign name shown in the Whop dashboard.
-
#total_spend ⇒ Float
Total amount spent in dollars.
-
#updated_at ⇒ Time
When the ad campaign was last updated.
Instance Method Summary collapse
-
#initialize(id:, budget:, budget_type:, created_at:, platform:, status:, title:, total_spend:, updated_at:) ⇒ Object
constructor
An advertising campaign running on an external platform or within Whop.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, budget:, budget_type:, created_at:, platform:, status:, title:, total_spend:, updated_at:) ⇒ Object
An advertising campaign running on an external platform or within Whop.
|
|
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 61
|
Instance Attribute Details
#budget ⇒ Float?
Total budget in dollars.
17 |
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 17 required :budget, Float, nil?: true |
#budget_type ⇒ Symbol, ...
The budget type for an ad campaign or ad group.
23 |
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 23 required :budget_type, enum: -> { WhopSDK::AdBudgetType }, nil?: true |
#created_at ⇒ Time
When the ad campaign was created.
29 |
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 29 required :created_at, Time |
#id ⇒ String
The unique identifier for this ad campaign.
11 |
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 11 required :id, String |
#platform ⇒ Symbol, WhopSDK::Models::AdCampaignPlatform
The external ad platform this campaign is running on (e.g., meta, tiktok).
35 |
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 35 required :platform, enum: -> { WhopSDK::AdCampaignPlatform } |
#status ⇒ Symbol, WhopSDK::Models::AdCampaignStatus
Current status of the campaign (active, paused, or inactive).
41 |
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 41 required :status, enum: -> { WhopSDK::AdCampaignStatus } |
#title ⇒ String
The campaign name shown in the Whop dashboard.
47 |
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 47 required :title, String |
#total_spend ⇒ Float
Total amount spent in dollars.
53 |
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 53 required :total_spend, Float |
#updated_at ⇒ Time
When the ad campaign was last updated.
59 |
# File 'lib/whop_sdk/models/ad_campaign_list_response.rb', line 59 required :updated_at, Time |