Class: WhopSDK::Models::AdCreateParams::Creative
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AdCreateParams::Creative
- Defined in:
- lib/whop_sdk/models/ad_create_params.rb,
sig/whop_sdk/models/ad_create_params.rbs
Defined Under Namespace
Instance Attribute Summary collapse
-
#crop ⇒ WhopSDK::Models::AdCreateParams::Creative::Crop?
The saved crop window for this creative, in source image pixels.
- #format_ ⇒ Symbol, ...
- #id ⇒ String?
Instance Method Summary collapse
-
#initialize(height: nil, width: nil, x: nil, y_: nil) ⇒ Object
constructor
The saved crop window for this creative, in source image pixels.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(height: nil, width: nil, x: nil, y_: nil) ⇒ Object
The saved crop window for this creative, in source image pixels. Omit it for the original asset or for a format that has not been cropped.
|
|
# File 'lib/whop_sdk/models/ad_create_params.rb', line 214
|
Instance Attribute Details
#crop ⇒ WhopSDK::Models::AdCreateParams::Creative::Crop?
The saved crop window for this creative, in source image pixels. Omit it for the original asset or for a format that has not been cropped.
207 |
# File 'lib/whop_sdk/models/ad_create_params.rb', line 207 optional :crop, -> { WhopSDK::AdCreateParams::Creative::Crop } |
#format_ ⇒ Symbol, ...
212 |
# File 'lib/whop_sdk/models/ad_create_params.rb', line 212 optional :format_, enum: -> { WhopSDK::AdCreateParams::Creative::Format }, api_name: :format |
#id ⇒ String?
200 |
# File 'lib/whop_sdk/models/ad_create_params.rb', line 200 optional :id, String |
Instance Method Details
#to_hash ⇒ {
234 |
# File 'sig/whop_sdk/models/ad_create_params.rbs', line 234
def to_hash: -> {
|