Module: WhopSDK::Models::AdGroup::ResultEvent
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/whop_sdk/models/ad_group.rb,
sig/whop_sdk/models/ad_group.rbs
Overview
The Whop pixel conversion event whose attributed count represents results — the optimization goal, or the highest-volume attributed event for campaigns that budget per ad group. Null when the goal isn't a Whop-attributed event.
Constant Summary collapse
- PURCHASE =
:purchase- LEAD =
:lead- SCHEDULE =
:schedule- SUBMIT_APPLICATION =
:submit_application- CONTACT =
:contact- COMPLETE_REGISTRATION =
:complete_registration- VIEW_CONTENT =
:view_content- ADD_TO_CART =
:add_to_cart- CUSTOM =
:custom
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[WhopSDK::Models::AdGroup::result_event]
527 |
# File 'sig/whop_sdk/models/ad_group.rbs', line 527
def self?.values: -> ::Array[WhopSDK::Models::AdGroup::result_event]
|