Class: WhopSDK::Models::AdGroupListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AdGroupListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/ad_group_list_params.rb
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#campaign_id ⇒ String?
Filter by campaign.
-
#company_id ⇒ String?
Filter by company.
-
#created_after ⇒ Time?
Only return ad groups created after this timestamp.
-
#created_before ⇒ Time?
Only return ad groups created before this timestamp.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#include_paused ⇒ Boolean?
When false, excludes paused ad groups so pagination matches the dashboard’s hide-paused toggle.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#query ⇒ String?
Case-insensitive substring match against the ad group name.
-
#status ⇒ Symbol, ...
The status of an external ad group.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, before: nil, campaign_id: nil, company_id: nil, created_after: nil, created_before: nil, first: nil, include_paused: nil, last: nil, query: nil, status: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AdGroupListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, campaign_id: nil, company_id: nil, created_after: nil, created_before: nil, first: nil, include_paused: nil, last: nil, query: nil, status: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AdGroupListParams for more details.
|
|
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 77
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
14 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 14 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
20 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 20 optional :before, String, nil?: true |
#campaign_id ⇒ String?
Filter by campaign. Provide exactly one of campaign_id or company_id.
26 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 26 optional :campaign_id, String, nil?: true |
#company_id ⇒ String?
Filter by company. Provide exactly one of campaign_id or company_id.
32 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 32 optional :company_id, String, nil?: true |
#created_after ⇒ Time?
Only return ad groups created after this timestamp.
38 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 38 optional :created_after, Time, nil?: true |
#created_before ⇒ Time?
Only return ad groups created before this timestamp.
44 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 44 optional :created_before, Time, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
50 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 50 optional :first, Integer, nil?: true |
#include_paused ⇒ Boolean?
When false, excludes paused ad groups so pagination matches the dashboard’s hide-paused toggle.
57 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 57 optional :include_paused, WhopSDK::Internal::Type::Boolean, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
63 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 63 optional :last, Integer, nil?: true |
#query ⇒ String?
Case-insensitive substring match against the ad group name.
69 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 69 optional :query, String, nil?: true |
#status ⇒ Symbol, ...
The status of an external ad group.
75 |
# File 'lib/whop_sdk/models/ad_group_list_params.rb', line 75 optional :status, enum: -> { WhopSDK::AdGroupStatus }, nil?: true |