Class: WhopSDK::Models::AdGroupUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AdGroupUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/ad_group_update_params.rb
Overview
Defined Under Namespace
Classes: Config, PlatformConfig
Instance Attribute Summary collapse
-
#budget ⇒ Float?
Budget amount in dollars.
-
#budget_type ⇒ Symbol, ...
The budget type for an ad campaign or ad group.
-
#config ⇒ WhopSDK::Models::AdGroupUpdateParams::Config?
Unified ad group configuration (bidding, optimization, targeting).
-
#daily_budget ⇒ Float?
Daily budget in dollars.
- #id ⇒ String
-
#name ⇒ String?
Human-readable ad group name.
-
#platform_config ⇒ WhopSDK::Models::AdGroupUpdateParams::PlatformConfig?
Platform-specific ad group configuration.
-
#status ⇒ Symbol, ...
The status of an external ad group.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#budget ⇒ Float?
Budget amount in dollars.
19 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 19 optional :budget, Float, nil?: true |
#budget_type ⇒ Symbol, ...
The budget type for an ad campaign or ad group.
25 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 25 optional :budget_type, enum: -> { WhopSDK::AdBudgetType }, nil?: true |
#config ⇒ WhopSDK::Models::AdGroupUpdateParams::Config?
Unified ad group configuration (bidding, optimization, targeting).
31 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 31 optional :config, -> { WhopSDK::AdGroupUpdateParams::Config }, nil?: true |
#daily_budget ⇒ Float?
Daily budget in dollars.
37 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 37 optional :daily_budget, Float, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 13 required :id, String |
#name ⇒ String?
Human-readable ad group name.
43 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 43 optional :name, String, nil?: true |
#platform_config ⇒ WhopSDK::Models::AdGroupUpdateParams::PlatformConfig?
Platform-specific ad group configuration.
49 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 49 optional :platform_config, -> { WhopSDK::AdGroupUpdateParams::PlatformConfig }, nil?: true |
#status ⇒ Symbol, ...
The status of an external ad group.
55 |
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 55 optional :status, enum: -> { WhopSDK::AdGroupStatus }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/ad_group_update_params.rb', line 359
|