Module: WhopSDK::Models::AdGroupUpdateParams::ConversionLocation
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/whop_sdk/models/ad_group_update_params.rb,
sig/whop_sdk/models/ad_group_update_params.rbs
Overview
Where results happen: website (conversions), profile (IG/FB engagement), messaging (DM), on_ad (engagement on the ad, surface follows the optimization goal), or the lead destinations (instant_forms, instant_forms_and_messenger, website_and_instant_forms). The lead form itself is set on the ad.
Constant Summary collapse
- WEBSITE =
:website- PROFILE =
:profile- MESSAGING =
:messaging- ON_AD =
:on_ad- INSTANT_FORMS =
:instant_forms- INSTANT_FORMS_AND_MESSENGER =
:instant_forms_and_messenger- WEBSITE_AND_INSTANT_FORMS =
:website_and_instant_forms
Instance Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Instance Method Details
#self?.values ⇒ ::Array[WhopSDK::Models::AdGroupUpdateParams::conversion_location]
258 |
# File 'sig/whop_sdk/models/ad_group_update_params.rbs', line 258
def self?.values: -> ::Array[WhopSDK::Models::AdGroupUpdateParams::conversion_location]
|