Class: WhopSDK::Models::AdListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/ad_list_params.rb

Overview

Defined Under Namespace

Modules: OrderBy

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(ad_group_id: nil, after: nil, before: nil, campaign_id: nil, company_id: nil, created_after: nil, created_before: nil, first: nil, include_paused: nil, last: nil, order_by: nil, order_direction: nil, query: nil, stats_from: nil, stats_to: nil, status: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AdListParams for more details.

Parameters:

  • ad_group_id (String, nil) (defaults to: nil)

    Filter by ad group. Provide exactly one of ad*group_id, campaign_id, or company*

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • campaign_id (String, nil) (defaults to: nil)

    Filter by campaign. Provide exactly one of ad*group_id, campaign_id, or company*

  • company_id (String, nil) (defaults to: nil)

    Filter by company. Provide exactly one of ad_group_id, campaign_id, or company_i

  • created_after (Time, nil) (defaults to: nil)

    Only return ads created after this timestamp.

  • created_before (Time, nil) (defaults to: nil)

    Only return ads created before this timestamp.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • include_paused (Boolean, nil) (defaults to: nil)

    When false, excludes paused ads so pagination matches the dashboard’s hide-pause

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • order_by (Symbol, WhopSDK::Models::AdListParams::OrderBy, nil) (defaults to: nil)

    Columns that the listAds query can sort by.

  • order_direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • query (String, nil) (defaults to: nil)

    Case-insensitive substring match against the ad title or tag.

  • stats_from (Time, nil) (defaults to: nil)

    Start of the stats date range used when order_by is a stats column.

  • stats_to (Time, nil) (defaults to: nil)

    End of the stats date range used when order_by is a stats column.

  • status (Symbol, WhopSDK::Models::ExternalAdStatus, nil) (defaults to: nil)

    The status of an external ad.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/ad_list_params.rb', line 110

Instance Attribute Details

#ad_group_idString?

Filter by ad group. Provide exactly one of ad_group_id, campaign_id, or company_id.

Returns:

  • (String, nil)


15
# File 'lib/whop_sdk/models/ad_list_params.rb', line 15

optional :ad_group_id, String, nil?: true

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


21
# File 'lib/whop_sdk/models/ad_list_params.rb', line 21

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


27
# File 'lib/whop_sdk/models/ad_list_params.rb', line 27

optional :before, String, nil?: true

#campaign_idString?

Filter by campaign. Provide exactly one of ad_group_id, campaign_id, or company_id.

Returns:

  • (String, nil)


34
# File 'lib/whop_sdk/models/ad_list_params.rb', line 34

optional :campaign_id, String, nil?: true

#company_idString?

Filter by company. Provide exactly one of ad_group_id, campaign_id, or company_id.

Returns:

  • (String, nil)


41
# File 'lib/whop_sdk/models/ad_list_params.rb', line 41

optional :company_id, String, nil?: true

#created_afterTime?

Only return ads created after this timestamp.

Returns:

  • (Time, nil)


47
# File 'lib/whop_sdk/models/ad_list_params.rb', line 47

optional :created_after, Time, nil?: true

#created_beforeTime?

Only return ads created before this timestamp.

Returns:

  • (Time, nil)


53
# File 'lib/whop_sdk/models/ad_list_params.rb', line 53

optional :created_before, Time, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


59
# File 'lib/whop_sdk/models/ad_list_params.rb', line 59

optional :first, Integer, nil?: true

#include_pausedBoolean?

When false, excludes paused ads so pagination matches the dashboard’s hide-paused toggle.

Returns:

  • (Boolean, nil)


66
# File 'lib/whop_sdk/models/ad_list_params.rb', line 66

optional :include_paused, WhopSDK::Internal::Type::Boolean, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


72
# File 'lib/whop_sdk/models/ad_list_params.rb', line 72

optional :last, Integer, nil?: true

#order_bySymbol, ...

Columns that the listAds query can sort by.

Returns:



78
# File 'lib/whop_sdk/models/ad_list_params.rb', line 78

optional :order_by, enum: -> { WhopSDK::AdListParams::OrderBy }, nil?: true

#order_directionSymbol, ...

The direction of the sort.

Returns:



84
# File 'lib/whop_sdk/models/ad_list_params.rb', line 84

optional :order_direction, enum: -> { WhopSDK::Direction }, nil?: true

#queryString?

Case-insensitive substring match against the ad title or tag.

Returns:

  • (String, nil)


90
# File 'lib/whop_sdk/models/ad_list_params.rb', line 90

optional :query, String, nil?: true

#stats_fromTime?

Start of the stats date range used when order_by is a stats column.

Returns:

  • (Time, nil)


96
# File 'lib/whop_sdk/models/ad_list_params.rb', line 96

optional :stats_from, Time, nil?: true

#stats_toTime?

End of the stats date range used when order_by is a stats column.

Returns:

  • (Time, nil)


102
# File 'lib/whop_sdk/models/ad_list_params.rb', line 102

optional :stats_to, Time, nil?: true

#statusSymbol, ...

The status of an external ad.

Returns:



108
# File 'lib/whop_sdk/models/ad_list_params.rb', line 108

optional :status, enum: -> { WhopSDK::ExternalAdStatus }, nil?: true