Class: WhopSDK::Models::AdReportRetrieveResponse::Summary

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/ad_report_retrieve_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(clicks:, cost_per_result:, cpc:, cpm:, ctr:, frequency:, impressions:, reach:, result_count:, result_label_key:, result_label_override:, roas:, spend:, spend_currency:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AdReportRetrieveResponse::Summary for more details.

Aggregate totals and rates over the date range.

Parameters:

  • clicks (Integer)

    Total clicks over the date range.

  • cost_per_result (Float, nil)

    Spend divided by ‘resultCount`. Null when there are no results.

  • cpc (Float)

    Cost per click in the requested reporting currency.

  • cpm (Float, nil)

    Cost per thousand impressions in the requested reporting currency.

  • ctr (Float)

    Click-through rate (clicks / impressions).

  • frequency (Float, nil)

    Average number of times each reached user saw an ad.

  • impressions (Integer)

    Total impressions over the date range.

  • reach (Integer)

    Unique users reached, deduplicated by the external ad platform.

  • result_count (Integer, nil)

    Count of the campaign’s primary optimization result (purchases, clicks, etc.) —

  • result_label_key (Symbol, WhopSDK::Models::ResultLabelKeys, nil)

    Types of optimization results tracked from external ad platforms

  • result_label_override (String, nil)

    Advertiser-defined label for the result when ‘resultLabelKey` is `custom`.

  • roas (Float, nil)

    Alias for ‘purchaseRoas` — return on ad spend for purchases, as reported by the

  • spend (Float)

    Total spend over the date range in the requested reporting currency.

  • spend_currency (Symbol, WhopSDK::Models::Currency, nil)

    The available currencies on the platform



# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 549

Instance Attribute Details

#clicksInteger

Total clicks over the date range.

Returns:

  • (Integer)


467
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 467

required :clicks, Integer

#cost_per_resultFloat?

Spend divided by ‘resultCount`. Null when there are no results.

Returns:

  • (Float, nil)


473
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 473

required :cost_per_result, Float, nil?: true

#cpcFloat

Cost per click in the requested reporting currency.

Returns:

  • (Float)


479
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 479

required :cpc, Float

#cpmFloat?

Cost per thousand impressions in the requested reporting currency.

Returns:

  • (Float, nil)


485
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 485

required :cpm, Float, nil?: true

#ctrFloat

Click-through rate (clicks / impressions).

Returns:

  • (Float)


491
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 491

required :ctr, Float

#frequencyFloat?

Average number of times each reached user saw an ad.

Returns:

  • (Float, nil)


497
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 497

required :frequency, Float, nil?: true

#impressionsInteger

Total impressions over the date range.

Returns:

  • (Integer)


503
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 503

required :impressions, Integer

#reachInteger

Unique users reached, deduplicated by the external ad platform.

Returns:

  • (Integer)


509
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 509

required :reach, Integer

#result_countInteger?

Count of the campaign’s primary optimization result (purchases, clicks, etc.) —see ‘resultLabelKey`.

Returns:

  • (Integer, nil)


516
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 516

required :result_count, Integer, nil?: true

#result_label_keySymbol, ...

Types of optimization results tracked from external ad platforms

Returns:



522
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 522

required :result_label_key, enum: -> { WhopSDK::ResultLabelKeys }, nil?: true

#result_label_overrideString?

Advertiser-defined label for the result when ‘resultLabelKey` is `custom`.

Returns:

  • (String, nil)


528
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 528

required :result_label_override, String, nil?: true

#roasFloat?

Alias for ‘purchaseRoas` — return on ad spend for purchases, as reported by the external ad platform.

Returns:

  • (Float, nil)


535
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 535

required :roas, Float, nil?: true

#spendFloat

Total spend over the date range in the requested reporting currency.

Returns:

  • (Float)


541
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 541

required :spend, Float

#spend_currencySymbol, ...

The available currencies on the platform

Returns:



547
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 547

required :spend_currency, enum: -> { WhopSDK::Currency }, nil?: true