Class: WhopSDK::Models::AdReportRetrieveResponse::Summary
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AdReportRetrieveResponse::Summary
- Defined in:
- lib/whop_sdk/models/ad_report_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#clicks ⇒ Integer
Total clicks over the date range.
-
#cost_per_result ⇒ Float?
Spend divided by ‘resultCount`.
-
#cpc ⇒ Float
Cost per click in the requested reporting currency.
-
#cpm ⇒ Float?
Cost per thousand impressions in the requested reporting currency.
-
#ctr ⇒ Float
Click-through rate (clicks / impressions).
-
#frequency ⇒ Float?
Average number of times each reached user saw an ad.
-
#impressions ⇒ Integer
Total impressions over the date range.
-
#reach ⇒ Integer
Unique users reached, deduplicated by the external ad platform.
-
#result_count ⇒ Integer?
Count of the campaign’s primary optimization result (purchases, clicks, etc.) — see ‘resultLabelKey`.
-
#result_label_key ⇒ Symbol, ...
Types of optimization results tracked from external ad platforms.
-
#result_label_override ⇒ String?
Advertiser-defined label for the result when ‘resultLabelKey` is `custom`.
-
#roas ⇒ Float?
Alias for ‘purchaseRoas` — return on ad spend for purchases, as reported by the external ad platform.
-
#spend ⇒ Float
Total spend over the date range in the requested reporting currency.
-
#spend_currency ⇒ Symbol, ...
The available currencies on the platform.
Instance Method Summary collapse
-
#initialize(clicks:, cost_per_result:, cpc:, cpm:, ctr:, frequency:, impressions:, reach:, result_count:, result_label_key:, result_label_override:, roas:, spend:, spend_currency:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Summary for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(clicks:, cost_per_result:, cpc:, cpm:, ctr:, frequency:, impressions:, reach:, result_count:, result_label_key:, result_label_override:, roas:, spend:, spend_currency:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AdReportRetrieveResponse::Summary for more details.
Aggregate totals and rates over the date range.
|
|
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 549
|
Instance Attribute Details
#clicks ⇒ Integer
Total clicks over the date range.
467 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 467 required :clicks, Integer |
#cost_per_result ⇒ Float?
Spend divided by ‘resultCount`. Null when there are no results.
473 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 473 required :cost_per_result, Float, nil?: true |
#cpc ⇒ Float
Cost per click in the requested reporting currency.
479 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 479 required :cpc, Float |
#cpm ⇒ Float?
Cost per thousand impressions in the requested reporting currency.
485 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 485 required :cpm, Float, nil?: true |
#ctr ⇒ Float
Click-through rate (clicks / impressions).
491 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 491 required :ctr, Float |
#frequency ⇒ Float?
Average number of times each reached user saw an ad.
497 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 497 required :frequency, Float, nil?: true |
#impressions ⇒ Integer
Total impressions over the date range.
503 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 503 required :impressions, Integer |
#reach ⇒ Integer
Unique users reached, deduplicated by the external ad platform.
509 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 509 required :reach, Integer |
#result_count ⇒ Integer?
Count of the campaign’s primary optimization result (purchases, clicks, etc.) —see ‘resultLabelKey`.
516 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 516 required :result_count, Integer, nil?: true |
#result_label_key ⇒ Symbol, ...
Types of optimization results tracked from external ad platforms
522 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 522 required :result_label_key, enum: -> { WhopSDK::ResultLabelKeys }, nil?: true |
#result_label_override ⇒ String?
Advertiser-defined label for the result when ‘resultLabelKey` is `custom`.
528 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 528 required :result_label_override, String, nil?: true |
#roas ⇒ Float?
Alias for ‘purchaseRoas` — return on ad spend for purchases, as reported by the external ad platform.
535 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 535 required :roas, Float, nil?: true |
#spend ⇒ Float
Total spend over the date range in the requested reporting currency.
541 |
# File 'lib/whop_sdk/models/ad_report_retrieve_response.rb', line 541 required :spend, Float |