Class: WhopSDK::Models::App

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app.rb

Defined Under Namespace

Classes: APIKey, Company, Creator, Icon, RequestedPermission, Stats

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(action: , name: ) ⇒ Object

The action that the app will request off of users when a user installs the app.

Parameters:

  • action (String) (defaults to: )

    The identifier of the action.

  • name (String) (defaults to: )

    The human readable name of the action.



# File 'lib/whop_sdk/models/app.rb', line 121

Instance Attribute Details

#api_keyWhopSDK::Models::App::APIKey?

The API key for the app



16
# File 'lib/whop_sdk/models/app.rb', line 16

required :api_key, -> { WhopSDK::App::APIKey }, nil?: true

#app_typeSymbol, WhopSDK::Models::AppType

The type of end-user an app is built for

Returns:



22
# File 'lib/whop_sdk/models/app.rb', line 22

required :app_type, enum: -> { WhopSDK::AppType }

#base_urlString?

The base url of the app

Returns:

  • (String, nil)


28
# File 'lib/whop_sdk/models/app.rb', line 28

required :base_url, String, nil?: true

#companyWhopSDK::Models::App::Company

The company that owns the app



34
# File 'lib/whop_sdk/models/app.rb', line 34

required :company, -> { WhopSDK::App::Company }

#creatorWhopSDK::Models::App::Creator

The creator of the app



40
# File 'lib/whop_sdk/models/app.rb', line 40

required :creator, -> { WhopSDK::App::Creator }

#dashboard_pathString?

The path part for a specific view of the app. This is the template part of the url after the base domain. Eg: /experiences/

Returns:

  • (String, nil)


47
# File 'lib/whop_sdk/models/app.rb', line 47

required :dashboard_path, String, nil?: true

#descriptionString?

The description of the app

Returns:

  • (String, nil)


53
# File 'lib/whop_sdk/models/app.rb', line 53

required :description, String, nil?: true

#discover_pathString?

The path part for a specific view of the app. This is the template part of the url after the base domain. Eg: /experiences/

Returns:

  • (String, nil)


60
# File 'lib/whop_sdk/models/app.rb', line 60

required :discover_path, String, nil?: true

#domain_idString

The unique part of the proxied domain for this app. Used to generate the base url used to display the app inside the whop platform. Refers to the id part in the final url: https://#domain_id.apps.whop.com

Returns:

  • (String)


68
# File 'lib/whop_sdk/models/app.rb', line 68

required :domain_id, String

#experience_pathString?

The path part for a specific view of the app. This is the template part of the url after the base domain. Eg: /experiences/

Returns:

  • (String, nil)


75
# File 'lib/whop_sdk/models/app.rb', line 75

required :experience_path, String, nil?: true

#iconWhopSDK::Models::App::Icon?

The icon for the app. This icon is shown on discovery, on the product page, on checkout, and as a default icon for the experiences.

Returns:



82
# File 'lib/whop_sdk/models/app.rb', line 82

required :icon, -> { WhopSDK::App::Icon }, nil?: true

#idString

The ID of the app

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/app.rb', line 10

required :id, String

#nameString

The name of the app

Returns:

  • (String)


88
# File 'lib/whop_sdk/models/app.rb', line 88

required :name, String

#requested_permissionsArray<WhopSDK::Models::App::RequestedPermission>

The set of permissions that an app requests to be granted when a user installs the app.



95
96
# File 'lib/whop_sdk/models/app.rb', line 95

required :requested_permissions,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::App::RequestedPermission] }

#statsWhopSDK::Models::App::Stats?

A collection of stats for the app.

Returns:



102
# File 'lib/whop_sdk/models/app.rb', line 102

required :stats, -> { WhopSDK::App::Stats }, nil?: true

#statusSymbol, WhopSDK::Models::AppStatuses

If the status is live, the app is visible on Whop discovery. In order to be live, you need to set the name, icon, and description. Being unlisted or hidden means it’s not visible on Whop but you can still install the app via direct link. To remove the app from whop discovery, you should set the status to unlisted.

Returns:



112
# File 'lib/whop_sdk/models/app.rb', line 112

required :status, enum: -> { WhopSDK::AppStatuses }

#verifiedBoolean

Whether this app has been verified by Whop. Verified apps are endorsed by whop and are shown in the ‘featured apps’ section of the app store.

Returns:

  • (Boolean)


119
# File 'lib/whop_sdk/models/app.rb', line 119

required :verified, WhopSDK::Internal::Type::Boolean