Class: WhopSDK::Models::App::ProductionWebBuild
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::App::ProductionWebBuild
- Defined in:
- lib/whop_sdk/models/app.rb,
sig/whop_sdk/models/app.rbs
Overview
Instance Attribute Summary collapse
-
#checksum ⇒ String
A SHA-256 hash of the uploaded build file, generated by the client and used to verify file integrity.
-
#file_url ⇒ String
A URL to download the app build as a .zip archive.
-
#id ⇒ String
The unique identifier for the app build.
-
#status ⇒ Symbol, WhopSDK::Models::AppBuildStatuses
The current review status of this build.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
206 |
# File 'sig/whop_sdk/models/app.rbs', line 206
def initialize: (
|
Instance Attribute Details
#checksum ⇒ String
A SHA-256 hash of the uploaded build file, generated by the client and used to verify file integrity.
358 |
# File 'lib/whop_sdk/models/app.rb', line 358 required :checksum, String |
#file_url ⇒ String
A URL to download the app build as a .zip archive.
364 |
# File 'lib/whop_sdk/models/app.rb', line 364 required :file_url, String |
#id ⇒ String
The unique identifier for the app build.
351 |
# File 'lib/whop_sdk/models/app.rb', line 351 required :id, String |
#status ⇒ Symbol, WhopSDK::Models::AppBuildStatuses
The current review status of this build.
370 |
# File 'lib/whop_sdk/models/app.rb', line 370 required :status, enum: -> { WhopSDK::AppBuildStatuses } |
Instance Method Details
#to_hash ⇒ {
213 |
# File 'sig/whop_sdk/models/app.rbs', line 213
def to_hash: -> {
|