Class: WhopSDK::Models::App::RequestedPermission

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app.rb

Defined Under Namespace

Classes: PermissionAction

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(is_required: , justification: , permission_action: ) ⇒ Object

A permission that the app requests from the admin of a company during the oauth flow.

Parameters:

  • is_required (Boolean) (defaults to: )

    Whether the action is required for the app to function.

  • justification (String) (defaults to: )

    The reason for requesting the action.

  • permission_action (WhopSDK::Models::App::RequestedPermission::PermissionAction) (defaults to: )

    The action that the app will request off of users when a user installs the app.



# File 'lib/whop_sdk/models/app.rb', line 281

Instance Attribute Details

#is_requiredBoolean

Whether the action is required for the app to function.

Returns:

  • (Boolean)


267
# File 'lib/whop_sdk/models/app.rb', line 267

required :is_required, WhopSDK::Internal::Type::Boolean

#justificationString

The reason for requesting the action.

Returns:

  • (String)


273
# File 'lib/whop_sdk/models/app.rb', line 273

required :justification, String

#permission_actionWhopSDK::Models::App::RequestedPermission::PermissionAction

The action that the app will request off of users when a user installs the app.



279
# File 'lib/whop_sdk/models/app.rb', line 279

required :permission_action, -> { WhopSDK::App::RequestedPermission::PermissionAction }