Class: WhopSDK::Models::App::RequestedPermission
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::App::RequestedPermission
- Defined in:
- lib/whop_sdk/models/app.rb
Defined Under Namespace
Classes: PermissionAction
Instance Attribute Summary collapse
-
#is_required ⇒ Boolean
Whether the action is required for the app to function.
-
#justification ⇒ String
The reason for requesting the action.
-
#permission_action ⇒ WhopSDK::Models::App::RequestedPermission::PermissionAction
The action that the app will request off of users when a user installs the app.
Instance Method Summary collapse
-
#initialize(is_required: , justification: , permission_action: ) ⇒ Object
constructor
A permission that the app requests from the admin of a company during the oauth flow.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(is_required: , justification: , permission_action: ) ⇒ Object
A permission that the app requests from the admin of a company during the oauth flow.
|
|
# File 'lib/whop_sdk/models/app.rb', line 273
|
Instance Attribute Details
#is_required ⇒ Boolean
Whether the action is required for the app to function.
259 |
# File 'lib/whop_sdk/models/app.rb', line 259 required :is_required, WhopSDK::Internal::Type::Boolean |
#justification ⇒ String
The reason for requesting the action.
265 |
# File 'lib/whop_sdk/models/app.rb', line 265 required :justification, String |
#permission_action ⇒ WhopSDK::Models::App::RequestedPermission::PermissionAction
The action that the app will request off of users when a user installs the app.
271 |
# File 'lib/whop_sdk/models/app.rb', line 271 required :permission_action, -> { WhopSDK::App::RequestedPermission::PermissionAction } |