Class: WhopSDK::Models::App::Stats

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dau:, mau:, time_spent_last24_hours:, wau:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::App::Stats for more details.

Aggregate usage statistics for this app, including daily, weekly, and monthly active user counts.

Parameters:

  • dau (Integer)

    The number of unique users who have spent time in this app in the last 24 hours.

  • mau (Integer)

    The number of unique users who have spent time in this app in the last 28 days.

  • time_spent_last24_hours (Integer)

    The total time, in seconds, that all users have spent in this app over the last

  • wau (Integer)

    The number of unique users who have spent time in this app in the last 7 days. R



# File 'lib/whop_sdk/models/app.rb', line 390

Instance Attribute Details

#dauInteger

The number of unique users who have spent time in this app in the last 24 hours. Returns 0 if no usage data is available.

Returns:

  • (Integer)


367
# File 'lib/whop_sdk/models/app.rb', line 367

required :dau, Integer

#mauInteger

The number of unique users who have spent time in this app in the last 28 days. Returns 0 if no usage data is available.

Returns:

  • (Integer)


374
# File 'lib/whop_sdk/models/app.rb', line 374

required :mau, Integer

#time_spent_last24_hoursInteger

The total time, in seconds, that all users have spent in this app over the last 24 hours. Returns 0 if no usage data is available.

Returns:

  • (Integer)


381
# File 'lib/whop_sdk/models/app.rb', line 381

required :time_spent_last24_hours, Integer

#wauInteger

The number of unique users who have spent time in this app in the last 7 days. Returns 0 if no usage data is available.

Returns:

  • (Integer)


388
# File 'lib/whop_sdk/models/app.rb', line 388

required :wau, Integer