Class: WhopSDK::Models::App::Stats

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(dau: , mau: , time_spent_last24_hours: , wau: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::App::Stats for more details.

A collection of stats for the app.

Parameters:

  • dau (Integer) (defaults to: )

    This is the number of users that have spent time in this app in the last 24 hour

  • mau (Integer) (defaults to: )

    This is the number of users that have spent time in this app in the last 28 days

  • time_spent_last24_hours (Integer) (defaults to: )

    This how much time, in seconds, users have spent in this app in the last 24 hour

  • wau (Integer) (defaults to: )

    This is the number of users that have spent time in this app in the last 7 days.



# File 'lib/whop_sdk/models/app.rb', line 335

Instance Attribute Details

#dauInteger

This is the number of users that have spent time in this app in the last 24 hours.

Returns:

  • (Integer)


313
# File 'lib/whop_sdk/models/app.rb', line 313

required :dau, Integer

#mauInteger

This is the number of users that have spent time in this app in the last 28 days.

Returns:

  • (Integer)


320
# File 'lib/whop_sdk/models/app.rb', line 320

required :mau, Integer

#time_spent_last24_hoursInteger

This how much time, in seconds, users have spent in this app in the last 24 hours.

Returns:

  • (Integer)


327
# File 'lib/whop_sdk/models/app.rb', line 327

required :time_spent_last24_hours, Integer

#wauInteger

This is the number of users that have spent time in this app in the last 7 days.

Returns:

  • (Integer)


333
# File 'lib/whop_sdk/models/app.rb', line 333

required :wau, Integer