Class: WhopSDK::Models::AppBuild
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppBuild
- Defined in:
- lib/whop_sdk/models/app_build.rb
Instance Attribute Summary collapse
-
#checksum ⇒ String
This is generated by the client and used to verify the integrity of the file that is submitted.
-
#created_at ⇒ Time
When this app build was created.
-
#file_url ⇒ String
The URL to download the app build .zip file.
-
#id ⇒ String
The ID of the app build.
-
#is_production ⇒ Boolean
Whether this app build is currently being used in production.
-
#platform ⇒ Symbol, WhopSDK::Models::AppBuildPlatforms
The platform of the app build (ios, android, web).
-
#review_message ⇒ String?
The review message for the app build, if any.
-
#status ⇒ Symbol, WhopSDK::Models::AppBuildStatuses
The status of the app build (draft, approved, rejected, pending, etc).
-
#supported_app_view_types ⇒ Array<Symbol, WhopSDK::Models::AppViewType>
The supported app view types for the app build.
Instance Method Summary collapse
-
#initialize(id: , checksum: , created_at: , file_url: , is_production: , platform: , review_message: , status: , supported_app_view_types: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see AppBuild for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , checksum: , created_at: , file_url: , is_production: , platform: , review_message: , status: , supported_app_view_types: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AppBuild for more details.
An App Build object representing a build of an application
|
|
# File 'lib/whop_sdk/models/app_build.rb', line 63
|
Instance Attribute Details
#checksum ⇒ String
This is generated by the client and used to verify the integrity of the file that is submitted. It is a SHA256 hash of the app build file.
17 |
# File 'lib/whop_sdk/models/app_build.rb', line 17 required :checksum, String |
#created_at ⇒ Time
When this app build was created.
23 |
# File 'lib/whop_sdk/models/app_build.rb', line 23 required :created_at, Time |
#file_url ⇒ String
The URL to download the app build .zip file.
29 |
# File 'lib/whop_sdk/models/app_build.rb', line 29 required :file_url, String |
#id ⇒ String
The ID of the app build. It will look like apbu_xxxxx.
10 |
# File 'lib/whop_sdk/models/app_build.rb', line 10 required :id, String |
#is_production ⇒ Boolean
Whether this app build is currently being used in production.
35 |
# File 'lib/whop_sdk/models/app_build.rb', line 35 required :is_production, WhopSDK::Internal::Type::Boolean |
#platform ⇒ Symbol, WhopSDK::Models::AppBuildPlatforms
The platform of the app build (ios, android, web)
41 |
# File 'lib/whop_sdk/models/app_build.rb', line 41 required :platform, enum: -> { WhopSDK::AppBuildPlatforms } |
#review_message ⇒ String?
The review message for the app build, if any. This is populated when the build is rejected and there is a reason specified by the reviewer.
48 |
# File 'lib/whop_sdk/models/app_build.rb', line 48 required :review_message, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::AppBuildStatuses
The status of the app build (draft, approved, rejected, pending, etc)
54 |
# File 'lib/whop_sdk/models/app_build.rb', line 54 required :status, enum: -> { WhopSDK::AppBuildStatuses } |
#supported_app_view_types ⇒ Array<Symbol, WhopSDK::Models::AppViewType>
The supported app view types for the app build. These are the views that the developer has specified that this build supports.
61 |
# File 'lib/whop_sdk/models/app_build.rb', line 61 required :supported_app_view_types, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppViewType] } |