Class: WhopSDK::Models::AppBuildCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppBuildCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/app_build_create_params.rb
Overview
Defined Under Namespace
Classes: Attachment
Instance Attribute Summary collapse
-
#ai_prompt_id ⇒ String?
The identifier of the AI prompt that generated this build, if applicable.
-
#app_id ⇒ String?
The unique identifier of the app to create the build for.
-
#attachment ⇒ WhopSDK::Models::AppBuildCreateParams::Attachment
The build file to upload.
-
#checksum ⇒ String
A client-generated checksum of the build file, used to verify file integrity when unpacked on a device.
-
#platform ⇒ Symbol, WhopSDK::Models::AppBuildPlatforms
The target platform for the build.
-
#supported_app_view_types ⇒ Array<Symbol, WhopSDK::Models::AppViewType>?
The view types this build supports.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#ai_prompt_id ⇒ String?
The identifier of the AI prompt that generated this build, if applicable.
35 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 35 optional :ai_prompt_id, String, nil?: true |
#app_id ⇒ String?
The unique identifier of the app to create the build for. Defaults to the app associated with the current API key.
42 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 42 optional :app_id, String, nil?: true |
#attachment ⇒ WhopSDK::Models::AppBuildCreateParams::Attachment
The build file to upload. For iOS and Android, this should be a .zip archive containing a main_js_bundle.hbc file and an optional assets folder. For web, this should be a JavaScript file.
16 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 16 required :attachment, -> { WhopSDK::AppBuildCreateParams::Attachment } |
#checksum ⇒ String
A client-generated checksum of the build file, used to verify file integrity when unpacked on a device.
23 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 23 required :checksum, String |
#platform ⇒ Symbol, WhopSDK::Models::AppBuildPlatforms
The target platform for the build. Accepted values: ios, android, web.
29 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 29 required :platform, enum: -> { WhopSDK::AppBuildPlatforms } |
#supported_app_view_types ⇒ Array<Symbol, WhopSDK::Models::AppViewType>?
The view types this build supports. A build can support multiple view types but should only list the ones its code implements.
49 50 51 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 49 optional :supported_app_view_types, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppViewType] }, nil?: true |