Class: WhopSDK::Models::AppBuildCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppBuildCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/app_build_create_params.rb
Overview
Defined Under Namespace
Classes: Attachment
Instance Attribute Summary collapse
-
#app_id ⇒ String?
The ID of the app to create a build for.
-
#attachment ⇒ WhopSDK::Models::AppBuildCreateParams::Attachment
Attachment input for the app build file.
-
#checksum ⇒ String
Checksum of the app build file.
-
#platform ⇒ Symbol, WhopSDK::Models::AppBuildPlatforms
The platform of the app build (ios, android, web).
-
#supported_app_view_types ⇒ Array<Symbol, WhopSDK::Models::AppViewType>?
Supported app view types for the app build.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#app_id ⇒ String?
The ID of the app to create a build for. By default the current app from the api key is used.
37 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 37 optional :app_id, String, nil?: true |
#attachment ⇒ WhopSDK::Models::AppBuildCreateParams::Attachment
Attachment input for the app build file. This should be an upload in .zip format. The zip should contain at least one main_js_bundle.hbc file and optionally an assets folder next to it.
16 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 16 required :attachment, -> { WhopSDK::AppBuildCreateParams::Attachment } |
#checksum ⇒ String
Checksum of the app build file. This is generated by the client and used to verify the integrity of the file that is submitted when un-packaged later on a device.
24 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 24 required :checksum, String |
#platform ⇒ Symbol, WhopSDK::Models::AppBuildPlatforms
The platform of the app build (ios, android, web)
30 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 30 required :platform, enum: -> { WhopSDK::AppBuildPlatforms } |
#supported_app_view_types ⇒ Array<Symbol, WhopSDK::Models::AppViewType>?
Supported app view types for the app build. A build can specify multiple view types, but should only specify ones that its code supports.
44 45 46 |
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 44 optional :supported_app_view_types, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppViewType] }, nil?: true |