Class: WhopSDK::Models::AppBuildCreateParams::Attachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app_build_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, direct_upload_id: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AppBuildCreateParams::Attachment for more details.

Attachment input for the app build file. This should be an upload in .zip format. The zip should contain at least one main_js_bundle.hbc file and optionally an assets folder next to it.

Parameters:

  • id (String, nil) (defaults to: nil)

    The ID of an existing attachment object. Use this when updating a resource and k

  • direct_upload_id (String, nil) (defaults to: nil)

    This ID should be used the first time you upload an attachment. It is the ID of



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 64

class Attachment < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing attachment object. Use this when updating a resource and
  #   keeping a subset of the attachments. Don't use this unless you know what you're
  #   doing.
  #
  #   @return [String, nil]
  optional :id, String, nil?: true

  # @!attribute direct_upload_id
  #   This ID should be used the first time you upload an attachment. It is the ID of
  #   the direct upload that was created when uploading the file to S3 via the
  #   mediaDirectUpload mutation.
  #
  #   @return [String, nil]
  optional :direct_upload_id, String, nil?: true

  # @!method initialize(id: nil, direct_upload_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::AppBuildCreateParams::Attachment} for more details.
  #
  #   Attachment input for the app build file. This should be an upload in .zip
  #   format. The zip should contain at least one main_js_bundle.hbc file and
  #   optionally an assets folder next to it.
  #
  #   @param id [String, nil] The ID of an existing attachment object. Use this when updating a resource and k
  #
  #   @param direct_upload_id [String, nil] This ID should be used the first time you upload an attachment. It is the ID of
end

Instance Attribute Details

#direct_upload_idString?

This ID should be used the first time you upload an attachment. It is the ID of the direct upload that was created when uploading the file to S3 via the mediaDirectUpload mutation.

Returns:

  • (String, nil)


79
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 79

optional :direct_upload_id, String, nil?: true

#idString?

The ID of an existing attachment object. Use this when updating a resource and keeping a subset of the attachments. Don’t use this unless you know what you’re doing.

Returns:

  • (String, nil)


71
# File 'lib/whop_sdk/models/app_build_create_params.rb', line 71

optional :id, String, nil?: true