Class: WhopSDK::Models::AppBuildListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppBuildListResponse
- Defined in:
- lib/whop_sdk/models/app_build_list_response.rb
Overview
Instance Attribute Summary collapse
-
#checksum ⇒ String
A SHA-256 hash of the uploaded build file, generated by the client and used to verify file integrity.
-
#created_at ⇒ Time
The datetime the app build was created.
-
#file_url ⇒ String
A URL to download the app build as a .zip archive.
-
#id ⇒ String
The unique identifier for the app build.
-
#is_production ⇒ Boolean
Whether this build is the currently active production build for its platform.
-
#platform ⇒ Symbol, WhopSDK::Models::AppBuildPlatforms
The target platform for this build.
-
#review_message ⇒ String?
Feedback from the reviewer explaining why the build was rejected.
-
#status ⇒ Symbol, WhopSDK::Models::AppBuildStatuses
The current review status of this build.
-
#supported_app_view_types ⇒ Array<Symbol, WhopSDK::Models::AppViewType>
The list of view types this build supports, as declared by the developer.
Instance Method Summary collapse
-
#initialize(id:, checksum:, created_at:, file_url:, is_production:, platform:, review_message:, status:, supported_app_view_types:) ⇒ Object
constructor
Some parameter documentations has been truncated, see AppBuildListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, checksum:, created_at:, file_url:, is_production:, platform:, review_message:, status:, supported_app_view_types:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AppBuildListResponse for more details.
A versioned build artifact for a Whop React Native App, submitted for review and deployment to a specific platform.
|
|
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 63
|
Instance Attribute Details
#checksum ⇒ String
A SHA-256 hash of the uploaded build file, generated by the client and used to verify file integrity.
18 |
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 18 required :checksum, String |
#created_at ⇒ Time
The datetime the app build was created.
24 |
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 24 required :created_at, Time |
#file_url ⇒ String
A URL to download the app build as a .zip archive.
30 |
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 30 required :file_url, String |
#id ⇒ String
The unique identifier for the app build.
11 |
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 11 required :id, String |
#is_production ⇒ Boolean
Whether this build is the currently active production build for its platform.
36 |
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 36 required :is_production, WhopSDK::Internal::Type::Boolean |
#platform ⇒ Symbol, WhopSDK::Models::AppBuildPlatforms
The target platform for this build.
42 |
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 42 required :platform, enum: -> { WhopSDK::AppBuildPlatforms } |
#review_message ⇒ String?
Feedback from the reviewer explaining why the build was rejected. Null if the build has not been reviewed or was approved.
49 |
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 49 required :review_message, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::AppBuildStatuses
The current review status of this build.
55 |
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 55 required :status, enum: -> { WhopSDK::AppBuildStatuses } |
#supported_app_view_types ⇒ Array<Symbol, WhopSDK::Models::AppViewType>
The list of view types this build supports, as declared by the developer.
61 |
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 61 required :supported_app_view_types, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppViewType] } |