Class: WhopSDK::Models::AppBuildListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app_build_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , checksum: , created_at: , file_url: , is_production: , platform: , review_message: , status: , supported_app_view_types: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AppBuildListResponse for more details.

An App Build object representing a build of an application

Parameters:

  • id (String) (defaults to: )

    The ID of the app build. It will look like apbu_xxxxx.

  • checksum (String) (defaults to: )

    This is generated by the client and used to verify the integrity of the file tha

  • created_at (Time) (defaults to: )

    When this app build was created.

  • file_url (String) (defaults to: )

    The URL to download the app build .zip file.

  • is_production (Boolean) (defaults to: )

    Whether this app build is currently being used in production.

  • platform (Symbol, WhopSDK::Models::AppBuildPlatforms) (defaults to: )

    The platform of the app build (ios, android, web)

  • review_message (String, nil) (defaults to: )

    The review message for the app build, if any. This is populated when the build i

  • status (Symbol, WhopSDK::Models::AppBuildStatuses) (defaults to: )

    The status of the app build (draft, approved, rejected, pending, etc)

  • supported_app_view_types (Array<Symbol, WhopSDK::Models::AppViewType>) (defaults to: )

    The supported app view types for the app build. These are the views that the dev



# File 'lib/whop_sdk/models/app_build_list_response.rb', line 64

Instance Attribute Details

#checksumString

This is generated by the client and used to verify the integrity of the file that is submitted. It is a SHA256 hash of the app build file.

Returns:

  • (String)


18
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 18

required :checksum, String

#created_atTime

When this app build was created.

Returns:

  • (Time)


24
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 24

required :created_at, Time

#file_urlString

The URL to download the app build .zip file.

Returns:

  • (String)


30
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 30

required :file_url, String

#idString

The ID of the app build. It will look like apbu_xxxxx.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 11

required :id, String

#is_productionBoolean

Whether this app build is currently being used in production.

Returns:

  • (Boolean)


36
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 36

required :is_production, WhopSDK::Internal::Type::Boolean

#platformSymbol, WhopSDK::Models::AppBuildPlatforms

The platform of the app build (ios, android, web)



42
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 42

required :platform, enum: -> { WhopSDK::AppBuildPlatforms }

#review_messageString?

The review message for the app build, if any. This is populated when the build is rejected and there is a reason specified by the reviewer.

Returns:

  • (String, nil)


49
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 49

required :review_message, String, nil?: true

#statusSymbol, WhopSDK::Models::AppBuildStatuses

The status of the app build (draft, approved, rejected, pending, etc)



55
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 55

required :status, enum: -> { WhopSDK::AppBuildStatuses }

#supported_app_view_typesArray<Symbol, WhopSDK::Models::AppViewType>

The supported app view types for the app build. These are the views that the developer has specified that this build supports.

Returns:



62
# File 'lib/whop_sdk/models/app_build_list_response.rb', line 62

required :supported_app_view_types, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppViewType] }