Class: WhopSDK::Models::AppCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/app_create_params.rb
Overview
Defined Under Namespace
Classes: Icon
Instance Attribute Summary collapse
-
#base_url ⇒ String?
The base production URL where the app is hosted, such as ‘myapp.example.com’.
-
#company_id ⇒ String
The unique identifier of the company to create the app for, starting with ‘biz_’.
-
#icon ⇒ WhopSDK::Models::AppCreateParams::Icon?
The icon image for the app in PNG, JPEG, or GIF format.
-
#name ⇒ String
The display name for the app, shown to users on the app store and product pages.
-
#redirect_uris ⇒ Array<String>?
The whitelisted OAuth callback URLs that users are redirected to after authorizing the app.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#base_url ⇒ String?
The base production URL where the app is hosted, such as ‘myapp.example.com’.
28 |
# File 'lib/whop_sdk/models/app_create_params.rb', line 28 optional :base_url, String, nil?: true |
#company_id ⇒ String
The unique identifier of the company to create the app for, starting with ‘biz_’.
15 |
# File 'lib/whop_sdk/models/app_create_params.rb', line 15 required :company_id, String |
#icon ⇒ WhopSDK::Models::AppCreateParams::Icon?
The icon image for the app in PNG, JPEG, or GIF format.
34 |
# File 'lib/whop_sdk/models/app_create_params.rb', line 34 optional :icon, -> { WhopSDK::AppCreateParams::Icon }, nil?: true |
#name ⇒ String
The display name for the app, shown to users on the app store and product pages.
21 |
# File 'lib/whop_sdk/models/app_create_params.rb', line 21 required :name, String |