Class: WhopSDK::Models::AppListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/app_list_params.rb

Overview

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, company_id: nil, direction: nil, first: nil, last: nil, order: nil, query: nil, verified_apps_only: nil, view_type: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::AppListParams for more details.

Parameters:

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • company_id (String, nil) (defaults to: nil)

    The ID of the company to filter apps by

  • direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • order (Symbol, WhopSDK::Models::AppListParams::Order, nil) (defaults to: nil)

    The order to fetch the apps in for discovery.

  • query (String, nil) (defaults to: nil)

    The query to search for apps by name.

  • verified_apps_only (Boolean, nil) (defaults to: nil)

    If true, you will only get apps that are verified by Whop. Use this to populate

  • view_type (Symbol, WhopSDK::Models::AppViewType, nil) (defaults to: nil)

    The different types of an app view

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/app_list_params.rb', line 71

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


14
# File 'lib/whop_sdk/models/app_list_params.rb', line 14

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/app_list_params.rb', line 20

optional :before, String, nil?: true

#company_idString?

The ID of the company to filter apps by

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/app_list_params.rb', line 26

optional :company_id, String, nil?: true

#directionSymbol, ...

The direction of the sort.

Returns:



32
# File 'lib/whop_sdk/models/app_list_params.rb', line 32

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


38
# File 'lib/whop_sdk/models/app_list_params.rb', line 38

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


44
# File 'lib/whop_sdk/models/app_list_params.rb', line 44

optional :last, Integer, nil?: true

#orderSymbol, ...

The order to fetch the apps in for discovery.

Returns:



50
# File 'lib/whop_sdk/models/app_list_params.rb', line 50

optional :order, enum: -> { WhopSDK::AppListParams::Order }, nil?: true

#queryString?

The query to search for apps by name.

Returns:

  • (String, nil)


56
# File 'lib/whop_sdk/models/app_list_params.rb', line 56

optional :query, String, nil?: true

#verified_apps_onlyBoolean?

If true, you will only get apps that are verified by Whop. Use this to populate a ‘featured apps’ section on the app store.

Returns:

  • (Boolean, nil)


63
# File 'lib/whop_sdk/models/app_list_params.rb', line 63

optional :verified_apps_only, WhopSDK::Internal::Type::Boolean, nil?: true

#view_typeSymbol, ...

The different types of an app view

Returns:



69
# File 'lib/whop_sdk/models/app_list_params.rb', line 69

optional :view_type, enum: -> { WhopSDK::AppViewType }, nil?: true