Class: WhopSDK::Models::AppListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app_list_response.rb

Overview

Defined Under Namespace

Classes: Company, Creator, Icon

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , name: , username: ) ⇒ Object

The creator of the app

Parameters:

  • id (String) (defaults to: )

    The internal ID of the user.

  • name (String, nil) (defaults to: )

    The name of the user from their Whop account.

  • username (String) (defaults to: )

    The username of the user from their Whop account.



# File 'lib/whop_sdk/models/app_list_response.rb', line 102

Instance Attribute Details

#app_typeSymbol, WhopSDK::Models::AppType

The type of end-user an app is built for

Returns:



17
# File 'lib/whop_sdk/models/app_list_response.rb', line 17

required :app_type, enum: -> { WhopSDK::AppType }

#base_urlString?

The base url of the app

Returns:

  • (String, nil)


23
# File 'lib/whop_sdk/models/app_list_response.rb', line 23

required :base_url, String, nil?: true

#companyWhopSDK::Models::AppListResponse::Company

The company that owns the app



29
# File 'lib/whop_sdk/models/app_list_response.rb', line 29

required :company, -> { WhopSDK::Models::AppListResponse::Company }

#creatorWhopSDK::Models::AppListResponse::Creator

The creator of the app



35
# File 'lib/whop_sdk/models/app_list_response.rb', line 35

required :creator, -> { WhopSDK::Models::AppListResponse::Creator }

#dashboard_pathString?

The path part for a specific view of the app. This is the template part of the url after the base domain. Eg: /experiences/

Returns:

  • (String, nil)


42
# File 'lib/whop_sdk/models/app_list_response.rb', line 42

required :dashboard_path, String, nil?: true

#descriptionString?

The description of the app

Returns:

  • (String, nil)


48
# File 'lib/whop_sdk/models/app_list_response.rb', line 48

required :description, String, nil?: true

#discover_pathString?

The path part for a specific view of the app. This is the template part of the url after the base domain. Eg: /experiences/

Returns:

  • (String, nil)


55
# File 'lib/whop_sdk/models/app_list_response.rb', line 55

required :discover_path, String, nil?: true

#domain_idString

The unique part of the proxied domain for this app. Used to generate the base url used to display the app inside the whop platform. Refers to the id part in the final url: https://#domain_id.apps.whop.com

Returns:

  • (String)


63
# File 'lib/whop_sdk/models/app_list_response.rb', line 63

required :domain_id, String

#experience_pathString?

The path part for a specific view of the app. This is the template part of the url after the base domain. Eg: /experiences/

Returns:

  • (String, nil)


70
# File 'lib/whop_sdk/models/app_list_response.rb', line 70

required :experience_path, String, nil?: true

#iconWhopSDK::Models::AppListResponse::Icon?

The icon for the app. This icon is shown on discovery, on the product page, on checkout, and as a default icon for the experiences.



77
# File 'lib/whop_sdk/models/app_list_response.rb', line 77

required :icon, -> { WhopSDK::Models::AppListResponse::Icon }, nil?: true

#idString

The ID of the app

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/app_list_response.rb', line 11

required :id, String

#nameString

The name of the app

Returns:

  • (String)


83
# File 'lib/whop_sdk/models/app_list_response.rb', line 83

required :name, String

#statusSymbol, WhopSDK::Models::AppStatuses

If the status is live, the app is visible on Whop discovery. In order to be live, you need to set the name, icon, and description. Being unlisted or hidden means it’s not visible on Whop but you can still install the app via direct link. To remove the app from whop discovery, you should set the status to unlisted.

Returns:



93
# File 'lib/whop_sdk/models/app_list_response.rb', line 93

required :status, enum: -> { WhopSDK::AppStatuses }

#verifiedBoolean

Whether this app has been verified by Whop. Verified apps are endorsed by whop and are shown in the ‘featured apps’ section of the app store.

Returns:

  • (Boolean)


100
# File 'lib/whop_sdk/models/app_list_response.rb', line 100

required :verified, WhopSDK::Internal::Type::Boolean