Class: WhopSDK::Models::AppListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppListResponse
- Defined in:
- lib/whop_sdk/models/app_list_response.rb
Overview
Defined Under Namespace
Classes: Company, Creator, Icon
Instance Attribute Summary collapse
-
#base_url ⇒ String?
The base url of the app.
-
#company ⇒ WhopSDK::Models::AppListResponse::Company
The company that owns the app.
-
#creator ⇒ WhopSDK::Models::AppListResponse::Creator
The creator of the app.
-
#dashboard_path ⇒ String?
The path part for a specific view of the app.
-
#description ⇒ String?
The description of the app.
-
#discover_path ⇒ String?
The path part for a specific view of the app.
-
#domain_id ⇒ String
The unique part of the proxied domain for this app.
-
#experience_path ⇒ String?
The path part for a specific view of the app.
-
#icon ⇒ WhopSDK::Models::AppListResponse::Icon?
The icon for the app.
-
#id ⇒ String
The ID of the app.
-
#name ⇒ String
The name of the app.
-
#status ⇒ Symbol, WhopSDK::Models::AppStatuses
If the status is live, the app is visible on Whop discovery.
-
#verified ⇒ Boolean
Whether this app has been verified by Whop.
Instance Method Summary collapse
-
#initialize(id: , name: , username: ) ⇒ Object
constructor
The creator of the app.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , name: , username: ) ⇒ Object
The creator of the app
|
|
# File 'lib/whop_sdk/models/app_list_response.rb', line 96
|
Instance Attribute Details
#base_url ⇒ String?
The base url of the app
17 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 17 required :base_url, String, nil?: true |
#company ⇒ WhopSDK::Models::AppListResponse::Company
The company that owns the app
23 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 23 required :company, -> { WhopSDK::Models::AppListResponse::Company } |
#creator ⇒ WhopSDK::Models::AppListResponse::Creator
The creator of the app
29 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 29 required :creator, -> { WhopSDK::Models::AppListResponse::Creator } |
#dashboard_path ⇒ String?
The path part for a specific view of the app. This is the template part of the url after the base domain. Eg: /experiences/
36 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 36 required :dashboard_path, String, nil?: true |
#description ⇒ String?
The description of the app
42 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 42 required :description, String, nil?: true |
#discover_path ⇒ String?
The path part for a specific view of the app. This is the template part of the url after the base domain. Eg: /experiences/
49 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 49 required :discover_path, String, nil?: true |
#domain_id ⇒ String
The unique part of the proxied domain for this app. Used to generate the base url used to display the app inside the whop platform. Refers to the id part in the final url: https://#domain_id.apps.whop.com
57 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 57 required :domain_id, String |
#experience_path ⇒ String?
The path part for a specific view of the app. This is the template part of the url after the base domain. Eg: /experiences/
64 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 64 required :experience_path, String, nil?: true |
#icon ⇒ WhopSDK::Models::AppListResponse::Icon?
The icon for the app. This icon is shown on discovery, on the product page, on checkout, and as a default icon for the experiences.
71 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 71 required :icon, -> { WhopSDK::Models::AppListResponse::Icon }, nil?: true |
#id ⇒ String
The ID of the app
11 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 11 required :id, String |
#name ⇒ String
The name of the app
77 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 77 required :name, String |
#status ⇒ Symbol, WhopSDK::Models::AppStatuses
If the status is live, the app is visible on Whop discovery. In order to be live, you need to set the name, icon, and description. Being unlisted or hidden means it’s not visible on Whop but you can still install the app via direct link. To remove the app from whop discovery, you should set the status to unlisted.
87 |
# File 'lib/whop_sdk/models/app_list_response.rb', line 87 required :status, enum: -> { WhopSDK::AppStatuses } |