Class: WhopSDK::Models::AppLogsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppLogsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/app_logs_params.rb,
sig/whop_sdk/models/app_logs_params.rbs
Overview
Defined Under Namespace
Modules: Level
Instance Attribute Summary collapse
-
#after ⇒ String?
A cursor for fetching logs after a previous page.
-
#app_build_id ⇒ String?
Only return logs from this build.
-
#before ⇒ String?
A cursor for fetching logs before a later page.
-
#created_after ⇒ Time?
Start of the time window as an ISO 8601 timestamp.
-
#created_before ⇒ Time?
End of the time window as an ISO 8601 timestamp.
-
#first ⇒ Integer?
The number of log lines to return (max 500).
- #id ⇒ String
-
#level ⇒ Symbol, ...
Only return console lines of this level.
-
#query ⇒ String?
Only return logs whose message contains this text (case-insensitive).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, after: nil, app_build_id: nil, before: nil, created_after: nil, created_before: nil, first: nil, level: nil, query: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AppLogsParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, after: nil, app_build_id: nil, before: nil, created_after: nil, created_before: nil, first: nil, level: nil, query: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AppLogsParams for more details.
|
|
# File 'lib/whop_sdk/models/app_logs_params.rb', line 64
|
Instance Attribute Details
#after ⇒ String?
A cursor for fetching logs after a previous page.
19 |
# File 'lib/whop_sdk/models/app_logs_params.rb', line 19 optional :after, String |
#app_build_id ⇒ String?
Only return logs from this build.
25 |
# File 'lib/whop_sdk/models/app_logs_params.rb', line 25 optional :app_build_id, String |
#before ⇒ String?
A cursor for fetching logs before a later page.
31 |
# File 'lib/whop_sdk/models/app_logs_params.rb', line 31 optional :before, String |
#created_after ⇒ Time?
Start of the time window as an ISO 8601 timestamp. Defaults to 7 days before created_before.
38 |
# File 'lib/whop_sdk/models/app_logs_params.rb', line 38 optional :created_after, Time |
#created_before ⇒ Time?
End of the time window as an ISO 8601 timestamp. Defaults to now.
44 |
# File 'lib/whop_sdk/models/app_logs_params.rb', line 44 optional :created_before, Time |
#first ⇒ Integer?
The number of log lines to return (max 500).
50 |
# File 'lib/whop_sdk/models/app_logs_params.rb', line 50 optional :first, Integer |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/app_logs_params.rb', line 13 required :id, String |
#level ⇒ Symbol, ...
Only return console lines of this level.
56 |
# File 'lib/whop_sdk/models/app_logs_params.rb', line 56 optional :level, enum: -> { WhopSDK::AppLogsParams::Level } |
#query ⇒ String?
Only return logs whose message contains this text (case-insensitive).
62 |
# File 'lib/whop_sdk/models/app_logs_params.rb', line 62 optional :query, String |
Instance Method Details
#to_hash ⇒ {
70 |
# File 'sig/whop_sdk/models/app_logs_params.rbs', line 70
def to_hash: -> {
|