Class: WhopSDK::Models::AppUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/app_update_params.rb
Overview
Defined Under Namespace
Modules: OAuthClientType, RequiredScope Classes: Icon
Instance Attribute Summary collapse
-
#app_store_description ⇒ String?
The detailed description shown on the app store’s in-depth app view page.
-
#app_type ⇒ Symbol, ...
The type of end-user an app is built for.
-
#base_url ⇒ String?
The base production URL where the app is hosted, such as ‘myapp.example.com’.
-
#dashboard_path ⇒ String?
The URL path for the company dashboard view of the app, such as ‘/dashboard’.
-
#description ⇒ String?
A short description of the app shown in listings and search results.
-
#discover_path ⇒ String?
The URL path for the discover view of the app, such as ‘/discover’.
-
#experience_path ⇒ String?
The URL path for the member-facing hub view of the app, such as ‘/experiences/’.
-
#icon ⇒ WhopSDK::Models::AppUpdateParams::Icon?
The icon image for the app, used in listings and navigation.
- #id ⇒ String
-
#name ⇒ String?
The display name for the app, shown to users on the app store and product pages.
-
#oauth_client_type ⇒ Symbol, ...
How this app authenticates at the OAuth token endpoint.
-
#openapi_path ⇒ String?
The URL path to the OpenAPI spec file of the app, such as ‘/assets/openapi.json’.
-
#redirect_uris ⇒ Array<String>?
The whitelisted OAuth callback URLs that users are redirected to after authorizing the app.
-
#required_scopes ⇒ Array<Symbol, WhopSDK::Models::AppUpdateParams::RequiredScope>?
The permission scopes the app will request from users when they install it.
-
#skills_path ⇒ String?
The URL path to the skills directory of the app, such as ‘/assets/skills/’.
-
#status ⇒ Symbol, ...
The status of an experience interface.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
The icon image for the app, used in listings and navigation.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
The icon image for the app, used in listings and navigation.
|
|
# File 'lib/whop_sdk/models/app_update_params.rb', line 156
|
Instance Attribute Details
#app_store_description ⇒ String?
The detailed description shown on the app store’s in-depth app view page.
19 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 19 optional :app_store_description, String, nil?: true |
#app_type ⇒ Symbol, ...
The type of end-user an app is built for
25 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 25 optional :app_type, enum: -> { WhopSDK::AppType }, nil?: true |
#base_url ⇒ String?
The base production URL where the app is hosted, such as ‘myapp.example.com’.
32 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 32 optional :base_url, String, nil?: true |
#dashboard_path ⇒ String?
The URL path for the company dashboard view of the app, such as ‘/dashboard’.
38 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 38 optional :dashboard_path, String, nil?: true |
#description ⇒ String?
A short description of the app shown in listings and search results.
44 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 44 optional :description, String, nil?: true |
#discover_path ⇒ String?
The URL path for the discover view of the app, such as ‘/discover’.
50 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 50 optional :discover_path, String, nil?: true |
#experience_path ⇒ String?
The URL path for the member-facing hub view of the app, such as ‘/experiences/’.
57 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 57 optional :experience_path, String, nil?: true |
#icon ⇒ WhopSDK::Models::AppUpdateParams::Icon?
The icon image for the app, used in listings and navigation.
63 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 63 optional :icon, -> { WhopSDK::AppUpdateParams::Icon }, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 13 required :id, String |
#name ⇒ String?
The display name for the app, shown to users on the app store and product pages.
69 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 69 optional :name, String, nil?: true |
#oauth_client_type ⇒ Symbol, ...
How this app authenticates at the OAuth token endpoint.
75 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 75 optional :oauth_client_type, enum: -> { WhopSDK::AppUpdateParams::OAuthClientType }, nil?: true |
#openapi_path ⇒ String?
The URL path to the OpenAPI spec file of the app, such as ‘/assets/openapi.json’.
82 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 82 optional :openapi_path, String, nil?: true |
#redirect_uris ⇒ Array<String>?
The whitelisted OAuth callback URLs that users are redirected to after authorizing the app
89 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 89 optional :redirect_uris, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#required_scopes ⇒ Array<Symbol, WhopSDK::Models::AppUpdateParams::RequiredScope>?
The permission scopes the app will request from users when they install it.
95 96 97 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 95 optional :required_scopes, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppUpdateParams::RequiredScope] }, nil?: true |
#skills_path ⇒ String?
The URL path to the skills directory of the app, such as ‘/assets/skills/’.
103 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 103 optional :skills_path, String, nil?: true |
#status ⇒ Symbol, ...
The status of an experience interface
109 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 109 optional :status, enum: -> { WhopSDK::AppStatuses }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/app_update_params.rb', line 169
|