Class: WhopSDK::Models::AppUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AppUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/app_update_params.rb
Overview
Defined Under Namespace
Modules: Icon, RequiredScope
Instance Attribute Summary collapse
-
#app_store_description ⇒ String?
The description of the app for the app store in-depth app view.
-
#app_type ⇒ Symbol, ...
The type of end-user an app is built for.
-
#base_url ⇒ String?
The base production url of the app.
-
#dashboard_path ⇒ String?
The path for the dashboard view of the app.
-
#description ⇒ String?
The description of the app.
-
#discover_path ⇒ String?
The path for the discover view of the app.
-
#experience_path ⇒ String?
The path for the hub view of the app.
-
#icon ⇒ WhopSDK::Models::AppUpdateParams::Icon::AttachmentInputWithDirectUploadID, ...
The icon for the app.
-
#name ⇒ String?
The name of the app.
-
#required_scopes ⇒ Array<Symbol, WhopSDK::Models::AppUpdateParams::RequiredScope>?
The scopes that the app will request off of users when a user installs the app.
-
#status ⇒ Symbol, ...
The status of an experience interface.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Icon::AttachmentInputWithID for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AppUpdateParams::Icon::AttachmentInputWithID for more details.
Input for an attachment
|
|
# File 'lib/whop_sdk/models/app_update_params.rb', line 78
|
Instance Attribute Details
#app_store_description ⇒ String?
The description of the app for the app store in-depth app view.
14 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 14 optional :app_store_description, String, nil?: true |
#app_type ⇒ Symbol, ...
The type of end-user an app is built for
20 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 20 optional :app_type, enum: -> { WhopSDK::AppType }, nil?: true |
#base_url ⇒ String?
The base production url of the app
26 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 26 optional :base_url, String, nil?: true |
#dashboard_path ⇒ String?
The path for the dashboard view of the app
32 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 32 optional :dashboard_path, String, nil?: true |
#description ⇒ String?
The description of the app
38 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 38 optional :description, String, nil?: true |
#discover_path ⇒ String?
The path for the discover view of the app
44 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 44 optional :discover_path, String, nil?: true |
#experience_path ⇒ String?
The path for the hub view of the app
50 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 50 optional :experience_path, String, nil?: true |
#icon ⇒ WhopSDK::Models::AppUpdateParams::Icon::AttachmentInputWithDirectUploadID, ...
The icon for the app
56 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 56 optional :icon, union: -> { WhopSDK::AppUpdateParams::Icon }, nil?: true |
#name ⇒ String?
The name of the app
62 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 62 optional :name, String, nil?: true |
#required_scopes ⇒ Array<Symbol, WhopSDK::Models::AppUpdateParams::RequiredScope>?
The scopes that the app will request off of users when a user installs the app.
68 69 70 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 68 optional :required_scopes, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppUpdateParams::RequiredScope] }, nil?: true |
#status ⇒ Symbol, ...
The status of an experience interface
76 |
# File 'lib/whop_sdk/models/app_update_params.rb', line 76 optional :status, enum: -> { WhopSDK::AppStatuses }, nil?: true |
Class Method Details
.variants ⇒ Array(WhopSDK::Models::AppUpdateParams::Icon::AttachmentInputWithDirectUploadID, WhopSDK::Models::AppUpdateParams::Icon::AttachmentInputWithID)
|
|
# File 'lib/whop_sdk/models/app_update_params.rb', line 151
|