Class: WhopSDK::Models::AppUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/app_update_params.rb

Overview

Defined Under Namespace

Modules: RequiredScope Classes: Icon

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, direct_upload_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Icon for more details.

The icon for the app

Parameters:

  • id (String, nil) (defaults to: nil)

    The ID of an existing attachment object. Use this when updating a resource and k

  • direct_upload_id (String, nil) (defaults to: nil)

    This ID should be used the first time you upload an attachment. It is the ID of



# File 'lib/whop_sdk/models/app_update_params.rb', line 112

Instance Attribute Details

#app_store_descriptionString?

The description of the app for the app store in-depth app view.

Returns:

  • (String, nil)


14
# File 'lib/whop_sdk/models/app_update_params.rb', line 14

optional :app_store_description, String, nil?: true

#base_urlString?

The base production url of the app

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/app_update_params.rb', line 20

optional :base_url, String, nil?: true

#dashboard_pathString?

The path for the dashboard view of the app

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/app_update_params.rb', line 26

optional :dashboard_path, String, nil?: true

#descriptionString?

The description of the app

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/app_update_params.rb', line 32

optional :description, String, nil?: true

#discover_pathString?

The path for the discover view of the app

Returns:

  • (String, nil)


38
# File 'lib/whop_sdk/models/app_update_params.rb', line 38

optional :discover_path, String, nil?: true

#experience_pathString?

The path for the hub view of the app

Returns:

  • (String, nil)


44
# File 'lib/whop_sdk/models/app_update_params.rb', line 44

optional :experience_path, String, nil?: true

#iconWhopSDK::Models::AppUpdateParams::Icon?

The icon for the app



50
# File 'lib/whop_sdk/models/app_update_params.rb', line 50

optional :icon, -> { WhopSDK::AppUpdateParams::Icon }, nil?: true

#nameString?

The name of the app

Returns:

  • (String, nil)


56
# File 'lib/whop_sdk/models/app_update_params.rb', line 56

optional :name, String, nil?: true

#required_scopesArray<Symbol, WhopSDK::Models::AppUpdateParams::RequiredScope>?

The scopes that the app will request off of users when a user installs the app.

Returns:



62
63
64
# File 'lib/whop_sdk/models/app_update_params.rb', line 62

optional :required_scopes,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AppUpdateParams::RequiredScope] },
nil?: true

#statusSymbol, ...

The status of an experience interface

Returns:



70
# File 'lib/whop_sdk/models/app_update_params.rb', line 70

optional :status, enum: -> { WhopSDK::AppStatuses }, nil?: true