Class: WhopSDK::Models::AppUpdateParams::Icon

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/app_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(app_store_description: nil, base_url: nil, dashboard_path: nil, description: nil, discover_path: nil, experience_path: nil, icon: nil, name: nil, required_scopes: nil, status: nil, request_options: {}) ⇒ Object

Parameters:

  • app_store_description (String, nil) (defaults to: nil)

    The description of the app for the app store in-depth app view.

  • base_url (String, nil) (defaults to: nil)

    The base production url of the app

  • dashboard_path (String, nil) (defaults to: nil)

    The path for the dashboard view of the app

  • description (String, nil) (defaults to: nil)

    The description of the app

  • discover_path (String, nil) (defaults to: nil)

    The path for the discover view of the app

  • experience_path (String, nil) (defaults to: nil)

    The path for the hub view of the app

  • icon (WhopSDK::Models::AppUpdateParams::Icon, nil) (defaults to: nil)

    The icon for the app

  • name (String, nil) (defaults to: nil)

    The name of the app

  • required_scopes (Array<Symbol, WhopSDK::Models::AppUpdateParams::RequiredScope>, nil) (defaults to: nil)

    The scopes that the app will request off of users when a user installs the app.

  • status (Symbol, WhopSDK::Models::AppStatuses, nil) (defaults to: nil)

    The status of an experience interface

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/whop_sdk/models/app_update_params.rb', line 95

class Icon < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing attachment object. Use this when updating a resource and
  #   keeping a subset of the attachments. Don't use this unless you know what you're
  #   doing.
  #
  #   @return [String, nil]
  optional :id, String, nil?: true

  # @!attribute direct_upload_id
  #   This ID should be used the first time you upload an attachment. It is the ID of
  #   the direct upload that was created when uploading the file to S3 via the
  #   mediaDirectUpload mutation.
  #
  #   @return [String, nil]
  optional :direct_upload_id, String, nil?: true

  # @!method initialize(id: nil, direct_upload_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::AppUpdateParams::Icon} for more details.
  #
  #   The icon for the app
  #
  #   @param id [String, nil] The ID of an existing attachment object. Use this when updating a resource and k
  #
  #   @param direct_upload_id [String, nil] This ID should be used the first time you upload an attachment. It is the ID of
end

Instance Attribute Details

#direct_upload_idString?

This ID should be used the first time you upload an attachment. It is the ID of the direct upload that was created when uploading the file to S3 via the mediaDirectUpload mutation.

Returns:

  • (String, nil)


110
# File 'lib/whop_sdk/models/app_update_params.rb', line 110

optional :direct_upload_id, String, nil?: true

#idString?

The ID of an existing attachment object. Use this when updating a resource and keeping a subset of the attachments. Don’t use this unless you know what you’re doing.

Returns:

  • (String, nil)


102
# File 'lib/whop_sdk/models/app_update_params.rb', line 102

optional :id, String, nil?: true