Class: WhopSDK::Models::AuthorizedUser
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AuthorizedUser
- Defined in:
- lib/whop_sdk/models/authorized_user.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#company ⇒ WhopSDK::Models::AuthorizedUser::Company
The company this authorized user has access to.
-
#id ⇒ String
The unique identifier for the authorized user.
-
#role ⇒ Symbol, WhopSDK::Models::AuthorizedUserRoles
The permission role assigned to this authorized user within the company.
-
#user ⇒ WhopSDK::Models::AuthorizedUser::User
The user account linked to this authorized user record.
Instance Method Summary collapse
-
#initialize(id:, title:) ⇒ Object
constructor
The company this authorized user has access to.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, title:) ⇒ Object
The company this authorized user has access to.
|
|
# File 'lib/whop_sdk/models/authorized_user.rb', line 31
|
Instance Attribute Details
#company ⇒ WhopSDK::Models::AuthorizedUser::Company
The company this authorized user has access to.
17 |
# File 'lib/whop_sdk/models/authorized_user.rb', line 17 required :company, -> { WhopSDK::AuthorizedUser::Company } |
#id ⇒ String
The unique identifier for the authorized user.
11 |
# File 'lib/whop_sdk/models/authorized_user.rb', line 11 required :id, String |
#role ⇒ Symbol, WhopSDK::Models::AuthorizedUserRoles
The permission role assigned to this authorized user within the company.
23 |
# File 'lib/whop_sdk/models/authorized_user.rb', line 23 required :role, enum: -> { WhopSDK::AuthorizedUserRoles } |
#user ⇒ WhopSDK::Models::AuthorizedUser::User
The user account linked to this authorized user record.
29 |
# File 'lib/whop_sdk/models/authorized_user.rb', line 29 required :user, -> { WhopSDK::AuthorizedUser::User } |