Class: WhopSDK::Models::AuthorizedUserCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::AuthorizedUserCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/authorized_user_create_params.rb
Overview
Instance Attribute Summary collapse
-
#company_id ⇒ String
The ID of the company to add the authorized user to.
-
#role ⇒ Symbol, WhopSDK::Models::AuthorizedUserRoles
The role to assign to the authorized user within the company.
-
#send_emails ⇒ Boolean?
Whether to send notification emails to the user on creation.
-
#user_id ⇒ String
The ID of the user to add as an authorized user.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(company_id:, role:, user_id:, send_emails: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AuthorizedUserCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, role:, user_id:, send_emails: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::AuthorizedUserCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 35
|
Instance Attribute Details
#company_id ⇒ String
The ID of the company to add the authorized user to.
14 |
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 14 required :company_id, String |
#role ⇒ Symbol, WhopSDK::Models::AuthorizedUserRoles
The role to assign to the authorized user within the company. Supported roles: ‘moderator’, ‘sales_manager’.
21 |
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 21 required :role, enum: -> { WhopSDK::AuthorizedUserRoles } |
#send_emails ⇒ Boolean?
Whether to send notification emails to the user on creation.
33 |
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 33 optional :send_emails, WhopSDK::Internal::Type::Boolean, nil?: true |
#user_id ⇒ String
The ID of the user to add as an authorized user.
27 |
# File 'lib/whop_sdk/models/authorized_user_create_params.rb', line 27 required :user_id, String |