Class: WhopSDK::Models::BountyCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/bounty_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(base_unit_amount:, currency:, description:, title:, accepted_submissions_limit: nil, allowed_country_codes: nil, experience_id: nil, origin_account_id: nil, post_markdown_content: nil, post_title: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::BountyCreateParams for more details.

D

Parameters:

  • base_unit_amount (Float)

    The amount paid to each approved submission. The total bounty pool funded is thi

  • currency (Symbol, WhopSDK::Models::Currency)

    The currency for the bounty pool funding amount.

  • description (String)

    The description of the bounty.

  • title (String)

    The title of the bounty.

  • accepted_submissions_limit (Integer, nil) (defaults to: nil)

    The number of submissions that can be approved before the bounty closes. Default

  • allowed_country_codes (Array<String>, nil) (defaults to: nil)

    The ISO3166 country codes where this bounty should be visible. Empty means globa

  • experience_id (String, nil) (defaults to: nil)

    An optional experience to scope the bounty to.

  • origin_account_id (String, nil) (defaults to: nil)

    The user (user**) or company (biz**) tag whose balance funds this bounty pool.

  • post_markdown_content (String, nil) (defaults to: nil)

    Optional markdown body for the anchor forum post. Falls back to the bounty descr

  • post_title (String, nil) (defaults to: nil)

    Optional title for the anchor forum post. Falls back to the bounty title when om

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/bounty_create_params.rb', line 77

Instance Attribute Details

#accepted_submissions_limitInteger?

The number of submissions that can be approved before the bounty closes. Defaults to 1.

Returns:

  • (Integer, nil)


40
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 40

optional :accepted_submissions_limit, Integer, nil?: true

#allowed_country_codesArray<String>?

The ISO3166 country codes where this bounty should be visible. Empty means globally visible.

Returns:

  • (Array<String>, nil)


47
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 47

optional :allowed_country_codes, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#base_unit_amountFloat

The amount paid to each approved submission. The total bounty pool funded is this amount times accepted_submissions_limit.

Returns:

  • (Float)


15
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 15

required :base_unit_amount, Float

#currencySymbol, WhopSDK::Models::Currency

The currency for the bounty pool funding amount.

Returns:



21
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 21

required :currency, enum: -> { WhopSDK::Currency }

#descriptionString

The description of the bounty.

Returns:

  • (String)


27
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 27

required :description, String

#experience_idString?

An optional experience to scope the bounty to.

Returns:

  • (String, nil)


53
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 53

optional :experience_id, String, nil?: true

#origin_account_idString?

The user (user**) or company (biz**) tag whose balance funds this bounty pool. Defaults to the requester’s personal balance when omitted. The requester must be the user themself or an owner/admin of the company.

Returns:

  • (String, nil)


61
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 61

optional :origin_account_id, String, nil?: true

#post_markdown_contentString?

Optional markdown body for the anchor forum post. Falls back to the bounty description when omitted.

Returns:

  • (String, nil)


68
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 68

optional :post_markdown_content, String, nil?: true

#post_titleString?

Optional title for the anchor forum post. Falls back to the bounty title when omitted.

Returns:

  • (String, nil)


75
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 75

optional :post_title, String, nil?: true

#titleString

The title of the bounty.

Returns:

  • (String)


33
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 33

required :title, String