Class: WhopSDK::Models::BountyCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::BountyCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/bounty_create_params.rb
Overview
Instance Attribute Summary collapse
-
#accepted_submissions_limit ⇒ Integer?
The number of submissions that can be approved before the bounty closes.
-
#allowed_country_codes ⇒ Array<String>?
The ISO3166 country codes where this bounty should be visible.
-
#base_unit_amount ⇒ Float
The amount paid to each approved submission.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency for the bounty pool funding amount.
-
#description ⇒ String
The description of the bounty.
-
#experience_id ⇒ String?
An optional experience to scope the bounty to.
-
#origin_account_id ⇒ String?
The user (user**) or company (biz**) tag whose balance funds this bounty pool.
-
#post_markdown_content ⇒ String?
Optional markdown body for the anchor forum post.
-
#post_title ⇒ String?
Optional title for the anchor forum post.
-
#title ⇒ String
The title of the bounty.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(base_unit_amount:, currency:, description:, title:, accepted_submissions_limit: nil, allowed_country_codes: nil, experience_id: nil, origin_account_id: nil, post_markdown_content: nil, post_title: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BountyCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(base_unit_amount:, currency:, description:, title:, accepted_submissions_limit: nil, allowed_country_codes: nil, experience_id: nil, origin_account_id: nil, post_markdown_content: nil, post_title: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::BountyCreateParams for more details.
D
|
|
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 77
|
Instance Attribute Details
#accepted_submissions_limit ⇒ Integer?
The number of submissions that can be approved before the bounty closes. Defaults to 1.
40 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 40 optional :accepted_submissions_limit, Integer, nil?: true |
#allowed_country_codes ⇒ Array<String>?
The ISO3166 country codes where this bounty should be visible. Empty means globally visible.
47 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 47 optional :allowed_country_codes, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#base_unit_amount ⇒ Float
The amount paid to each approved submission. The total bounty pool funded is this amount times accepted_submissions_limit.
15 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 15 required :base_unit_amount, Float |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency for the bounty pool funding amount.
21 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 21 required :currency, enum: -> { WhopSDK::Currency } |
#description ⇒ String
The description of the bounty.
27 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 27 required :description, String |
#experience_id ⇒ String?
An optional experience to scope the bounty to.
53 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 53 optional :experience_id, String, nil?: true |
#origin_account_id ⇒ String?
The user (user**) or company (biz**) tag whose balance funds this bounty pool. Defaults to the requester’s personal balance when omitted. The requester must be the user themself or an owner/admin of the company.
61 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 61 optional :origin_account_id, String, nil?: true |
#post_markdown_content ⇒ String?
Optional markdown body for the anchor forum post. Falls back to the bounty description when omitted.
68 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 68 optional :post_markdown_content, String, nil?: true |
#post_title ⇒ String?
Optional title for the anchor forum post. Falls back to the bounty title when omitted.
75 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 75 optional :post_title, String, nil?: true |
#title ⇒ String
The title of the bounty.
33 |
# File 'lib/whop_sdk/models/bounty_create_params.rb', line 33 required :title, String |