Class: WhopSDK::Models::CardUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CardUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/card_update_params.rb,
sig/whop_sdk/models/card_update_params.rbs
Overview
Defined Under Namespace
Modules: SpendLimitFrequency Classes: Billing
Instance Attribute Summary collapse
-
#account_id ⇒ String?
The owning account ID (a biz_ identifier).
-
#billing ⇒ WhopSDK::Models::CardUpdateParams::Billing?
New billing address.
-
#canceled ⇒ Boolean?
Pass
trueto permanently cancel the card. - #card_id ⇒ String
-
#frozen ⇒ Boolean?
Pass
trueto freeze the card,falseto unfreeze it. -
#name ⇒ String?
A display name for the card.
-
#pin ⇒ String?
New 4-digit PIN.
-
#remove_limit ⇒ Boolean?
Pass
trueto remove the spending limit (make the card unlimited). -
#spend_limit ⇒ Float?
Spending limit amount, in dollars.
-
#spend_limit_frequency ⇒ Symbol, ...
The spending limit window.
-
#transaction_limit ⇒ Float?
Per-transaction limit amount, in dollars.
-
#user_id ⇒ String?
The owning user ID (a user_ identifier).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(city:, country_code:, line1:, postal_code:, region:, line2: nil) ⇒ Object
constructor
New billing address.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city:, country_code:, line1:, postal_code:, region:, line2: nil) ⇒ Object
New billing address. Requires line1, city, region, postal_code, and country_code.
|
|
# File 'lib/whop_sdk/models/card_update_params.rb', line 150
|
Instance Attribute Details
#account_id ⇒ String?
The owning account ID (a biz_ identifier). Provide this or user_id.
19 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 19 optional :account_id, String |
#billing ⇒ WhopSDK::Models::CardUpdateParams::Billing?
New billing address. Requires line1, city, region, postal_code, and country_code.
26 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 26 optional :billing, -> { WhopSDK::CardUpdateParams::Billing } |
#canceled ⇒ Boolean?
Pass true to permanently cancel the card. A canceled card cannot be
uncanceled. Cannot be combined with other fields.
33 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 33 optional :canceled, WhopSDK::Internal::Type::Boolean |
#card_id ⇒ String
13 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 13 required :card_id, String |
#frozen ⇒ Boolean?
Pass true to freeze the card, false to unfreeze it.
39 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 39 optional :frozen, WhopSDK::Internal::Type::Boolean |
#name ⇒ String?
A display name for the card.
45 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 45 optional :name, String |
#pin ⇒ String?
New 4-digit PIN. Can only be set on a card assigned to the acting user.
51 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 51 optional :pin, String |
#remove_limit ⇒ Boolean?
Pass true to remove the spending limit (make the card unlimited).
57 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 57 optional :remove_limit, WhopSDK::Internal::Type::Boolean |
#spend_limit ⇒ Float?
Spending limit amount, in dollars.
63 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 63 optional :spend_limit, Float |
#spend_limit_frequency ⇒ Symbol, ...
The spending limit window.
69 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 69 optional :spend_limit_frequency, enum: -> { WhopSDK::CardUpdateParams::SpendLimitFrequency } |
#transaction_limit ⇒ Float?
Per-transaction limit amount, in dollars.
75 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 75 optional :transaction_limit, Float |
#user_id ⇒ String?
The owning user ID (a user_ identifier). Provide this or account_id.
81 |
# File 'lib/whop_sdk/models/card_update_params.rb', line 81 optional :user_id, String |
Instance Method Details
#to_hash ⇒ {
90 |
# File 'sig/whop_sdk/models/card_update_params.rbs', line 90
def to_hash: -> {
|