Class: WhopSDK::Models::ChatChannel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ChatChannel
- Defined in:
- lib/whop_sdk/models/chat_channel.rb
Defined Under Namespace
Classes: Experience
Instance Attribute Summary collapse
-
#ban_media ⇒ Boolean
Whether or not media is banned in this chat.
-
#ban_urls ⇒ Boolean
Whether or not URLs are banned in this chat.
-
#banned_words ⇒ Array<String>
List of banned words in this chat.
-
#experience ⇒ WhopSDK::Models::ChatChannel::Experience
The experience for this chat.
-
#id ⇒ String
The unique identifier for the entity.
-
#user_posts_cooldown_seconds ⇒ Integer?
The number of seconds a user needs to wait before posting again, if any.
-
#who_can_post ⇒ Symbol, WhopSDK::Models::WhoCanPost
Who can post on this chat.
-
#who_can_react ⇒ Symbol, WhopSDK::Models::WhoCanReact
Who can react on this chat.
Instance Method Summary collapse
-
#initialize(id: , ban_media: , ban_urls: , banned_words: , experience: , user_posts_cooldown_seconds: , who_can_post: , who_can_react: ) ⇒ Object
constructor
Represents a Chat feed.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , ban_media: , ban_urls: , banned_words: , experience: , user_posts_cooldown_seconds: , who_can_post: , who_can_react: ) ⇒ Object
Represents a Chat feed
|
|
# File 'lib/whop_sdk/models/chat_channel.rb', line 54
|
Instance Attribute Details
#ban_media ⇒ Boolean
Whether or not media is banned in this chat
16 |
# File 'lib/whop_sdk/models/chat_channel.rb', line 16 required :ban_media, WhopSDK::Internal::Type::Boolean |
#ban_urls ⇒ Boolean
Whether or not URLs are banned in this chat
22 |
# File 'lib/whop_sdk/models/chat_channel.rb', line 22 required :ban_urls, WhopSDK::Internal::Type::Boolean |
#banned_words ⇒ Array<String>
List of banned words in this chat
28 |
# File 'lib/whop_sdk/models/chat_channel.rb', line 28 required :banned_words, WhopSDK::Internal::Type::ArrayOf[String] |
#experience ⇒ WhopSDK::Models::ChatChannel::Experience
The experience for this chat
34 |
# File 'lib/whop_sdk/models/chat_channel.rb', line 34 required :experience, -> { WhopSDK::ChatChannel::Experience } |
#id ⇒ String
The unique identifier for the entity
10 |
# File 'lib/whop_sdk/models/chat_channel.rb', line 10 required :id, String |
#user_posts_cooldown_seconds ⇒ Integer?
The number of seconds a user needs to wait before posting again, if any
40 |
# File 'lib/whop_sdk/models/chat_channel.rb', line 40 required :user_posts_cooldown_seconds, Integer, nil?: true |
#who_can_post ⇒ Symbol, WhopSDK::Models::WhoCanPost
Who can post on this chat
46 |
# File 'lib/whop_sdk/models/chat_channel.rb', line 46 required :who_can_post, enum: -> { WhopSDK::WhoCanPost } |
#who_can_react ⇒ Symbol, WhopSDK::Models::WhoCanReact
Who can react on this chat
52 |
# File 'lib/whop_sdk/models/chat_channel.rb', line 52 required :who_can_react, enum: -> { WhopSDK::WhoCanReact } |