Class: WhopSDK::Models::ChatChannelListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/chat_channel_list_response.rb

Overview

Defined Under Namespace

Classes: Experience

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , ban_media: , ban_urls: , banned_words: , experience: , user_posts_cooldown_seconds: , who_can_post: , who_can_react: ) ⇒ Object

Represents a Chat feed

Parameters:

  • id (String) (defaults to: )

    The unique identifier for the entity

  • ban_media (Boolean) (defaults to: )

    Whether or not media is banned in this chat

  • ban_urls (Boolean) (defaults to: )

    Whether or not URLs are banned in this chat

  • banned_words (Array<String>) (defaults to: )

    List of banned words in this chat

  • experience (WhopSDK::Models::ChatChannelListResponse::Experience) (defaults to: )

    The experience for this chat

  • user_posts_cooldown_seconds (Integer, nil) (defaults to: )

    The number of seconds a user needs to wait before posting again, if any

  • who_can_post (Symbol, WhopSDK::Models::WhoCanPost) (defaults to: )

    Who can post on this chat

  • who_can_react (Symbol, WhopSDK::Models::WhoCanReact) (defaults to: )

    Who can react on this chat



# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 55

Instance Attribute Details

#ban_mediaBoolean

Whether or not media is banned in this chat

Returns:

  • (Boolean)


17
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 17

required :ban_media, WhopSDK::Internal::Type::Boolean

#ban_urlsBoolean

Whether or not URLs are banned in this chat

Returns:

  • (Boolean)


23
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 23

required :ban_urls, WhopSDK::Internal::Type::Boolean

#banned_wordsArray<String>

List of banned words in this chat

Returns:

  • (Array<String>)


29
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 29

required :banned_words, WhopSDK::Internal::Type::ArrayOf[String]

#experienceWhopSDK::Models::ChatChannelListResponse::Experience

The experience for this chat



35
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 35

required :experience, -> { WhopSDK::Models::ChatChannelListResponse::Experience }

#idString

The unique identifier for the entity

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 11

required :id, String

#user_posts_cooldown_secondsInteger?

The number of seconds a user needs to wait before posting again, if any

Returns:

  • (Integer, nil)


41
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 41

required :user_posts_cooldown_seconds, Integer, nil?: true

#who_can_postSymbol, WhopSDK::Models::WhoCanPost

Who can post on this chat

Returns:



47
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 47

required :who_can_post, enum: -> { WhopSDK::WhoCanPost }

#who_can_reactSymbol, WhopSDK::Models::WhoCanReact

Who can react on this chat

Returns:



53
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 53

required :who_can_react, enum: -> { WhopSDK::WhoCanReact }