Class: WhopSDK::Models::ChatChannelListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ChatChannelListResponse
- Defined in:
- lib/whop_sdk/models/chat_channel_list_response.rb
Overview
Defined Under Namespace
Classes: Experience
Instance Attribute Summary collapse
-
#ban_media ⇒ Boolean
Whether or not media is banned in this chat.
-
#ban_urls ⇒ Boolean
Whether or not URLs are banned in this chat.
-
#banned_words ⇒ Array<String>
List of banned words in this chat.
-
#experience ⇒ WhopSDK::Models::ChatChannelListResponse::Experience
The experience for this chat.
-
#id ⇒ String
The unique identifier for the entity.
-
#user_posts_cooldown_seconds ⇒ Integer?
The number of seconds a user needs to wait before posting again, if any.
-
#who_can_post ⇒ Symbol, WhopSDK::Models::WhoCanPost
Who can post on this chat.
-
#who_can_react ⇒ Symbol, WhopSDK::Models::WhoCanReact
Who can react on this chat.
Instance Method Summary collapse
-
#initialize(id: , ban_media: , ban_urls: , banned_words: , experience: , user_posts_cooldown_seconds: , who_can_post: , who_can_react: ) ⇒ Object
constructor
Represents a Chat feed.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , ban_media: , ban_urls: , banned_words: , experience: , user_posts_cooldown_seconds: , who_can_post: , who_can_react: ) ⇒ Object
Represents a Chat feed
|
|
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 55
|
Instance Attribute Details
#ban_media ⇒ Boolean
Whether or not media is banned in this chat
17 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 17 required :ban_media, WhopSDK::Internal::Type::Boolean |
#ban_urls ⇒ Boolean
Whether or not URLs are banned in this chat
23 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 23 required :ban_urls, WhopSDK::Internal::Type::Boolean |
#banned_words ⇒ Array<String>
List of banned words in this chat
29 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 29 required :banned_words, WhopSDK::Internal::Type::ArrayOf[String] |
#experience ⇒ WhopSDK::Models::ChatChannelListResponse::Experience
The experience for this chat
35 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 35 required :experience, -> { WhopSDK::Models::ChatChannelListResponse::Experience } |
#id ⇒ String
The unique identifier for the entity
11 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 11 required :id, String |
#user_posts_cooldown_seconds ⇒ Integer?
The number of seconds a user needs to wait before posting again, if any
41 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 41 required :user_posts_cooldown_seconds, Integer, nil?: true |
#who_can_post ⇒ Symbol, WhopSDK::Models::WhoCanPost
Who can post on this chat
47 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 47 required :who_can_post, enum: -> { WhopSDK::WhoCanPost } |
#who_can_react ⇒ Symbol, WhopSDK::Models::WhoCanReact
Who can react on this chat
53 |
# File 'lib/whop_sdk/models/chat_channel_list_response.rb', line 53 required :who_can_react, enum: -> { WhopSDK::WhoCanReact } |