Class: WhopSDK::Models::CheckoutConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfiguration
- Defined in:
- lib/whop_sdk/models/checkout_configuration.rb
Defined Under Namespace
Classes: PaymentMethodConfiguration, Plan
Instance Attribute Summary collapse
-
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration.
-
#company_id ⇒ String
The ID of the company to use for the checkout configuration.
-
#id ⇒ String
The ID of the checkout configuration.
-
#metadata ⇒ Hash{Symbol=>Object}?
The metadata to use for the checkout configuration.
-
#mode ⇒ Symbol, WhopSDK::Models::CheckoutModes
The mode of the checkout session.
-
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfiguration::PaymentMethodConfiguration?
The explicit payment method configuration for the session, if any.
-
#plan ⇒ WhopSDK::Models::CheckoutConfiguration::Plan?
The plan to use for the checkout configuration.
-
#purchase_url ⇒ String
A URL you can send to customers to complete a checkout.
-
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created.
Instance Method Summary collapse
-
#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
The explicit payment method configuration for the session, if any. This currently only works in ‘setup’ mode. Use the plan’s payment_method_configuration for payment method.
|
|
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 65
|
Instance Attribute Details
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration
16 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 16 required :affiliate_code, String, nil?: true |
#company_id ⇒ String
The ID of the company to use for the checkout configuration
22 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 22 required :company_id, String |
#id ⇒ String
The ID of the checkout configuration
10 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 10 required :id, String |
#metadata ⇒ Hash{Symbol=>Object}?
The metadata to use for the checkout configuration
28 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 28 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#mode ⇒ Symbol, WhopSDK::Models::CheckoutModes
The mode of the checkout session.
34 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 34 required :mode, enum: -> { WhopSDK::CheckoutModes } |
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfiguration::PaymentMethodConfiguration?
The explicit payment method configuration for the session, if any. This currently only works in ‘setup’ mode. Use the plan’s payment_method_configuration for payment method.
42 43 44 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 42 required :payment_method_configuration, -> { WhopSDK::CheckoutConfiguration::PaymentMethodConfiguration }, nil?: true |
#plan ⇒ WhopSDK::Models::CheckoutConfiguration::Plan?
The plan to use for the checkout configuration
50 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 50 required :plan, -> { WhopSDK::CheckoutConfiguration::Plan }, nil?: true |
#purchase_url ⇒ String
A URL you can send to customers to complete a checkout. It looks like ‘/checkout/plan_xxxx?session=#id`
57 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 57 required :purchase_url, String |
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created
63 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 63 required :redirect_url, String, nil?: true |