Class: WhopSDK::Models::CheckoutConfiguration

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/checkout_configuration.rb

Defined Under Namespace

Classes: Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , affiliate_code: , company_id: , metadata: , plan: , purchase_url: , redirect_url: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CheckoutConfiguration for more details.

A checkout configuration object.
Can be used to create a reusable custom configuration for a checkout, including attaching plans, affiliates and custom metadata to the checkout.
This configuration can be re-used by multiple users.
All successful payments and memberships resulting from a checkout will contain the passed metadata.

Parameters:

  • id (String) (defaults to: )

    The ID of the checkout configuration

  • affiliate_code (String, nil) (defaults to: )

    The affiliate code to use for the checkout configuration

  • company_id (String) (defaults to: )

    The ID of the company to use for the checkout configuration

  • metadata (Hash{Symbol=>Object}) (defaults to: )

    The metadata to use for the checkout configuration

  • plan (WhopSDK::Models::CheckoutConfiguration::Plan) (defaults to: )

    The plan to use for the checkout configuration

  • purchase_url (String) (defaults to: )

    A URL you can send to customers to complete a checkout. It looks like ‘/checkout

  • redirect_url (String, nil) (defaults to: )

    The URL to redirect the user to after the checkout configuration is created



# File 'lib/whop_sdk/models/checkout_configuration.rb', line 49

Instance Attribute Details

#affiliate_codeString?

The affiliate code to use for the checkout configuration

Returns:

  • (String, nil)


16
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 16

required :affiliate_code, String, nil?: true

#company_idString

The ID of the company to use for the checkout configuration

Returns:

  • (String)


22
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 22

required :company_id, String

#idString

The ID of the checkout configuration

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 10

required :id, String

#metadataHash{Symbol=>Object}

The metadata to use for the checkout configuration

Returns:

  • (Hash{Symbol=>Object})


28
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 28

required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown]

#planWhopSDK::Models::CheckoutConfiguration::Plan

The plan to use for the checkout configuration



34
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 34

required :plan, -> { WhopSDK::CheckoutConfiguration::Plan }

#purchase_urlString

A URL you can send to customers to complete a checkout. It looks like ‘/checkout/plan_xxxx?session=#id`

Returns:

  • (String)


41
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 41

required :purchase_url, String

#redirect_urlString?

The URL to redirect the user to after the checkout configuration is created

Returns:

  • (String, nil)


47
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 47

required :redirect_url, String, nil?: true