Class: WhopSDK::Models::CheckoutConfiguration::Plan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfiguration::Plan
- Defined in:
- lib/whop_sdk/models/checkout_configuration.rb
Overview
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
-
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
-
#id ⇒ String
The internal ID of the plan.
-
#initial_price ⇒ Float
The price a person has to pay for a plan on the initial purchase.
-
#plan_type ⇒ Symbol, WhopSDK::Models::PlanType
Indicates if the plan is a one time payment or recurring.
-
#release_method ⇒ Symbol, WhopSDK::Models::ReleaseMethod
This is the release method the business uses to sell this plan.
-
#renewal_price ⇒ Float
The price a person has to pay for a plan on the renewal purchase.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Shows or hides the plan from public/business view.
Instance Method Summary collapse
-
#initialize(id: , billing_period: , currency: , expiration_days: , initial_price: , plan_type: , release_method: , renewal_price: , trial_period_days: , visibility: ) ⇒ Object
constructor
The plan to use for the checkout configuration.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , billing_period: , currency: , expiration_days: , initial_price: , plan_type: , release_method: , renewal_price: , trial_period_days: , visibility: ) ⇒ Object
The plan to use for the checkout configuration
|
|
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 196
|
Instance Attribute Details
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
146 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 146 required :billing_period, Integer, nil?: true |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
152 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 152 required :currency, enum: -> { WhopSDK::Currency } |
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
158 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 158 required :expiration_days, Integer, nil?: true |
#id ⇒ String
The internal ID of the plan.
140 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 140 required :id, String |
#initial_price ⇒ Float
The price a person has to pay for a plan on the initial purchase.
164 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 164 required :initial_price, Float |
#plan_type ⇒ Symbol, WhopSDK::Models::PlanType
Indicates if the plan is a one time payment or recurring.
170 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 170 required :plan_type, enum: -> { WhopSDK::PlanType } |
#release_method ⇒ Symbol, WhopSDK::Models::ReleaseMethod
This is the release method the business uses to sell this plan.
176 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 176 required :release_method, enum: -> { WhopSDK::ReleaseMethod } |
#renewal_price ⇒ Float
The price a person has to pay for a plan on the renewal purchase.
182 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 182 required :renewal_price, Float |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
188 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 188 required :trial_period_days, Integer, nil?: true |
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Shows or hides the plan from public/business view.
194 |
# File 'lib/whop_sdk/models/checkout_configuration.rb', line 194 required :visibility, enum: -> { WhopSDK::Visibility } |