Class: WhopSDK::Models::CheckoutConfigurationCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Overview
Defined Under Namespace
Classes: PaymentMethodConfiguration, Plan
Instance Attribute Summary collapse
-
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration.
-
#company_id ⇒ String
The ID of the company for which to generate the checkout configuration.
-
#metadata ⇒ Hash{Symbol=>Object}?
The metadata to use for the checkout configuration.
- #mode ⇒ Symbol, :setup
-
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::PaymentMethodConfiguration?
This currently only works for configurations made in ‘setup’ mode.
-
#plan ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Plan
Pass this object to create a new plan for this checkout configuration.
-
#plan_id ⇒ String
The ID of the plan to use for the checkout configuration.
-
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(external_identifier: , title: , business_type: nil, collect_shipping_address: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, industry_type: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Plan::Product for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_identifier: , title: , business_type: nil, collect_shipping_address: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, industry_type: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Product for more details.
Pass this object to create a new product for this plan. We will use the product external identifier to find or create an existing product.
betwee
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 497
|
Instance Attribute Details
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration
20 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 20 optional :affiliate_code, String, nil?: true |
#company_id ⇒ String
The ID of the company for which to generate the checkout configuration. Only required in setup mode.
60 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 60 required :company_id, String |
#metadata ⇒ Hash{Symbol=>Object}?
The metadata to use for the checkout configuration
26 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 26 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#mode ⇒ Symbol, :setup
31 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 31 required :mode, const: :setup |
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::PaymentMethodConfiguration?
This currently only works for configurations made in ‘setup’ mode. The explicit payment method configuration for the checkout session. If not provided, the platform or company’s defaults will apply.
39 40 41 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 39 optional :payment_method_configuration, -> { WhopSDK::CheckoutConfigurationCreateParams::PaymentMethodConfiguration }, nil?: true |
#plan ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Plan
Pass this object to create a new plan for this checkout configuration
14 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 14 required :plan, -> { WhopSDK::CheckoutConfigurationCreateParams::Plan } |
#plan_id ⇒ String
The ID of the plan to use for the checkout configuration
53 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 53 required :plan_id, String |
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created
47 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 47 optional :redirect_url, String, nil?: true |