Class: WhopSDK::Models::CheckoutConfigurationCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Overview
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration.
-
#metadata ⇒ Hash{Symbol=>Object}?
The metadata to use for the checkout configuration.
-
#plan ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Plan?
Pass this object to create a new plan for this checkout configuration.
-
#plan_id ⇒ String?
The ID of the plan to use for the checkout configuration.
-
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration
14 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 14 optional :affiliate_code, String, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
The metadata to use for the checkout configuration
20 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 20 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#plan ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Plan?
Pass this object to create a new plan for this checkout configuration
26 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 26 optional :plan, -> { WhopSDK::CheckoutConfigurationCreateParams::Plan }, nil?: true |
#plan_id ⇒ String?
The ID of the plan to use for the checkout configuration
32 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 32 optional :plan_id, String, nil?: true |
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created
38 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 38 optional :redirect_url, String, nil?: true |