Module: WhopSDK::Models::CheckoutConfigurationCreateParams::Body
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Overview
Parameters for CreateCheckoutSession
Defined Under Namespace
Classes: CreateCheckoutSessionInputModePaymentWithPlan, CreateCheckoutSessionInputModePaymentWithPlanID, CreateCheckoutSessionInputModeSetup
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(disabled:, enabled:, include_platform_defaults:) ⇒ Object
Some parameter documentations has been truncated, see CreateCheckoutSessionInputModePaymentWithPlanID::PaymentMethodConfiguration for more details.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan, WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID, WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup)
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 1005
|
Instance Method Details
#initialize(disabled:, enabled:, include_platform_defaults:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::PaymentMethodConfiguration for more details.
The explicit payment method configuration for the checkout session. Only applies to setup mode. If not provided, the platform or company defaults will apply.
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 642
|