Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Defined Under Namespace
Modules: Mode Classes: CheckoutStyling, PaymentMethodConfiguration, Plan
Instance Attribute Summary collapse
-
#affiliate_code ⇒ String?
An affiliate tracking code to attribute the checkout to a specific affiliate.
-
#allow_promo_codes ⇒ Boolean?
Whether the checkout should show the promo code input field and accept promo codes.
-
#checkout_styling ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::CheckoutStyling?
Checkout styling overrides for this session.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value metadata to attach to the checkout configuration.
- #mode ⇒ Symbol, ...
-
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::PaymentMethodConfiguration?
The explicit payment method configuration for the checkout session.
-
#plan ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan
The plan attributes to create a new plan inline for this checkout configuration.
-
#redirect_url ⇒ String?
The URL to redirect the user to after checkout is completed.
-
#source_url ⇒ String?
The URL of the page where the checkout is being initiated from.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(border_style: nil, button_color: nil, font_family: nil) ⇒ Object
constructor
Checkout styling overrides for this session.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(border_style: nil, button_color: nil, font_family: nil) ⇒ Object
Checkout styling overrides for this session. Overrides plan and company defaults.
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 107
|
Instance Attribute Details
#affiliate_code ⇒ String?
An affiliate tracking code to attribute the checkout to a specific affiliate.
46 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 46 optional :affiliate_code, String, nil?: true |
#allow_promo_codes ⇒ Boolean?
Whether the checkout should show the promo code input field and accept promo codes. Defaults to true.
53 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 53 optional :allow_promo_codes, WhopSDK::Internal::Type::Boolean, nil?: true |
#checkout_styling ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::CheckoutStyling?
Checkout styling overrides for this session. Overrides plan and company defaults.
60 61 62 63 64 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 60 optional :checkout_styling, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::CheckoutStyling }, nil?: true |
#currency ⇒ Symbol, ...
The available currencies on the platform
70 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 70 optional :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value metadata to attach to the checkout configuration.
76 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 76 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#mode ⇒ Symbol, ...
81 82 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 81 optional :mode, enum: -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Mode } |
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::PaymentMethodConfiguration?
The explicit payment method configuration for the checkout session. Only applies to setup mode. If not provided, the platform or company defaults will apply.
89 90 91 92 93 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 89 optional :payment_method_configuration, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::PaymentMethodConfiguration }, nil?: true |
#plan ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan
The plan attributes to create a new plan inline for this checkout configuration.
39 40 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 39 required :plan, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan } |
#redirect_url ⇒ String?
The URL to redirect the user to after checkout is completed.
99 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 99 optional :redirect_url, String, nil?: true |
#source_url ⇒ String?
The URL of the page where the checkout is being initiated from.
105 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 105 optional :source_url, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 612
|