Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Overview
Defined Under Namespace
Classes: CustomField, Image, PaymentMethodConfiguration, Product
Instance Attribute Summary collapse
-
#application_fee_amount ⇒ Float?
The application fee amount collected by the platform from this connected account.
-
#billing_period ⇒ Integer?
The interval in days at which the plan charges (renewal plans).
-
#company_id ⇒ String
The company the plan should be created for.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
-
#custom_fields ⇒ Array<WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::CustomField>?
An array of custom field objects.
-
#description ⇒ String?
The description of the plan.
-
#expiration_days ⇒ Integer?
The number of days until the membership expires (for expiration-based plans).
-
#force_create_new_plan ⇒ Boolean?
Whether to force the creation of a new plan even if one with the same attributes already exists.
-
#image ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::Image?
An image for the plan.
-
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
-
#internal_notes ⇒ String?
A personal description or notes section for the business.
-
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up).
-
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::PaymentMethodConfiguration?
The explicit payment method configuration for the plan.
-
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to a product.
-
#product ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::Product?
Pass this object to create a new product for this plan.
-
#product_id ⇒ String?
The product the plan is related to.
-
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
-
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
-
#split_pay_required_payments ⇒ Integer?
The number of payments required before pausing the subscription.
-
#stock ⇒ Integer?
The number of units available for purchase.
-
#title ⇒ String?
The title of the plan.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Instance Method Summary collapse
-
#initialize(disabled:, enabled:, include_platform_defaults:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(disabled:, enabled:, include_platform_defaults:) ⇒ Object
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
The explicit payment method configuration for the plan. If not provided, the platform or company’s defaults will apply.
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 393
|
Instance Attribute Details
#application_fee_amount ⇒ Float?
The application fee amount collected by the platform from this connected account. Provided as a number in dollars (e.g., 5.00 for $5.00). Must be less than the total payment amount. Only valid for connected accounts with a parent company.
155 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 155 optional :application_fee_amount, Float, nil?: true |
#billing_period ⇒ Integer?
The interval in days at which the plan charges (renewal plans). For example, 30 for monthly billing.
162 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 162 optional :billing_period, Integer, nil?: true |
#company_id ⇒ String
The company the plan should be created for.
140 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 140 required :company_id, String |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
146 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 146 required :currency, enum: -> { WhopSDK::Currency } |
#custom_fields ⇒ Array<WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::CustomField>?
An array of custom field objects.
168 169 170 171 172 173 174 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 168 optional :custom_fields, -> do WhopSDK::Internal::Type::ArrayOf[ WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::CustomField ] end, nil?: true |
#description ⇒ String?
The description of the plan.
180 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 180 optional :description, String, nil?: true |
#expiration_days ⇒ Integer?
The number of days until the membership expires (for expiration-based plans). For example, 365 for a one-year access pass.
187 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 187 optional :expiration_days, Integer, nil?: true |
#force_create_new_plan ⇒ Boolean?
Whether to force the creation of a new plan even if one with the same attributes already exists.
194 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 194 optional :force_create_new_plan, WhopSDK::Internal::Type::Boolean, nil?: true |
#image ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::Image?
An image for the plan. This will be visible on the product page to customers.
200 201 202 203 204 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 200 optional :image, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::Image }, nil?: true |
#initial_price ⇒ Float?
An additional amount charged upon first purchase. Provided as a number in dollars (e.g., 10.00 for $10.00).
211 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 211 optional :initial_price, Float, nil?: true |
#internal_notes ⇒ String?
A personal description or notes section for the business.
217 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 217 optional :internal_notes, String, nil?: true |
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up)
224 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 224 optional :override_tax_type, enum: -> { WhopSDK::TaxType }, nil?: true |
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::PaymentMethodConfiguration?
The explicit payment method configuration for the plan. If not provided, the platform or company’s defaults will apply.
231 232 233 234 235 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 231 optional :payment_method_configuration, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::PaymentMethodConfiguration }, nil?: true |
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to a product
241 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 241 optional :plan_type, enum: -> { WhopSDK::PlanType }, nil?: true |
#product ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::Product?
Pass this object to create a new product for this plan. We will use the product external identifier to find or create an existing product.
248 249 250 251 252 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 248 optional :product, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlan::Plan::Product }, nil?: true |
#product_id ⇒ String?
The product the plan is related to. Either this or product is required.
258 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 258 optional :product_id, String, nil?: true |
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
264 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 264 optional :release_method, enum: -> { WhopSDK::ReleaseMethod }, nil?: true |
#renewal_price ⇒ Float?
The amount the customer is charged every billing period. Provided as a number in dollars (e.g., 9.99 for $9.99/period).
271 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 271 optional :renewal_price, Float, nil?: true |
#split_pay_required_payments ⇒ Integer?
The number of payments required before pausing the subscription.
277 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 277 optional :split_pay_required_payments, Integer, nil?: true |
#stock ⇒ Integer?
The number of units available for purchase. If not provided, stock is unlimited.
283 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 283 optional :stock, Integer, nil?: true |
#title ⇒ String?
The title of the plan. This will be visible on the product page to customers.
289 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 289 optional :title, String, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
295 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 295 optional :trial_period_days, Integer, nil?: true |
#visibility ⇒ Symbol, ...
Visibility of a resource
301 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 301 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |