Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Defined Under Namespace
Modules: Mode Classes: CheckoutStyling, PaymentMethodConfiguration
Instance Attribute Summary collapse
-
#affiliate_code ⇒ String?
An affiliate tracking code to attribute the checkout to a specific affiliate.
-
#allow_promo_codes ⇒ Boolean?
Whether the checkout should show the promo code input field and accept promo codes.
-
#checkout_styling ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::CheckoutStyling?
Checkout styling overrides for this session.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value metadata to attach to the checkout configuration.
- #mode ⇒ Symbol, ...
-
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::PaymentMethodConfiguration?
The explicit payment method configuration for the checkout session.
-
#plan_id ⇒ String
The unique identifier of an existing plan to use for this checkout configuration.
-
#redirect_url ⇒ String?
The URL to redirect the user to after checkout is completed.
-
#source_url ⇒ String?
The URL of the page where the checkout is being initiated from.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(border_style: nil, button_color: nil, font_family: nil) ⇒ Object
constructor
Checkout styling overrides for this session.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(border_style: nil, button_color: nil, font_family: nil) ⇒ Object
Checkout styling overrides for this session. Overrides plan and company defaults.
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 731
|
Instance Attribute Details
#affiliate_code ⇒ String?
An affiliate tracking code to attribute the checkout to a specific affiliate.
670 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 670 optional :affiliate_code, String, nil?: true |
#allow_promo_codes ⇒ Boolean?
Whether the checkout should show the promo code input field and accept promo codes. Defaults to true.
677 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 677 optional :allow_promo_codes, WhopSDK::Internal::Type::Boolean, nil?: true |
#checkout_styling ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::CheckoutStyling?
Checkout styling overrides for this session. Overrides plan and company defaults.
684 685 686 687 688 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 684 optional :checkout_styling, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::CheckoutStyling }, nil?: true |
#currency ⇒ Symbol, ...
The available currencies on the platform
694 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 694 optional :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value metadata to attach to the checkout configuration.
700 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 700 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#mode ⇒ Symbol, ...
705 706 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 705 optional :mode, enum: -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::Mode } |
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::PaymentMethodConfiguration?
The explicit payment method configuration for the checkout session. Only applies to setup mode. If not provided, the platform or company defaults will apply.
713 714 715 716 717 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 713 optional :payment_method_configuration, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModePaymentWithPlanID::PaymentMethodConfiguration }, nil?: true |
#plan_id ⇒ String
The unique identifier of an existing plan to use for this checkout configuration.
664 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 664 required :plan_id, String |
#redirect_url ⇒ String?
The URL to redirect the user to after checkout is completed.
723 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 723 optional :redirect_url, String, nil?: true |
#source_url ⇒ String?
The URL of the page where the checkout is being initiated from.
729 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 729 optional :source_url, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 795
|