Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Defined Under Namespace
Modules: ThreeDSLevel Classes: CheckoutStyling, PaymentMethodConfiguration
Instance Attribute Summary collapse
-
#allow_promo_codes ⇒ Boolean?
Whether the checkout should show the promo code input field and accept promo codes.
-
#checkout_styling ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::CheckoutStyling?
Checkout styling overrides for this session.
-
#company_id ⇒ String
The unique identifier of the company to create the checkout configuration for.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value metadata to attach to the checkout configuration.
- #mode ⇒ Symbol, :setup
-
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::PaymentMethodConfiguration?
The explicit payment method configuration for the checkout session.
-
#redirect_url ⇒ String?
The URL to redirect the user to after checkout is completed.
-
#source_url ⇒ String?
The URL of the page where the checkout is being initiated from.
-
#three_ds_level ⇒ Symbol, ...
The 3D Secure behavior for a plan.
Instance Method Summary collapse
-
#initialize(disabled:, enabled:, include_platform_defaults: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(disabled:, enabled:, include_platform_defaults: nil) ⇒ Object
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
The explicit payment method configuration for the checkout session. Only applies to setup mode. If not provided, the platform or company defaults will apply.
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 951
|
Instance Attribute Details
#allow_promo_codes ⇒ Boolean?
Whether the checkout should show the promo code input field and accept promo codes. Defaults to true.
893 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 893 optional :allow_promo_codes, WhopSDK::Internal::Type::Boolean, nil?: true |
#checkout_styling ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::CheckoutStyling?
Checkout styling overrides for this session. Overrides plan and company defaults.
900 901 902 903 904 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 900 optional :checkout_styling, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::CheckoutStyling }, nil?: true |
#company_id ⇒ String
The unique identifier of the company to create the checkout configuration for. Only required in setup mode.
881 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 881 required :company_id, String |
#currency ⇒ Symbol, ...
The available currencies on the platform
910 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 910 optional :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value metadata to attach to the checkout configuration.
916 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 916 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#mode ⇒ Symbol, :setup
886 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 886 required :mode, const: :setup |
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::PaymentMethodConfiguration?
The explicit payment method configuration for the checkout session. Only applies to setup mode. If not provided, the platform or company defaults will apply.
923 924 925 926 927 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 923 optional :payment_method_configuration, -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::PaymentMethodConfiguration }, nil?: true |
#redirect_url ⇒ String?
The URL to redirect the user to after checkout is completed.
933 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 933 optional :redirect_url, String, nil?: true |
#source_url ⇒ String?
The URL of the page where the checkout is being initiated from.
939 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 939 optional :source_url, String, nil?: true |
#three_ds_level ⇒ Symbol, ...
The 3D Secure behavior for a plan.
945 946 947 948 949 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 945 optional :three_ds_level, enum: -> { WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::ThreeDSLevel }, nil?: true |