Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/whop_sdk/models/checkout_configuration_create_params.rb

Defined Under Namespace

Classes: CheckoutStyling, PaymentMethodConfiguration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(border_style: nil, button_color: nil, font_family: nil) ⇒ Object

Checkout styling overrides for this session. Overrides plan and company defaults.

Parameters:

  • border_style (Symbol, WhopSDK::Models::CheckoutShape, nil) (defaults to: nil)

    The different border-radius styles available for checkout pages.

  • button_color (String, nil) (defaults to: nil)

    A hex color code for the button color (e.g. #FF5733).

  • font_family (Symbol, WhopSDK::Models::CheckoutFont, nil) (defaults to: nil)

    The different font families available for checkout pages.



# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 907

Instance Attribute Details

#allow_promo_codesBoolean?

Whether the checkout should show the promo code input field and accept promo codes. Defaults to true.

Returns:

  • (Boolean, nil)


859
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 859

optional :allow_promo_codes, WhopSDK::Internal::Type::Boolean, nil?: true

#checkout_stylingWhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::CheckoutStyling?

Checkout styling overrides for this session. Overrides plan and company defaults.



866
867
868
869
870
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 866

optional :checkout_styling,
-> {
  WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::CheckoutStyling
},
nil?: true

#company_idString

The unique identifier of the company to create the checkout configuration for. Only required in setup mode.

Returns:

  • (String)


847
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 847

required :company_id, String

#currencySymbol, ...

The available currencies on the platform

Returns:



876
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 876

optional :currency, enum: -> { WhopSDK::Currency }, nil?: true

#metadataHash{Symbol=>Object}?

Custom key-value metadata to attach to the checkout configuration.

Returns:

  • (Hash{Symbol=>Object}, nil)


882
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 882

optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#modeSymbol, :setup

Returns:

  • (Symbol, :setup)


852
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 852

required :mode, const: :setup

#payment_method_configurationWhopSDK::Models::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::PaymentMethodConfiguration?

The explicit payment method configuration for the checkout session. Only applies to setup mode. If not provided, the platform or company defaults will apply.



889
890
891
892
893
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 889

optional :payment_method_configuration,
-> {
  WhopSDK::CheckoutConfigurationCreateParams::Body::CreateCheckoutSessionInputModeSetup::PaymentMethodConfiguration
},
nil?: true

#redirect_urlString?

The URL to redirect the user to after checkout is completed.

Returns:

  • (String, nil)


899
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 899

optional :redirect_url, String, nil?: true

#source_urlString?

The URL of the page where the checkout is being initiated from.

Returns:

  • (String, nil)


905
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 905

optional :source_url, String, nil?: true