Class: WhopSDK::Models::CheckoutConfigurationCreateParams::PaymentMethodConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams::PaymentMethodConfiguration
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Instance Attribute Summary collapse
-
#disabled ⇒ Array<Symbol, WhopSDK::Models::PaymentMethodTypes>
An array of payment method identifiers that are explicitly disabled.
-
#enabled ⇒ Array<Symbol, WhopSDK::Models::PaymentMethodTypes>
An array of payment method identifiers that are explicitly enabled.
-
#include_platform_defaults ⇒ Boolean
Whether Whop’s platform default payment method enablement settings are included in this configuration.
Instance Method Summary collapse
-
#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CheckoutConfigurationCreateParams::PaymentMethodConfiguration for more details.
This currently only works for configurations made in ‘setup’ mode. The explicit payment method configuration for the checkout session. If not provided, the platform or company’s defaults will apply.
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 561
|
Instance Attribute Details
#disabled ⇒ Array<Symbol, WhopSDK::Models::PaymentMethodTypes>
An array of payment method identifiers that are explicitly disabled. Only applies if the include_platform_defaults is true.
542 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 542 required :disabled, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::PaymentMethodTypes] } |
#enabled ⇒ Array<Symbol, WhopSDK::Models::PaymentMethodTypes>
An array of payment method identifiers that are explicitly enabled. This means these payment methods will be shown on checkout. Example use case is to only enable a specific payment method like cashapp, or extending the platform defaults with additional methods.
551 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 551 required :enabled, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::PaymentMethodTypes] } |
#include_platform_defaults ⇒ Boolean
Whether Whop’s platform default payment method enablement settings are included in this configuration. The full list of default payment methods can be found in the documentation at docs.whop.com/payments.
559 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 559 required :include_platform_defaults, WhopSDK::Internal::Type::Boolean |