Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Product
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Overview
Instance Attribute Summary collapse
-
#business_type ⇒ Symbol, ...
The different business types a company can be.
-
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
-
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e.
-
#description ⇒ String?
A written description of the product.
-
#external_identifier ⇒ String
A unique ID used to find or create a product.
-
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
-
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
-
#headline ⇒ String?
The headline of the product.
-
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
-
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
-
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
-
#route ⇒ String?
The route of the product.
-
#title ⇒ String
The title of the product.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#business_type ⇒ Symbol, ...
The different business types a company can be.
427 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 427 optional :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true |
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
433 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 433 optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true |
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ‘, “
441 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 441 optional :custom_statement_descriptor, String, nil?: true |
#description ⇒ String?
A written description of the product.
447 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 447 optional :description, String, nil?: true |
#external_identifier ⇒ String
A unique ID used to find or create a product. When provided during creation, we will look for an existing product with this external identifier — if found, it will be updated; otherwise, a new product will be created.
415 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 415 required :external_identifier, String |
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
453 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 453 optional :global_affiliate_percentage, Float, nil?: true |
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
459 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 459 optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true |
#headline ⇒ String?
The headline of the product.
465 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 465 optional :headline, String, nil?: true |
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
471 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 471 optional :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true |
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
477 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 477 optional :product_tax_code_id, String, nil?: true |
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
483 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 483 optional :redirect_purchase_url, String, nil?: true |
#route ⇒ String?
The route of the product.
489 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 489 optional :route, String, nil?: true |
#title ⇒ String
The title of the product.
421 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 421 required :title, String |
#visibility ⇒ Symbol, ...
Visibility of a resource
495 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 495 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |