Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Product

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/checkout_configuration_create_params.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(external_identifier: , title: , business_type: nil, collect_shipping_address: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, industry_type: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Product for more details.

Pass this object to create a new product for this plan. We will use the product external identifier to find or create an existing product.

betwee

Parameters:

  • external_identifier (String) (defaults to: )

    A unique ID used to find or create a product. When provided during creation, we

  • title (String) (defaults to: )

    The title of the product.

  • business_type (Symbol, WhopSDK::Models::BusinessTypes, nil) (defaults to: nil)

    The different business types a company can be.

  • collect_shipping_address (Boolean, nil) (defaults to: nil)

    Whether or not to collect shipping information at checkout from the customer.

  • custom_statement_descriptor (String, nil) (defaults to: nil)

    The custom statement descriptor for the product i.e. WHOP*SPORTS, must be

  • description (String, nil) (defaults to: nil)

    A written description of the product.

  • global_affiliate_percentage (Float, nil) (defaults to: nil)

    The percentage of the revenue that goes to the global affiliate program.

  • global_affiliate_status (Symbol, WhopSDK::Models::GlobalAffiliateStatus, nil) (defaults to: nil)

    The different statuses of the global affiliate program for a product.

  • headline (String, nil) (defaults to: nil)

    The headline of the product.

  • industry_type (Symbol, WhopSDK::Models::IndustryTypes, nil) (defaults to: nil)

    The different industry types a company can be in.

  • product_tax_code_id (String, nil) (defaults to: nil)

    The ID of the product tax code to apply to this product.

  • redirect_purchase_url (String, nil) (defaults to: nil)

    The URL to redirect the customer to after a purchase.

  • route (String, nil) (defaults to: nil)

    The route of the product.

  • visibility (Symbol, WhopSDK::Models::Visibility, nil) (defaults to: nil)

    Visibility of a resource



# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 466

Instance Attribute Details

#business_typeSymbol, ...

The different business types a company can be.

Returns:



396
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 396

optional :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true

#collect_shipping_addressBoolean?

Whether or not to collect shipping information at checkout from the customer.

Returns:

  • (Boolean, nil)


402
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 402

optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true

#custom_statement_descriptorString?

The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ‘, “

Returns:

  • (String, nil)


410
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 410

optional :custom_statement_descriptor, String, nil?: true

#descriptionString?

A written description of the product.

Returns:

  • (String, nil)


416
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 416

optional :description, String, nil?: true

#external_identifierString

A unique ID used to find or create a product. When provided during creation, we will look for an existing product with this external identifier — if found, it will be updated; otherwise, a new product will be created.

Returns:

  • (String)


384
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 384

required :external_identifier, String

#global_affiliate_percentageFloat?

The percentage of the revenue that goes to the global affiliate program.

Returns:

  • (Float, nil)


422
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 422

optional :global_affiliate_percentage, Float, nil?: true

#global_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for a product.

Returns:



428
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 428

optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#headlineString?

The headline of the product.

Returns:

  • (String, nil)


434
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 434

optional :headline, String, nil?: true

#industry_typeSymbol, ...

The different industry types a company can be in.

Returns:



440
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 440

optional :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true

#product_tax_code_idString?

The ID of the product tax code to apply to this product.

Returns:

  • (String, nil)


446
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 446

optional :product_tax_code_id, String, nil?: true

#redirect_purchase_urlString?

The URL to redirect the customer to after a purchase.

Returns:

  • (String, nil)


452
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 452

optional :redirect_purchase_url, String, nil?: true

#routeString?

The route of the product.

Returns:

  • (String, nil)


458
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 458

optional :route, String, nil?: true

#titleString

The title of the product.

Returns:

  • (String)


390
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 390

required :title, String

#visibilitySymbol, ...

Visibility of a resource

Returns:



464
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 464

optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true