Class: WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Product
- Defined in:
- lib/whop_sdk/models/checkout_configuration_create_params.rb
Overview
Instance Attribute Summary collapse
-
#business_type ⇒ Symbol, ...
The different business types a company can be.
-
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
-
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e.
-
#description ⇒ String?
A written description of the product.
-
#external_identifier ⇒ String
A unique ID used to find or create a product.
-
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
-
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for an access pass.
-
#headline ⇒ String?
The headline of the product.
-
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
-
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
-
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
-
#route ⇒ String?
The route of the product.
-
#title ⇒ String
The title of the product.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Instance Method Summary collapse
-
#initialize(external_identifier: , title: , business_type: nil, collect_shipping_address: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, industry_type: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Product for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(external_identifier: , title: , business_type: nil, collect_shipping_address: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, industry_type: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CheckoutConfigurationCreateParams::Plan::Product for more details.
Pass this object to create a new product for this plan. We will use the product external identifier to find or create an existing product.
betwee
|
|
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 390
|
Instance Attribute Details
#business_type ⇒ Symbol, ...
The different business types a company can be.
320 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 320 optional :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true |
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
326 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 326 optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true |
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ‘, “
334 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 334 optional :custom_statement_descriptor, String, nil?: true |
#description ⇒ String?
A written description of the product.
340 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 340 optional :description, String, nil?: true |
#external_identifier ⇒ String
A unique ID used to find or create a product. When provided during creation, we will look for an existing product with this external identifier — if found, it will be updated; otherwise, a new product will be created.
308 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 308 required :external_identifier, String |
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
346 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 346 optional :global_affiliate_percentage, Float, nil?: true |
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for an access pass.
352 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 352 optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true |
#headline ⇒ String?
The headline of the product.
358 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 358 optional :headline, String, nil?: true |
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
364 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 364 optional :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true |
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
370 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 370 optional :product_tax_code_id, String, nil?: true |
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
376 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 376 optional :redirect_purchase_url, String, nil?: true |
#route ⇒ String?
The route of the product.
382 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 382 optional :route, String, nil?: true |
#title ⇒ String
The title of the product.
314 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 314 required :title, String |
#visibility ⇒ Symbol, ...
Visibility of a resource
388 |
# File 'lib/whop_sdk/models/checkout_configuration_create_params.rb', line 388 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |