Class: WhopSDK::Models::CheckoutConfigurationListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/checkout_configuration_list_params.rb,
sig/whop_sdk/models/checkout_configuration_list_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#after ⇒ String?
Cursor for the next page of results.
-
#company_id ⇒ String
Account ID, prefixed
biz_. -
#created_after ⇒ Integer?
Only return checkout configurations created after this Unix timestamp.
-
#created_before ⇒ Integer?
Only return checkout configurations created before this Unix timestamp.
-
#direction ⇒ Symbol, ...
Sort direction.
-
#first ⇒ Integer?
Number of checkout configurations to return.
-
#order ⇒ Symbol, ...
Field used to sort checkout configurations.
-
#plan_id ⇒ String?
Only return checkout configurations for this plan ID, prefixed
plan_.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(company_id:, after: nil, created_after: nil, created_before: nil, direction: nil, first: nil, order: nil, plan_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, after: nil, created_after: nil, created_before: nil, direction: nil, first: nil, order: nil, plan_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 58
|
Instance Attribute Details
#after ⇒ String?
Cursor for the next page of results.
20 |
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 20 optional :after, String |
#company_id ⇒ String
Account ID, prefixed biz_.
14 |
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 14 required :company_id, String |
#created_after ⇒ Integer?
Only return checkout configurations created after this Unix timestamp.
26 |
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 26 optional :created_after, Integer |
#created_before ⇒ Integer?
Only return checkout configurations created before this Unix timestamp.
32 |
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 32 optional :created_before, Integer |
#direction ⇒ Symbol, ...
Sort direction. Defaults to desc.
38 |
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 38 optional :direction, enum: -> { WhopSDK::CheckoutConfigurationListParams::Direction } |
#first ⇒ Integer?
Number of checkout configurations to return.
44 |
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 44 optional :first, Integer |
#order ⇒ Symbol, ...
Field used to sort checkout configurations.
50 |
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 50 optional :order, enum: -> { WhopSDK::CheckoutConfigurationListParams::Order } |
#plan_id ⇒ String?
Only return checkout configurations for this plan ID, prefixed plan_.
56 |
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 56 optional :plan_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/checkout_configuration_list_params.rb', line 84
|
Instance Method Details
#to_hash ⇒ {
66 |
# File 'sig/whop_sdk/models/checkout_configuration_list_params.rbs', line 66
def to_hash: -> {
|