Class: WhopSDK::Models::CheckoutConfigurationListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/checkout_configuration_list_response.rb

Overview

Defined Under Namespace

Classes: PaymentMethodConfiguration, Plan

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(disabled:, enabled:, include_platform_defaults:) ⇒ Object

Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.

The explicit payment method configuration for the session, if any. This currently only works in ‘setup’ mode. Use the plan’s payment_method_configuration for payment method.

Parameters:

  • disabled (Array<Symbol, WhopSDK::Models::PaymentMethodTypes>)

    An array of payment method identifiers that are explicitly disabled. Only applie

  • enabled (Array<Symbol, WhopSDK::Models::PaymentMethodTypes>)

    An array of payment method identifiers that are explicitly enabled. This means t

  • include_platform_defaults (Boolean)

    Whether Whop’s platform default payment method enablement settings are included



# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 79

Instance Attribute Details

#affiliate_codeString?

The affiliate code to use for the checkout configuration

Returns:

  • (String, nil)


17
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 17

required :affiliate_code, String, nil?: true

#allow_promo_codesBoolean

Whether the checkout configuration allows promo codes. When false, the promo code input is hidden and promo codes are rejected.

Returns:

  • (Boolean)


24
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 24

required :allow_promo_codes, WhopSDK::Internal::Type::Boolean

#company_idString

The ID of the company to use for the checkout configuration

Returns:

  • (String)


30
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 30

required :company_id, String

#currencySymbol, ...

The available currencies on the platform

Returns:



36
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 36

required :currency, enum: -> { WhopSDK::Currency }, nil?: true

#idString

The unique identifier for the checkout session.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 11

required :id, String

#metadataHash{Symbol=>Object}?

The metadata to use for the checkout configuration

Returns:

  • (Hash{Symbol=>Object}, nil)


42
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 42

required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#modeSymbol, WhopSDK::Models::CheckoutModes

The mode of the checkout session.

Returns:



48
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 48

required :mode, enum: -> { WhopSDK::CheckoutModes }

#payment_method_configurationWhopSDK::Models::CheckoutConfigurationListResponse::PaymentMethodConfiguration?

The explicit payment method configuration for the session, if any. This currently only works in ‘setup’ mode. Use the plan’s payment_method_configuration for payment method.



56
57
58
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 56

required :payment_method_configuration,
-> { WhopSDK::Models::CheckoutConfigurationListResponse::PaymentMethodConfiguration },
nil?: true

#planWhopSDK::Models::CheckoutConfigurationListResponse::Plan?

The plan to use for the checkout configuration



64
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 64

required :plan, -> { WhopSDK::Models::CheckoutConfigurationListResponse::Plan }, nil?: true

#purchase_urlString

A URL you can send to customers to complete a checkout. It looks like ‘/checkout/plan_xxxx?session=#id`

Returns:

  • (String)


71
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 71

required :purchase_url, String

#redirect_urlString?

The URL to redirect the user to after the checkout configuration is created

Returns:

  • (String, nil)


77
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 77

required :redirect_url, String, nil?: true