Class: WhopSDK::Models::CheckoutConfigurationListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationListResponse
- Defined in:
- lib/whop_sdk/models/checkout_configuration_list_response.rb
Overview
Defined Under Namespace
Classes: PaymentMethodConfiguration, Plan
Instance Attribute Summary collapse
-
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration.
-
#company_id ⇒ String
The ID of the company to use for the checkout configuration.
-
#id ⇒ String
The ID of the checkout configuration.
-
#metadata ⇒ Hash{Symbol=>Object}?
The metadata to use for the checkout configuration.
-
#mode ⇒ Symbol, WhopSDK::Models::CheckoutModes
The mode of the checkout session.
-
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationListResponse::PaymentMethodConfiguration?
The explicit payment method configuration for the session, if any.
-
#plan ⇒ WhopSDK::Models::CheckoutConfigurationListResponse::Plan?
The plan to use for the checkout configuration.
-
#purchase_url ⇒ String
A URL you can send to customers to complete a checkout.
-
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created.
Instance Method Summary collapse
-
#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
The explicit payment method configuration for the session, if any. This currently only works in ‘setup’ mode. Use the plan’s payment_method_configuration for payment method.
|
|
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 66
|
Instance Attribute Details
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration
17 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 17 required :affiliate_code, String, nil?: true |
#company_id ⇒ String
The ID of the company to use for the checkout configuration
23 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 23 required :company_id, String |
#id ⇒ String
The ID of the checkout configuration
11 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 11 required :id, String |
#metadata ⇒ Hash{Symbol=>Object}?
The metadata to use for the checkout configuration
29 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 29 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#mode ⇒ Symbol, WhopSDK::Models::CheckoutModes
The mode of the checkout session.
35 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 35 required :mode, enum: -> { WhopSDK::CheckoutModes } |
#payment_method_configuration ⇒ WhopSDK::Models::CheckoutConfigurationListResponse::PaymentMethodConfiguration?
The explicit payment method configuration for the session, if any. This currently only works in ‘setup’ mode. Use the plan’s payment_method_configuration for payment method.
43 44 45 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 43 required :payment_method_configuration, -> { WhopSDK::Models::CheckoutConfigurationListResponse::PaymentMethodConfiguration }, nil?: true |
#plan ⇒ WhopSDK::Models::CheckoutConfigurationListResponse::Plan?
The plan to use for the checkout configuration
51 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 51 required :plan, -> { WhopSDK::Models::CheckoutConfigurationListResponse::Plan }, nil?: true |
#purchase_url ⇒ String
A URL you can send to customers to complete a checkout. It looks like ‘/checkout/plan_xxxx?session=#id`
58 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 58 required :purchase_url, String |
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created
64 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 64 required :redirect_url, String, nil?: true |