Class: WhopSDK::Models::CheckoutConfigurationListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CheckoutConfigurationListResponse
- Defined in:
- lib/whop_sdk/models/checkout_configuration_list_response.rb
Overview
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration.
-
#company_id ⇒ String
The ID of the company to use for the checkout configuration.
-
#id ⇒ String
The ID of the checkout configuration.
-
#metadata ⇒ Hash{Symbol=>Object}
The metadata to use for the checkout configuration.
-
#plan ⇒ WhopSDK::Models::CheckoutConfigurationListResponse::Plan
The plan to use for the checkout configuration.
-
#purchase_url ⇒ String
A URL you can send to customers to complete a checkout.
-
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created.
Instance Method Summary collapse
-
#initialize(id: , affiliate_code: , company_id: , metadata: , plan: , purchase_url: , redirect_url: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see CheckoutConfigurationListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , affiliate_code: , company_id: , metadata: , plan: , purchase_url: , redirect_url: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CheckoutConfigurationListResponse for more details.
A checkout configuration object.
Can be used to create a reusable custom configuration for a checkout, including attaching plans, affiliates and custom metadata to the checkout.
This configuration can be re-used by multiple users.
All successful payments and memberships resulting from a checkout will contain the passed metadata.
|
|
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 50
|
Instance Attribute Details
#affiliate_code ⇒ String?
The affiliate code to use for the checkout configuration
17 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 17 required :affiliate_code, String, nil?: true |
#company_id ⇒ String
The ID of the company to use for the checkout configuration
23 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 23 required :company_id, String |
#id ⇒ String
The ID of the checkout configuration
11 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 11 required :id, String |
#metadata ⇒ Hash{Symbol=>Object}
The metadata to use for the checkout configuration
29 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 29 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown] |
#plan ⇒ WhopSDK::Models::CheckoutConfigurationListResponse::Plan
The plan to use for the checkout configuration
35 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 35 required :plan, -> { WhopSDK::Models::CheckoutConfigurationListResponse::Plan } |
#purchase_url ⇒ String
A URL you can send to customers to complete a checkout. It looks like ‘/checkout/plan_xxxx?session=#id`
42 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 42 required :purchase_url, String |
#redirect_url ⇒ String?
The URL to redirect the user to after the checkout configuration is created
48 |
# File 'lib/whop_sdk/models/checkout_configuration_list_response.rb', line 48 required :redirect_url, String, nil?: true |