Class: WhopSDK::Models::Company
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Company
- Defined in:
- lib/whop_sdk/models/company.rb
Defined Under Namespace
Classes: Logo, OwnerUser, SocialLink
Instance Attribute Summary collapse
-
#business_type ⇒ Symbol, ...
The different business types a company can be.
-
#created_at ⇒ Time
When the company was created (signed up).
-
#description ⇒ String?
The creator pitch for the company.
-
#id ⇒ String
The ID (tag) of the company.
-
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
-
#logo ⇒ WhopSDK::Models::Company::Logo?
The company’s logo.
-
#member_count ⇒ Integer
The number of members in the company.
-
#metadata ⇒ Hash{Symbol=>Object}?
A key-value store of data for the account, created/updated by the platform that made the account.
-
#owner_user ⇒ WhopSDK::Models::Company::OwnerUser
The user who owns this company.
-
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the company.
-
#route ⇒ String
The slug/route of the company on the Whop site.
-
#social_links ⇒ Array<WhopSDK::Models::Company::SocialLink>
The social media accounts of the company.
-
#title ⇒ String
The title of the company.
-
#updated_at ⇒ Time
The time the company was last updated.
-
#verified ⇒ Boolean
If the company is Whop Verified.
Instance Method Summary collapse
-
#initialize(id: , name: , username: ) ⇒ Object
constructor
The user who owns this company.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , name: , username: ) ⇒ Object
The user who owns this company
|
|
# File 'lib/whop_sdk/models/company.rb', line 97
|
Instance Attribute Details
#business_type ⇒ Symbol, ...
The different business types a company can be.
16 |
# File 'lib/whop_sdk/models/company.rb', line 16 required :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true |
#created_at ⇒ Time
When the company was created (signed up)
22 |
# File 'lib/whop_sdk/models/company.rb', line 22 required :created_at, Time |
#description ⇒ String?
The creator pitch for the company.
28 |
# File 'lib/whop_sdk/models/company.rb', line 28 required :description, String, nil?: true |
#id ⇒ String
The ID (tag) of the company.
10 |
# File 'lib/whop_sdk/models/company.rb', line 10 required :id, String |
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
34 |
# File 'lib/whop_sdk/models/company.rb', line 34 required :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true |
#logo ⇒ WhopSDK::Models::Company::Logo?
The company’s logo.
40 |
# File 'lib/whop_sdk/models/company.rb', line 40 required :logo, -> { WhopSDK::Company::Logo }, nil?: true |
#member_count ⇒ Integer
The number of members in the company.
46 |
# File 'lib/whop_sdk/models/company.rb', line 46 required :member_count, Integer |
#metadata ⇒ Hash{Symbol=>Object}?
A key-value store of data for the account, created/updated by the platform that made the account.
53 |
# File 'lib/whop_sdk/models/company.rb', line 53 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#owner_user ⇒ WhopSDK::Models::Company::OwnerUser
The user who owns this company
59 |
# File 'lib/whop_sdk/models/company.rb', line 59 required :owner_user, -> { WhopSDK::Company::OwnerUser } |
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the company.
65 |
# File 'lib/whop_sdk/models/company.rb', line 65 required :published_reviews_count, Integer |
#route ⇒ String
The slug/route of the company on the Whop site.
71 |
# File 'lib/whop_sdk/models/company.rb', line 71 required :route, String |
#social_links ⇒ Array<WhopSDK::Models::Company::SocialLink>
The social media accounts of the company
77 |
# File 'lib/whop_sdk/models/company.rb', line 77 required :social_links, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Company::SocialLink] } |
#title ⇒ String
The title of the company.
83 |
# File 'lib/whop_sdk/models/company.rb', line 83 required :title, String |
#updated_at ⇒ Time
The time the company was last updated.
89 |
# File 'lib/whop_sdk/models/company.rb', line 89 required :updated_at, Time |