Class: WhopSDK::Models::Company

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/company.rb

Defined Under Namespace

Classes: Logo, OwnerUser, SocialLink

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , name: , username: ) ⇒ Object

The user who owns this company

Parameters:

  • id (String) (defaults to: )

    The internal ID of the user.

  • name (String, nil) (defaults to: )

    The name of the user from their Whop account.

  • username (String) (defaults to: )

    The username of the user from their Whop account.



# File 'lib/whop_sdk/models/company.rb', line 90

Instance Attribute Details

#business_typeSymbol, ...

The different business types a company can be.

Returns:



16
# File 'lib/whop_sdk/models/company.rb', line 16

required :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true

#created_atTime

When the company was created (signed up)

Returns:

  • (Time)


22
# File 'lib/whop_sdk/models/company.rb', line 22

required :created_at, Time

#descriptionString?

The creator pitch for the company.

Returns:

  • (String, nil)


28
# File 'lib/whop_sdk/models/company.rb', line 28

required :description, String, nil?: true

#idString

The ID (tag) of the company.

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/company.rb', line 10

required :id, String

#industry_typeSymbol, ...

The different industry types a company can be in.

Returns:



34
# File 'lib/whop_sdk/models/company.rb', line 34

required :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true

#logoWhopSDK::Models::Company::Logo?

The company’s logo.



40
# File 'lib/whop_sdk/models/company.rb', line 40

required :logo, -> { WhopSDK::Company::Logo }, nil?: true

#member_countInteger

The number of members in the company.

Returns:

  • (Integer)


46
# File 'lib/whop_sdk/models/company.rb', line 46

required :member_count, Integer

#owner_userWhopSDK::Models::Company::OwnerUser

The user who owns this company



52
# File 'lib/whop_sdk/models/company.rb', line 52

required :owner_user, -> { WhopSDK::Company::OwnerUser }

#published_reviews_countInteger

The number of reviews that have been published for the company.

Returns:

  • (Integer)


58
# File 'lib/whop_sdk/models/company.rb', line 58

required :published_reviews_count, Integer

#routeString

The slug/route of the company on the Whop site.

Returns:

  • (String)


64
# File 'lib/whop_sdk/models/company.rb', line 64

required :route, String

The social media accounts of the company



70
# File 'lib/whop_sdk/models/company.rb', line 70

required :social_links, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Company::SocialLink] }

#titleString

The title of the company.

Returns:

  • (String)


76
# File 'lib/whop_sdk/models/company.rb', line 76

required :title, String

#updated_atTime

The time the company was last updated.

Returns:

  • (Time)


82
# File 'lib/whop_sdk/models/company.rb', line 82

required :updated_at, Time

#verifiedBoolean

If the company is Whop Verified

Returns:

  • (Boolean)


88
# File 'lib/whop_sdk/models/company.rb', line 88

required :verified, WhopSDK::Internal::Type::Boolean