Class: WhopSDK::Models::Company::SocialLink
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Company::SocialLink
- Defined in:
- lib/whop_sdk/models/company.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the social link.
-
#url ⇒ String
The URL of the social media profile or external link.
-
#website ⇒ Symbol, WhopSDK::Models::SocialLinkWebsites
The website.
Instance Method Summary collapse
-
#initialize(id:, url:, website:) ⇒ Object
constructor
A social link attached to a resource on the site.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, url:, website:) ⇒ Object
A social link attached to a resource on the site.
|
|
# File 'lib/whop_sdk/models/company.rb', line 247
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the social link.
233 |
# File 'lib/whop_sdk/models/company.rb', line 233 required :id, String |
#url ⇒ String
The URL of the social media profile or external link.
239 |
# File 'lib/whop_sdk/models/company.rb', line 239 required :url, String |
#website ⇒ Symbol, WhopSDK::Models::SocialLinkWebsites
The website
245 |
# File 'lib/whop_sdk/models/company.rb', line 245 required :website, enum: -> { WhopSDK::SocialLinkWebsites } |