Class: WhopSDK::Models::CompanyCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CompanyCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/company_create_params.rb
Overview
Instance Attribute Summary collapse
-
#email ⇒ String
The email of the user who the company will belong to.
-
#metadata ⇒ Hash{Symbol=>Object}?
Additional metadata for the account.
-
#parent_company_id ⇒ String
The company ID of the platform creating this company.
-
#title ⇒ String
The name of the company being created.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(email: , parent_company_id: , title: , metadata: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(email: , parent_company_id: , title: , metadata: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/company_create_params.rb', line 34
|
Instance Attribute Details
#email ⇒ String
The email of the user who the company will belong to.
14 |
# File 'lib/whop_sdk/models/company_create_params.rb', line 14 required :email, String |
#metadata ⇒ Hash{Symbol=>Object}?
Additional metadata for the account
32 |
# File 'lib/whop_sdk/models/company_create_params.rb', line 32 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#parent_company_id ⇒ String
The company ID of the platform creating this company.
20 |
# File 'lib/whop_sdk/models/company_create_params.rb', line 20 required :parent_company_id, String |
#title ⇒ String
The name of the company being created.
26 |
# File 'lib/whop_sdk/models/company_create_params.rb', line 26 required :title, String |