Class: WhopSDK::Models::CompanyCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/company_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(email: , parent_company_id: , title: , metadata: nil, request_options: {}) ⇒ Object

Parameters:

  • email (String) (defaults to: )

    The email of the user who the company will belong to.

  • parent_company_id (String) (defaults to: )

    The company ID of the platform creating this company.

  • title (String) (defaults to: )

    The name of the company being created.

  • metadata (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Additional metadata for the account

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/company_create_params.rb', line 34

Instance Attribute Details

#emailString

The email of the user who the company will belong to.

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/company_create_params.rb', line 14

required :email, String

#metadataHash{Symbol=>Object}?

Additional metadata for the account

Returns:

  • (Hash{Symbol=>Object}, nil)


32
# File 'lib/whop_sdk/models/company_create_params.rb', line 32

optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#parent_company_idString

The company ID of the platform creating this company.

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/company_create_params.rb', line 20

required :parent_company_id, String

#titleString

The name of the company being created.

Returns:

  • (String)


26
# File 'lib/whop_sdk/models/company_create_params.rb', line 26

required :title, String