Class: WhopSDK::Models::CompanyListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/company_list_response.rb

Overview

Defined Under Namespace

Classes: Logo, OwnerUser

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(url: ) ⇒ Object

Some parameter documentations has been truncated, see Logo for more details.

The company’s logo.

Parameters:

  • url (String, nil) (defaults to: )

    This is the URL you use to render optimized attachments on the client. This shou



# File 'lib/whop_sdk/models/company_list_response.rb', line 92

Instance Attribute Details

#business_typeSymbol, ...

The different business types a company can be.

Returns:



17
# File 'lib/whop_sdk/models/company_list_response.rb', line 17

required :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true

#created_atTime

When the company was created (signed up)

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/company_list_response.rb', line 23

required :created_at, Time

#descriptionString?

The creator pitch for the company.

Returns:

  • (String, nil)


29
# File 'lib/whop_sdk/models/company_list_response.rb', line 29

required :description, String, nil?: true

#idString

The ID (tag) of the company.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/company_list_response.rb', line 11

required :id, String

#industry_typeSymbol, ...

The different industry types a company can be in.

Returns:



35
# File 'lib/whop_sdk/models/company_list_response.rb', line 35

required :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true

#logoWhopSDK::Models::CompanyListResponse::Logo?

The company’s logo.



41
# File 'lib/whop_sdk/models/company_list_response.rb', line 41

required :logo, -> { WhopSDK::Models::CompanyListResponse::Logo }, nil?: true

#member_countInteger

The number of members in the company.

Returns:

  • (Integer)


47
# File 'lib/whop_sdk/models/company_list_response.rb', line 47

required :member_count, Integer

#metadataHash{Symbol=>Object}?

A key-value store of data for the account, created/updated by the platform that made the account.

Returns:

  • (Hash{Symbol=>Object}, nil)


54
# File 'lib/whop_sdk/models/company_list_response.rb', line 54

required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#owner_userWhopSDK::Models::CompanyListResponse::OwnerUser

The user who owns this company



60
# File 'lib/whop_sdk/models/company_list_response.rb', line 60

required :owner_user, -> { WhopSDK::Models::CompanyListResponse::OwnerUser }

#published_reviews_countInteger

The number of reviews that have been published for the company.

Returns:

  • (Integer)


66
# File 'lib/whop_sdk/models/company_list_response.rb', line 66

required :published_reviews_count, Integer

#routeString

The slug/route of the company on the Whop site.

Returns:

  • (String)


72
# File 'lib/whop_sdk/models/company_list_response.rb', line 72

required :route, String

#titleString

The title of the company.

Returns:

  • (String)


78
# File 'lib/whop_sdk/models/company_list_response.rb', line 78

required :title, String

#updated_atTime

The time the company was last updated.

Returns:

  • (Time)


84
# File 'lib/whop_sdk/models/company_list_response.rb', line 84

required :updated_at, Time

#verifiedBoolean

If the company is Whop Verified

Returns:

  • (Boolean)


90
# File 'lib/whop_sdk/models/company_list_response.rb', line 90

required :verified, WhopSDK::Internal::Type::Boolean