Class: WhopSDK::Models::CompanyListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CompanyListResponse
- Defined in:
- lib/whop_sdk/models/company_list_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#business_type ⇒ Symbol, ...
The different business types a company can be.
-
#created_at ⇒ Time
When the company was created (signed up).
-
#description ⇒ String?
The creator pitch for the company.
-
#id ⇒ String
The ID (tag) of the company.
-
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
-
#logo ⇒ WhopSDK::Models::CompanyListResponse::Logo?
The company’s logo.
-
#member_count ⇒ Integer
The number of members in the company.
-
#metadata ⇒ Hash{Symbol=>Object}?
A key-value store of data for the account, created/updated by the platform that made the account.
-
#owner_user ⇒ WhopSDK::Models::CompanyListResponse::OwnerUser
The user who owns this company.
-
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the company.
-
#route ⇒ String
The slug/route of the company on the Whop site.
-
#title ⇒ String
The title of the company.
-
#updated_at ⇒ Time
The time the company was last updated.
-
#verified ⇒ Boolean
If the company is Whop Verified.
Instance Method Summary collapse
-
#initialize(url: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Logo for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url: ) ⇒ Object
Some parameter documentations has been truncated, see Logo for more details.
The company’s logo.
|
|
# File 'lib/whop_sdk/models/company_list_response.rb', line 92
|
Instance Attribute Details
#business_type ⇒ Symbol, ...
The different business types a company can be.
17 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 17 required :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true |
#created_at ⇒ Time
When the company was created (signed up)
23 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 23 required :created_at, Time |
#description ⇒ String?
The creator pitch for the company.
29 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 29 required :description, String, nil?: true |
#id ⇒ String
The ID (tag) of the company.
11 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 11 required :id, String |
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
35 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 35 required :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true |
#logo ⇒ WhopSDK::Models::CompanyListResponse::Logo?
The company’s logo.
41 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 41 required :logo, -> { WhopSDK::Models::CompanyListResponse::Logo }, nil?: true |
#member_count ⇒ Integer
The number of members in the company.
47 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 47 required :member_count, Integer |
#metadata ⇒ Hash{Symbol=>Object}?
A key-value store of data for the account, created/updated by the platform that made the account.
54 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 54 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#owner_user ⇒ WhopSDK::Models::CompanyListResponse::OwnerUser
The user who owns this company
60 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 60 required :owner_user, -> { WhopSDK::Models::CompanyListResponse::OwnerUser } |
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the company.
66 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 66 required :published_reviews_count, Integer |
#route ⇒ String
The slug/route of the company on the Whop site.
72 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 72 required :route, String |
#title ⇒ String
The title of the company.
78 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 78 required :title, String |
#updated_at ⇒ Time
The time the company was last updated.
84 |
# File 'lib/whop_sdk/models/company_list_response.rb', line 84 required :updated_at, Time |