Class: WhopSDK::Models::CompanyTokenTransactionListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CompanyTokenTransactionListResponse
- Defined in:
- lib/whop_sdk/models/company_token_transaction_list_response.rb
Overview
Defined Under Namespace
Classes: Company, Member, User
Instance Attribute Summary collapse
-
#amount ⇒ Float
The token amount for this transaction.
-
#company ⇒ WhopSDK::Models::CompanyTokenTransactionListResponse::Company
The company whose token balance this transaction affects.
-
#created_at ⇒ Time
The datetime the company token transaction was created.
-
#description ⇒ String?
Free-text description explaining the reason for this token transaction.
-
#id ⇒ String
The unique identifier for the company token transaction.
-
#idempotency_key ⇒ String?
A unique key used to prevent duplicate transactions when retrying API requests.
-
#linked_transaction_id ⇒ String?
The ID of the corresponding transaction on the other side of a transfer.
-
#member ⇒ WhopSDK::Models::CompanyTokenTransactionListResponse::Member
The member whose token balance was affected by this transaction.
-
#transaction_type ⇒ Symbol, WhopSDK::Models::CompanyTokenTransactionType
The direction of this token transaction (add, subtract, or transfer).
-
#user ⇒ WhopSDK::Models::CompanyTokenTransactionListResponse::User
The user whose token balance was affected by this transaction.
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
The member whose token balance was affected by this transaction.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
The member whose token balance was affected by this transaction.
|
|
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 71
|
Instance Attribute Details
#amount ⇒ Float
The token amount for this transaction. Always a positive value regardless of transaction type.
18 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 18 required :amount, Float |
#company ⇒ WhopSDK::Models::CompanyTokenTransactionListResponse::Company
The company whose token balance this transaction affects.
24 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 24 required :company, -> { WhopSDK::Models::CompanyTokenTransactionListResponse::Company } |
#created_at ⇒ Time
The datetime the company token transaction was created.
30 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 30 required :created_at, Time |
#description ⇒ String?
Free-text description explaining the reason for this token transaction. Null if no description was provided.
37 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 37 required :description, String, nil?: true |
#id ⇒ String
The unique identifier for the company token transaction.
11 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 11 required :id, String |
#idempotency_key ⇒ String?
A unique key used to prevent duplicate transactions when retrying API requests. Null if no idempotency key was provided.
44 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 44 required :idempotency_key, String, nil?: true |
#linked_transaction_id ⇒ String?
The ID of the corresponding transaction on the other side of a transfer. Null if this is not a transfer transaction.
51 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 51 required :linked_transaction_id, String, nil?: true |
#member ⇒ WhopSDK::Models::CompanyTokenTransactionListResponse::Member
The member whose token balance was affected by this transaction.
57 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 57 required :member, -> { WhopSDK::Models::CompanyTokenTransactionListResponse::Member } |
#transaction_type ⇒ Symbol, WhopSDK::Models::CompanyTokenTransactionType
The direction of this token transaction (add, subtract, or transfer).
63 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 63 required :transaction_type, enum: -> { WhopSDK::CompanyTokenTransactionType } |
#user ⇒ WhopSDK::Models::CompanyTokenTransactionListResponse::User
The user whose token balance was affected by this transaction.
69 |
# File 'lib/whop_sdk/models/company_token_transaction_list_response.rb', line 69 required :user, -> { WhopSDK::Models::CompanyTokenTransactionListResponse::User } |