Class: WhopSDK::Models::Course
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Course
- Defined in:
- lib/whop_sdk/models/course.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#certificate_after_completion_enabled ⇒ Boolean?
Whether the course will award its students a PDF certificate after completing all lessons.
-
#chapters ⇒ Array<WhopSDK::Models::Course::Chapter>
The chapters in this course.
-
#cover_image ⇒ String?
The URL of the course’s cover image, which is shown in course preview cards.
-
#created_at ⇒ Time
The timestamp of when the course was created.
-
#description ⇒ String?
A short description of the course.
-
#id ⇒ String
The ID of the course.
-
#language ⇒ Symbol, WhopSDK::Models::Languages
The language spoken in the video content of the course, used to generate closed captions in the right language.
-
#order ⇒ String
The order of the course within its experience.
-
#require_completing_lessons_in_order ⇒ Boolean
Whether the course requires students to complete the previous lesson before moving on to the next one.
-
#tagline ⇒ String?
A short tagline for the course.
-
#thumbnail ⇒ WhopSDK::Models::Course::Thumbnail?
The thumbnail for the course.
-
#title ⇒ String?
The title of the course.
-
#updated_at ⇒ Time
The timestamp of when the course was last updated.
-
#visibility ⇒ Symbol, WhopSDK::Models::CourseVisibilities
The visibility of the course.
Instance Method Summary collapse
-
#initialize(id: , lesson_type: , order: , title: ) ⇒ Object
constructor
A lesson from the courses app.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , lesson_type: , order: , title: ) ⇒ Object
A lesson from the courses app
|
|
# File 'lib/whop_sdk/models/course.rb', line 190
|
Instance Attribute Details
#certificate_after_completion_enabled ⇒ Boolean?
Whether the course will award its students a PDF certificate after completing all lessons
18 |
# File 'lib/whop_sdk/models/course.rb', line 18 required :certificate_after_completion_enabled, WhopSDK::Internal::Type::Boolean, nil?: true |
#chapters ⇒ Array<WhopSDK::Models::Course::Chapter>
The chapters in this course
24 |
# File 'lib/whop_sdk/models/course.rb', line 24 required :chapters, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Course::Chapter] } |
#cover_image ⇒ String?
The URL of the course’s cover image, which is shown in course preview cards
30 |
# File 'lib/whop_sdk/models/course.rb', line 30 required :cover_image, String, nil?: true |
#created_at ⇒ Time
The timestamp of when the course was created
36 |
# File 'lib/whop_sdk/models/course.rb', line 36 required :created_at, Time |
#description ⇒ String?
A short description of the course
42 |
# File 'lib/whop_sdk/models/course.rb', line 42 required :description, String, nil?: true |
#id ⇒ String
The ID of the course. Looks like cors_XXX
11 |
# File 'lib/whop_sdk/models/course.rb', line 11 required :id, String |
#language ⇒ Symbol, WhopSDK::Models::Languages
The language spoken in the video content of the course, used to generate closed captions in the right language
49 |
# File 'lib/whop_sdk/models/course.rb', line 49 required :language, enum: -> { WhopSDK::Languages } |
#order ⇒ String
The order of the course within its experience
55 |
# File 'lib/whop_sdk/models/course.rb', line 55 required :order, String |
#require_completing_lessons_in_order ⇒ Boolean
Whether the course requires students to complete the previous lesson before moving on to the next one
62 |
# File 'lib/whop_sdk/models/course.rb', line 62 required :require_completing_lessons_in_order, WhopSDK::Internal::Type::Boolean |
#tagline ⇒ String?
A short tagline for the course. It is displayed under the course title in the UI
68 |
# File 'lib/whop_sdk/models/course.rb', line 68 required :tagline, String, nil?: true |
#thumbnail ⇒ WhopSDK::Models::Course::Thumbnail?
The thumbnail for the course
74 |
# File 'lib/whop_sdk/models/course.rb', line 74 required :thumbnail, -> { WhopSDK::Course::Thumbnail }, nil?: true |
#title ⇒ String?
The title of the course
80 |
# File 'lib/whop_sdk/models/course.rb', line 80 required :title, String, nil?: true |
#updated_at ⇒ Time
The timestamp of when the course was last updated
86 |
# File 'lib/whop_sdk/models/course.rb', line 86 required :updated_at, Time |
#visibility ⇒ Symbol, WhopSDK::Models::CourseVisibilities
The visibility of the course. Determines how / whether this course is visible to users.
93 |
# File 'lib/whop_sdk/models/course.rb', line 93 required :visibility, enum: -> { WhopSDK::CourseVisibilities } |