Class: WhopSDK::Models::Course::Chapter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Course::Chapter
- Defined in:
- lib/whop_sdk/models/course.rb
Defined Under Namespace
Classes: Lesson
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the chapter.
-
#lessons ⇒ Array<WhopSDK::Models::Course::Chapter::Lesson>
The lessons in this chapter.
-
#order ⇒ Integer
The order of the chapter within its course.
-
#title ⇒ String
The title of the chapter.
Instance Method Summary collapse
-
#initialize(id: , certificate_after_completion_enabled: , chapters: , cover_image: , created_at: , description: , language: , order: , require_completing_lessons_in_order: , tagline: , thumbnail: , title: , updated_at: , visibility: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhopSDK::Models::Course for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , certificate_after_completion_enabled: , chapters: , cover_image: , created_at: , description: , language: , order: , require_completing_lessons_in_order: , tagline: , thumbnail: , title: , updated_at: , visibility: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Course for more details.
A course from the courses app
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/whop_sdk/models/course.rb', line 129 class Chapter < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of the chapter. Looks like chap_XXX # # @return [String] required :id, String # @!attribute lessons # The lessons in this chapter # # @return [Array<WhopSDK::Models::Course::Chapter::Lesson>] required :lessons, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Course::Chapter::Lesson] } # @!attribute order # The order of the chapter within its course # # @return [Integer] required :order, Integer # @!attribute title # The title of the chapter # # @return [String] required :title, String # @!method initialize(id:, lessons:, order:, title:) # A chapter from the courses app # # @param id [String] The ID of the chapter. Looks like chap_XXX # # @param lessons [Array<WhopSDK::Models::Course::Chapter::Lesson>] The lessons in this chapter # # @param order [Integer] The order of the chapter within its course # # @param title [String] The title of the chapter class Lesson < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of the lesson # # @return [String] required :id, String # @!attribute lesson_type # The type of the lesson (text, video, pdf, multi, quiz, knowledge_check) # # @return [Symbol, WhopSDK::Models::LessonTypes] required :lesson_type, enum: -> { WhopSDK::LessonTypes } # @!attribute order # The order of the lesson within its chapter # # @return [Integer] required :order, Integer # @!attribute title # The title of the lesson # # @return [String] required :title, String # @!method initialize(id:, lesson_type:, order:, title:) # A lesson from the courses app # # @param id [String] The ID of the lesson # # @param lesson_type [Symbol, WhopSDK::Models::LessonTypes] The type of the lesson (text, video, pdf, multi, quiz, knowledge_check) # # @param order [Integer] The order of the lesson within its chapter # # @param title [String] The title of the lesson end end |
Instance Attribute Details
#id ⇒ String
The ID of the chapter. Looks like chap_XXX
134 |
# File 'lib/whop_sdk/models/course.rb', line 134 required :id, String |
#lessons ⇒ Array<WhopSDK::Models::Course::Chapter::Lesson>
The lessons in this chapter
140 |
# File 'lib/whop_sdk/models/course.rb', line 140 required :lessons, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Course::Chapter::Lesson] } |
#order ⇒ Integer
The order of the chapter within its course
146 |
# File 'lib/whop_sdk/models/course.rb', line 146 required :order, Integer |
#title ⇒ String
The title of the chapter
152 |
# File 'lib/whop_sdk/models/course.rb', line 152 required :title, String |