Class: WhopSDK::Models::Course::Chapter::Lesson
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Course::Chapter::Lesson
- Defined in:
- lib/whop_sdk/models/course.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the lesson.
-
#lesson_type ⇒ Symbol, WhopSDK::Models::LessonTypes
The type of the lesson (text, video, pdf, multi, quiz, knowledge_check).
-
#order ⇒ Integer
The order of the lesson within its chapter.
-
#title ⇒ String
The title of the lesson.
Instance Method Summary collapse
-
#initialize(id: , lessons: , order: , title: ) ⇒ Object
constructor
A chapter from the courses app.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , lessons: , order: , title: ) ⇒ Object
A chapter from the courses app
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/whop_sdk/models/course.rb', line 140 class Lesson < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of the lesson # # @return [String] required :id, String # @!attribute lesson_type # The type of the lesson (text, video, pdf, multi, quiz, knowledge_check) # # @return [Symbol, WhopSDK::Models::LessonTypes] required :lesson_type, enum: -> { WhopSDK::LessonTypes } # @!attribute order # The order of the lesson within its chapter # # @return [Integer] required :order, Integer # @!attribute title # The title of the lesson # # @return [String] required :title, String # @!method initialize(id:, lesson_type:, order:, title:) # A lesson from the courses app # # @param id [String] The ID of the lesson # # @param lesson_type [Symbol, WhopSDK::Models::LessonTypes] The type of the lesson (text, video, pdf, multi, quiz, knowledge_check) # # @param order [Integer] The order of the lesson within its chapter # # @param title [String] The title of the lesson end |
Instance Attribute Details
#id ⇒ String
The ID of the lesson
145 |
# File 'lib/whop_sdk/models/course.rb', line 145 required :id, String |
#lesson_type ⇒ Symbol, WhopSDK::Models::LessonTypes
The type of the lesson (text, video, pdf, multi, quiz, knowledge_check)
151 |
# File 'lib/whop_sdk/models/course.rb', line 151 required :lesson_type, enum: -> { WhopSDK::LessonTypes } |
#order ⇒ Integer
The order of the lesson within its chapter
157 |
# File 'lib/whop_sdk/models/course.rb', line 157 required :order, Integer |
#title ⇒ String
The title of the lesson
163 |
# File 'lib/whop_sdk/models/course.rb', line 163 required :title, String |