Class: WhopSDK::Models::CourseChapter
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseChapter
- Defined in:
- lib/whop_sdk/models/course_chapter.rb,
sig/whop_sdk/models/course_chapter.rbs
Overview
Defined Under Namespace
Classes: Lesson
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the chapter.
-
#lessons ⇒ Array<WhopSDK::Models::CourseChapter::Lesson>
An ordered list of lessons in this chapter, sorted by display position.
-
#order ⇒ Integer
The sort position of this chapter within its parent course, starting from zero.
-
#title ⇒ String
The display name of the chapter shown to students.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
20 |
# File 'sig/whop_sdk/models/course_chapter.rbs', line 20
def initialize: (
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the chapter.
11 |
# File 'lib/whop_sdk/models/course_chapter.rb', line 11 required :id, String |
#lessons ⇒ Array<WhopSDK::Models::CourseChapter::Lesson>
An ordered list of lessons in this chapter, sorted by display position. Hidden lessons are excluded for non-admin users.
18 |
# File 'lib/whop_sdk/models/course_chapter.rb', line 18 required :lessons, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseChapter::Lesson] } |
#order ⇒ Integer
The sort position of this chapter within its parent course, starting from zero.
24 |
# File 'lib/whop_sdk/models/course_chapter.rb', line 24 required :order, Integer |
#title ⇒ String
The display name of the chapter shown to students. Maximum 150 characters.
30 |
# File 'lib/whop_sdk/models/course_chapter.rb', line 30 required :title, String |
Instance Method Details
#to_hash ⇒ {
27 |
# File 'sig/whop_sdk/models/course_chapter.rbs', line 27
def to_hash: -> {
|