Class: WhopSDK::Models::CourseChapter

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/course_chapter.rb

Overview

Defined Under Namespace

Classes: Lesson

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#idString

The unique identifier for the chapter.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/course_chapter.rb', line 11

required :id, String

#lessonsArray<WhopSDK::Models::CourseChapter::Lesson>

An ordered list of lessons in this chapter, sorted by display position. Hidden lessons are excluded for non-admin users.



18
# File 'lib/whop_sdk/models/course_chapter.rb', line 18

required :lessons, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseChapter::Lesson] }

#orderInteger

The sort position of this chapter within its parent course, starting from zero.

Returns:

  • (Integer)


24
# File 'lib/whop_sdk/models/course_chapter.rb', line 24

required :order, Integer

#titleString

The display name of the chapter shown to students. Maximum 150 characters.

Returns:

  • (String)


30
# File 'lib/whop_sdk/models/course_chapter.rb', line 30

required :title, String