Class: WhopSDK::Models::CourseChapter::Lesson
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseChapter::Lesson
- Defined in:
- lib/whop_sdk/models/course_chapter.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of the lesson.
-
#order ⇒ Integer
The order of the lesson within its chapter.
-
#title ⇒ String
The title of the lesson.
Instance Method Summary collapse
-
#initialize(id: , order: , title: ) ⇒ Object
constructor
A lesson from the courses app.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , order: , title: ) ⇒ Object
A lesson from the courses app
42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/whop_sdk/models/course_chapter.rb', line 42 class Lesson < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of the lesson # # @return [String] required :id, String # @!attribute order # The order of the lesson within its chapter # # @return [Integer] required :order, Integer # @!attribute title # The title of the lesson # # @return [String] required :title, String # @!method initialize(id:, order:, title:) # A lesson from the courses app # # @param id [String] The ID of the lesson # # @param order [Integer] The order of the lesson within its chapter # # @param title [String] The title of the lesson end |
Instance Attribute Details
#id ⇒ String
The ID of the lesson
47 |
# File 'lib/whop_sdk/models/course_chapter.rb', line 47 required :id, String |
#order ⇒ Integer
The order of the lesson within its chapter
53 |
# File 'lib/whop_sdk/models/course_chapter.rb', line 53 required :order, Integer |
#title ⇒ String
The title of the lesson
59 |
# File 'lib/whop_sdk/models/course_chapter.rb', line 59 required :title, String |