Class: WhopSDK::Models::CourseCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_create_params.rb
Overview
Defined Under Namespace
Modules: Thumbnail
Instance Attribute Summary collapse
-
#certificate_after_completion_enabled ⇒ Boolean?
Whether the course will award its students a PDF certificate after completing all lessons.
-
#cover_image ⇒ String?
The cover image URL of the course.
-
#experience_id ⇒ String
The ID of the experience to create the course in.
-
#order ⇒ String?
The decimal order position of the course within its experience.
-
#require_completing_lessons_in_order ⇒ Boolean?
Whether the course requires students to complete the previous lesson before moving on to the next one.
-
#tagline ⇒ String?
The tagline of the course.
-
#thumbnail ⇒ WhopSDK::Models::CourseCreateParams::Thumbnail::AttachmentInputWithDirectUploadID, ...
The thumbnail for the course in png, jpeg, or gif format.
-
#title ⇒ String
The title of the course.
-
#visibility ⇒ Symbol, ...
The available visibilities for a course.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(experience_id: , title: , certificate_after_completion_enabled: nil, cover_image: nil, order: nil, require_completing_lessons_in_order: nil, tagline: nil, thumbnail: nil, visibility: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CourseCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(experience_id: , title: , certificate_after_completion_enabled: nil, cover_image: nil, order: nil, require_completing_lessons_in_order: nil, tagline: nil, thumbnail: nil, visibility: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/course_create_params.rb', line 69
|
Instance Attribute Details
#certificate_after_completion_enabled ⇒ Boolean?
Whether the course will award its students a PDF certificate after completing all lessons
27 |
# File 'lib/whop_sdk/models/course_create_params.rb', line 27 optional :certificate_after_completion_enabled, WhopSDK::Internal::Type::Boolean, nil?: true |
#cover_image ⇒ String?
The cover image URL of the course
33 |
# File 'lib/whop_sdk/models/course_create_params.rb', line 33 optional :cover_image, String, nil?: true |
#experience_id ⇒ String
The ID of the experience to create the course in
14 |
# File 'lib/whop_sdk/models/course_create_params.rb', line 14 required :experience_id, String |
#order ⇒ String?
The decimal order position of the course within its experience. If not provided, it will be set to the next sequential order. Use fractional values (e.g., 1.5) to place between existing courses.
41 |
# File 'lib/whop_sdk/models/course_create_params.rb', line 41 optional :order, String, nil?: true |
#require_completing_lessons_in_order ⇒ Boolean?
Whether the course requires students to complete the previous lesson before moving on to the next one
48 |
# File 'lib/whop_sdk/models/course_create_params.rb', line 48 optional :require_completing_lessons_in_order, WhopSDK::Internal::Type::Boolean, nil?: true |
#tagline ⇒ String?
The tagline of the course
54 |
# File 'lib/whop_sdk/models/course_create_params.rb', line 54 optional :tagline, String, nil?: true |
#thumbnail ⇒ WhopSDK::Models::CourseCreateParams::Thumbnail::AttachmentInputWithDirectUploadID, ...
The thumbnail for the course in png, jpeg, or gif format
60 |
# File 'lib/whop_sdk/models/course_create_params.rb', line 60 optional :thumbnail, union: -> { WhopSDK::CourseCreateParams::Thumbnail }, nil?: true |
#title ⇒ String
The title of the course
20 |
# File 'lib/whop_sdk/models/course_create_params.rb', line 20 required :title, String |
#visibility ⇒ Symbol, ...
The available visibilities for a course. Determines how / whether a course is visible to users.
67 |
# File 'lib/whop_sdk/models/course_create_params.rb', line 67 optional :visibility, enum: -> { WhopSDK::CourseVisibilities }, nil?: true |