Class: WhopSDK::Models::CourseCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/course_create_params.rb

Overview

Defined Under Namespace

Modules: Thumbnail

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(experience_id: , title: , certificate_after_completion_enabled: nil, cover_image: nil, order: nil, require_completing_lessons_in_order: nil, tagline: nil, thumbnail: nil, visibility: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CourseCreateParams for more details.

Parameters:

  • experience_id (String) (defaults to: )

    The ID of the experience to create the course in

  • title (String) (defaults to: )

    The title of the course

  • certificate_after_completion_enabled (Boolean, nil) (defaults to: nil)

    Whether the course will award its students a PDF certificate after completing al

  • cover_image (String, nil) (defaults to: nil)

    The cover image URL of the course

  • order (String, nil) (defaults to: nil)

    The decimal order position of the course within its experience. If not provided,

  • require_completing_lessons_in_order (Boolean, nil) (defaults to: nil)

    Whether the course requires students to complete the previous lesson before movi

  • tagline (String, nil) (defaults to: nil)

    The tagline of the course

  • thumbnail (WhopSDK::Models::CourseCreateParams::Thumbnail::AttachmentInputWithDirectUploadID, WhopSDK::Models::CourseCreateParams::Thumbnail::AttachmentInputWithID, nil) (defaults to: nil)

    The thumbnail for the course in png, jpeg, or gif format

  • visibility (Symbol, WhopSDK::Models::CourseVisibilities, nil) (defaults to: nil)

    The available visibilities for a course. Determines how / whether a course is vi

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/course_create_params.rb', line 69

Instance Attribute Details

#certificate_after_completion_enabledBoolean?

Whether the course will award its students a PDF certificate after completing all lessons

Returns:

  • (Boolean, nil)


27
# File 'lib/whop_sdk/models/course_create_params.rb', line 27

optional :certificate_after_completion_enabled, WhopSDK::Internal::Type::Boolean, nil?: true

#cover_imageString?

The cover image URL of the course

Returns:

  • (String, nil)


33
# File 'lib/whop_sdk/models/course_create_params.rb', line 33

optional :cover_image, String, nil?: true

#experience_idString

The ID of the experience to create the course in

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/course_create_params.rb', line 14

required :experience_id, String

#orderString?

The decimal order position of the course within its experience. If not provided, it will be set to the next sequential order. Use fractional values (e.g., 1.5) to place between existing courses.

Returns:

  • (String, nil)


41
# File 'lib/whop_sdk/models/course_create_params.rb', line 41

optional :order, String, nil?: true

#require_completing_lessons_in_orderBoolean?

Whether the course requires students to complete the previous lesson before moving on to the next one

Returns:

  • (Boolean, nil)


48
# File 'lib/whop_sdk/models/course_create_params.rb', line 48

optional :require_completing_lessons_in_order, WhopSDK::Internal::Type::Boolean, nil?: true

#taglineString?

The tagline of the course

Returns:

  • (String, nil)


54
# File 'lib/whop_sdk/models/course_create_params.rb', line 54

optional :tagline, String, nil?: true

#thumbnailWhopSDK::Models::CourseCreateParams::Thumbnail::AttachmentInputWithDirectUploadID, ...

The thumbnail for the course in png, jpeg, or gif format



60
# File 'lib/whop_sdk/models/course_create_params.rb', line 60

optional :thumbnail, union: -> { WhopSDK::CourseCreateParams::Thumbnail }, nil?: true

#titleString

The title of the course

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/course_create_params.rb', line 20

required :title, String

#visibilitySymbol, ...

The available visibilities for a course. Determines how / whether a course is visible to users.

Returns:



67
# File 'lib/whop_sdk/models/course_create_params.rb', line 67

optional :visibility, enum: -> { WhopSDK::CourseVisibilities }, nil?: true