Class: WhopSDK::Models::CourseCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/course_create_params.rb

Overview

Defined Under Namespace

Classes: Thumbnail

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#cover_imageString?

The cover image URL of the course

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/course_create_params.rb', line 26

optional :cover_image, String, nil?: true

#experience_idString

The ID of the experience to create the course in

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/course_create_params.rb', line 14

required :experience_id, String

#taglineString?

The tagline of the course

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/course_create_params.rb', line 32

optional :tagline, String, nil?: true

#thumbnailWhopSDK::Models::CourseCreateParams::Thumbnail?

The thumbnail for the course in png, jpeg, or gif format



38
# File 'lib/whop_sdk/models/course_create_params.rb', line 38

optional :thumbnail, -> { WhopSDK::CourseCreateParams::Thumbnail }, nil?: true

#titleString

The title of the course

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/course_create_params.rb', line 20

required :title, String