Class: WhopSDK::Models::CourseLessonCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/course_lesson_create_params.rb

Overview

Defined Under Namespace

Classes: Thumbnail

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#chapter_idString

The unique identifier of the chapter to create the lesson in (e.g., “chap_XXXXX”).

Returns:

  • (String)


15
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 15

required :chapter_id, String

#contentString?

The Markdown content body of the lesson.

Returns:

  • (String, nil)


27
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 27

optional :content, String, nil?: true

#days_from_course_start_until_unlockInteger?

The number of days after a student starts the course before this lesson becomes accessible.

Returns:

  • (Integer, nil)


34
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 34

optional :days_from_course_start_until_unlock, Integer, nil?: true

#embed_idString?

The external video identifier for embedded content (e.g., a YouTube video ID or Loom share ID).

Returns:

  • (String, nil)


41
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 41

optional :embed_id, String, nil?: true

#embed_typeSymbol, ...

The type of embed for a lesson

Returns:



47
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 47

optional :embed_type, enum: -> { WhopSDK::EmbedType }, nil?: true

#lesson_typeSymbol, WhopSDK::Models::LessonTypes

The content type of the lesson, such as video, text, quiz, or knowledge check.

Returns:



21
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 21

required :lesson_type, enum: -> { WhopSDK::LessonTypes }

#thumbnailWhopSDK::Models::CourseLessonCreateParams::Thumbnail?

The thumbnail image for the lesson in PNG, JPEG, or GIF format.



53
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 53

optional :thumbnail, -> { WhopSDK::CourseLessonCreateParams::Thumbnail }, nil?: true

#titleString?

The display title of the lesson (e.g., “Getting Started with APIs”).

Returns:

  • (String, nil)


59
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 59

optional :title, String, nil?: true