Class: WhopSDK::Models::CourseLessonCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_lesson_create_params.rb
Overview
Defined Under Namespace
Classes: Thumbnail
Instance Attribute Summary collapse
-
#chapter_id ⇒ String
The unique identifier of the chapter to create the lesson in (e.g., “chap_XXXXX”).
-
#content ⇒ String?
The Markdown content body of the lesson.
-
#days_from_course_start_until_unlock ⇒ Integer?
The number of days after a student starts the course before this lesson becomes accessible.
-
#embed_id ⇒ String?
The external video identifier for embedded content (e.g., a YouTube video ID or Loom share ID).
-
#embed_type ⇒ Symbol, ...
The type of embed for a lesson.
-
#lesson_type ⇒ Symbol, WhopSDK::Models::LessonTypes
The content type of the lesson, such as video, text, quiz, or knowledge check.
-
#thumbnail ⇒ WhopSDK::Models::CourseLessonCreateParams::Thumbnail?
The thumbnail image for the lesson in PNG, JPEG, or GIF format.
-
#title ⇒ String?
The display title of the lesson (e.g., “Getting Started with APIs”).
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#chapter_id ⇒ String
The unique identifier of the chapter to create the lesson in (e.g., “chap_XXXXX”).
15 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 15 required :chapter_id, String |
#content ⇒ String?
The Markdown content body of the lesson.
27 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 27 optional :content, String, nil?: true |
#days_from_course_start_until_unlock ⇒ Integer?
The number of days after a student starts the course before this lesson becomes accessible.
34 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 34 optional :days_from_course_start_until_unlock, Integer, nil?: true |
#embed_id ⇒ String?
The external video identifier for embedded content (e.g., a YouTube video ID or Loom share ID).
41 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 41 optional :embed_id, String, nil?: true |
#embed_type ⇒ Symbol, ...
The type of embed for a lesson
47 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 47 optional :embed_type, enum: -> { WhopSDK::EmbedType }, nil?: true |
#lesson_type ⇒ Symbol, WhopSDK::Models::LessonTypes
The content type of the lesson, such as video, text, quiz, or knowledge check.
21 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 21 required :lesson_type, enum: -> { WhopSDK::LessonTypes } |
#thumbnail ⇒ WhopSDK::Models::CourseLessonCreateParams::Thumbnail?
The thumbnail image for the lesson in PNG, JPEG, or GIF format.
53 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 53 optional :thumbnail, -> { WhopSDK::CourseLessonCreateParams::Thumbnail }, nil?: true |
#title ⇒ String?
The display title of the lesson (e.g., “Getting Started with APIs”).
59 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 59 optional :title, String, nil?: true |