Class: WhopSDK::Models::CourseLessonCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_lesson_create_params.rb
Overview
Instance Attribute Summary collapse
-
#chapter_id ⇒ String
The ID of the chapter to create the lesson in.
-
#content ⇒ String?
The content of the lesson.
-
#days_from_course_start_until_unlock ⇒ Integer?
Days from course start until unlock.
-
#lesson_type ⇒ Symbol, WhopSDK::Models::LessonTypes
The type of the lesson.
-
#title ⇒ String?
The title of the lesson.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(chapter_id: , lesson_type: , content: nil, days_from_course_start_until_unlock: nil, title: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 40
|
Instance Attribute Details
#chapter_id ⇒ String
The ID of the chapter to create the lesson in
14 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 14 required :chapter_id, String |
#content ⇒ String?
The content of the lesson
26 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 26 optional :content, String, nil?: true |
#days_from_course_start_until_unlock ⇒ Integer?
Days from course start until unlock
32 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 32 optional :days_from_course_start_until_unlock, Integer, nil?: true |
#lesson_type ⇒ Symbol, WhopSDK::Models::LessonTypes
The type of the lesson
20 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 20 required :lesson_type, enum: -> { WhopSDK::LessonTypes } |
#title ⇒ String?
The title of the lesson
38 |
# File 'lib/whop_sdk/models/course_lesson_create_params.rb', line 38 optional :title, String, nil?: true |