Class: WhopSDK::Models::CourseLessonListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/course_lesson_list_response.rb

Overview

Defined Under Namespace

Classes: Thumbnail

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , content: , days_from_course_start_until_unlock: , embed_id: , embed_type: , lesson_type: , order: , thumbnail: , title: , visibility: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CourseLessonListResponse for more details.

A lesson from the courses app

Parameters:

  • id (String) (defaults to: )

    The ID of the lesson

  • content (String, nil) (defaults to: )

    The content of the lesson

  • days_from_course_start_until_unlock (Integer, nil) (defaults to: )

    Number of days from course start until the lesson is unlocked

  • embed_id (String, nil) (defaults to: )

    ID for the embed (YouTube video ID or Loom share ID)

  • embed_type (Symbol, WhopSDK::Models::EmbedType, nil) (defaults to: )

    The type of embed for a lesson

  • lesson_type (Symbol, WhopSDK::Models::LessonTypes) (defaults to: )

    The type of the lesson (text, video, pdf, multi, quiz, knowledge_check)

  • order (Integer) (defaults to: )

    The order of the lesson within its chapter

  • thumbnail (WhopSDK::Models::CourseLessonListResponse::Thumbnail, nil) (defaults to: )

    The thumbnail for the lesson

  • title (String) (defaults to: )

    The title of the lesson

  • visibility (Symbol, WhopSDK::Models::LessonVisibilities) (defaults to: )

    The visibility of the lesson. Determines how / whether this lesson is visible to



# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 68

Instance Attribute Details

#contentString?

The content of the lesson

Returns:

  • (String, nil)


17
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 17

required :content, String, nil?: true

#days_from_course_start_until_unlockInteger?

Number of days from course start until the lesson is unlocked

Returns:

  • (Integer, nil)


23
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 23

required :days_from_course_start_until_unlock, Integer, nil?: true

#embed_idString?

ID for the embed (YouTube video ID or Loom share ID)

Returns:

  • (String, nil)


29
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 29

required :embed_id, String, nil?: true

#embed_typeSymbol, ...

The type of embed for a lesson

Returns:



35
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 35

required :embed_type, enum: -> { WhopSDK::EmbedType }, nil?: true

#idString

The ID of the lesson

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 11

required :id, String

#lesson_typeSymbol, WhopSDK::Models::LessonTypes

The type of the lesson (text, video, pdf, multi, quiz, knowledge_check)

Returns:



41
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 41

required :lesson_type, enum: -> { WhopSDK::LessonTypes }

#orderInteger

The order of the lesson within its chapter

Returns:

  • (Integer)


47
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 47

required :order, Integer

#thumbnailWhopSDK::Models::CourseLessonListResponse::Thumbnail?

The thumbnail for the lesson



53
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 53

required :thumbnail, -> { WhopSDK::Models::CourseLessonListResponse::Thumbnail }, nil?: true

#titleString

The title of the lesson

Returns:

  • (String)


59
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 59

required :title, String

#visibilitySymbol, WhopSDK::Models::LessonVisibilities

The visibility of the lesson. Determines how / whether this lesson is visible to users.



66
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 66

required :visibility, enum: -> { WhopSDK::LessonVisibilities }