Class: WhopSDK::Models::CourseLessonListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonListResponse
- Defined in:
- lib/whop_sdk/models/course_lesson_list_response.rb
Overview
Defined Under Namespace
Classes: Thumbnail
Instance Attribute Summary collapse
-
#content ⇒ String?
The content of the lesson.
-
#days_from_course_start_until_unlock ⇒ Integer?
Number of days from course start until the lesson is unlocked.
-
#embed_id ⇒ String?
ID for the embed (YouTube video ID or Loom share ID).
-
#embed_type ⇒ Symbol, ...
The type of embed for a lesson.
-
#id ⇒ String
The ID of the lesson.
-
#lesson_type ⇒ Symbol, WhopSDK::Models::LessonTypes
The type of the lesson (text, video, pdf, multi, quiz, knowledge_check).
-
#order ⇒ Integer
The order of the lesson within its chapter.
-
#thumbnail ⇒ WhopSDK::Models::CourseLessonListResponse::Thumbnail?
The thumbnail for the lesson.
-
#title ⇒ String
The title of the lesson.
-
#visibility ⇒ Symbol, WhopSDK::Models::LessonVisibilities
The visibility of the lesson.
Instance Method Summary collapse
-
#initialize(id: , content: , days_from_course_start_until_unlock: , embed_id: , embed_type: , lesson_type: , order: , thumbnail: , title: , visibility: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see CourseLessonListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , content: , days_from_course_start_until_unlock: , embed_id: , embed_type: , lesson_type: , order: , thumbnail: , title: , visibility: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseLessonListResponse for more details.
A lesson from the courses app
|
|
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 68
|
Instance Attribute Details
#content ⇒ String?
The content of the lesson
17 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 17 required :content, String, nil?: true |
#days_from_course_start_until_unlock ⇒ Integer?
Number of days from course start until the lesson is unlocked
23 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 23 required :days_from_course_start_until_unlock, Integer, nil?: true |
#embed_id ⇒ String?
ID for the embed (YouTube video ID or Loom share ID)
29 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 29 required :embed_id, String, nil?: true |
#embed_type ⇒ Symbol, ...
The type of embed for a lesson
35 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 35 required :embed_type, enum: -> { WhopSDK::EmbedType }, nil?: true |
#id ⇒ String
The ID of the lesson
11 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 11 required :id, String |
#lesson_type ⇒ Symbol, WhopSDK::Models::LessonTypes
The type of the lesson (text, video, pdf, multi, quiz, knowledge_check)
41 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 41 required :lesson_type, enum: -> { WhopSDK::LessonTypes } |
#order ⇒ Integer
The order of the lesson within its chapter
47 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 47 required :order, Integer |
#thumbnail ⇒ WhopSDK::Models::CourseLessonListResponse::Thumbnail?
The thumbnail for the lesson
53 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 53 required :thumbnail, -> { WhopSDK::Models::CourseLessonListResponse::Thumbnail }, nil?: true |
#title ⇒ String
The title of the lesson
59 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 59 required :title, String |
#visibility ⇒ Symbol, WhopSDK::Models::LessonVisibilities
The visibility of the lesson. Determines how / whether this lesson is visible to users.
66 |
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 66 required :visibility, enum: -> { WhopSDK::LessonVisibilities } |