Class: WhopSDK::Models::CourseLessonListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/course_lesson_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , content: , days_from_course_start_until_unlock: , lesson_type: , order: , title: , visibility: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CourseLessonListResponse for more details.

A lesson from the courses app

Parameters:

  • id (String) (defaults to: )

    The ID of the lesson

  • content (String, nil) (defaults to: )

    The content of the lesson

  • days_from_course_start_until_unlock (Integer, nil) (defaults to: )

    Number of days from course start until the lesson is unlocked

  • lesson_type (Symbol, WhopSDK::Models::LessonTypes) (defaults to: )

    The type of the lesson (text, video, pdf, multi, quiz, knowledge_check)

  • order (Integer) (defaults to: )

    The order of the lesson within its chapter

  • title (String) (defaults to: )

    The title of the lesson

  • visibility (Symbol, WhopSDK::Models::LessonVisibilities) (defaults to: )

    The visibility of the lesson. Determines how / whether this lesson is visible to



# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 50

Instance Attribute Details

#contentString?

The content of the lesson

Returns:

  • (String, nil)


17
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 17

required :content, String, nil?: true

#days_from_course_start_until_unlockInteger?

Number of days from course start until the lesson is unlocked

Returns:

  • (Integer, nil)


23
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 23

required :days_from_course_start_until_unlock, Integer, nil?: true

#idString

The ID of the lesson

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 11

required :id, String

#lesson_typeSymbol, WhopSDK::Models::LessonTypes

The type of the lesson (text, video, pdf, multi, quiz, knowledge_check)

Returns:



29
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 29

required :lesson_type, enum: -> { WhopSDK::LessonTypes }

#orderInteger

The order of the lesson within its chapter

Returns:

  • (Integer)


35
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 35

required :order, Integer

#titleString

The title of the lesson

Returns:

  • (String)


41
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 41

required :title, String

#visibilitySymbol, WhopSDK::Models::LessonVisibilities

The visibility of the lesson. Determines how / whether this lesson is visible to users.



48
# File 'lib/whop_sdk/models/course_lesson_list_response.rb', line 48

required :visibility, enum: -> { WhopSDK::LessonVisibilities }