Class: WhopSDK::Models::CourseLessonUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_lesson_update_params.rb
Overview
Defined Under Namespace
Classes: AssessmentCompletionRequirement, AssessmentQuestion, Attachment, MainPdf, Thumbnail
Instance Attribute Summary collapse
-
#assessment_completion_requirement ⇒ WhopSDK::Models::CourseLessonUpdateParams::AssessmentCompletionRequirement?
The passing criteria for quiz or knowledge check lessons, such as minimum grade or correct answers.
-
#assessment_questions ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::AssessmentQuestion>?
The full list of assessment questions for quiz or knowledge check lessons.
-
#attachments ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::Attachment>?
File attachments for the lesson such as PDFs or documents.
-
#content ⇒ String?
The Markdown content body of the lesson.
-
#days_from_course_start_until_unlock ⇒ Integer?
The number of days after a student starts the course before this lesson becomes accessible.
-
#embed_id ⇒ String?
The external video identifier for embedded content (e.g., a YouTube video ID or Loom share ID).
-
#embed_type ⇒ Symbol, ...
The type of embed for a lesson.
- #id ⇒ String
-
#lesson_type ⇒ Symbol, ...
The available types for a lesson.
-
#main_pdf ⇒ WhopSDK::Models::CourseLessonUpdateParams::MainPdf?
The primary PDF document attached to this lesson for student reference.
-
#max_attempts ⇒ Integer?
The maximum number of attempts a student is allowed for assessment lessons.
-
#mux_asset_id ⇒ String?
The identifier of a Mux video asset to attach to this lesson (e.g., “mux_XXXXX”).
-
#thumbnail ⇒ WhopSDK::Models::CourseLessonUpdateParams::Thumbnail?
The thumbnail image for the lesson in PNG, JPEG, or GIF format.
-
#title ⇒ String?
The display title of the lesson (e.g., “Getting Started with APIs”).
-
#visibility ⇒ Symbol, ...
The available visibilities for a lesson.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
The primary PDF document attached to this lesson for student reference.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
The primary PDF document attached to this lesson for student reference.
|
|
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 163
|
Instance Attribute Details
#assessment_completion_requirement ⇒ WhopSDK::Models::CourseLessonUpdateParams::AssessmentCompletionRequirement?
The passing criteria for quiz or knowledge check lessons, such as minimum grade or correct answers.
20 21 22 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 20 optional :assessment_completion_requirement, -> { WhopSDK::CourseLessonUpdateParams::AssessmentCompletionRequirement }, nil?: true |
#assessment_questions ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::AssessmentQuestion>?
The full list of assessment questions for quiz or knowledge check lessons. Replaces all existing questions.
29 30 31 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 29 optional :assessment_questions, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseLessonUpdateParams::AssessmentQuestion] }, nil?: true |
#attachments ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::Attachment>?
File attachments for the lesson such as PDFs or documents. Replaces all existing attachments.
38 39 40 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 38 optional :attachments, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseLessonUpdateParams::Attachment] }, nil?: true |
#content ⇒ String?
The Markdown content body of the lesson.
46 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 46 optional :content, String, nil?: true |
#days_from_course_start_until_unlock ⇒ Integer?
The number of days after a student starts the course before this lesson becomes accessible.
53 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 53 optional :days_from_course_start_until_unlock, Integer, nil?: true |
#embed_id ⇒ String?
The external video identifier for embedded content (e.g., a YouTube video ID or Loom share ID).
60 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 60 optional :embed_id, String, nil?: true |
#embed_type ⇒ Symbol, ...
The type of embed for a lesson
66 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 66 optional :embed_type, enum: -> { WhopSDK::EmbedType }, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 13 required :id, String |
#lesson_type ⇒ Symbol, ...
The available types for a lesson
72 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 72 optional :lesson_type, enum: -> { WhopSDK::LessonTypes }, nil?: true |
#main_pdf ⇒ WhopSDK::Models::CourseLessonUpdateParams::MainPdf?
The primary PDF document attached to this lesson for student reference.
78 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 78 optional :main_pdf, -> { WhopSDK::CourseLessonUpdateParams::MainPdf }, nil?: true |
#max_attempts ⇒ Integer?
The maximum number of attempts a student is allowed for assessment lessons.
84 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 84 optional :max_attempts, Integer, nil?: true |
#mux_asset_id ⇒ String?
The identifier of a Mux video asset to attach to this lesson (e.g., “mux_XXXXX”).
91 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 91 optional :mux_asset_id, String, nil?: true |
#thumbnail ⇒ WhopSDK::Models::CourseLessonUpdateParams::Thumbnail?
The thumbnail image for the lesson in PNG, JPEG, or GIF format.
97 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 97 optional :thumbnail, -> { WhopSDK::CourseLessonUpdateParams::Thumbnail }, nil?: true |
#title ⇒ String?
The display title of the lesson (e.g., “Getting Started with APIs”).
103 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 103 optional :title, String, nil?: true |
#visibility ⇒ Symbol, ...
The available visibilities for a lesson. Determines how / whether a lesson is visible to users.
110 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 110 optional :visibility, enum: -> { WhopSDK::LessonVisibilities }, nil?: true |