Class: WhopSDK::Models::CourseLessonUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/course_lesson_update_params.rb

Overview

Defined Under Namespace

Modules: Attachment, MainPdf, Thumbnail Classes: AssessmentCompletionRequirement, AssessmentQuestion

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CourseLessonUpdateParams::MainPdf::AttachmentInputWithID for more details.

Input for an attachment

Parameters:

  • id (String) (defaults to: )

    The ID of an existing attachment object. Use this when updating a resource and k



# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 152

Instance Attribute Details

#assessment_completion_requirementWhopSDK::Models::CourseLessonUpdateParams::AssessmentCompletionRequirement?

Completion requirements for quiz/knowledge check lessons



14
15
16
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 14

optional :assessment_completion_requirement,
-> { WhopSDK::CourseLessonUpdateParams::AssessmentCompletionRequirement },
nil?: true

#assessment_questionsArray<WhopSDK::Models::CourseLessonUpdateParams::AssessmentQuestion>?

Assessment questions for quiz/knowledge check lessons. Replaces all existing questions.



23
24
25
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 23

optional :assessment_questions,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseLessonUpdateParams::AssessmentQuestion] },
nil?: true

#attachmentsArray<WhopSDK::Models::CourseLessonUpdateParams::Attachment::AttachmentInputWithDirectUploadID, WhopSDK::Models::CourseLessonUpdateParams::Attachment::AttachmentInputWithID>?

General attachments for the lesson (PDFs, files, etc). Replaces all existing attachments.



32
33
34
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 32

optional :attachments,
-> { WhopSDK::Internal::Type::ArrayOf[union: WhopSDK::CourseLessonUpdateParams::Attachment] },
nil?: true

#contentString?

The content of the lesson

Returns:

  • (String, nil)


40
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 40

optional :content, String, nil?: true

#days_from_course_start_until_unlockInteger?

Days from course start until unlock

Returns:

  • (Integer, nil)


46
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 46

optional :days_from_course_start_until_unlock, Integer, nil?: true

#embed_idString?

ID for the embed (YouTube video ID or Loom share ID)

Returns:

  • (String, nil)


52
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 52

optional :embed_id, String, nil?: true

#embed_typeSymbol, ...

The type of embed for a lesson

Returns:



58
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 58

optional :embed_type, enum: -> { WhopSDK::EmbedType }, nil?: true

#lesson_typeSymbol, ...

The available types for a lesson

Returns:



64
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 64

optional :lesson_type, enum: -> { WhopSDK::LessonTypes }, nil?: true

#main_pdfWhopSDK::Models::CourseLessonUpdateParams::MainPdf::AttachmentInputWithDirectUploadID, ...

The main PDF file for this lesson



70
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 70

optional :main_pdf, union: -> { WhopSDK::CourseLessonUpdateParams::MainPdf }, nil?: true

#max_attemptsInteger?

Maximum number of attempts allowed for assessments

Returns:

  • (Integer, nil)


76
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 76

optional :max_attempts, Integer, nil?: true

#mux_asset_idString?

The ID of the Mux asset to attach to this lesson for video lessons

Returns:

  • (String, nil)


82
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 82

optional :mux_asset_id, String, nil?: true

#thumbnailWhopSDK::Models::CourseLessonUpdateParams::Thumbnail::AttachmentInputWithDirectUploadID, ...

The thumbnail for the lesson in png, jpeg, or gif format



88
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 88

optional :thumbnail, union: -> { WhopSDK::CourseLessonUpdateParams::Thumbnail }, nil?: true

#titleString?

The title of the lesson

Returns:

  • (String, nil)


94
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 94

optional :title, String, nil?: true

#visibilitySymbol, ...

The available visibilities for a lesson. Determines how / whether a lesson is visible to users.

Returns:



101
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 101

optional :visibility, enum: -> { WhopSDK::LessonVisibilities }, nil?: true