Class: WhopSDK::Models::CourseLessonUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_lesson_update_params.rb
Overview
Defined Under Namespace
Modules: Attachment, MainPdf, Thumbnail Classes: AssessmentCompletionRequirement, AssessmentQuestion
Instance Attribute Summary collapse
-
#assessment_completion_requirement ⇒ WhopSDK::Models::CourseLessonUpdateParams::AssessmentCompletionRequirement?
Completion requirements for quiz/knowledge check lessons.
-
#assessment_questions ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::AssessmentQuestion>?
Assessment questions for quiz/knowledge check lessons.
-
#attachments ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::Attachment::AttachmentInputWithDirectUploadID, WhopSDK::Models::CourseLessonUpdateParams::Attachment::AttachmentInputWithID>?
General attachments for the lesson (PDFs, files, etc).
-
#content ⇒ String?
The content of the lesson.
-
#days_from_course_start_until_unlock ⇒ Integer?
Days from course start until unlock.
-
#embed_id ⇒ String?
ID for the embed (YouTube video ID or Loom share ID).
-
#embed_type ⇒ Symbol, ...
The type of embed for a lesson.
-
#lesson_type ⇒ Symbol, ...
The available types for a lesson.
-
#main_pdf ⇒ WhopSDK::Models::CourseLessonUpdateParams::MainPdf::AttachmentInputWithDirectUploadID, ...
The main PDF file for this lesson.
-
#max_attempts ⇒ Integer?
Maximum number of attempts allowed for assessments.
-
#mux_asset_id ⇒ String?
The ID of the Mux asset to attach to this lesson for video lessons.
-
#thumbnail ⇒ WhopSDK::Models::CourseLessonUpdateParams::Thumbnail::AttachmentInputWithDirectUploadID, ...
The thumbnail for the lesson in png, jpeg, or gif format.
-
#title ⇒ String?
The title of the lesson.
-
#visibility ⇒ Symbol, ...
The available visibilities for a lesson.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see MainPdf::AttachmentInputWithID for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseLessonUpdateParams::MainPdf::AttachmentInputWithID for more details.
Input for an attachment
|
|
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 152
|
Instance Attribute Details
#assessment_completion_requirement ⇒ WhopSDK::Models::CourseLessonUpdateParams::AssessmentCompletionRequirement?
Completion requirements for quiz/knowledge check lessons
14 15 16 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 14 optional :assessment_completion_requirement, -> { WhopSDK::CourseLessonUpdateParams::AssessmentCompletionRequirement }, nil?: true |
#assessment_questions ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::AssessmentQuestion>?
Assessment questions for quiz/knowledge check lessons. Replaces all existing questions.
23 24 25 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 23 optional :assessment_questions, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseLessonUpdateParams::AssessmentQuestion] }, nil?: true |
#attachments ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::Attachment::AttachmentInputWithDirectUploadID, WhopSDK::Models::CourseLessonUpdateParams::Attachment::AttachmentInputWithID>?
General attachments for the lesson (PDFs, files, etc). Replaces all existing attachments.
32 33 34 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 32 optional :attachments, -> { WhopSDK::Internal::Type::ArrayOf[union: WhopSDK::CourseLessonUpdateParams::Attachment] }, nil?: true |
#content ⇒ String?
The content of the lesson
40 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 40 optional :content, String, nil?: true |
#days_from_course_start_until_unlock ⇒ Integer?
Days from course start until unlock
46 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 46 optional :days_from_course_start_until_unlock, Integer, nil?: true |
#embed_id ⇒ String?
ID for the embed (YouTube video ID or Loom share ID)
52 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 52 optional :embed_id, String, nil?: true |
#embed_type ⇒ Symbol, ...
The type of embed for a lesson
58 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 58 optional :embed_type, enum: -> { WhopSDK::EmbedType }, nil?: true |
#lesson_type ⇒ Symbol, ...
The available types for a lesson
64 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 64 optional :lesson_type, enum: -> { WhopSDK::LessonTypes }, nil?: true |
#main_pdf ⇒ WhopSDK::Models::CourseLessonUpdateParams::MainPdf::AttachmentInputWithDirectUploadID, ...
The main PDF file for this lesson
70 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 70 optional :main_pdf, union: -> { WhopSDK::CourseLessonUpdateParams::MainPdf }, nil?: true |
#max_attempts ⇒ Integer?
Maximum number of attempts allowed for assessments
76 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 76 optional :max_attempts, Integer, nil?: true |
#mux_asset_id ⇒ String?
The ID of the Mux asset to attach to this lesson for video lessons
82 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 82 optional :mux_asset_id, String, nil?: true |
#thumbnail ⇒ WhopSDK::Models::CourseLessonUpdateParams::Thumbnail::AttachmentInputWithDirectUploadID, ...
The thumbnail for the lesson in png, jpeg, or gif format
88 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 88 optional :thumbnail, union: -> { WhopSDK::CourseLessonUpdateParams::Thumbnail }, nil?: true |
#title ⇒ String?
The title of the lesson
94 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 94 optional :title, String, nil?: true |
#visibility ⇒ Symbol, ...
The available visibilities for a lesson. Determines how / whether a lesson is visible to users.
101 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 101 optional :visibility, enum: -> { WhopSDK::LessonVisibilities }, nil?: true |
Class Method Details
.variants ⇒ Array(WhopSDK::Models::CourseLessonUpdateParams::MainPdf::AttachmentInputWithDirectUploadID, WhopSDK::Models::CourseLessonUpdateParams::MainPdf::AttachmentInputWithID)
|
|
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 366
|