Class: WhopSDK::Models::CourseLessonUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/course_lesson_update_params.rb

Overview

Defined Under Namespace

Classes: AssessmentQuestion, Attachment, MainPdf

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, direct_upload_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Attachment for more details.

Input for an attachment

Parameters:

  • id (String, nil) (defaults to: nil)

    The ID of an existing attachment object. Use this when updating a resource and k

  • direct_upload_id (String, nil) (defaults to: nil)

    This ID should be used the first time you upload an attachment. It is the ID of



# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 206

Instance Attribute Details

#assessment_questionsArray<WhopSDK::Models::CourseLessonUpdateParams::AssessmentQuestion>?

Assessment questions for quiz/knowledge check lessons. Replaces all existing questions.



15
16
17
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 15

optional :assessment_questions,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseLessonUpdateParams::AssessmentQuestion] },
nil?: true

#attachmentsArray<WhopSDK::Models::CourseLessonUpdateParams::Attachment>?

General attachments for the lesson (PDFs, files, etc). Replaces all existing attachments.



24
25
26
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 24

optional :attachments,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseLessonUpdateParams::Attachment] },
nil?: true

#contentString?

The content of the lesson

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 32

optional :content, String, nil?: true

#days_from_course_start_until_unlockInteger?

Days from course start until unlock

Returns:

  • (Integer, nil)


38
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 38

optional :days_from_course_start_until_unlock, Integer, nil?: true

#lesson_typeSymbol, ...

The available types for a lesson

Returns:



44
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 44

optional :lesson_type, enum: -> { WhopSDK::LessonTypes }, nil?: true

#main_pdfWhopSDK::Models::CourseLessonUpdateParams::MainPdf?

The main PDF file for this lesson



50
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 50

optional :main_pdf, -> { WhopSDK::CourseLessonUpdateParams::MainPdf }, nil?: true

#mux_asset_idString?

The ID of the Mux asset to attach to this lesson for video lessons

Returns:

  • (String, nil)


56
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 56

optional :mux_asset_id, String, nil?: true

#titleString?

The title of the lesson

Returns:

  • (String, nil)


62
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 62

optional :title, String, nil?: true

#visibilitySymbol, ...

The available visibilities for a lesson. Determines how / whether a lesson is visible to users.

Returns:



69
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 69

optional :visibility, enum: -> { WhopSDK::LessonVisibilities }, nil?: true