Class: WhopSDK::Models::CourseLessonUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_lesson_update_params.rb
Overview
Defined Under Namespace
Classes: AssessmentQuestion, Attachment, MainPdf
Instance Attribute Summary collapse
-
#assessment_questions ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::AssessmentQuestion>?
Assessment questions for quiz/knowledge check lessons.
-
#attachments ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::Attachment>?
General attachments for the lesson (PDFs, files, etc).
-
#content ⇒ String?
The content of the lesson.
-
#days_from_course_start_until_unlock ⇒ Integer?
Days from course start until unlock.
-
#lesson_type ⇒ Symbol, ...
The available types for a lesson.
-
#main_pdf ⇒ WhopSDK::Models::CourseLessonUpdateParams::MainPdf?
The main PDF file for this lesson.
-
#mux_asset_id ⇒ String?
The ID of the Mux asset to attach to this lesson for video lessons.
-
#title ⇒ String?
The title of the lesson.
-
#visibility ⇒ Symbol, ...
The available visibilities for a lesson.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id: nil, direct_upload_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Attachment for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, direct_upload_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Attachment for more details.
Input for an attachment
|
|
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 206
|
Instance Attribute Details
#assessment_questions ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::AssessmentQuestion>?
Assessment questions for quiz/knowledge check lessons. Replaces all existing questions.
15 16 17 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 15 optional :assessment_questions, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseLessonUpdateParams::AssessmentQuestion] }, nil?: true |
#attachments ⇒ Array<WhopSDK::Models::CourseLessonUpdateParams::Attachment>?
General attachments for the lesson (PDFs, files, etc). Replaces all existing attachments.
24 25 26 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 24 optional :attachments, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseLessonUpdateParams::Attachment] }, nil?: true |
#content ⇒ String?
The content of the lesson
32 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 32 optional :content, String, nil?: true |
#days_from_course_start_until_unlock ⇒ Integer?
Days from course start until unlock
38 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 38 optional :days_from_course_start_until_unlock, Integer, nil?: true |
#lesson_type ⇒ Symbol, ...
The available types for a lesson
44 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 44 optional :lesson_type, enum: -> { WhopSDK::LessonTypes }, nil?: true |
#main_pdf ⇒ WhopSDK::Models::CourseLessonUpdateParams::MainPdf?
The main PDF file for this lesson
50 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 50 optional :main_pdf, -> { WhopSDK::CourseLessonUpdateParams::MainPdf }, nil?: true |
#mux_asset_id ⇒ String?
The ID of the Mux asset to attach to this lesson for video lessons
56 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 56 optional :mux_asset_id, String, nil?: true |
#title ⇒ String?
The title of the lesson
62 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 62 optional :title, String, nil?: true |
#visibility ⇒ Symbol, ...
The available visibilities for a lesson. Determines how / whether a lesson is visible to users.
69 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 69 optional :visibility, enum: -> { WhopSDK::LessonVisibilities }, nil?: true |