Class: WhopSDK::Models::CourseLessonUpdateParams::AssessmentCompletionRequirement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseLessonUpdateParams::AssessmentCompletionRequirement
- Defined in:
- lib/whop_sdk/models/course_lesson_update_params.rb
Instance Attribute Summary collapse
-
#minimum_grade_percent ⇒ Float?
The minimum grade percentage required to pass (0-100).
-
#minimum_questions_correct ⇒ Integer?
The minimum number of questions that must be answered correctly.
Instance Method Summary collapse
-
#initialize(id:, assessment_completion_requirement: nil, assessment_questions: nil, attachments: nil, content: nil, days_from_course_start_until_unlock: nil, embed_id: nil, embed_type: nil, lesson_type: nil, main_pdf: nil, max_attempts: nil, mux_asset_id: nil, thumbnail: nil, title: nil, visibility: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhopSDK::Models::CourseLessonUpdateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, assessment_completion_requirement: nil, assessment_questions: nil, attachments: nil, content: nil, days_from_course_start_until_unlock: nil, embed_id: nil, embed_type: nil, lesson_type: nil, main_pdf: nil, max_attempts: nil, mux_asset_id: nil, thumbnail: nil, title: nil, visibility: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseLessonUpdateParams for more details.
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 148 class AssessmentCompletionRequirement < WhopSDK::Internal::Type::BaseModel # @!attribute minimum_grade_percent # The minimum grade percentage required to pass (0-100). Cannot be set together # with minimum_questions_correct. # # @return [Float, nil] optional :minimum_grade_percent, Float, nil?: true # @!attribute minimum_questions_correct # The minimum number of questions that must be answered correctly. Cannot be set # together with minimum_grade_percent. # # @return [Integer, nil] optional :minimum_questions_correct, Integer, nil?: true # @!method initialize(minimum_grade_percent: nil, minimum_questions_correct: nil) # Some parameter documentations has been truncated, see # {WhopSDK::Models::CourseLessonUpdateParams::AssessmentCompletionRequirement} for # more details. # # The passing criteria for quiz or knowledge check lessons, such as minimum grade # or correct answers. # # @param minimum_grade_percent [Float, nil] The minimum grade percentage required to pass (0-100). Cannot be set together wi # # @param minimum_questions_correct [Integer, nil] The minimum number of questions that must be answered correctly. Cannot be set t end |
Instance Attribute Details
#minimum_grade_percent ⇒ Float?
The minimum grade percentage required to pass (0-100). Cannot be set together with minimum_questions_correct.
154 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 154 optional :minimum_grade_percent, Float, nil?: true |
#minimum_questions_correct ⇒ Integer?
The minimum number of questions that must be answered correctly. Cannot be set together with minimum_grade_percent.
161 |
# File 'lib/whop_sdk/models/course_lesson_update_params.rb', line 161 optional :minimum_questions_correct, Integer, nil?: true |