Class: WhopSDK::Models::CourseListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/course_list_response.rb

Overview

Defined Under Namespace

Classes: Thumbnail

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , certificate_after_completion_enabled: , created_at: , description: , language: , require_completing_lessons_in_order: , tagline: , thumbnail: , title: , updated_at: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CourseListResponse for more details.

A course from the courses app

Parameters:

  • id (String) (defaults to: )

    The ID of the course. Looks like cors_XXX

  • certificate_after_completion_enabled (Boolean, nil) (defaults to: )

    Whether the course will award its students a PDF certificate after completing al

  • created_at (Time) (defaults to: )

    The timestamp of when the course was created

  • description (String, nil) (defaults to: )

    A short description of the course

  • language (Symbol, WhopSDK::Models::Languages) (defaults to: )

    The language spoken in the video content of the course, used to generate closed

  • require_completing_lessons_in_order (Boolean) (defaults to: )

    Whether the course requires students to complete the previous lesson before movi

  • tagline (String, nil) (defaults to: )

    A short tagline for the course. It is displayed under the course title in the UI

  • thumbnail (WhopSDK::Models::CourseListResponse::Thumbnail, nil) (defaults to: )

    The thumbnail for the course

  • title (String, nil) (defaults to: )

    The title of the course

  • updated_at (Time) (defaults to: )

    The timestamp of when the course was last updated



# File 'lib/whop_sdk/models/course_list_response.rb', line 70

Instance Attribute Details

#certificate_after_completion_enabledBoolean?

Whether the course will award its students a PDF certificate after completing all lessons

Returns:

  • (Boolean, nil)


18
# File 'lib/whop_sdk/models/course_list_response.rb', line 18

required :certificate_after_completion_enabled, WhopSDK::Internal::Type::Boolean, nil?: true

#created_atTime

The timestamp of when the course was created

Returns:

  • (Time)


24
# File 'lib/whop_sdk/models/course_list_response.rb', line 24

required :created_at, Time

#descriptionString?

A short description of the course

Returns:

  • (String, nil)


30
# File 'lib/whop_sdk/models/course_list_response.rb', line 30

required :description, String, nil?: true

#idString

The ID of the course. Looks like cors_XXX

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/course_list_response.rb', line 11

required :id, String

#languageSymbol, WhopSDK::Models::Languages

The language spoken in the video content of the course, used to generate closed captions in the right language

Returns:



37
# File 'lib/whop_sdk/models/course_list_response.rb', line 37

required :language, enum: -> { WhopSDK::Languages }

#require_completing_lessons_in_orderBoolean

Whether the course requires students to complete the previous lesson before moving on to the next one

Returns:

  • (Boolean)


44
# File 'lib/whop_sdk/models/course_list_response.rb', line 44

required :require_completing_lessons_in_order, WhopSDK::Internal::Type::Boolean

#taglineString?

A short tagline for the course. It is displayed under the course title in the UI

Returns:

  • (String, nil)


50
# File 'lib/whop_sdk/models/course_list_response.rb', line 50

required :tagline, String, nil?: true

#thumbnailWhopSDK::Models::CourseListResponse::Thumbnail?

The thumbnail for the course



56
# File 'lib/whop_sdk/models/course_list_response.rb', line 56

required :thumbnail, -> { WhopSDK::Models::CourseListResponse::Thumbnail }, nil?: true

#titleString?

The title of the course

Returns:

  • (String, nil)


62
# File 'lib/whop_sdk/models/course_list_response.rb', line 62

required :title, String, nil?: true

#updated_atTime

The timestamp of when the course was last updated

Returns:

  • (Time)


68
# File 'lib/whop_sdk/models/course_list_response.rb', line 68

required :updated_at, Time