Class: WhopSDK::Models::CourseListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseListResponse
- Defined in:
- lib/whop_sdk/models/course_list_response.rb
Overview
Defined Under Namespace
Classes: Thumbnail
Instance Attribute Summary collapse
-
#certificate_after_completion_enabled ⇒ Boolean?
Whether the course will award its students a PDF certificate after completing all lessons.
-
#created_at ⇒ Time
The timestamp of when the course was created.
-
#description ⇒ String?
A short description of the course.
-
#id ⇒ String
The ID of the course.
-
#language ⇒ Symbol, WhopSDK::Models::Languages
The language spoken in the video content of the course, used to generate closed captions in the right language.
-
#require_completing_lessons_in_order ⇒ Boolean
Whether the course requires students to complete the previous lesson before moving on to the next one.
-
#tagline ⇒ String?
A short tagline for the course.
-
#thumbnail ⇒ WhopSDK::Models::CourseListResponse::Thumbnail?
The thumbnail for the course.
-
#title ⇒ String?
The title of the course.
-
#updated_at ⇒ Time
The timestamp of when the course was last updated.
Instance Method Summary collapse
-
#initialize(id: , certificate_after_completion_enabled: , created_at: , description: , language: , require_completing_lessons_in_order: , tagline: , thumbnail: , title: , updated_at: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see CourseListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , certificate_after_completion_enabled: , created_at: , description: , language: , require_completing_lessons_in_order: , tagline: , thumbnail: , title: , updated_at: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseListResponse for more details.
A course from the courses app
|
|
# File 'lib/whop_sdk/models/course_list_response.rb', line 70
|
Instance Attribute Details
#certificate_after_completion_enabled ⇒ Boolean?
Whether the course will award its students a PDF certificate after completing all lessons
18 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 18 required :certificate_after_completion_enabled, WhopSDK::Internal::Type::Boolean, nil?: true |
#created_at ⇒ Time
The timestamp of when the course was created
24 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 24 required :created_at, Time |
#description ⇒ String?
A short description of the course
30 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 30 required :description, String, nil?: true |
#id ⇒ String
The ID of the course. Looks like cors_XXX
11 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 11 required :id, String |
#language ⇒ Symbol, WhopSDK::Models::Languages
The language spoken in the video content of the course, used to generate closed captions in the right language
37 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 37 required :language, enum: -> { WhopSDK::Languages } |
#require_completing_lessons_in_order ⇒ Boolean
Whether the course requires students to complete the previous lesson before moving on to the next one
44 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 44 required :require_completing_lessons_in_order, WhopSDK::Internal::Type::Boolean |
#tagline ⇒ String?
A short tagline for the course. It is displayed under the course title in the UI
50 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 50 required :tagline, String, nil?: true |
#thumbnail ⇒ WhopSDK::Models::CourseListResponse::Thumbnail?
The thumbnail for the course
56 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 56 required :thumbnail, -> { WhopSDK::Models::CourseListResponse::Thumbnail }, nil?: true |
#title ⇒ String?
The title of the course
62 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 62 required :title, String, nil?: true |
#updated_at ⇒ Time
The timestamp of when the course was last updated
68 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 68 required :updated_at, Time |