Class: WhopSDK::Models::CourseListResponse::Thumbnail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseListResponse::Thumbnail
- Defined in:
- lib/whop_sdk/models/course_list_response.rb
Overview
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
-
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#optimized_url ⇒ String?
A pre-optimized URL for rendering this attachment on the client.
-
#source_url ⇒ String?
The original source URL of the attachment, such as a direct link to S3.
Instance Method Summary collapse
-
#initialize(id:, content_type:, filename:, optimized_url:, source_url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Thumbnail for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, content_type:, filename:, optimized_url:, source_url:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseListResponse::Thumbnail for more details.
The thumbnail image displayed on course cards and previews. Null if no thumbnail has been uploaded.
|
|
# File 'lib/whop_sdk/models/course_list_response.rb', line 167
|
Instance Attribute Details
#content_type ⇒ String?
The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
144 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 144 required :content_type, String, nil?: true |
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
150 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 150 required :filename, String, nil?: true |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.
138 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 138 required :id, String |
#optimized_url ⇒ String?
A pre-optimized URL for rendering this attachment on the client. This should be used for displaying attachments in apps.
157 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 157 required :optimized_url, String, nil?: true |
#source_url ⇒ String?
The original source URL of the attachment, such as a direct link to S3. This should never be displayed on the client and should always be passed through an Imgproxy transformer.
165 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 165 required :source_url, String, nil?: true |