Class: WhopSDK::Models::CourseListResponse::Thumbnail

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/course_list_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , content_type: , filename: , optimized_url: , source_url: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::CourseListResponse::Thumbnail for more details.

The thumbnail for the course

Parameters:

  • id (String) (defaults to: )

    The ID of the attachment

  • content_type (String, nil) (defaults to: )

    The attachment’s content type (e.g., image/jpg, video/mp4)

  • filename (String, nil) (defaults to: )

    The name of the file

  • optimized_url (String, nil) (defaults to: )

    This is the URL you use to render optimized attachments on the client. This shou

  • source_url (String, nil) (defaults to: )

    The original URL of the attachment, such as a direct link to S3. This should nev



# File 'lib/whop_sdk/models/course_list_response.rb', line 130

Instance Attribute Details

#content_typeString?

The attachment’s content type (e.g., image/jpg, video/mp4)

Returns:

  • (String, nil)


108
# File 'lib/whop_sdk/models/course_list_response.rb', line 108

required :content_type, String, nil?: true

#filenameString?

The name of the file

Returns:

  • (String, nil)


114
# File 'lib/whop_sdk/models/course_list_response.rb', line 114

required :filename, String, nil?: true

#idString

The ID of the attachment

Returns:

  • (String)


102
# File 'lib/whop_sdk/models/course_list_response.rb', line 102

required :id, String

#optimized_urlString?

This is the URL you use to render optimized attachments on the client. This should be used for apps.

Returns:

  • (String, nil)


121
# File 'lib/whop_sdk/models/course_list_response.rb', line 121

required :optimized_url, String, nil?: true

#source_urlString?

The original URL of the attachment, such as a direct link to S3. This should never be displayed on the client and always passed to an Imgproxy transformer.

Returns:

  • (String, nil)


128
# File 'lib/whop_sdk/models/course_list_response.rb', line 128

required :source_url, String, nil?: true