Class: WhopSDK::Models::CourseListResponse::Thumbnail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseListResponse::Thumbnail
- Defined in:
- lib/whop_sdk/models/course_list_response.rb
Overview
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The attachment’s content type (e.g., image/jpg, video/mp4).
-
#filename ⇒ String?
The name of the file.
-
#id ⇒ String
The ID of the attachment.
-
#optimized_url ⇒ String?
This is the URL you use to render optimized attachments on the client.
-
#source_url ⇒ String?
The original URL of the attachment, such as a direct link to S3.
Instance Method Summary collapse
-
#initialize(id: , content_type: , filename: , optimized_url: , source_url: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Thumbnail for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , content_type: , filename: , optimized_url: , source_url: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseListResponse::Thumbnail for more details.
The thumbnail for the course
|
|
# File 'lib/whop_sdk/models/course_list_response.rb', line 130
|
Instance Attribute Details
#content_type ⇒ String?
The attachment’s content type (e.g., image/jpg, video/mp4)
108 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 108 required :content_type, String, nil?: true |
#filename ⇒ String?
The name of the file
114 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 114 required :filename, String, nil?: true |
#id ⇒ String
The ID of the attachment
102 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 102 required :id, String |
#optimized_url ⇒ String?
This is the URL you use to render optimized attachments on the client. This should be used for apps.
121 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 121 required :optimized_url, String, nil?: true |
#source_url ⇒ String?
The original URL of the attachment, such as a direct link to S3. This should never be displayed on the client and always passed to an Imgproxy transformer.
128 |
# File 'lib/whop_sdk/models/course_list_response.rb', line 128 required :source_url, String, nil?: true |