Class: WhopSDK::Models::CourseStudentListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseStudentListResponse
- Defined in:
- lib/whop_sdk/models/course_student_list_response.rb
Overview
Defined Under Namespace
Classes: User
Instance Attribute Summary collapse
-
#completed_lessons_count ⇒ Integer
The total number of lessons this student has marked as completed in the course.
-
#completion_rate ⇒ Float
The percentage of available lessons the student has completed, as a value from 0 to 100 rounded to two decimal places.
-
#first_interaction_at ⇒ Time
The timestamp when the student first interacted with this course, as a Unix timestamp.
-
#id ⇒ String
The unique identifier for the course student type.
-
#last_interaction_at ⇒ Time
The timestamp when the student most recently interacted with this course, as a Unix timestamp.
-
#total_lessons_count ⇒ Integer
The total number of visible lessons available to this student in the course.
-
#user ⇒ WhopSDK::Models::CourseStudentListResponse::User
The user profile of the enrolled student.
Instance Method Summary collapse
-
#initialize(id:, completed_lessons_count:, completion_rate:, first_interaction_at:, last_interaction_at:, total_lessons_count:, user:) ⇒ Object
constructor
Some parameter documentations has been truncated, see CourseStudentListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, completed_lessons_count:, completion_rate:, first_interaction_at:, last_interaction_at:, total_lessons_count:, user:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseStudentListResponse for more details.
An enrollment record for a student in a course, including progress and completion metrics.
|
|
# File 'lib/whop_sdk/models/course_student_list_response.rb', line 52
|
Instance Attribute Details
#completed_lessons_count ⇒ Integer
The total number of lessons this student has marked as completed in the course.
17 |
# File 'lib/whop_sdk/models/course_student_list_response.rb', line 17 required :completed_lessons_count, Integer |
#completion_rate ⇒ Float
The percentage of available lessons the student has completed, as a value from 0 to 100 rounded to two decimal places.
24 |
# File 'lib/whop_sdk/models/course_student_list_response.rb', line 24 required :completion_rate, Float |
#first_interaction_at ⇒ Time
The timestamp when the student first interacted with this course, as a Unix timestamp.
31 |
# File 'lib/whop_sdk/models/course_student_list_response.rb', line 31 required :first_interaction_at, Time |
#id ⇒ String
The unique identifier for the course student type.
11 |
# File 'lib/whop_sdk/models/course_student_list_response.rb', line 11 required :id, String |
#last_interaction_at ⇒ Time
The timestamp when the student most recently interacted with this course, as a Unix timestamp.
38 |
# File 'lib/whop_sdk/models/course_student_list_response.rb', line 38 required :last_interaction_at, Time |
#total_lessons_count ⇒ Integer
The total number of visible lessons available to this student in the course.
44 |
# File 'lib/whop_sdk/models/course_student_list_response.rb', line 44 required :total_lessons_count, Integer |
#user ⇒ WhopSDK::Models::CourseStudentListResponse::User
The user profile of the enrolled student.
50 |
# File 'lib/whop_sdk/models/course_student_list_response.rb', line 50 required :user, -> { WhopSDK::Models::CourseStudentListResponse::User } |