Class: WhopSDK::Models::CourseStudentRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseStudentRetrieveResponse
- Defined in:
- lib/whop_sdk/models/course_student_retrieve_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#completed_lessons_count ⇒ Integer
The total number of lessons this student has marked as completed in the course.
-
#completion_rate ⇒ Float
The percentage of available lessons the student has completed, as a value from 0 to 100 rounded to two decimal places.
-
#course ⇒ WhopSDK::Models::CourseStudentRetrieveResponse::Course
The course this student is enrolled in.
-
#first_interaction_at ⇒ Time
The timestamp when the student first interacted with this course, as a Unix timestamp.
-
#id ⇒ String
The unique identifier for the course student type.
-
#last_interaction_at ⇒ Time
The timestamp when the student most recently interacted with this course, as a Unix timestamp.
-
#total_lessons_count ⇒ Integer
The total number of visible lessons available to this student in the course.
-
#user ⇒ WhopSDK::Models::CourseStudentRetrieveResponse::User
The user profile of the enrolled student.
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
The parent experience that this course belongs to.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
The parent experience that this course belongs to.
|
|
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 58
|
Instance Attribute Details
#completed_lessons_count ⇒ Integer
The total number of lessons this student has marked as completed in the course.
17 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 17 required :completed_lessons_count, Integer |
#completion_rate ⇒ Float
The percentage of available lessons the student has completed, as a value from 0 to 100 rounded to two decimal places.
24 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 24 required :completion_rate, Float |
#course ⇒ WhopSDK::Models::CourseStudentRetrieveResponse::Course
The course this student is enrolled in.
30 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 30 required :course, -> { WhopSDK::Models::CourseStudentRetrieveResponse::Course } |
#first_interaction_at ⇒ Time
The timestamp when the student first interacted with this course, as a Unix timestamp.
37 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 37 required :first_interaction_at, Time |
#id ⇒ String
The unique identifier for the course student type.
11 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 11 required :id, String |
#last_interaction_at ⇒ Time
The timestamp when the student most recently interacted with this course, as a Unix timestamp.
44 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 44 required :last_interaction_at, Time |
#total_lessons_count ⇒ Integer
The total number of visible lessons available to this student in the course.
50 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 50 required :total_lessons_count, Integer |
#user ⇒ WhopSDK::Models::CourseStudentRetrieveResponse::User
The user profile of the enrolled student.
56 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 56 required :user, -> { WhopSDK::Models::CourseStudentRetrieveResponse::User } |