Class: WhopSDK::Models::CourseStudentRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseStudentRetrieveResponse
- Defined in:
- lib/whop_sdk/models/course_student_retrieve_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#completed_lessons_count ⇒ Integer
The number of lessons the student has completed.
-
#completion_rate ⇒ Float
The percentage of lessons completed (0-100).
-
#course ⇒ WhopSDK::Models::CourseStudentRetrieveResponse::Course
The course the student is enrolled in.
-
#first_interaction_at ⇒ Time
When the student first interacted with the course.
-
#id ⇒ String
The ID of the course student.
-
#last_interaction_at ⇒ Time
When the student last interacted with the course.
-
#total_lessons_count ⇒ Integer
The total number of lessons the student has access to.
-
#user ⇒ WhopSDK::Models::CourseStudentRetrieveResponse::User
The user who is enrolled in the course.
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
The experience that the course belongs to.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
The experience that the course belongs to
|
|
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 55
|
Instance Attribute Details
#completed_lessons_count ⇒ Integer
The number of lessons the student has completed
17 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 17 required :completed_lessons_count, Integer |
#completion_rate ⇒ Float
The percentage of lessons completed (0-100)
23 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 23 required :completion_rate, Float |
#course ⇒ WhopSDK::Models::CourseStudentRetrieveResponse::Course
The course the student is enrolled in
29 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 29 required :course, -> { WhopSDK::Models::CourseStudentRetrieveResponse::Course } |
#first_interaction_at ⇒ Time
When the student first interacted with the course
35 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 35 required :first_interaction_at, Time |
#id ⇒ String
The ID of the course student. Looks like crsi_XXX
11 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 11 required :id, String |
#last_interaction_at ⇒ Time
When the student last interacted with the course
41 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 41 required :last_interaction_at, Time |
#total_lessons_count ⇒ Integer
The total number of lessons the student has access to
47 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 47 required :total_lessons_count, Integer |
#user ⇒ WhopSDK::Models::CourseStudentRetrieveResponse::User
The user who is enrolled in the course
53 |
# File 'lib/whop_sdk/models/course_student_retrieve_response.rb', line 53 required :user, -> { WhopSDK::Models::CourseStudentRetrieveResponse::User } |