Class: WhopSDK::Models::CourseUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/course_update_params.rb
Overview
Defined Under Namespace
Modules: Thumbnail Classes: Chapter
Instance Attribute Summary collapse
-
#certificate_after_completion_enabled ⇒ Boolean?
Whether the course will award its students a PDF certificate after completing all lessons.
-
#chapters ⇒ Array<WhopSDK::Models::CourseUpdateParams::Chapter>?
The chapters and lessons to update.
-
#cover_image ⇒ String?
The cover image URL of the course.
-
#description ⇒ String?
A short description of the course.
-
#language ⇒ Symbol, ...
The available languages for a course.
-
#order ⇒ String?
The decimal order position of the course within its experience.
-
#require_completing_lessons_in_order ⇒ Boolean?
Whether the course requires students to complete the previous lesson before moving on to the next one.
-
#tagline ⇒ String?
A short tagline for the course.
-
#thumbnail ⇒ WhopSDK::Models::CourseUpdateParams::Thumbnail::AttachmentInputWithDirectUploadID, ...
The thumbnail for the course in png, jpeg, or gif format.
-
#title ⇒ String?
The title of the course.
-
#visibility ⇒ Symbol, ...
The available visibilities for a course.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id: , chapter_id: , order: , title: ) ⇒ Object
constructor
Input for updating a lesson while updating a course.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , chapter_id: , order: , title: ) ⇒ Object
Input for updating a lesson while updating a course
|
|
# File 'lib/whop_sdk/models/course_update_params.rb', line 173
|
Instance Attribute Details
#certificate_after_completion_enabled ⇒ Boolean?
Whether the course will award its students a PDF certificate after completing all lessons
15 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 15 optional :certificate_after_completion_enabled, WhopSDK::Internal::Type::Boolean, nil?: true |
#chapters ⇒ Array<WhopSDK::Models::CourseUpdateParams::Chapter>?
The chapters and lessons to update
21 22 23 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 21 optional :chapters, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseUpdateParams::Chapter] }, nil?: true |
#cover_image ⇒ String?
The cover image URL of the course
29 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 29 optional :cover_image, String, nil?: true |
#description ⇒ String?
A short description of the course
35 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 35 optional :description, String, nil?: true |
#language ⇒ Symbol, ...
The available languages for a course
41 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 41 optional :language, enum: -> { WhopSDK::Languages }, nil?: true |
#order ⇒ String?
The decimal order position of the course within its experience. Use fractional values (e.g., 1.5) to place between existing courses.
48 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 48 optional :order, String, nil?: true |
#require_completing_lessons_in_order ⇒ Boolean?
Whether the course requires students to complete the previous lesson before moving on to the next one
55 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 55 optional :require_completing_lessons_in_order, WhopSDK::Internal::Type::Boolean, nil?: true |
#tagline ⇒ String?
A short tagline for the course
61 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 61 optional :tagline, String, nil?: true |
#thumbnail ⇒ WhopSDK::Models::CourseUpdateParams::Thumbnail::AttachmentInputWithDirectUploadID, ...
The thumbnail for the course in png, jpeg, or gif format
67 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 67 optional :thumbnail, union: -> { WhopSDK::CourseUpdateParams::Thumbnail }, nil?: true |
#title ⇒ String?
The title of the course
73 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 73 optional :title, String, nil?: true |
#visibility ⇒ Symbol, ...
The available visibilities for a course. Determines how / whether a course is visible to users.
80 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 80 optional :visibility, enum: -> { WhopSDK::CourseVisibilities }, nil?: true |