Class: WhopSDK::Models::CourseUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/course_update_params.rb

Overview

Defined Under Namespace

Classes: Chapter, Thumbnail

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , chapter_id: , order: , title: ) ⇒ Object

Input for updating a lesson while updating a course

Parameters:

  • id (String) (defaults to: )

    The ID of the lesson to update

  • chapter_id (String) (defaults to: )

    The ID of the chapter this lesson belongs to (for moving between chapters)

  • order (Integer) (defaults to: )

    The order of the lesson within its chapter

  • title (String) (defaults to: )

    The title of the lesson



# File 'lib/whop_sdk/models/course_update_params.rb', line 155

Instance Attribute Details

#certificate_after_completion_enabledBoolean?

Whether the course will award its students a PDF certificate after completing all lessons

Returns:

  • (Boolean, nil)


15
# File 'lib/whop_sdk/models/course_update_params.rb', line 15

optional :certificate_after_completion_enabled, WhopSDK::Internal::Type::Boolean, nil?: true

#chaptersArray<WhopSDK::Models::CourseUpdateParams::Chapter>?

The chapters and lessons to update



21
22
23
# File 'lib/whop_sdk/models/course_update_params.rb', line 21

optional :chapters,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::CourseUpdateParams::Chapter] },
nil?: true

#cover_imageString?

The cover image URL of the course

Returns:

  • (String, nil)


29
# File 'lib/whop_sdk/models/course_update_params.rb', line 29

optional :cover_image, String, nil?: true

#descriptionString?

A short description of the course

Returns:

  • (String, nil)


35
# File 'lib/whop_sdk/models/course_update_params.rb', line 35

optional :description, String, nil?: true

#languageSymbol, ...

The available languages for a course

Returns:



41
# File 'lib/whop_sdk/models/course_update_params.rb', line 41

optional :language, enum: -> { WhopSDK::Languages }, nil?: true

#require_completing_lessons_in_orderBoolean?

Whether the course requires students to complete the previous lesson before moving on to the next one

Returns:

  • (Boolean, nil)


48
# File 'lib/whop_sdk/models/course_update_params.rb', line 48

optional :require_completing_lessons_in_order, WhopSDK::Internal::Type::Boolean, nil?: true

#taglineString?

A short tagline for the course

Returns:

  • (String, nil)


54
# File 'lib/whop_sdk/models/course_update_params.rb', line 54

optional :tagline, String, nil?: true

#thumbnailWhopSDK::Models::CourseUpdateParams::Thumbnail?

The thumbnail for the course in png, jpeg, or gif format



60
# File 'lib/whop_sdk/models/course_update_params.rb', line 60

optional :thumbnail, -> { WhopSDK::CourseUpdateParams::Thumbnail }, nil?: true

#titleString?

The title of the course

Returns:

  • (String, nil)


66
# File 'lib/whop_sdk/models/course_update_params.rb', line 66

optional :title, String, nil?: true