Class: WhopSDK::Models::CourseUpdateParams::Chapter::Lesson
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseUpdateParams::Chapter::Lesson
- Defined in:
- lib/whop_sdk/models/course_update_params.rb
Instance Attribute Summary collapse
-
#chapter_id ⇒ String
The ID of the chapter this lesson belongs to (for moving between chapters).
-
#id ⇒ String
The ID of the lesson to update.
-
#order ⇒ Integer
The order of the lesson within its chapter.
-
#title ⇒ String
The title of the lesson.
Instance Method Summary collapse
-
#initialize(id: , order: , title: , lessons: nil) ⇒ Object
constructor
Input for updating a chapter while updating a course.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , order: , title: , lessons: nil) ⇒ Object
Input for updating a chapter while updating a course
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 130 class Lesson < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of the lesson to update # # @return [String] required :id, String # @!attribute chapter_id # The ID of the chapter this lesson belongs to (for moving between chapters) # # @return [String] required :chapter_id, String # @!attribute order # The order of the lesson within its chapter # # @return [Integer] required :order, Integer # @!attribute title # The title of the lesson # # @return [String] required :title, String # @!method initialize(id:, chapter_id:, order:, title:) # Input for updating a lesson while updating a course # # @param id [String] The ID of the lesson to update # # @param chapter_id [String] The ID of the chapter this lesson belongs to (for moving between chapters) # # @param order [Integer] The order of the lesson within its chapter # # @param title [String] The title of the lesson end |
Instance Attribute Details
#chapter_id ⇒ String
The ID of the chapter this lesson belongs to (for moving between chapters)
141 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 141 required :chapter_id, String |
#id ⇒ String
The ID of the lesson to update
135 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 135 required :id, String |
#order ⇒ Integer
The order of the lesson within its chapter
147 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 147 required :order, Integer |
#title ⇒ String
The title of the lesson
153 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 153 required :title, String |