Class: WhopSDK::Models::CourseUpdateParams::Thumbnail
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::CourseUpdateParams::Thumbnail
- Defined in:
- lib/whop_sdk/models/course_update_params.rb
Instance Attribute Summary collapse
-
#direct_upload_id ⇒ String?
This ID should be used the first time you upload an attachment.
-
#id ⇒ String?
The ID of an existing attachment object.
Instance Method Summary collapse
-
#initialize(id: nil, direct_upload_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Thumbnail for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: nil, direct_upload_id: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::CourseUpdateParams::Thumbnail for more details.
The thumbnail for the course in png, jpeg, or gif format
|
|
# File 'lib/whop_sdk/models/course_update_params.rb', line 185
|
Instance Attribute Details
#direct_upload_id ⇒ String?
This ID should be used the first time you upload an attachment. It is the ID of the direct upload that was created when uploading the file to S3 via the mediaDirectUpload mutation.
183 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 183 optional :direct_upload_id, String, nil?: true |
#id ⇒ String?
The ID of an existing attachment object. Use this when updating a resource and keeping a subset of the attachments. Don’t use this unless you know what you’re doing.
175 |
# File 'lib/whop_sdk/models/course_update_params.rb', line 175 optional :id, String, nil?: true |