Class: WhopSDK::Models::Dispute
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Dispute
- Defined in:
- lib/whop_sdk/models/dispute.rb
Overview
Defined Under Namespace
Classes: CancellationPolicyAttachment, Company, CustomerCommunicationAttachment, Payment, Plan, Product, RefundPolicyAttachment, UncategorizedAttachment
Instance Attribute Summary collapse
-
#access_activity_log ⇒ String?
An IP access log for the user from Whop.
-
#amount ⇒ Float
The amount of the dispute (formatted).
-
#billing_address ⇒ String?
The billing address of the user from their payment details.
-
#cancellation_policy_attachment ⇒ WhopSDK::Models::Dispute::CancellationPolicyAttachment?
The cancellation policy for this dispute.
-
#cancellation_policy_disclosure ⇒ String?
A cancellation policy disclosure from the company.
-
#company ⇒ WhopSDK::Models::Dispute::Company?
The company the dispute is against.
-
#created_at ⇒ Time?
When it was made.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the dispute.
-
#customer_communication_attachment ⇒ WhopSDK::Models::Dispute::CustomerCommunicationAttachment?
The customer communication for this dispute.
-
#customer_email_address ⇒ String?
The email of the customer from their payment details.
-
#customer_name ⇒ String?
The name of the customer from their payment details.
-
#editable ⇒ Boolean?
Whether or not the dispute data can be edited.
-
#id ⇒ String
The internal ID of the dispute.
-
#needs_response_by ⇒ Time?
The last date the dispute is allow to be submitted by.
-
#notes ⇒ String?
Additional notes the company chooses to submit regarding the dispute.
-
#payment ⇒ WhopSDK::Models::Dispute::Payment?
The payment that got disputed.
-
#plan ⇒ WhopSDK::Models::Dispute::Plan?
The plan that got disputed.
-
#product ⇒ WhopSDK::Models::Dispute::Product?
The product that got disputed.
-
#product_description ⇒ String?
The description of the product from the company.
-
#reason ⇒ String?
The reason for the dispute.
-
#refund_policy_attachment ⇒ WhopSDK::Models::Dispute::RefundPolicyAttachment?
The refund policy for this dispute.
-
#refund_policy_disclosure ⇒ String?
A refund policy disclosure from the company.
-
#refund_refusal_explanation ⇒ String?
A description on why the refund is being refused by the company.
-
#service_date ⇒ String?
When the product was delivered by the company.
-
#status ⇒ Symbol, WhopSDK::Models::DisputeStatuses
The status of the dispute (mimics stripe’s dispute status).
-
#uncategorized_attachment ⇒ WhopSDK::Models::Dispute::UncategorizedAttachment?
An attachment that did not fit into the other categories.
-
#visa_rdr ⇒ Boolean
Whether or not the dispute is a Visa Rapid Dispute Resolution.
Instance Method Summary collapse
-
#initialize(id: , content_type: , filename: , url: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see RefundPolicyAttachment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , content_type: , filename: , url: ) ⇒ Object
Some parameter documentations has been truncated, see RefundPolicyAttachment for more details.
The refund policy for this dispute
|
|
# File 'lib/whop_sdk/models/dispute.rb', line 177
|
Instance Attribute Details
#access_activity_log ⇒ String?
An IP access log for the user from Whop.
17 |
# File 'lib/whop_sdk/models/dispute.rb', line 17 required :access_activity_log, String, nil?: true |
#amount ⇒ Float
The amount of the dispute (formatted).
23 |
# File 'lib/whop_sdk/models/dispute.rb', line 23 required :amount, Float |
#billing_address ⇒ String?
The billing address of the user from their payment details.
29 |
# File 'lib/whop_sdk/models/dispute.rb', line 29 required :billing_address, String, nil?: true |
#cancellation_policy_attachment ⇒ WhopSDK::Models::Dispute::CancellationPolicyAttachment?
The cancellation policy for this dispute
35 36 37 |
# File 'lib/whop_sdk/models/dispute.rb', line 35 required :cancellation_policy_attachment, -> { WhopSDK::Dispute::CancellationPolicyAttachment }, nil?: true |
#cancellation_policy_disclosure ⇒ String?
A cancellation policy disclosure from the company.
43 |
# File 'lib/whop_sdk/models/dispute.rb', line 43 required :cancellation_policy_disclosure, String, nil?: true |
#company ⇒ WhopSDK::Models::Dispute::Company?
The company the dispute is against.
49 |
# File 'lib/whop_sdk/models/dispute.rb', line 49 required :company, -> { WhopSDK::Dispute::Company }, nil?: true |
#created_at ⇒ Time?
When it was made.
55 |
# File 'lib/whop_sdk/models/dispute.rb', line 55 required :created_at, Time, nil?: true |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the dispute.
61 |
# File 'lib/whop_sdk/models/dispute.rb', line 61 required :currency, enum: -> { WhopSDK::Currency } |
#customer_communication_attachment ⇒ WhopSDK::Models::Dispute::CustomerCommunicationAttachment?
The customer communication for this dispute
67 68 69 |
# File 'lib/whop_sdk/models/dispute.rb', line 67 required :customer_communication_attachment, -> { WhopSDK::Dispute::CustomerCommunicationAttachment }, nil?: true |
#customer_email_address ⇒ String?
The email of the customer from their payment details. This is submitted in the evidence packet to the payment processor. You can change it before submitting the dispute.
77 |
# File 'lib/whop_sdk/models/dispute.rb', line 77 required :customer_email_address, String, nil?: true |
#customer_name ⇒ String?
The name of the customer from their payment details. This is submitted in the evidence packet to the payment processor. You can change it before submitting the dispute.
85 |
# File 'lib/whop_sdk/models/dispute.rb', line 85 required :customer_name, String, nil?: true |
#editable ⇒ Boolean?
Whether or not the dispute data can be edited.
91 |
# File 'lib/whop_sdk/models/dispute.rb', line 91 required :editable, WhopSDK::Internal::Type::Boolean, nil?: true |
#id ⇒ String
The internal ID of the dispute.
11 |
# File 'lib/whop_sdk/models/dispute.rb', line 11 required :id, String |
#needs_response_by ⇒ Time?
The last date the dispute is allow to be submitted by.
97 |
# File 'lib/whop_sdk/models/dispute.rb', line 97 required :needs_response_by, Time, nil?: true |
#notes ⇒ String?
Additional notes the company chooses to submit regarding the dispute.
103 |
# File 'lib/whop_sdk/models/dispute.rb', line 103 required :notes, String, nil?: true |
#payment ⇒ WhopSDK::Models::Dispute::Payment?
The payment that got disputed
109 |
# File 'lib/whop_sdk/models/dispute.rb', line 109 required :payment, -> { WhopSDK::Dispute::Payment }, nil?: true |
#plan ⇒ WhopSDK::Models::Dispute::Plan?
The plan that got disputed
115 |
# File 'lib/whop_sdk/models/dispute.rb', line 115 required :plan, -> { WhopSDK::Dispute::Plan }, nil?: true |
#product ⇒ WhopSDK::Models::Dispute::Product?
The product that got disputed
121 |
# File 'lib/whop_sdk/models/dispute.rb', line 121 required :product, -> { WhopSDK::Dispute::Product }, nil?: true |
#product_description ⇒ String?
The description of the product from the company.
127 |
# File 'lib/whop_sdk/models/dispute.rb', line 127 required :product_description, String, nil?: true |
#reason ⇒ String?
The reason for the dispute
133 |
# File 'lib/whop_sdk/models/dispute.rb', line 133 required :reason, String, nil?: true |
#refund_policy_attachment ⇒ WhopSDK::Models::Dispute::RefundPolicyAttachment?
The refund policy for this dispute
139 |
# File 'lib/whop_sdk/models/dispute.rb', line 139 required :refund_policy_attachment, -> { WhopSDK::Dispute::RefundPolicyAttachment }, nil?: true |
#refund_policy_disclosure ⇒ String?
A refund policy disclosure from the company.
145 |
# File 'lib/whop_sdk/models/dispute.rb', line 145 required :refund_policy_disclosure, String, nil?: true |
#refund_refusal_explanation ⇒ String?
A description on why the refund is being refused by the company.
151 |
# File 'lib/whop_sdk/models/dispute.rb', line 151 required :refund_refusal_explanation, String, nil?: true |
#service_date ⇒ String?
When the product was delivered by the company.
157 |
# File 'lib/whop_sdk/models/dispute.rb', line 157 required :service_date, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::DisputeStatuses
The status of the dispute (mimics stripe’s dispute status).
163 |
# File 'lib/whop_sdk/models/dispute.rb', line 163 required :status, enum: -> { WhopSDK::DisputeStatuses } |
#uncategorized_attachment ⇒ WhopSDK::Models::Dispute::UncategorizedAttachment?
An attachment that did not fit into the other categories
169 |
# File 'lib/whop_sdk/models/dispute.rb', line 169 required :uncategorized_attachment, -> { WhopSDK::Dispute::UncategorizedAttachment }, nil?: true |