Class: WhopSDK::Models::Dispute::CancellationPolicyAttachment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Dispute::CancellationPolicyAttachment
- Defined in:
- lib/whop_sdk/models/dispute.rb
Overview
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
-
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#content_type ⇒ String?
The MIME type of the uploaded file (e.g., image/jpeg, video/mp4, audio/mpeg).
269 |
# File 'lib/whop_sdk/models/dispute.rb', line 269 required :content_type, String, nil?: true |
#filename ⇒ String?
The original filename of the uploaded attachment, including its file extension.
275 |
# File 'lib/whop_sdk/models/dispute.rb', line 275 required :filename, String, nil?: true |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.
263 |
# File 'lib/whop_sdk/models/dispute.rb', line 263 required :id, String |
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client. This should be used for displaying attachments in apps.
282 |
# File 'lib/whop_sdk/models/dispute.rb', line 282 required :url, String, nil?: true |