Class: WhopSDK::Models::Dispute::Payment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dispute.rb

Overview

See Also:

Defined Under Namespace

Classes: Member, Membership, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , status: ) ⇒ Object

The membership attached to this payment.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the membership.

  • status (Symbol, WhopSDK::Models::MembershipStatus) (defaults to: )

    The state of the membership.



# File 'lib/whop_sdk/models/dispute.rb', line 435

Instance Attribute Details

#billing_reasonSymbol, ...

The reason why a specific payment was billed

Returns:



355
# File 'lib/whop_sdk/models/dispute.rb', line 355

required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true

#card_brandSymbol, ...

Possible card brands that a payment token can have

Returns:



361
# File 'lib/whop_sdk/models/dispute.rb', line 361

required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true

#card_last4String?

The last 4 digits of the card used to make the payment.

Returns:

  • (String, nil)


367
# File 'lib/whop_sdk/models/dispute.rb', line 367

required :card_last4, String, nil?: true

#created_atTime

The datetime the payment was created

Returns:

  • (Time)


373
# File 'lib/whop_sdk/models/dispute.rb', line 373

required :created_at, Time

#currencySymbol, ...

The available currencies on the platform

Returns:



379
# File 'lib/whop_sdk/models/dispute.rb', line 379

required :currency, enum: -> { WhopSDK::Currency }, nil?: true

#dispute_alerted_atTime?

When an alert came in that this transaction will be disputed

Returns:

  • (Time, nil)


385
# File 'lib/whop_sdk/models/dispute.rb', line 385

required :dispute_alerted_at, Time, nil?: true

#idString

The payment ID

Returns:

  • (String)


349
# File 'lib/whop_sdk/models/dispute.rb', line 349

required :id, String

#memberWhopSDK::Models::Dispute::Payment::Member?

The member attached to this payment.



391
# File 'lib/whop_sdk/models/dispute.rb', line 391

required :member, -> { WhopSDK::Dispute::Payment::Member }, nil?: true

#membershipWhopSDK::Models::Dispute::Payment::Membership?

The membership attached to this payment.



397
# File 'lib/whop_sdk/models/dispute.rb', line 397

required :membership, -> { WhopSDK::Dispute::Payment::Membership }, nil?: true

The datetime the payment was paid

Returns:

  • (Time, nil)


403
# File 'lib/whop_sdk/models/dispute.rb', line 403

required :paid_at, Time, nil?: true

#payment_method_typeSymbol, ...

The different types of payment methods that can be used.

Returns:



409
# File 'lib/whop_sdk/models/dispute.rb', line 409

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true

#subtotalFloat?

The subtotal to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


415
# File 'lib/whop_sdk/models/dispute.rb', line 415

required :subtotal, Float, nil?: true

#totalFloat?

The total to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


421
# File 'lib/whop_sdk/models/dispute.rb', line 421

required :total, Float, nil?: true

#usd_totalFloat?

The total in USD to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


427
# File 'lib/whop_sdk/models/dispute.rb', line 427

required :usd_total, Float, nil?: true

#userWhopSDK::Models::Dispute::Payment::User?

The user that made this payment.



433
# File 'lib/whop_sdk/models/dispute.rb', line 433

required :user, -> { WhopSDK::Dispute::Payment::User }, nil?: true