Class: WhopSDK::Models::Dispute::Payment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Dispute::Payment
- Defined in:
- lib/whop_sdk/models/dispute.rb
Overview
Defined Under Namespace
Classes: Member, Membership, User
Instance Attribute Summary collapse
-
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed.
-
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#card_last4 ⇒ String?
The last 4 digits of the card used to make the payment.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed.
-
#id ⇒ String
The payment ID.
-
#member ⇒ WhopSDK::Models::Dispute::Payment::Member?
The member attached to this payment.
-
#membership ⇒ WhopSDK::Models::Dispute::Payment::Membership?
The membership attached to this payment.
-
#paid_at ⇒ Time?
The datetime the payment was paid.
-
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
-
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
-
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
-
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
-
#user ⇒ WhopSDK::Models::Dispute::Payment::User?
The user that made this payment.
Instance Method Summary collapse
-
#initialize(id: , status: ) ⇒ Object
constructor
The membership attached to this payment.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , status: ) ⇒ Object
The membership attached to this payment.
|
|
# File 'lib/whop_sdk/models/dispute.rb', line 435
|
Instance Attribute Details
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed
355 |
# File 'lib/whop_sdk/models/dispute.rb', line 355 required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true |
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have
361 |
# File 'lib/whop_sdk/models/dispute.rb', line 361 required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#card_last4 ⇒ String?
The last 4 digits of the card used to make the payment.
367 |
# File 'lib/whop_sdk/models/dispute.rb', line 367 required :card_last4, String, nil?: true |
#created_at ⇒ Time
The datetime the payment was created
373 |
# File 'lib/whop_sdk/models/dispute.rb', line 373 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
379 |
# File 'lib/whop_sdk/models/dispute.rb', line 379 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed
385 |
# File 'lib/whop_sdk/models/dispute.rb', line 385 required :dispute_alerted_at, Time, nil?: true |
#id ⇒ String
The payment ID
349 |
# File 'lib/whop_sdk/models/dispute.rb', line 349 required :id, String |
#member ⇒ WhopSDK::Models::Dispute::Payment::Member?
The member attached to this payment.
391 |
# File 'lib/whop_sdk/models/dispute.rb', line 391 required :member, -> { WhopSDK::Dispute::Payment::Member }, nil?: true |
#membership ⇒ WhopSDK::Models::Dispute::Payment::Membership?
The membership attached to this payment.
397 |
# File 'lib/whop_sdk/models/dispute.rb', line 397 required :membership, -> { WhopSDK::Dispute::Payment::Membership }, nil?: true |
#paid_at ⇒ Time?
The datetime the payment was paid
403 |
# File 'lib/whop_sdk/models/dispute.rb', line 403 required :paid_at, Time, nil?: true |
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
409 |
# File 'lib/whop_sdk/models/dispute.rb', line 409 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true |
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
415 |
# File 'lib/whop_sdk/models/dispute.rb', line 415 required :subtotal, Float, nil?: true |
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
421 |
# File 'lib/whop_sdk/models/dispute.rb', line 421 required :total, Float, nil?: true |
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
427 |
# File 'lib/whop_sdk/models/dispute.rb', line 427 required :usd_total, Float, nil?: true |
#user ⇒ WhopSDK::Models::Dispute::Payment::User?
The user that made this payment.
433 |
# File 'lib/whop_sdk/models/dispute.rb', line 433 required :user, -> { WhopSDK::Dispute::Payment::User }, nil?: true |