Class: WhopSDK::Models::Dispute::UncategorizedAttachment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Dispute::UncategorizedAttachment
- Defined in:
- lib/whop_sdk/models/dispute.rb
Overview
Instance Attribute Summary collapse
-
#content_type ⇒ String?
The attachment’s content type (e.g., image/jpg, video/mp4).
-
#filename ⇒ String?
The name of the file.
-
#id ⇒ String
The ID of the attachment.
-
#url ⇒ String?
This is the URL you use to render optimized attachments on the client.
Instance Method Summary collapse
-
#initialize(id: , content_type: , filename: , url: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see UncategorizedAttachment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , content_type: , filename: , url: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Dispute::UncategorizedAttachment for more details.
An attachment that did not fit into the other categories
|
|
# File 'lib/whop_sdk/models/dispute.rb', line 656
|
Instance Attribute Details
#content_type ⇒ String?
The attachment’s content type (e.g., image/jpg, video/mp4)
641 |
# File 'lib/whop_sdk/models/dispute.rb', line 641 required :content_type, String, nil?: true |
#filename ⇒ String?
The name of the file
647 |
# File 'lib/whop_sdk/models/dispute.rb', line 647 required :filename, String, nil?: true |
#id ⇒ String
The ID of the attachment
635 |
# File 'lib/whop_sdk/models/dispute.rb', line 635 required :id, String |
#url ⇒ String?
This is the URL you use to render optimized attachments on the client. This should be used for apps.
654 |
# File 'lib/whop_sdk/models/dispute.rb', line 654 required :url, String, nil?: true |