Class: WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dispute_alert_created_webhook_event.rb

Overview

See Also:

Defined Under Namespace

Classes: Dispute, Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, amount:, created_at:, currency:, reason:, status:) ⇒ Object

Some parameter documentations has been truncated, see Dispute for more details.

The dispute associated with the dispute alert.

Parameters:

  • id (String)

    The unique identifier for the dispute.

  • amount (Float)

    The disputed amount in the specified currency, formatted as a decimal.

  • created_at (Time, nil)

    The datetime the dispute was created.

  • currency (Symbol, WhopSDK::Models::Currency)

    The three-letter ISO currency code for the disputed amount.

  • reason (String, nil)

    A human-readable reason for the dispute.

  • status (Symbol, WhopSDK::Models::DisputeStatuses)

    The current status of the dispute lifecycle, such as needs_response, under_revie



# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 115

Instance Attribute Details

#alert_typeSymbol, WhopSDK::Models::DisputeAlertType

The type of the dispute alert.



71
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 71

required :alert_type, enum: -> { WhopSDK::DisputeAlertType }

#amountFloat

The alerted amount in the specified currency.

Returns:

  • (Float)


77
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 77

required :amount, Float

#charge_for_alertBoolean

Whether this alert incurs a charge.

Returns:

  • (Boolean)


83
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 83

required :charge_for_alert, WhopSDK::Internal::Type::Boolean

#created_atTime

The time the dispute alert was created.

Returns:

  • (Time)


89
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 89

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The three-letter ISO currency code for the alerted amount.

Returns:



95
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 95

required :currency, enum: -> { WhopSDK::Currency }

#disputeWhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Dispute?

The dispute associated with the dispute alert.



101
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 101

required :dispute, -> { WhopSDK::DisputeAlertCreatedWebhookEvent::Data::Dispute }, nil?: true

#idString

The unique identifier of the dispute alert.

Returns:

  • (String)


65
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 65

required :id, String

#paymentWhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Payment?

The payment associated with the dispute alert.



107
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 107

required :payment, -> { WhopSDK::DisputeAlertCreatedWebhookEvent::Data::Payment }, nil?: true

#transaction_dateTime?

The date of the original transaction.

Returns:

  • (Time, nil)


113
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 113

required :transaction_date, Time, nil?: true