Class: WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Dispute

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dispute_alert_created_webhook_event.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#amountFloat

The disputed amount in the specified currency, formatted as a decimal.

Returns:

  • (Float)


149
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 149

required :amount, Float

#created_atTime?

The datetime the dispute was created.

Returns:

  • (Time, nil)


155
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 155

required :created_at, Time, nil?: true

#currencySymbol, WhopSDK::Models::Currency

The three-letter ISO currency code for the disputed amount.

Returns:



161
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 161

required :currency, enum: -> { WhopSDK::Currency }

#idString

The unique identifier for the dispute.

Returns:

  • (String)


143
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 143

required :id, String

#reasonString?

A human-readable reason for the dispute.

Returns:

  • (String, nil)


167
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 167

required :reason, String, nil?: true

#statusSymbol, WhopSDK::Models::DisputeStatuses

The current status of the dispute lifecycle, such as needs_response, under_review, won, or lost.



174
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 174

required :status, enum: -> { WhopSDK::DisputeStatuses }