Class: WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Payment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Payment
- Defined in:
- lib/whop_sdk/models/dispute_alert_created_webhook_event.rb
Overview
Defined Under Namespace
Classes: Member, Membership, User
Instance Attribute Summary collapse
-
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed.
-
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#card_last4 ⇒ String?
The last four digits of the card used to make this payment.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed.
-
#id ⇒ String
The unique identifier for the payment.
-
#member ⇒ WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Payment::Member?
The member attached to this payment.
-
#membership ⇒ WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Payment::Membership?
The membership attached to this payment.
-
#paid_at ⇒ Time?
The time at which this payment was successfully collected.
-
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
-
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
-
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
-
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
-
#user ⇒ WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Payment::User?
The user that made this payment.
Instance Method Summary collapse
-
#initialize(id:, status:) ⇒ Object
constructor
The membership attached to this payment.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, status:) ⇒ Object
The membership attached to this payment.
|
|
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 292
|
Instance Attribute Details
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed
208 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 208 required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true |
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have
214 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 214 required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#card_last4 ⇒ String?
The last four digits of the card used to make this payment. Null if the payment was not made with a card.
221 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 221 required :card_last4, String, nil?: true |
#created_at ⇒ Time
The datetime the payment was created.
227 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 227 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
233 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 233 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed
239 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 239 required :dispute_alerted_at, Time, nil?: true |
#id ⇒ String
The unique identifier for the payment.
202 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 202 required :id, String |
#member ⇒ WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Payment::Member?
The member attached to this payment.
245 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 245 required :member, -> { WhopSDK::DisputeAlertCreatedWebhookEvent::Data::Payment::Member }, nil?: true |
#membership ⇒ WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Payment::Membership?
The membership attached to this payment.
251 252 253 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 251 required :membership, -> { WhopSDK::DisputeAlertCreatedWebhookEvent::Data::Payment::Membership }, nil?: true |
#paid_at ⇒ Time?
The time at which this payment was successfully collected. Null if the payment has not yet succeeded. As a Unix timestamp.
260 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 260 required :paid_at, Time, nil?: true |
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
266 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 266 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true |
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
272 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 272 required :subtotal, Float, nil?: true |
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
278 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 278 required :total, Float, nil?: true |
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
284 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 284 required :usd_total, Float, nil?: true |
#user ⇒ WhopSDK::Models::DisputeAlertCreatedWebhookEvent::Data::Payment::User?
The user that made this payment.
290 |
# File 'lib/whop_sdk/models/dispute_alert_created_webhook_event.rb', line 290 required :user, -> { WhopSDK::DisputeAlertCreatedWebhookEvent::Data::Payment::User }, nil?: true |