Class: WhopSDK::Models::DisputeAlertRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::DisputeAlertRetrieveResponse
- Defined in:
- lib/whop_sdk/models/dispute_alert_retrieve_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#alert_type ⇒ Symbol, WhopSDK::Models::DisputeAlertType
The type of the dispute alert.
-
#amount ⇒ Float
The alerted amount in the specified currency.
-
#charge_for_alert ⇒ Boolean
Whether this alert incurs a charge.
-
#created_at ⇒ Time
The time the dispute alert was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The three-letter ISO currency code for the alerted amount.
-
#dispute ⇒ WhopSDK::Models::DisputeAlertRetrieveResponse::Dispute?
The dispute associated with the dispute alert.
-
#id ⇒ String
The unique identifier of the dispute alert.
-
#payment ⇒ WhopSDK::Models::DisputeAlertRetrieveResponse::Payment?
The payment associated with the dispute alert.
-
#transaction_date ⇒ Time?
The date of the original transaction.
Instance Method Summary collapse
-
#initialize(id:, amount:, created_at:, currency:, reason:, status:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Dispute for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, created_at:, currency:, reason:, status:) ⇒ Object
Some parameter documentations has been truncated, see Dispute for more details.
The dispute associated with the dispute alert.
|
|
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 61
|
Instance Attribute Details
#alert_type ⇒ Symbol, WhopSDK::Models::DisputeAlertType
The type of the dispute alert.
17 |
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 17 required :alert_type, enum: -> { WhopSDK::DisputeAlertType } |
#amount ⇒ Float
The alerted amount in the specified currency.
23 |
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 23 required :amount, Float |
#charge_for_alert ⇒ Boolean
Whether this alert incurs a charge.
29 |
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 29 required :charge_for_alert, WhopSDK::Internal::Type::Boolean |
#created_at ⇒ Time
The time the dispute alert was created.
35 |
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 35 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The three-letter ISO currency code for the alerted amount.
41 |
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 41 required :currency, enum: -> { WhopSDK::Currency } |
#dispute ⇒ WhopSDK::Models::DisputeAlertRetrieveResponse::Dispute?
The dispute associated with the dispute alert.
47 |
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 47 required :dispute, -> { WhopSDK::Models::DisputeAlertRetrieveResponse::Dispute }, nil?: true |
#id ⇒ String
The unique identifier of the dispute alert.
11 |
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 11 required :id, String |
#payment ⇒ WhopSDK::Models::DisputeAlertRetrieveResponse::Payment?
The payment associated with the dispute alert.
53 |
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 53 required :payment, -> { WhopSDK::Models::DisputeAlertRetrieveResponse::Payment }, nil?: true |
#transaction_date ⇒ Time?
The date of the original transaction.
59 |
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 59 required :transaction_date, Time, nil?: true |