Class: WhopSDK::Models::DisputeAlertRetrieveResponse::Dispute

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dispute_alert_retrieve_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#amountFloat

The disputed amount in the specified currency, formatted as a decimal.

Returns:

  • (Float)


95
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 95

required :amount, Float

#created_atTime?

The datetime the dispute was created.

Returns:

  • (Time, nil)


101
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 101

required :created_at, Time, nil?: true

#currencySymbol, WhopSDK::Models::Currency

The three-letter ISO currency code for the disputed amount.

Returns:



107
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 107

required :currency, enum: -> { WhopSDK::Currency }

#idString

The unique identifier for the dispute.

Returns:

  • (String)


89
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 89

required :id, String

#reasonString?

A human-readable reason for the dispute.

Returns:

  • (String, nil)


113
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 113

required :reason, String, nil?: true

#statusSymbol, WhopSDK::Models::DisputeStatuses

The current status of the dispute lifecycle, such as needs_response, under_review, won, or lost.



120
# File 'lib/whop_sdk/models/dispute_alert_retrieve_response.rb', line 120

required :status, enum: -> { WhopSDK::DisputeStatuses }