Class: WhopSDK::Models::DisputeListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/dispute_list_response.rb

Overview

Defined Under Namespace

Classes: Company, Payment, Plan, Product

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: ) ⇒ Object

The plan that got disputed

Parameters:

  • id (String) (defaults to: )

    The internal ID of the plan.



# File 'lib/whop_sdk/models/dispute_list_response.rb', line 85

Instance Attribute Details

#amountFloat

The amount of the dispute (formatted).

Returns:

  • (Float)


17
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 17

required :amount, Float

#companyWhopSDK::Models::DisputeListResponse::Company?

The company the dispute is against.



23
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 23

required :company, -> { WhopSDK::Models::DisputeListResponse::Company }, nil?: true

#created_atTime?

When it was made.

Returns:

  • (Time, nil)


29
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 29

required :created_at, Time, nil?: true

#currencySymbol, WhopSDK::Models::Currency

The currency of the dispute.

Returns:



35
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 35

required :currency, enum: -> { WhopSDK::Currency }

#editableBoolean?

Whether or not the dispute data can be edited.

Returns:

  • (Boolean, nil)


41
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 41

required :editable, WhopSDK::Internal::Type::Boolean, nil?: true

#idString

The internal ID of the dispute.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 11

required :id, String

#needs_response_byTime?

The last date the dispute is allow to be submitted by.

Returns:

  • (Time, nil)


47
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 47

required :needs_response_by, Time, nil?: true

#paymentWhopSDK::Models::DisputeListResponse::Payment?

The payment that got disputed



53
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 53

required :payment, -> { WhopSDK::Models::DisputeListResponse::Payment }, nil?: true

#planWhopSDK::Models::DisputeListResponse::Plan?

The plan that got disputed



59
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 59

required :plan, -> { WhopSDK::Models::DisputeListResponse::Plan }, nil?: true

#productWhopSDK::Models::DisputeListResponse::Product?

The product that got disputed



65
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 65

required :product, -> { WhopSDK::Models::DisputeListResponse::Product }, nil?: true

#reasonString?

The reason for the dispute

Returns:

  • (String, nil)


71
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 71

required :reason, String, nil?: true

#statusSymbol, WhopSDK::Models::DisputeStatuses

The status of the dispute (mimics stripe’s dispute status).



77
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 77

required :status, enum: -> { WhopSDK::DisputeStatuses }

#visa_rdrBoolean

Whether or not the dispute is a Visa Rapid Dispute Resolution.

Returns:

  • (Boolean)


83
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 83

required :visa_rdr, WhopSDK::Internal::Type::Boolean