Class: WhopSDK::Models::DisputeListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::DisputeListResponse
- Defined in:
- lib/whop_sdk/models/dispute_list_response.rb
Overview
Defined Under Namespace
Classes: Company, Payment, Plan, Product
Instance Attribute Summary collapse
-
#amount ⇒ Float
The amount of the dispute (formatted).
-
#company ⇒ WhopSDK::Models::DisputeListResponse::Company?
The company the dispute is against.
-
#created_at ⇒ Time?
When it was made.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the dispute.
-
#editable ⇒ Boolean?
Whether or not the dispute data can be edited.
-
#id ⇒ String
The internal ID of the dispute.
-
#needs_response_by ⇒ Time?
The last date the dispute is allow to be submitted by.
-
#payment ⇒ WhopSDK::Models::DisputeListResponse::Payment?
The payment that got disputed.
-
#plan ⇒ WhopSDK::Models::DisputeListResponse::Plan?
The plan that got disputed.
-
#product ⇒ WhopSDK::Models::DisputeListResponse::Product?
The product that got disputed.
-
#reason ⇒ String?
The reason for the dispute.
-
#status ⇒ Symbol, WhopSDK::Models::DisputeStatuses
The status of the dispute (mimics stripe’s dispute status).
-
#visa_rdr ⇒ Boolean
Whether or not the dispute is a Visa Rapid Dispute Resolution.
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
The plan that got disputed.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
The plan that got disputed
|
|
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 85
|
Instance Attribute Details
#amount ⇒ Float
The amount of the dispute (formatted).
17 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 17 required :amount, Float |
#company ⇒ WhopSDK::Models::DisputeListResponse::Company?
The company the dispute is against.
23 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 23 required :company, -> { WhopSDK::Models::DisputeListResponse::Company }, nil?: true |
#created_at ⇒ Time?
When it was made.
29 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 29 required :created_at, Time, nil?: true |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the dispute.
35 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 35 required :currency, enum: -> { WhopSDK::Currency } |
#editable ⇒ Boolean?
Whether or not the dispute data can be edited.
41 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 41 required :editable, WhopSDK::Internal::Type::Boolean, nil?: true |
#id ⇒ String
The internal ID of the dispute.
11 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 11 required :id, String |
#needs_response_by ⇒ Time?
The last date the dispute is allow to be submitted by.
47 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 47 required :needs_response_by, Time, nil?: true |
#payment ⇒ WhopSDK::Models::DisputeListResponse::Payment?
The payment that got disputed
53 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 53 required :payment, -> { WhopSDK::Models::DisputeListResponse::Payment }, nil?: true |
#plan ⇒ WhopSDK::Models::DisputeListResponse::Plan?
The plan that got disputed
59 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 59 required :plan, -> { WhopSDK::Models::DisputeListResponse::Plan }, nil?: true |
#product ⇒ WhopSDK::Models::DisputeListResponse::Product?
The product that got disputed
65 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 65 required :product, -> { WhopSDK::Models::DisputeListResponse::Product }, nil?: true |
#reason ⇒ String?
The reason for the dispute
71 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 71 required :reason, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::DisputeStatuses
The status of the dispute (mimics stripe’s dispute status).
77 |
# File 'lib/whop_sdk/models/dispute_list_response.rb', line 77 required :status, enum: -> { WhopSDK::DisputeStatuses } |