Class: WhopSDK::Models::DisputeUpdateEvidenceParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::DisputeUpdateEvidenceParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/dispute_update_evidence_params.rb
Overview
Defined Under Namespace
Classes: CancellationPolicyAttachment, CustomerCommunicationAttachment, RefundPolicyAttachment, UncategorizedAttachment
Instance Attribute Summary collapse
-
#access_activity_log ⇒ String?
An IP access activity log showing the customer used the service.
-
#billing_address ⇒ String?
The billing address associated with the customer’s payment method.
-
#cancellation_policy_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::CancellationPolicyAttachment?
A file upload containing the company’s cancellation policy document.
-
#cancellation_policy_disclosure ⇒ String?
The company’s cancellation policy text to submit as evidence.
-
#customer_communication_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::CustomerCommunicationAttachment?
A file upload containing evidence of customer communication.
-
#customer_email_address ⇒ String?
The email address of the customer associated with the disputed payment.
-
#customer_name ⇒ String?
The full name of the customer associated with the disputed payment.
- #id ⇒ String
-
#notes ⇒ String?
Additional notes or context to submit as part of the dispute evidence.
-
#product_description ⇒ String?
A description of the product or service that was provided to the customer.
-
#refund_policy_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::RefundPolicyAttachment?
A file upload containing the company’s refund policy document.
-
#refund_policy_disclosure ⇒ String?
The company’s refund policy text to submit as evidence.
-
#refund_refusal_explanation ⇒ String?
An explanation of why the refund request was refused.
-
#service_date ⇒ String?
The date when the product or service was delivered to the customer.
-
#uncategorized_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::UncategorizedAttachment?
A file upload for evidence that does not fit into the other categories.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
A file upload containing the company’s refund policy document.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
A file upload containing the company’s refund policy document.
|
|
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 151
|
Instance Attribute Details
#access_activity_log ⇒ String?
An IP access activity log showing the customer used the service.
19 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 19 optional :access_activity_log, String, nil?: true |
#billing_address ⇒ String?
The billing address associated with the customer’s payment method.
25 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 25 optional :billing_address, String, nil?: true |
#cancellation_policy_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::CancellationPolicyAttachment?
A file upload containing the company’s cancellation policy document.
31 32 33 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 31 optional :cancellation_policy_attachment, -> { WhopSDK::DisputeUpdateEvidenceParams::CancellationPolicyAttachment }, nil?: true |
#cancellation_policy_disclosure ⇒ String?
The company’s cancellation policy text to submit as evidence.
39 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 39 optional :cancellation_policy_disclosure, String, nil?: true |
#customer_communication_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::CustomerCommunicationAttachment?
A file upload containing evidence of customer communication. Must be a JPEG, PNG, GIF, or PDF.
46 47 48 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 46 optional :customer_communication_attachment, -> { WhopSDK::DisputeUpdateEvidenceParams::CustomerCommunicationAttachment }, nil?: true |
#customer_email_address ⇒ String?
The email address of the customer associated with the disputed payment.
54 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 54 optional :customer_email_address, String, nil?: true |
#customer_name ⇒ String?
The full name of the customer associated with the disputed payment.
60 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 60 optional :customer_name, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 13 required :id, String |
#notes ⇒ String?
Additional notes or context to submit as part of the dispute evidence.
66 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 66 optional :notes, String, nil?: true |
#product_description ⇒ String?
A description of the product or service that was provided to the customer.
72 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 72 optional :product_description, String, nil?: true |
#refund_policy_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::RefundPolicyAttachment?
A file upload containing the company’s refund policy document.
78 79 80 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 78 optional :refund_policy_attachment, -> { WhopSDK::DisputeUpdateEvidenceParams::RefundPolicyAttachment }, nil?: true |
#refund_policy_disclosure ⇒ String?
The company’s refund policy text to submit as evidence.
86 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 86 optional :refund_policy_disclosure, String, nil?: true |
#refund_refusal_explanation ⇒ String?
An explanation of why the refund request was refused.
92 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 92 optional :refund_refusal_explanation, String, nil?: true |
#service_date ⇒ String?
The date when the product or service was delivered to the customer.
98 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 98 optional :service_date, String, nil?: true |
#uncategorized_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::UncategorizedAttachment?
A file upload for evidence that does not fit into the other categories.
104 105 106 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 104 optional :uncategorized_attachment, -> { WhopSDK::DisputeUpdateEvidenceParams::UncategorizedAttachment }, nil?: true |