Class: WhopSDK::Models::DisputeUpdateEvidenceParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::DisputeUpdateEvidenceParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/dispute_update_evidence_params.rb
Overview
Defined Under Namespace
Modules: CancellationPolicyAttachment, CustomerCommunicationAttachment, RefundPolicyAttachment, UncategorizedAttachment
Instance Attribute Summary collapse
-
#access_activity_log ⇒ String?
An IP access log for the user from Whop.
-
#billing_address ⇒ String?
The billing address of the user from their payment details.
-
#cancellation_policy_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::CancellationPolicyAttachment::AttachmentInputWithDirectUploadID, ...
A file containing the cancellation policy from the company.
-
#cancellation_policy_disclosure ⇒ String?
A cancellation policy disclosure from the company.
-
#customer_communication_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::CustomerCommunicationAttachment::AttachmentInputWithDirectUploadID, ...
A file containing the customer communication from the company (An image).
-
#customer_email_address ⇒ String?
The email of the customer from their payment details.
-
#customer_name ⇒ String?
The name of the customer from their payment details.
-
#notes ⇒ String?
Additional notes the company chooses to submit regarding the dispute.
-
#product_description ⇒ String?
The description of the product from the company.
-
#refund_policy_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::RefundPolicyAttachment::AttachmentInputWithDirectUploadID, ...
A file containing the refund policy from the company.
-
#refund_policy_disclosure ⇒ String?
A refund policy disclosure from the company.
-
#refund_refusal_explanation ⇒ String?
A description on why the refund is being refused by the company.
-
#service_date ⇒ String?
When the product was delivered by the company.
-
#uncategorized_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::UncategorizedAttachment::AttachmentInputWithDirectUploadID, ...
A file that does not fit in the other categories.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see RefundPolicyAttachment::AttachmentInputWithID for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::DisputeUpdateEvidenceParams::RefundPolicyAttachment::AttachmentInputWithID for more details.
Input for an attachment
|
|
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 102
|
Instance Attribute Details
#access_activity_log ⇒ String?
An IP access log for the user from Whop.
14 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 14 optional :access_activity_log, String, nil?: true |
#billing_address ⇒ String?
The billing address of the user from their payment details.
20 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 20 optional :billing_address, String, nil?: true |
#cancellation_policy_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::CancellationPolicyAttachment::AttachmentInputWithDirectUploadID, ...
A file containing the cancellation policy from the company.
26 27 28 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 26 optional :cancellation_policy_attachment, union: -> { WhopSDK::DisputeUpdateEvidenceParams::CancellationPolicyAttachment }, nil?: true |
#cancellation_policy_disclosure ⇒ String?
A cancellation policy disclosure from the company.
34 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 34 optional :cancellation_policy_disclosure, String, nil?: true |
#customer_communication_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::CustomerCommunicationAttachment::AttachmentInputWithDirectUploadID, ...
A file containing the customer communication from the company (An image).
40 41 42 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 40 optional :customer_communication_attachment, union: -> { WhopSDK::DisputeUpdateEvidenceParams::CustomerCommunicationAttachment }, nil?: true |
#customer_email_address ⇒ String?
The email of the customer from their payment details.
48 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 48 optional :customer_email_address, String, nil?: true |
#customer_name ⇒ String?
The name of the customer from their payment details.
54 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 54 optional :customer_name, String, nil?: true |
#notes ⇒ String?
Additional notes the company chooses to submit regarding the dispute.
60 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 60 optional :notes, String, nil?: true |
#product_description ⇒ String?
The description of the product from the company.
66 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 66 optional :product_description, String, nil?: true |
#refund_policy_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::RefundPolicyAttachment::AttachmentInputWithDirectUploadID, ...
A file containing the refund policy from the company.
72 73 74 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 72 optional :refund_policy_attachment, union: -> { WhopSDK::DisputeUpdateEvidenceParams::RefundPolicyAttachment }, nil?: true |
#refund_policy_disclosure ⇒ String?
A refund policy disclosure from the company.
80 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 80 optional :refund_policy_disclosure, String, nil?: true |
#refund_refusal_explanation ⇒ String?
A description on why the refund is being refused by the company.
86 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 86 optional :refund_refusal_explanation, String, nil?: true |
#service_date ⇒ String?
When the product was delivered by the company.
92 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 92 optional :service_date, String, nil?: true |
#uncategorized_attachment ⇒ WhopSDK::Models::DisputeUpdateEvidenceParams::UncategorizedAttachment::AttachmentInputWithDirectUploadID, ...
A file that does not fit in the other categories.
98 99 100 |
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 98 optional :uncategorized_attachment, union: -> { WhopSDK::DisputeUpdateEvidenceParams::UncategorizedAttachment }, nil?: true |
Class Method Details
.variants ⇒ Array(WhopSDK::Models::DisputeUpdateEvidenceParams::RefundPolicyAttachment::AttachmentInputWithDirectUploadID, WhopSDK::Models::DisputeUpdateEvidenceParams::RefundPolicyAttachment::AttachmentInputWithID)
|
|
# File 'lib/whop_sdk/models/dispute_update_evidence_params.rb', line 181
|