Class: WhopSDK::Models::DmChannelCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::DmChannelCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/dm_channel_create_params.rb
Overview
Instance Attribute Summary collapse
-
#company_id ⇒ String?
The unique identifier of the company to scope this DM channel to.
-
#custom_name ⇒ String?
A custom display name for the DM channel.
-
#with_user_ids ⇒ Array<String>
The list of user identifiers to include in the DM channel.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(with_user_ids:, company_id: nil, custom_name: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see DmChannelCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(with_user_ids:, company_id: nil, custom_name: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::DmChannelCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/dm_channel_create_params.rb', line 30
|
Instance Attribute Details
#company_id ⇒ String?
The unique identifier of the company to scope this DM channel to. When set, the channel is visible only within that company context.
22 |
# File 'lib/whop_sdk/models/dm_channel_create_params.rb', line 22 optional :company_id, String, nil?: true |
#custom_name ⇒ String?
A custom display name for the DM channel. For example, ‘Project Discussion’.
28 |
# File 'lib/whop_sdk/models/dm_channel_create_params.rb', line 28 optional :custom_name, String, nil?: true |