Class: WhopSDK::Models::Entry

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/entry.rb

Defined Under Namespace

Classes: CustomFieldResponse, Plan, Product, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , title: ) ⇒ Object

The access pass tied to this entry, if there is one.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the public product.

  • title (String) (defaults to: )

    The title of the product. Use for Whop 4.0.



# File 'lib/whop_sdk/models/entry.rb', line 86

Instance Attribute Details

#created_atTime?

When the entry was created.

Returns:

  • (Time, nil)


16
# File 'lib/whop_sdk/models/entry.rb', line 16

required :created_at, Time, nil?: true

#custom_field_responsesArray<WhopSDK::Models::Entry::CustomFieldResponse>?

Responses collected from the user when submitting their entry.



22
23
24
# File 'lib/whop_sdk/models/entry.rb', line 22

required :custom_field_responses,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Entry::CustomFieldResponse] },
nil?: true

#idString

The internal ID of the entry.

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/entry.rb', line 10

required :id, String

#planWhopSDK::Models::Entry::Plan?

The waitlist plan the entry if for.



30
# File 'lib/whop_sdk/models/entry.rb', line 30

required :plan, -> { WhopSDK::Entry::Plan }, nil?: true

#productWhopSDK::Models::Entry::Product?

The access pass tied to this entry, if there is one.



36
# File 'lib/whop_sdk/models/entry.rb', line 36

required :product, -> { WhopSDK::Entry::Product }, nil?: true

#statusSymbol, WhopSDK::Models::EntryStatus

The status of the entry.

Returns:



42
# File 'lib/whop_sdk/models/entry.rb', line 42

required :status, enum: -> { WhopSDK::EntryStatus }

#userWhopSDK::Models::Entry::User

The user who created the entry.



48
# File 'lib/whop_sdk/models/entry.rb', line 48

required :user, -> { WhopSDK::Entry::User }