Class: WhopSDK::Models::Entry
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Entry
- Defined in:
- lib/whop_sdk/models/entry.rb
Defined Under Namespace
Classes: CustomFieldResponse, Plan, Product, User
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
When the entry was created.
-
#custom_field_responses ⇒ Array<WhopSDK::Models::Entry::CustomFieldResponse>?
Responses collected from the user when submitting their entry.
-
#id ⇒ String
The internal ID of the entry.
-
#plan ⇒ WhopSDK::Models::Entry::Plan?
The waitlist plan the entry if for.
-
#product ⇒ WhopSDK::Models::Entry::Product?
The access pass tied to this entry, if there is one.
-
#status ⇒ Symbol, WhopSDK::Models::EntryStatus
The status of the entry.
-
#user ⇒ WhopSDK::Models::Entry::User
The user who created the entry.
Instance Method Summary collapse
-
#initialize(id: , title: ) ⇒ Object
constructor
The access pass tied to this entry, if there is one.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , title: ) ⇒ Object
The access pass tied to this entry, if there is one.
|
|
# File 'lib/whop_sdk/models/entry.rb', line 86
|
Instance Attribute Details
#created_at ⇒ Time?
When the entry was created.
16 |
# File 'lib/whop_sdk/models/entry.rb', line 16 required :created_at, Time, nil?: true |
#custom_field_responses ⇒ Array<WhopSDK::Models::Entry::CustomFieldResponse>?
Responses collected from the user when submitting their entry.
22 23 24 |
# File 'lib/whop_sdk/models/entry.rb', line 22 required :custom_field_responses, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Entry::CustomFieldResponse] }, nil?: true |
#id ⇒ String
The internal ID of the entry.
10 |
# File 'lib/whop_sdk/models/entry.rb', line 10 required :id, String |
#plan ⇒ WhopSDK::Models::Entry::Plan?
The waitlist plan the entry if for.
30 |
# File 'lib/whop_sdk/models/entry.rb', line 30 required :plan, -> { WhopSDK::Entry::Plan }, nil?: true |
#product ⇒ WhopSDK::Models::Entry::Product?
The access pass tied to this entry, if there is one.
36 |
# File 'lib/whop_sdk/models/entry.rb', line 36 required :product, -> { WhopSDK::Entry::Product }, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::EntryStatus
The status of the entry.
42 |
# File 'lib/whop_sdk/models/entry.rb', line 42 required :status, enum: -> { WhopSDK::EntryStatus } |
#user ⇒ WhopSDK::Models::Entry::User
The user who created the entry.
48 |
# File 'lib/whop_sdk/models/entry.rb', line 48 required :user, -> { WhopSDK::Entry::User } |