Class: WhopSDK::Models::Entry::CustomFieldResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Entry::CustomFieldResponse
- Defined in:
- lib/whop_sdk/models/entry.rb
Instance Attribute Summary collapse
-
#answer ⇒ String
The response a user gave to the specific question or field.
-
#id ⇒ String
The ID of the custom field item.
-
#question ⇒ String
The question asked by the custom field.
Instance Method Summary collapse
-
#initialize(id: , created_at: , custom_field_responses: , plan: , product: , status: , user: ) ⇒ Object
constructor
An object representing an entry in a waitlist.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , created_at: , custom_field_responses: , plan: , product: , status: , user: ) ⇒ Object
An object representing an entry in a waitlist.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/whop_sdk/models/entry.rb', line 67 class CustomFieldResponse < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of the custom field item # # @return [String] required :id, String # @!attribute answer # The response a user gave to the specific question or field. # # @return [String] required :answer, String # @!attribute question # The question asked by the custom field # # @return [String] required :question, String # @!method initialize(id:, answer:, question:) # The response from a custom field on checkout # # @param id [String] The ID of the custom field item # # @param answer [String] The response a user gave to the specific question or field. # # @param question [String] The question asked by the custom field end |
Instance Attribute Details
#answer ⇒ String
The response a user gave to the specific question or field.
78 |
# File 'lib/whop_sdk/models/entry.rb', line 78 required :answer, String |
#id ⇒ String
The ID of the custom field item
72 |
# File 'lib/whop_sdk/models/entry.rb', line 72 required :id, String |
#question ⇒ String
The question asked by the custom field
84 |
# File 'lib/whop_sdk/models/entry.rb', line 84 required :question, String |