Class: WhopSDK::Models::EntryListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::EntryListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/entry_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#company_id ⇒ String
The ID of the company.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#order ⇒ Symbol, ...
Which columns can be used to sort.
-
#plan_ids ⇒ Array<String>?
The plan IDs to filter the entries by.
-
#product_ids ⇒ Array<String>?
The product IDs to filter the entries by.
-
#statuses ⇒ Array<Symbol, WhopSDK::Models::EntryStatus>?
The statuses to filter the entries by.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id: , after: nil, before: nil, direction: nil, first: nil, last: nil, order: nil, plan_ids: nil, product_ids: nil, statuses: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/entry_list_params.rb', line 70
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
20 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 20 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
26 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 26 optional :before, String, nil?: true |
#company_id ⇒ String
The ID of the company
14 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 14 required :company_id, String |
#direction ⇒ Symbol, ...
The direction of the sort.
32 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 32 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
38 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 38 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
44 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 44 optional :last, Integer, nil?: true |
#order ⇒ Symbol, ...
Which columns can be used to sort.
50 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 50 optional :order, enum: -> { WhopSDK::EntryListParams::Order }, nil?: true |
#plan_ids ⇒ Array<String>?
The plan IDs to filter the entries by
56 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 56 optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#product_ids ⇒ Array<String>?
The product IDs to filter the entries by
62 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 62 optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#statuses ⇒ Array<Symbol, WhopSDK::Models::EntryStatus>?
The statuses to filter the entries by
68 |
# File 'lib/whop_sdk/models/entry_list_params.rb', line 68 optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::EntryStatus] }, nil?: true |