Class: WhopSDK::Models::EntryListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/entry_list_response.rb

Overview

Defined Under Namespace

Classes: Plan, Product, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , title: ) ⇒ Object

The access pass tied to this entry, if there is one.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the public product.

  • title (String) (defaults to: )

    The title of the product. Use for Whop 4.0.



# File 'lib/whop_sdk/models/entry_list_response.rb', line 43

Instance Attribute Details

#created_atTime?

When the entry was created.

Returns:

  • (Time, nil)


17
# File 'lib/whop_sdk/models/entry_list_response.rb', line 17

required :created_at, Time, nil?: true

#idString

The internal ID of the entry.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/entry_list_response.rb', line 11

required :id, String

#planWhopSDK::Models::EntryListResponse::Plan?

The waitlist plan the entry if for.



23
# File 'lib/whop_sdk/models/entry_list_response.rb', line 23

required :plan, -> { WhopSDK::Models::EntryListResponse::Plan }, nil?: true

#productWhopSDK::Models::EntryListResponse::Product?

The access pass tied to this entry, if there is one.



29
# File 'lib/whop_sdk/models/entry_list_response.rb', line 29

required :product, -> { WhopSDK::Models::EntryListResponse::Product }, nil?: true

#statusSymbol, WhopSDK::Models::EntryStatus

The status of the entry.

Returns:



35
# File 'lib/whop_sdk/models/entry_list_response.rb', line 35

required :status, enum: -> { WhopSDK::EntryStatus }

#userWhopSDK::Models::EntryListResponse::User

The user who created the entry.



41
# File 'lib/whop_sdk/models/entry_list_response.rb', line 41

required :user, -> { WhopSDK::Models::EntryListResponse::User }