Class: WhopSDK::Models::EntryListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::EntryListResponse
- Defined in:
- lib/whop_sdk/models/entry_list_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#created_at ⇒ Time?
When the entry was created.
-
#id ⇒ String
The internal ID of the entry.
-
#plan ⇒ WhopSDK::Models::EntryListResponse::Plan?
The waitlist plan the entry if for.
-
#product ⇒ WhopSDK::Models::EntryListResponse::Product?
The access pass tied to this entry, if there is one.
-
#status ⇒ Symbol, WhopSDK::Models::EntryStatus
The status of the entry.
-
#user ⇒ WhopSDK::Models::EntryListResponse::User
The user who created the entry.
Instance Method Summary collapse
-
#initialize(id: , title: ) ⇒ Object
constructor
The access pass tied to this entry, if there is one.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , title: ) ⇒ Object
The access pass tied to this entry, if there is one.
|
|
# File 'lib/whop_sdk/models/entry_list_response.rb', line 43
|
Instance Attribute Details
#created_at ⇒ Time?
When the entry was created.
17 |
# File 'lib/whop_sdk/models/entry_list_response.rb', line 17 required :created_at, Time, nil?: true |
#id ⇒ String
The internal ID of the entry.
11 |
# File 'lib/whop_sdk/models/entry_list_response.rb', line 11 required :id, String |
#plan ⇒ WhopSDK::Models::EntryListResponse::Plan?
The waitlist plan the entry if for.
23 |
# File 'lib/whop_sdk/models/entry_list_response.rb', line 23 required :plan, -> { WhopSDK::Models::EntryListResponse::Plan }, nil?: true |
#product ⇒ WhopSDK::Models::EntryListResponse::Product?
The access pass tied to this entry, if there is one.
29 |
# File 'lib/whop_sdk/models/entry_list_response.rb', line 29 required :product, -> { WhopSDK::Models::EntryListResponse::Product }, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::EntryStatus
The status of the entry.
35 |
# File 'lib/whop_sdk/models/entry_list_response.rb', line 35 required :status, enum: -> { WhopSDK::EntryStatus } |
#user ⇒ WhopSDK::Models::EntryListResponse::User
The user who created the entry.
41 |
# File 'lib/whop_sdk/models/entry_list_response.rb', line 41 required :user, -> { WhopSDK::Models::EntryListResponse::User } |