Class: WhopSDK::Models::Experience

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/experience.rb

Defined Under Namespace

Classes: App, Company, Image, Product

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(url: ) ⇒ Object

Some parameter documentations has been truncated, see Image for more details.

The logo for the experience.

Parameters:

  • url (String, nil) (defaults to: )

    This is the URL you use to render optimized attachments on the client. This shou



# File 'lib/whop_sdk/models/experience.rb', line 57

Instance Attribute Details

#appWhopSDK::Models::Experience::App

The experience interface for this experience.



16
# File 'lib/whop_sdk/models/experience.rb', line 16

required :app, -> { WhopSDK::Experience::App }

#companyWhopSDK::Models::Experience::Company

The company that owns this experience.



22
# File 'lib/whop_sdk/models/experience.rb', line 22

required :company, -> { WhopSDK::Experience::Company }

#created_atTime

The timestamp of when this experience was created.

Returns:

  • (Time)


28
# File 'lib/whop_sdk/models/experience.rb', line 28

required :created_at, Time

#idString

The unique ID representing this experience

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/experience.rb', line 10

required :id, String

#imageWhopSDK::Models::Experience::Image?

The logo for the experience.



34
# File 'lib/whop_sdk/models/experience.rb', line 34

required :image, -> { WhopSDK::Experience::Image }, nil?: true

#nameString

The written name of the description.

Returns:

  • (String)


40
# File 'lib/whop_sdk/models/experience.rb', line 40

required :name, String

#orderString?

The order of the experience in the section

Returns:

  • (String, nil)


46
# File 'lib/whop_sdk/models/experience.rb', line 46

required :order, String, nil?: true

#productsArray<WhopSDK::Models::Experience::Product>

The access passes that are associated with this experience. This should not be used unless you are trying to list all access passes the experience has, for some reason. You probably don’t want to use this though and should be using accessPass.



55
# File 'lib/whop_sdk/models/experience.rb', line 55

required :products, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Experience::Product] }