Class: WhopSDK::Models::Experience
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Experience
- Defined in:
- lib/whop_sdk/models/experience.rb
Defined Under Namespace
Classes: App, Company, Image, Product
Instance Attribute Summary collapse
-
#app ⇒ WhopSDK::Models::Experience::App
The experience interface for this experience.
-
#company ⇒ WhopSDK::Models::Experience::Company
The company that owns this experience.
-
#created_at ⇒ Time
The timestamp of when this experience was created.
-
#id ⇒ String
The unique ID representing this experience.
-
#image ⇒ WhopSDK::Models::Experience::Image?
The logo for the experience.
-
#name ⇒ String
The written name of the description.
-
#order ⇒ String?
The order of the experience in the section.
-
#products ⇒ Array<WhopSDK::Models::Experience::Product>
The access passes that are associated with this experience.
Instance Method Summary collapse
-
#initialize(url: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Image for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(url: ) ⇒ Object
Some parameter documentations has been truncated, see Image for more details.
The logo for the experience.
|
|
# File 'lib/whop_sdk/models/experience.rb', line 57
|
Instance Attribute Details
#app ⇒ WhopSDK::Models::Experience::App
The experience interface for this experience.
16 |
# File 'lib/whop_sdk/models/experience.rb', line 16 required :app, -> { WhopSDK::Experience::App } |
#company ⇒ WhopSDK::Models::Experience::Company
The company that owns this experience.
22 |
# File 'lib/whop_sdk/models/experience.rb', line 22 required :company, -> { WhopSDK::Experience::Company } |
#created_at ⇒ Time
The timestamp of when this experience was created.
28 |
# File 'lib/whop_sdk/models/experience.rb', line 28 required :created_at, Time |
#id ⇒ String
The unique ID representing this experience
10 |
# File 'lib/whop_sdk/models/experience.rb', line 10 required :id, String |
#image ⇒ WhopSDK::Models::Experience::Image?
The logo for the experience.
34 |
# File 'lib/whop_sdk/models/experience.rb', line 34 required :image, -> { WhopSDK::Experience::Image }, nil?: true |
#name ⇒ String
The written name of the description.
40 |
# File 'lib/whop_sdk/models/experience.rb', line 40 required :name, String |
#order ⇒ String?
The order of the experience in the section
46 |
# File 'lib/whop_sdk/models/experience.rb', line 46 required :order, String, nil?: true |
#products ⇒ Array<WhopSDK::Models::Experience::Product>
The access passes that are associated with this experience. This should not be used unless you are trying to list all access passes the experience has, for some reason. You probably don’t want to use this though and should be using accessPass.
55 |
# File 'lib/whop_sdk/models/experience.rb', line 55 required :products, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Experience::Product] } |