Class: WhopSDK::Models::Experience::App

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/experience.rb

Overview

See Also:

Defined Under Namespace

Classes: Icon

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , icon: , name: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::Experience::App for more details.

The experience interface for this experience.

Parameters:

  • id (String) (defaults to: )

    The ID of the app

  • icon (WhopSDK::Models::Experience::App::Icon, nil) (defaults to: )

    The icon for the app. This icon is shown on discovery, on the product page, on c

  • name (String) (defaults to: )

    The name of the app



# File 'lib/whop_sdk/models/experience.rb', line 99

Instance Attribute Details

#iconWhopSDK::Models::Experience::App::Icon?

The icon for the app. This icon is shown on discovery, on the product page, on checkout, and as a default icon for the experiences.



91
# File 'lib/whop_sdk/models/experience.rb', line 91

required :icon, -> { WhopSDK::Experience::App::Icon }, nil?: true

#idString

The ID of the app

Returns:

  • (String)


84
# File 'lib/whop_sdk/models/experience.rb', line 84

required :id, String

#nameString

The name of the app

Returns:

  • (String)


97
# File 'lib/whop_sdk/models/experience.rb', line 97

required :name, String