Class: WhopSDK::Models::Experience::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Experience::Product
- Defined in:
- lib/whop_sdk/models/experience.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the product.
-
#route ⇒ String
The URL slug used in the product’s public link (e.g., ‘my-product’ in whop.com/company/my-product).
-
#title ⇒ String
The display name of the product shown to customers on the product page and in search results.
Instance Method Summary collapse
-
#initialize(id:, route:, title:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Product for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, route:, title:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Experience::Product for more details.
A product is a digital good or service sold on Whop. Products contain plans for pricing and experiences for content delivery.
|
|
# File 'lib/whop_sdk/models/experience.rb', line 218
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the product.
202 |
# File 'lib/whop_sdk/models/experience.rb', line 202 required :id, String |
#route ⇒ String
The URL slug used in the product’s public link (e.g., ‘my-product’ in whop.com/company/my-product).
209 |
# File 'lib/whop_sdk/models/experience.rb', line 209 required :route, String |
#title ⇒ String
The display name of the product shown to customers on the product page and in search results.
216 |
# File 'lib/whop_sdk/models/experience.rb', line 216 required :title, String |