Class: WhopSDK::Models::ExperienceCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/experience_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(app_id: , company_id: , name: nil, section_id: nil, request_options: {}) ⇒ Object

Parameters:

  • app_id (String) (defaults to: )

    The ID of the app to create the experience for

  • company_id (String) (defaults to: )

    The ID of the company to create the experience for

  • name (String, nil) (defaults to: nil)

    The name of the experience

  • section_id (String, nil) (defaults to: nil)

    The ID of the section to create the experience in

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/experience_create_params.rb', line 34

Instance Attribute Details

#app_idString

The ID of the app to create the experience for

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/experience_create_params.rb', line 14

required :app_id, String

#company_idString

The ID of the company to create the experience for

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/experience_create_params.rb', line 20

required :company_id, String

#nameString?

The name of the experience

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/experience_create_params.rb', line 26

optional :name, String, nil?: true

#section_idString?

The ID of the section to create the experience in

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/experience_create_params.rb', line 32

optional :section_id, String, nil?: true