Class: WhopSDK::Models::ExperienceCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ExperienceCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/experience_create_params.rb
Overview
Instance Attribute Summary collapse
-
#app_id ⇒ String
The ID of the app to create the experience for.
-
#company_id ⇒ String
The ID of the company to create the experience for.
-
#name ⇒ String?
The name of the experience.
-
#section_id ⇒ String?
The ID of the section to create the experience in.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(app_id: , company_id: , name: nil, section_id: nil, request_options: {}) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(app_id: , company_id: , name: nil, section_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/experience_create_params.rb', line 34
|
Instance Attribute Details
#app_id ⇒ String
The ID of the app to create the experience for
14 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 14 required :app_id, String |
#company_id ⇒ String
The ID of the company to create the experience for
20 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 20 required :company_id, String |
#name ⇒ String?
The name of the experience
26 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 26 optional :name, String, nil?: true |
#section_id ⇒ String?
The ID of the section to create the experience in
32 |
# File 'lib/whop_sdk/models/experience_create_params.rb', line 32 optional :section_id, String, nil?: true |