Class: WhopSDK::Models::ExperienceListResponse::App
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ExperienceListResponse::App
- Defined in:
- lib/whop_sdk/models/experience_list_response.rb
Overview
Defined Under Namespace
Classes: Icon
Instance Attribute Summary collapse
-
#icon ⇒ WhopSDK::Models::ExperienceListResponse::App::Icon?
The icon for the app.
-
#id ⇒ String
The ID of the app.
-
#name ⇒ String
The name of the app.
Instance Method Summary collapse
-
#initialize(id: , icon: , name: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see App for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , icon: , name: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ExperienceListResponse::App for more details.
The experience interface for this experience.
|
|
# File 'lib/whop_sdk/models/experience_list_response.rb', line 87
|
Instance Attribute Details
#icon ⇒ WhopSDK::Models::ExperienceListResponse::App::Icon?
The icon for the app. This icon is shown on discovery, on the product page, on checkout, and as a default icon for the experiences.
79 |
# File 'lib/whop_sdk/models/experience_list_response.rb', line 79 required :icon, -> { WhopSDK::Models::ExperienceListResponse::App::Icon }, nil?: true |
#id ⇒ String
The ID of the app
72 |
# File 'lib/whop_sdk/models/experience_list_response.rb', line 72 required :id, String |
#name ⇒ String
The name of the app
85 |
# File 'lib/whop_sdk/models/experience_list_response.rb', line 85 required :name, String |