Class: WhopSDK::Models::FeeMarkupCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::FeeMarkupCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/fee_markup_create_params.rb
Overview
Instance Attribute Summary collapse
-
#company_id ⇒ String
The unique identifier of the company to create or update the fee markup for.
-
#fee_type ⇒ Symbol, WhopSDK::Models::FeeMarkupType
The type of fee this markup applies to, such as processing or platform fees.
-
#fixed_fee_usd ⇒ Float?
The fixed fee amount in USD to charge per transaction.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value metadata to attach to this fee markup.
-
#notes ⇒ String?
Internal notes about this fee markup for record-keeping purposes.
-
#percentage_fee ⇒ Float?
The percentage fee to charge per transaction.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(company_id:, fee_type:, fixed_fee_usd: nil, metadata: nil, notes: nil, percentage_fee: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see FeeMarkupCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, fee_type:, fixed_fee_usd: nil, metadata: nil, notes: nil, percentage_fee: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::FeeMarkupCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 46
|
Instance Attribute Details
#company_id ⇒ String
The unique identifier of the company to create or update the fee markup for.
14 |
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 14 required :company_id, String |
#fee_type ⇒ Symbol, WhopSDK::Models::FeeMarkupType
The type of fee this markup applies to, such as processing or platform fees.
20 |
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 20 required :fee_type, enum: -> { WhopSDK::FeeMarkupType } |
#fixed_fee_usd ⇒ Float?
The fixed fee amount in USD to charge per transaction. Must be between 0 and 50.
26 |
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 26 optional :fixed_fee_usd, Float, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value metadata to attach to this fee markup.
32 |
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 32 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#notes ⇒ String?
Internal notes about this fee markup for record-keeping purposes.
38 |
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 38 optional :notes, String, nil?: true |
#percentage_fee ⇒ Float?
The percentage fee to charge per transaction. Must be between 0 and 25.
44 |
# File 'lib/whop_sdk/models/fee_markup_create_params.rb', line 44 optional :percentage_fee, Float, nil?: true |