Class: WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6
- Defined in:
- lib/whop_sdk/models/financial_activity_list_response.rb,
sig/whop_sdk/models/financial_activity_list_response.rbs
Defined Under Namespace
Modules: Object
Instance Attribute Summary collapse
-
#authorized_at ⇒ Time?
ISO 8601 timestamp the transaction was authorized.
-
#card_id ⇒ String?
Identifier of the card that the transaction was charged to.
-
#cashback_usd ⇒ String?
Cashback earned on this transaction as a USD decimal string.
-
#declined_reason ⇒ String?
Reason the transaction was declined (when status is declined).
-
#id ⇒ String
Card transaction ID.
-
#local_amount ⇒ String?
Amount the merchant charged in their local currency, as a decimal string.
-
#local_currency ⇒ String?
ISO 4217 currency code of the merchant-charged amount in local_amount.
-
#merchant_category ⇒ String?
Merchant category.
-
#merchant_icon_url ⇒ String?
Merchant icon URL.
-
#merchant_name ⇒ String?
Merchant display name.
- #object ⇒ Symbol, WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6::Object
-
#posted_at ⇒ Time?
ISO 8601 timestamp the transaction was settled by the card network.
-
#status ⇒ String?
Current card transaction status.
-
#usd_amount ⇒ String?
The processor-settled USD amount as a decimal string.
Instance Method Summary collapse
-
#initialize(id:, authorized_at:, card_id:, cashback_usd:, declined_reason:, local_amount:, local_currency:, merchant_category:, merchant_icon_url:, merchant_name:, object:, posted_at:, status:, usd_amount:) ⇒ Object
constructor
Some parameter documentations has been truncated, see UnionMember6 for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, authorized_at:, card_id:, cashback_usd:, declined_reason:, local_amount:, local_currency:, merchant_category:, merchant_icon_url:, merchant_name:, object:, posted_at:, status:, usd_amount:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6 for more details.
|
|
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 793
|
Instance Attribute Details
#authorized_at ⇒ Time?
ISO 8601 timestamp the transaction was authorized.
716 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 716 required :authorized_at, Time, nil?: true |
#card_id ⇒ String?
Identifier of the card that the transaction was charged to.
722 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 722 required :card_id, String, nil?: true |
#cashback_usd ⇒ String?
Cashback earned on this transaction as a USD decimal string. Zero for declined or ineligible transactions; null when cashback has not been computed yet.
729 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 729 required :cashback_usd, String, nil?: true |
#declined_reason ⇒ String?
Reason the transaction was declined (when status is declined).
735 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 735 required :declined_reason, String, nil?: true |
#id ⇒ String
Card transaction ID.
710 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 710 required :id, String |
#local_amount ⇒ String?
Amount the merchant charged in their local currency, as a decimal string. Pair with local_currency.
742 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 742 required :local_amount, String, nil?: true |
#local_currency ⇒ String?
ISO 4217 currency code of the merchant-charged amount in local_amount.
748 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 748 required :local_currency, String, nil?: true |
#merchant_category ⇒ String?
Merchant category.
754 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 754 required :merchant_category, String, nil?: true |
#merchant_icon_url ⇒ String?
Merchant icon URL.
760 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 760 required :merchant_icon_url, String, nil?: true |
#merchant_name ⇒ String?
Merchant display name.
766 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 766 required :merchant_name, String, nil?: true |
#object ⇒ Symbol, WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6::Object
771 772 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 771 required :object, enum: -> { WhopSDK::Models::FinancialActivityListResponse::Data::Resource::UnionMember6::Object } |
#posted_at ⇒ Time?
ISO 8601 timestamp the transaction was settled by the card network.
778 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 778 required :posted_at, Time, nil?: true |
#status ⇒ String?
Current card transaction status.
784 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 784 required :status, String, nil?: true |
#usd_amount ⇒ String?
The processor-settled USD amount as a decimal string. The ledger's USDT leg is posted 1:1 from this value.
791 |
# File 'lib/whop_sdk/models/financial_activity_list_response.rb', line 791 required :usd_amount, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
652 |
# File 'sig/whop_sdk/models/financial_activity_list_response.rbs', line 652
def to_hash: -> {
|