Class: WhopSDK::Models::ForumPostCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/forum_post_create_params.rb

Overview

Defined Under Namespace

Modules: Attachment Classes: Poll

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ForumPostCreateParams::Attachment::AttachmentInputWithID for more details.

Input for an attachment

Parameters:

  • id (String) (defaults to: )

    The ID of an existing attachment object. Use this when updating a resource and k



# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 83

Instance Attribute Details

#contentString?

This is the main body of the post in Markdown format. Hidden if paywalled and user hasn’t purchased access to it.

Returns:

  • (String, nil)


29
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 29

optional :content, String, nil?: true

#experience_idString

The experience to create this post in

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 14

required :experience_id, String

#is_mentionBoolean?

This is used to determine if the post should be sent as a ‘mention’ notification to all of the users who are in the experience. This means that anyone with ‘mentions’ enabled will receive a notification about this post.

Returns:

  • (Boolean, nil)


37
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 37

optional :is_mention, WhopSDK::Internal::Type::Boolean, nil?: true

#parent_idString?

The ID of the parent post. Set it to the ID of the post you want to comment on or don’t include it if its a top level post.

Returns:

  • (String, nil)


44
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 44

optional :parent_id, String, nil?: true

#paywall_amountFloat?

The amount to paywall this post by. A paywalled post requires the user to purchase it in order to view its content.

Returns:

  • (Float, nil)


51
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 51

optional :paywall_amount, Float, nil?: true

#paywall_currencySymbol, ...

The available currencies on the platform

Returns:



57
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 57

optional :paywall_currency, enum: -> { WhopSDK::Currency }, nil?: true

#pinnedBoolean?

Whether the post should be pinned

Returns:

  • (Boolean, nil)


63
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 63

optional :pinned, WhopSDK::Internal::Type::Boolean, nil?: true

#pollWhopSDK::Models::ForumPostCreateParams::Poll?

The poll for this post



69
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 69

optional :poll, -> { WhopSDK::ForumPostCreateParams::Poll }, nil?: true

#titleString?

The title of the post. Only visible if paywalled.

Returns:

  • (String, nil)


75
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 75

optional :title, String, nil?: true

#visibilitySymbol, ...

The visibility types for forum posts



81
# File 'lib/whop_sdk/models/forum_post_create_params.rb', line 81

optional :visibility, enum: -> { WhopSDK::ForumPostVisibilityType }, nil?: true