Class: WhopSDK::Models::ForumPostListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ForumPostListResponse
- Defined in:
- lib/whop_sdk/models/forum_post_list_response.rb
Overview
Defined Under Namespace
Classes: Attachment, User
Instance Attribute Summary collapse
-
#attachments ⇒ Array<WhopSDK::Models::ForumPostListResponse::Attachment>
All file attachments on this post, such as images, documents, and videos.
-
#comment_count ⇒ Integer
The total number of direct comments on this post.
-
#content ⇒ String?
The body of the forum post in Markdown format.
-
#created_at ⇒ Time
The time this post was created, as a Unix timestamp.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#is_edited ⇒ Boolean
Whether this post has been edited after its initial creation.
-
#is_pinned ⇒ Boolean
Whether this post is pinned to the top of the forum feed.
-
#is_poster_admin ⇒ Boolean
Whether the author of this post is an admin of the company that owns the forum.
-
#like_count ⇒ Integer?
The total number of like reactions this post has received.
-
#parent_id ⇒ String?
The unique identifier of the parent post.
-
#title ⇒ String?
The headline of the forum post.
-
#updated_at ⇒ Time
The time this post was last updated, as a Unix timestamp.
-
#user ⇒ WhopSDK::Models::ForumPostListResponse::User
The user who authored this forum post.
-
#view_count ⇒ Integer?
The total number of times this post has been viewed by users.
Instance Method Summary collapse
-
#initialize(id:, content_type:, filename:, url:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Attachment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, content_type:, filename:, url:) ⇒ Object
Some parameter documentations has been truncated, see Attachment for more details.
Represents an image attachment
|
|
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 162
|
Instance Attribute Details
#attachments ⇒ Array<WhopSDK::Models::ForumPostListResponse::Attachment>
All file attachments on this post, such as images, documents, and videos.
21 22 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 21 required :attachments, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::ForumPostListResponse::Attachment] } |
#comment_count ⇒ Integer
The total number of direct comments on this post.
28 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 28 required :comment_count, Integer |
#content ⇒ String?
The body of the forum post in Markdown format. Null if the post is paywalled and the current user does not have access.
35 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 35 required :content, String, nil?: true |
#created_at ⇒ Time
The time this post was created, as a Unix timestamp.
41 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 41 required :created_at, Time |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.
15 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 15 required :id, String |
#is_edited ⇒ Boolean
Whether this post has been edited after its initial creation.
47 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 47 required :is_edited, WhopSDK::Internal::Type::Boolean |
#is_pinned ⇒ Boolean
Whether this post is pinned to the top of the forum feed.
53 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 53 required :is_pinned, WhopSDK::Internal::Type::Boolean |
#is_poster_admin ⇒ Boolean
Whether the author of this post is an admin of the company that owns the forum.
59 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 59 required :is_poster_admin, WhopSDK::Internal::Type::Boolean |
#like_count ⇒ Integer?
The total number of like reactions this post has received.
65 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 65 required :like_count, Integer, nil?: true |
#parent_id ⇒ String?
The unique identifier of the parent post. Null if this is a top-level post.
71 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 71 required :parent_id, String, nil?: true |
#title ⇒ String?
The headline of the forum post. Null if the post has no title.
77 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 77 required :title, String, nil?: true |
#updated_at ⇒ Time
The time this post was last updated, as a Unix timestamp.
83 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 83 required :updated_at, Time |
#user ⇒ WhopSDK::Models::ForumPostListResponse::User
The user who authored this forum post.
89 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 89 required :user, -> { WhopSDK::Models::ForumPostListResponse::User } |
#view_count ⇒ Integer?
The total number of times this post has been viewed by users.
95 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 95 required :view_count, Integer, nil?: true |