Class: WhopSDK::Models::ForumPostListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/forum_post_list_response.rb

Overview

Defined Under Namespace

Classes: User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , comment_count: , content: , created_at: , is_edited: , is_pinned: , is_poster_admin: , like_count: , parent_id: , title: , updated_at: , user: , view_count: ) ⇒ Object

Represents a post in forum

Parameters:

  • id (String) (defaults to: )

    The unique identifier for the entity

  • comment_count (Integer) (defaults to: )

    The amount of comments on this post

  • content (String, nil) (defaults to: )

    The content of the forum post in Markdown format

  • created_at (Time) (defaults to: )

    The timestamp when the post was created

  • is_edited (Boolean) (defaults to: )

    Whether the forum post has been edited

  • is_pinned (Boolean) (defaults to: )

    Whether this forum post is pinned

  • is_poster_admin (Boolean) (defaults to: )

    Whether the user that sent the post is an admin of the company

  • like_count (Integer, nil) (defaults to: )

    The number of likes this post has received

  • parent_id (String, nil) (defaults to: )

    The ID of the parent forum post, if applicable

  • title (String, nil) (defaults to: )

    The title of the forum post

  • updated_at (Time) (defaults to: )

    The timestamp when the post was last updated

  • user (WhopSDK::Models::ForumPostListResponse::User) (defaults to: )

    The user who created this forum post

  • view_count (Integer, nil) (defaults to: )

    The number of times this message has been viewed



# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 85

Instance Attribute Details

#comment_countInteger

The amount of comments on this post

Returns:

  • (Integer)


17
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 17

required :comment_count, Integer

#contentString?

The content of the forum post in Markdown format

Returns:

  • (String, nil)


23
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 23

required :content, String, nil?: true

#created_atTime

The timestamp when the post was created

Returns:

  • (Time)


29
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 29

required :created_at, Time

#idString

The unique identifier for the entity

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 11

required :id, String

#is_editedBoolean

Whether the forum post has been edited

Returns:

  • (Boolean)


35
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 35

required :is_edited, WhopSDK::Internal::Type::Boolean

#is_pinnedBoolean

Whether this forum post is pinned

Returns:

  • (Boolean)


41
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 41

required :is_pinned, WhopSDK::Internal::Type::Boolean

#is_poster_adminBoolean

Whether the user that sent the post is an admin of the company

Returns:

  • (Boolean)


47
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 47

required :is_poster_admin, WhopSDK::Internal::Type::Boolean

#like_countInteger?

The number of likes this post has received

Returns:

  • (Integer, nil)


53
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 53

required :like_count, Integer, nil?: true

#parent_idString?

The ID of the parent forum post, if applicable

Returns:

  • (String, nil)


59
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 59

required :parent_id, String, nil?: true

#titleString?

The title of the forum post

Returns:

  • (String, nil)


65
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 65

required :title, String, nil?: true

#updated_atTime

The timestamp when the post was last updated

Returns:

  • (Time)


71
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 71

required :updated_at, Time

#userWhopSDK::Models::ForumPostListResponse::User

The user who created this forum post



77
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 77

required :user, -> { WhopSDK::Models::ForumPostListResponse::User }

#view_countInteger?

The number of times this message has been viewed

Returns:

  • (Integer, nil)


83
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 83

required :view_count, Integer, nil?: true