Class: WhopSDK::Models::ForumPostListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ForumPostListResponse
- Defined in:
- lib/whop_sdk/models/forum_post_list_response.rb
Overview
Defined Under Namespace
Classes: User
Instance Attribute Summary collapse
-
#comment_count ⇒ Integer
The amount of comments on this post.
-
#content ⇒ String?
The content of the forum post in Markdown format.
-
#created_at ⇒ Time
The timestamp when the post was created.
-
#id ⇒ String
The unique identifier for the entity.
-
#is_edited ⇒ Boolean
Whether the forum post has been edited.
-
#is_pinned ⇒ Boolean
Whether this forum post is pinned.
-
#is_poster_admin ⇒ Boolean
Whether the user that sent the post is an admin of the company.
-
#like_count ⇒ Integer?
The number of likes this post has received.
-
#parent_id ⇒ String?
The ID of the parent forum post, if applicable.
-
#title ⇒ String?
The title of the forum post.
-
#updated_at ⇒ Time
The timestamp when the post was last updated.
-
#user ⇒ WhopSDK::Models::ForumPostListResponse::User
The user who created this forum post.
-
#view_count ⇒ Integer?
The number of times this message has been viewed.
Instance Method Summary collapse
-
#initialize(id: , comment_count: , content: , created_at: , is_edited: , is_pinned: , is_poster_admin: , like_count: , parent_id: , title: , updated_at: , user: , view_count: ) ⇒ Object
constructor
Represents a post in forum.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , comment_count: , content: , created_at: , is_edited: , is_pinned: , is_poster_admin: , like_count: , parent_id: , title: , updated_at: , user: , view_count: ) ⇒ Object
Represents a post in forum
|
|
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 85
|
Instance Attribute Details
#comment_count ⇒ Integer
The amount of comments on this post
17 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 17 required :comment_count, Integer |
#content ⇒ String?
The content of the forum post in Markdown format
23 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 23 required :content, String, nil?: true |
#created_at ⇒ Time
The timestamp when the post was created
29 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 29 required :created_at, Time |
#id ⇒ String
The unique identifier for the entity
11 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 11 required :id, String |
#is_edited ⇒ Boolean
Whether the forum post has been edited
35 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 35 required :is_edited, WhopSDK::Internal::Type::Boolean |
#is_pinned ⇒ Boolean
Whether this forum post is pinned
41 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 41 required :is_pinned, WhopSDK::Internal::Type::Boolean |
#is_poster_admin ⇒ Boolean
Whether the user that sent the post is an admin of the company
47 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 47 required :is_poster_admin, WhopSDK::Internal::Type::Boolean |
#like_count ⇒ Integer?
The number of likes this post has received
53 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 53 required :like_count, Integer, nil?: true |
#parent_id ⇒ String?
The ID of the parent forum post, if applicable
59 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 59 required :parent_id, String, nil?: true |
#title ⇒ String?
The title of the forum post
65 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 65 required :title, String, nil?: true |
#updated_at ⇒ Time
The timestamp when the post was last updated
71 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 71 required :updated_at, Time |
#user ⇒ WhopSDK::Models::ForumPostListResponse::User
The user who created this forum post
77 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 77 required :user, -> { WhopSDK::Models::ForumPostListResponse::User } |
#view_count ⇒ Integer?
The number of times this message has been viewed
83 |
# File 'lib/whop_sdk/models/forum_post_list_response.rb', line 83 required :view_count, Integer, nil?: true |