Class: WhopSDK::Models::ForumPostUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/forum_post_update_params.rb

Overview

Defined Under Namespace

Classes: Attachment

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#attachmentsArray<WhopSDK::Models::ForumPostUpdateParams::Attachment>?

The attachments for this post



14
15
16
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 14

optional :attachments,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::ForumPostUpdateParams::Attachment] },
nil?: true

#contentString?

This is the main body of the post in Markdown format. Hidden if paywalled and user hasn’t purchased access to it.

Returns:

  • (String, nil)


23
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 23

optional :content, String, nil?: true

#is_pinnedBoolean?

Whether the post is pinned. You can only pin a top level posts (not comments).

Returns:

  • (Boolean, nil)


29
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 29

optional :is_pinned, WhopSDK::Internal::Type::Boolean, nil?: true

#titleString?

The title of the post. Only visible if paywalled.

Returns:

  • (String, nil)


35
# File 'lib/whop_sdk/models/forum_post_update_params.rb', line 35

optional :title, String, nil?: true