Class: WhopSDK::Models::ForumUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ForumUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/forum_update_params.rb
Overview
Defined Under Namespace
Classes: BannerImage
Instance Attribute Summary collapse
-
#banned_words ⇒ Array<String>?
A list of words that are automatically blocked from posts in this forum.
-
#banner_image ⇒ WhopSDK::Models::ForumUpdateParams::BannerImage?
The banner image displayed at the top of the forum page.
-
#email_notification_preference ⇒ Symbol, ...
Email notification preference option for a forum feed.
- #id ⇒ String
-
#who_can_comment ⇒ Symbol, ...
Who can comment on a forum feed.
-
#who_can_post ⇒ Symbol, ...
Who can post on a forum feed.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#banned_words ⇒ Array<String>?
A list of words that are automatically blocked from posts in this forum. For example, [‘spam’, ‘scam’].
20 |
# File 'lib/whop_sdk/models/forum_update_params.rb', line 20 optional :banned_words, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#banner_image ⇒ WhopSDK::Models::ForumUpdateParams::BannerImage?
The banner image displayed at the top of the forum page. Pass null to remove the existing banner.
27 |
# File 'lib/whop_sdk/models/forum_update_params.rb', line 27 optional :banner_image, -> { WhopSDK::ForumUpdateParams::BannerImage }, nil?: true |
#email_notification_preference ⇒ Symbol, ...
Email notification preference option for a forum feed
33 |
# File 'lib/whop_sdk/models/forum_update_params.rb', line 33 optional :email_notification_preference, enum: -> { WhopSDK::EmailNotificationPreferences }, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/forum_update_params.rb', line 13 required :id, String |
#who_can_comment ⇒ Symbol, ...
Who can comment on a forum feed
39 |
# File 'lib/whop_sdk/models/forum_update_params.rb', line 39 optional :who_can_comment, enum: -> { WhopSDK::WhoCanCommentTypes }, nil?: true |
#who_can_post ⇒ Symbol, ...
Who can post on a forum feed
45 |
# File 'lib/whop_sdk/models/forum_update_params.rb', line 45 optional :who_can_post, enum: -> { WhopSDK::WhoCanPostTypes }, nil?: true |