Class: WhopSDK::Models::ForumUpdateParams::BannerImage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ForumUpdateParams::BannerImage
- Defined in:
- lib/whop_sdk/models/forum_update_params.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The ID of an existing file object.
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
The banner image displayed at the top of the forum page.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
The banner image displayed at the top of the forum page. Pass null to remove the existing banner.
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/whop_sdk/models/forum_update_params.rb', line 65 class BannerImage < WhopSDK::Internal::Type::BaseModel # @!attribute id # The ID of an existing file object. # # @return [String] required :id, String # @!method initialize(id:) # The banner image displayed at the top of the forum page. Pass null to remove the # existing banner. # # @param id [String] The ID of an existing file object. end |
Instance Attribute Details
#id ⇒ String
The ID of an existing file object.
70 |
# File 'lib/whop_sdk/models/forum_update_params.rb', line 70 required :id, String |