Class: WhopSDK::Models::InvoiceCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::InvoiceCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/invoice_create_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#charge_buyer_fee ⇒ Boolean?
Whether or not to charge the customer a buyer fee.
-
#collection_method ⇒ Symbol, WhopSDK::Models::CollectionMethod
The method of collection for this invoice.
-
#company_id ⇒ String
The company ID to create this invoice for.
-
#customer_name ⇒ String?
The name of the customer to create this invoice for.
-
#due_date ⇒ Time
The date the invoice is due, if applicable.
-
#email_address ⇒ String
The email address to create this invoice for.
-
#member_id ⇒ String
The member ID to create this invoice for.
-
#payment_method_id ⇒ String?
The payment method ID to use for this invoice.
-
#payment_token_id ⇒ String?
The payment token ID to use for this invoice.
-
#plan ⇒ WhopSDK::Models::InvoiceCreateParams::Plan
The properties of the plan to create for this invoice.
-
#product ⇒ WhopSDK::Models::InvoiceCreateParams::Product
The properties of the product to create for this invoice.
-
#product_id ⇒ String
The product ID to create this invoice for.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object
|
|
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 275
|
Instance Attribute Details
#charge_buyer_fee ⇒ Boolean?
Whether or not to charge the customer a buyer fee.
54 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 54 optional :charge_buyer_fee, WhopSDK::Internal::Type::Boolean, nil?: true |
#collection_method ⇒ Symbol, WhopSDK::Models::CollectionMethod
The method of collection for this invoice. If using charge_automatically, you must provide a payment_token.
15 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 15 required :collection_method, enum: -> { WhopSDK::CollectionMethod } |
#company_id ⇒ String
The company ID to create this invoice for.
21 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 21 required :company_id, String |
#customer_name ⇒ String?
The name of the customer to create this invoice for. This is required if you want to create an invoice for a customer who does not have a member of your company yet.
62 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 62 optional :customer_name, String, nil?: true |
#due_date ⇒ Time
The date the invoice is due, if applicable.
27 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 27 required :due_date, Time |
#email_address ⇒ String
The email address to create this invoice for. This is required if you want to create an invoice for a user who does not have a member of your company yet.
83 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 83 required :email_address, String |
#member_id ⇒ String
The member ID to create this invoice for. Include this if you want to create an invoice for an existing member. If you do not have a member ID, you must provide an email_address and customer_name.
35 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 35 required :member_id, String |
#payment_method_id ⇒ String?
The payment method ID to use for this invoice. If using charge_automatically, you must provide a payment_method_id.
69 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 69 optional :payment_method_id, String, nil?: true |
#payment_token_id ⇒ String?
The payment token ID to use for this invoice. If using charge_automatically, you must provide a payment_token.
76 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 76 optional :payment_token_id, String, nil?: true |
#plan ⇒ WhopSDK::Models::InvoiceCreateParams::Plan
The properties of the plan to create for this invoice.
41 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 41 required :plan, -> { WhopSDK::InvoiceCreateParams::Plan } |
#product ⇒ WhopSDK::Models::InvoiceCreateParams::Product
The properties of the product to create for this invoice. Include this if you want to create an invoice for a new product.
48 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 48 required :product, -> { WhopSDK::InvoiceCreateParams::Product } |
#product_id ⇒ String
The product ID to create this invoice for. Include this if you want to create an invoice for an existing product.
90 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 90 required :product_id, String |