Class: WhopSDK::Models::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Plan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Plan
- Defined in:
- lib/whop_sdk/models/invoice_create_params.rb
Overview
Defined Under Namespace
Classes: CustomField, PaymentMethodConfiguration
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The interval in days at which the plan charges (renewal plans).
-
#custom_fields ⇒ Array<WhopSDK::Models::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Plan::CustomField>?
An array of custom field objects.
-
#description ⇒ String?
The description of the plan.
-
#expiration_days ⇒ Integer?
The number of days until the membership expires and revokes access (expiration plans).
-
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
-
#internal_notes ⇒ String?
A personal description or notes section for the business.
-
#legacy_payment_method_controls ⇒ Boolean?
Whether this plan uses legacy payment method controls.
-
#payment_method_configuration ⇒ WhopSDK::Models::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Plan::PaymentMethodConfiguration?
The explicit payment method configuration for the plan.
-
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to a product.
-
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
-
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
-
#stock ⇒ Integer?
The number of units available for purchase.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#unlimited_stock ⇒ Boolean?
When true, the plan has unlimited stock (stock field is ignored).
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Instance Method Summary collapse
- #initialize(name:, id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name:, id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object
|
|
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 379
|
Instance Attribute Details
#billing_period ⇒ Integer?
The interval in days at which the plan charges (renewal plans).
204 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 204 optional :billing_period, Integer, nil?: true |
#custom_fields ⇒ Array<WhopSDK::Models::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Plan::CustomField>?
An array of custom field objects.
210 211 212 213 214 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 210 optional :custom_fields, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Plan::CustomField] }, nil?: true |
#description ⇒ String?
The description of the plan.
220 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 220 optional :description, String, nil?: true |
#expiration_days ⇒ Integer?
The number of days until the membership expires and revokes access (expiration plans). For example, 365 for a one-year access period.
227 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 227 optional :expiration_days, Integer, nil?: true |
#initial_price ⇒ Float?
An additional amount charged upon first purchase. Use only if a one time payment OR you want to charge an additional amount on top of the renewal price. Provided as a number in the specified currency. Eg: 10.43 for $10.43
235 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 235 optional :initial_price, Float, nil?: true |
#internal_notes ⇒ String?
A personal description or notes section for the business.
241 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 241 optional :internal_notes, String, nil?: true |
#legacy_payment_method_controls ⇒ Boolean?
Whether this plan uses legacy payment method controls
247 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 247 optional :legacy_payment_method_controls, WhopSDK::Internal::Type::Boolean, nil?: true |
#payment_method_configuration ⇒ WhopSDK::Models::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Plan::PaymentMethodConfiguration?
The explicit payment method configuration for the plan. If not provided, the platform or company’s defaults will apply.
254 255 256 257 258 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 254 optional :payment_method_configuration, -> { WhopSDK::InvoiceCreateParams::Body::CreateInvoiceInputWithProduct::Plan::PaymentMethodConfiguration }, nil?: true |
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to a product
264 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 264 optional :plan_type, enum: -> { WhopSDK::PlanType }, nil?: true |
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
270 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 270 optional :release_method, enum: -> { WhopSDK::ReleaseMethod }, nil?: true |
#renewal_price ⇒ Float?
The amount the customer is charged every billing period. Use only if a recurring payment. Provided as a number in the specified currency. Eg: 10.43 for $10.43
277 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 277 optional :renewal_price, Float, nil?: true |
#stock ⇒ Integer?
The number of units available for purchase.
283 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 283 optional :stock, Integer, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
289 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 289 optional :trial_period_days, Integer, nil?: true |
#unlimited_stock ⇒ Boolean?
When true, the plan has unlimited stock (stock field is ignored). When false, purchases are limited by the stock field.
296 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 296 optional :unlimited_stock, WhopSDK::Internal::Type::Boolean, nil?: true |
#visibility ⇒ Symbol, ...
Visibility of a resource
302 |
# File 'lib/whop_sdk/models/invoice_create_params.rb', line 302 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |