Class: WhopSDK::Models::InvoiceListItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::InvoiceListItem
- Defined in:
- lib/whop_sdk/models/invoice_list_item.rb
Defined Under Namespace
Classes: CurrentPlan, User
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date the invoice was created.
-
#current_plan ⇒ WhopSDK::Models::InvoiceListItem::CurrentPlan
The plan that the invoice was created for.
-
#due_date ⇒ Time?
The date the invoice is due.
-
#email_address ⇒ String?
The email address that the invoice was created for.
-
#fetch_invoice_token ⇒ String
A signed token that allows fetching the invoice data publically without being authenticated.
-
#id ⇒ String
The ID of the invoice.
-
#number ⇒ String
The number of the invoice.
-
#status ⇒ Symbol, WhopSDK::Models::InvoiceStatus
The status of the invoice.
-
#user ⇒ WhopSDK::Models::InvoiceListItem::User?
The user that the invoice was created for.
Instance Method Summary collapse
-
#initialize(id: , currency: , formatted_price: ) ⇒ Object
constructor
The plan that the invoice was created for.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , currency: , formatted_price: ) ⇒ Object
The plan that the invoice was created for.
|
|
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 61
|
Instance Attribute Details
#created_at ⇒ Time
The date the invoice was created.
16 |
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 16 required :created_at, Time |
#current_plan ⇒ WhopSDK::Models::InvoiceListItem::CurrentPlan
The plan that the invoice was created for.
22 |
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 22 required :current_plan, -> { WhopSDK::InvoiceListItem::CurrentPlan } |
#due_date ⇒ Time?
The date the invoice is due.
28 |
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 28 required :due_date, Time, nil?: true |
#email_address ⇒ String?
The email address that the invoice was created for.
34 |
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 34 required :email_address, String, nil?: true |
#fetch_invoice_token ⇒ String
A signed token that allows fetching the invoice data publically without being authenticated.
41 |
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 41 required :fetch_invoice_token, String |
#id ⇒ String
The ID of the invoice.
10 |
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 10 required :id, String |
#number ⇒ String
The number of the invoice.
47 |
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 47 required :number, String |
#status ⇒ Symbol, WhopSDK::Models::InvoiceStatus
The status of the invoice.
53 |
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 53 required :status, enum: -> { WhopSDK::InvoiceStatus } |
#user ⇒ WhopSDK::Models::InvoiceListItem::User?
The user that the invoice was created for.
59 |
# File 'lib/whop_sdk/models/invoice_list_item.rb', line 59 required :user, -> { WhopSDK::InvoiceListItem::User }, nil?: true |