Class: WhopSDK::Models::InvoiceListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/invoice_list_params.rb

Overview

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id: , after: nil, before: nil, collection_methods: nil, direction: nil, first: nil, last: nil, order: nil, product_ids: nil, statuses: nil, request_options: {}) ⇒ Object

Parameters:

  • company_id (String) (defaults to: )

    The ID of the company to list invoices for

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • collection_methods (Array<Symbol, WhopSDK::Models::CollectionMethod>, nil) (defaults to: nil)

    Filter invoices by their collection method

  • direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • order (Symbol, WhopSDK::Models::InvoiceListParams::Order, nil) (defaults to: nil)

    Which columns can be used to sort.

  • product_ids (Array<String>, nil) (defaults to: nil)

    Return only invoices created for these specific product ids

  • statuses (Array<Symbol, WhopSDK::Models::InvoiceStatus>, nil) (defaults to: nil)

    The statuses to filter the invoices by

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/invoice_list_params.rb', line 72

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 20

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 26

optional :before, String, nil?: true

#collection_methodsArray<Symbol, WhopSDK::Models::CollectionMethod>?

Filter invoices by their collection method

Returns:



32
33
34
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 32

optional :collection_methods,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::CollectionMethod] },
nil?: true

#company_idString

The ID of the company to list invoices for

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 14

required :company_id, String

#directionSymbol, ...

The direction of the sort.

Returns:



40
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 40

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


46
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 46

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


52
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 52

optional :last, Integer, nil?: true

#orderSymbol, ...

Which columns can be used to sort.



58
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 58

optional :order, enum: -> { WhopSDK::InvoiceListParams::Order }, nil?: true

#product_idsArray<String>?

Return only invoices created for these specific product ids

Returns:

  • (Array<String>, nil)


64
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 64

optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#statusesArray<Symbol, WhopSDK::Models::InvoiceStatus>?

The statuses to filter the invoices by

Returns:



70
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 70

optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::InvoiceStatus] }, nil?: true