Class: WhopSDK::Models::InvoiceListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/invoice_list_params.rb

Overview

Defined Under Namespace

Modules: Order Classes: Filters

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_pass_ids: nil, collection_methods: nil, statuses: nil) ⇒ Object

The filters to apply to the invoices

Parameters:

  • access_pass_ids (Array<String>, nil) (defaults to: nil)

    The access pass IDs to filter the invoices by

  • collection_methods (Array<Symbol, WhopSDK::Models::CollectionMethod>, nil) (defaults to: nil)

    The collection methods to filter the invoices by

  • statuses (Array<Symbol, WhopSDK::Models::InvoiceStatus>, nil) (defaults to: nil)

    The statuses to filter the invoices by



# File 'lib/whop_sdk/models/invoice_list_params.rb', line 98

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 20

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 26

optional :before, String, nil?: true

#company_idString

The ID of the company to list invoices for

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 14

required :company_id, String

#directionSymbol, ...

The direction of the sort.

Returns:



32
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 32

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#filtersWhopSDK::Models::InvoiceListParams::Filters?

The filters to apply to the invoices



38
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 38

optional :filters, -> { WhopSDK::InvoiceListParams::Filters }, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


44
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 44

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


50
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 50

optional :last, Integer, nil?: true

#orderSymbol, ...

Which columns can be used to sort.



56
# File 'lib/whop_sdk/models/invoice_list_params.rb', line 56

optional :order, enum: -> { WhopSDK::InvoiceListParams::Order }, nil?: true