Class: WhopSDK::Models::InvoicePastDueWebhookEvent

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/invoice_past_due_webhook_event.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , data: , timestamp: , api_version: :v1, type: :"invoice.past_due") ⇒ Object

Parameters:

  • id (String) (defaults to: )

    A unique ID for every single webhook request

  • data (WhopSDK::Models::Invoice) (defaults to: )

    A statement that defines an amount due by a customer.

  • timestamp (Time) (defaults to: )

    The timestamp in ISO 8601 format that the webhook was sent at on the server

  • api_version (Symbol, :v1) (defaults to: :v1)

    The API version for this webhook

  • type (Symbol, :"invoice.past_due") (defaults to: :"invoice.past_due")

    The webhook event type



# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 36

Instance Attribute Details

#api_versionSymbol, :v1

The API version for this webhook

Returns:

  • (Symbol, :v1)


16
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 16

required :api_version, const: :v1

#dataWhopSDK::Models::Invoice

A statement that defines an amount due by a customer.



22
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 22

required :data, -> { WhopSDK::Invoice }

#idString

A unique ID for every single webhook request

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 10

required :id, String

#timestampTime

The timestamp in ISO 8601 format that the webhook was sent at on the server

Returns:

  • (Time)


28
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 28

required :timestamp, Time

#typeSymbol, :"invoice.past_due"

The webhook event type

Returns:

  • (Symbol, :"invoice.past_due")


34
# File 'lib/whop_sdk/models/invoice_past_due_webhook_event.rb', line 34

required :type, const: :"invoice.past_due"