Class: WhopSDK::Models::InvoiceUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::InvoiceUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/invoice_update_params.rb
Overview
Defined Under Namespace
Classes: BillingAddress, LineItem, Plan
Instance Attribute Summary collapse
-
#automatically_finalizes_at ⇒ Time?
The date and time when the invoice will be automatically finalized.
-
#billing_address ⇒ WhopSDK::Models::InvoiceUpdateParams::BillingAddress?
Inline billing address to create or update a mailing address for this invoice.
-
#charge_buyer_fee ⇒ Boolean?
Whether to charge the customer a buyer fee on this invoice.
-
#collection_method ⇒ Symbol, ...
The method of collection for an invoice.
-
#customer_name ⇒ String?
The name of the customer.
-
#due_date ⇒ Time?
The date by which the invoice must be paid.
-
#email_address ⇒ String?
The email address of the customer.
- #id ⇒ String
-
#line_items ⇒ Array<WhopSDK::Models::InvoiceUpdateParams::LineItem>?
Line items that break down the invoice total.
-
#mailing_address_id ⇒ String?
The unique identifier of an existing mailing address to attach.
-
#member_id ⇒ String?
The unique identifier of a member to assign as the customer.
-
#payment_method_id ⇒ String?
The unique identifier of the payment method to charge.
-
#plan ⇒ WhopSDK::Models::InvoiceUpdateParams::Plan?
Updated plan attributes.
-
#subscription_billing_anchor_at ⇒ Time?
The date that defines when the subscription billing cycle should start.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(label:, unit_price:, quantity: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see LineItem for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(label:, unit_price:, quantity: nil) ⇒ Object
Some parameter documentations has been truncated, see LineItem for more details.
A single line item to include on the invoice, with a label, quantity, and unit price.
|
|
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 192
|
Instance Attribute Details
#automatically_finalizes_at ⇒ Time?
The date and time when the invoice will be automatically finalized. For charge_automatically, triggers an automatic charge. For send_invoice, sends the invoice email at the specified time.
21 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 21 optional :automatically_finalizes_at, Time, nil?: true |
#billing_address ⇒ WhopSDK::Models::InvoiceUpdateParams::BillingAddress?
Inline billing address to create or update a mailing address for this invoice.
27 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 27 optional :billing_address, -> { WhopSDK::InvoiceUpdateParams::BillingAddress }, nil?: true |
#charge_buyer_fee ⇒ Boolean?
Whether to charge the customer a buyer fee on this invoice.
33 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 33 optional :charge_buyer_fee, WhopSDK::Internal::Type::Boolean, nil?: true |
#collection_method ⇒ Symbol, ...
The method of collection for an invoice.
39 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 39 optional :collection_method, enum: -> { WhopSDK::CollectionMethod }, nil?: true |
#customer_name ⇒ String?
The name of the customer.
45 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 45 optional :customer_name, String, nil?: true |
#due_date ⇒ Time?
The date by which the invoice must be paid.
51 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 51 optional :due_date, Time, nil?: true |
#email_address ⇒ String?
The email address of the customer.
57 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 57 optional :email_address, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 13 required :id, String |
#line_items ⇒ Array<WhopSDK::Models::InvoiceUpdateParams::LineItem>?
Line items that break down the invoice total.
63 64 65 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 63 optional :line_items, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::InvoiceUpdateParams::LineItem] }, nil?: true |
#mailing_address_id ⇒ String?
The unique identifier of an existing mailing address to attach.
71 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 71 optional :mailing_address_id, String, nil?: true |
#member_id ⇒ String?
The unique identifier of a member to assign as the customer.
77 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 77 optional :member_id, String, nil?: true |
#payment_method_id ⇒ String?
The unique identifier of the payment method to charge.
83 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 83 optional :payment_method_id, String, nil?: true |
#plan ⇒ WhopSDK::Models::InvoiceUpdateParams::Plan?
Updated plan attributes.
89 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 89 optional :plan, -> { WhopSDK::InvoiceUpdateParams::Plan }, nil?: true |
#subscription_billing_anchor_at ⇒ Time?
The date that defines when the subscription billing cycle should start.
95 |
# File 'lib/whop_sdk/models/invoice_update_params.rb', line 95 optional :subscription_billing_anchor_at, Time, nil?: true |