Class: WhopSDK::Models::Lead
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Lead
- Defined in:
- lib/whop_sdk/models/lead.rb
Overview
Defined Under Namespace
Classes: Member, Product, User
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The datetime the lead was created.
-
#id ⇒ String
The unique identifier for the lead.
-
#member ⇒ WhopSDK::Models::Lead::Member?
The company member record if this lead has converted into a paying customer.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs attached to this lead.
-
#product ⇒ WhopSDK::Models::Lead::Product?
The product the lead expressed interest in.
-
#referrer ⇒ String?
The URL of the page that referred this lead to the company.
-
#updated_at ⇒ Time
The datetime the lead was last updated.
-
#user ⇒ WhopSDK::Models::Lead::User
The user account associated with this lead.
Instance Method Summary collapse
-
#initialize(id:, title:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Product for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, title:) ⇒ Object
Some parameter documentations has been truncated, see Product for more details.
The product the lead expressed interest in. Null if the lead is not associated with a specific product.
|
|
# File 'lib/whop_sdk/models/lead.rb', line 58
|
Instance Attribute Details
#created_at ⇒ Time
The datetime the lead was created.
17 |
# File 'lib/whop_sdk/models/lead.rb', line 17 required :created_at, Time |
#id ⇒ String
The unique identifier for the lead.
11 |
# File 'lib/whop_sdk/models/lead.rb', line 11 required :id, String |
#member ⇒ WhopSDK::Models::Lead::Member?
The company member record if this lead has converted into a paying customer. Null if the lead has not converted.
24 |
# File 'lib/whop_sdk/models/lead.rb', line 24 required :member, -> { WhopSDK::Lead::Member }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs attached to this lead. Null if no metadata was provided.
30 |
# File 'lib/whop_sdk/models/lead.rb', line 30 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#product ⇒ WhopSDK::Models::Lead::Product?
The product the lead expressed interest in. Null if the lead is not associated with a specific product.
37 |
# File 'lib/whop_sdk/models/lead.rb', line 37 required :product, -> { WhopSDK::Lead::Product }, nil?: true |
#referrer ⇒ String?
The URL of the page that referred this lead to the company. Null if no referrer was captured.
44 |
# File 'lib/whop_sdk/models/lead.rb', line 44 required :referrer, String, nil?: true |
#updated_at ⇒ Time
The datetime the lead was last updated.
50 |
# File 'lib/whop_sdk/models/lead.rb', line 50 required :updated_at, Time |
#user ⇒ WhopSDK::Models::Lead::User
The user account associated with this lead.
56 |
# File 'lib/whop_sdk/models/lead.rb', line 56 required :user, -> { WhopSDK::Lead::User } |