Class: WhopSDK::Models::LeadCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::LeadCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/lead_create_params.rb
Overview
Instance Attribute Summary collapse
-
#company_id ⇒ String
The unique identifier of the company to create the lead for, starting with ‘biz_’.
-
#metadata ⇒ Hash{Symbol=>Object}?
A JSON object of custom metadata to attach to the lead for tracking purposes.
-
#product_id ⇒ String?
The unique identifier of the product the lead is interested in, starting with ‘prod_’.
-
#referrer ⇒ String?
The referral URL that brought the lead to the company, such as ‘example.com/landing’.
-
#user_id ⇒ String?
The unique identifier of the user to record as the lead.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(company_id:, metadata: nil, product_id: nil, referrer: nil, user_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see LeadCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, metadata: nil, product_id: nil, referrer: nil, user_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::LeadCreateParams for more details.
‘biz_
|
|
# File 'lib/whop_sdk/models/lead_create_params.rb', line 44
|
Instance Attribute Details
#company_id ⇒ String
The unique identifier of the company to create the lead for, starting with ‘biz_’.
15 |
# File 'lib/whop_sdk/models/lead_create_params.rb', line 15 required :company_id, String |
#metadata ⇒ Hash{Symbol=>Object}?
A JSON object of custom metadata to attach to the lead for tracking purposes.
21 |
# File 'lib/whop_sdk/models/lead_create_params.rb', line 21 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#product_id ⇒ String?
The unique identifier of the product the lead is interested in, starting with ‘prod_’.
28 |
# File 'lib/whop_sdk/models/lead_create_params.rb', line 28 optional :product_id, String, nil?: true |
#referrer ⇒ String?
The referral URL that brought the lead to the company, such as ‘example.com/landing’.
35 |
# File 'lib/whop_sdk/models/lead_create_params.rb', line 35 optional :referrer, String, nil?: true |
#user_id ⇒ String?
The unique identifier of the user to record as the lead. If authenticated as a user, that user is used automatically.
42 |
# File 'lib/whop_sdk/models/lead_create_params.rb', line 42 optional :user_id, String, nil?: true |