Class: WhopSDK::Models::LeadUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::LeadUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/lead_update_params.rb
Overview
Instance Attribute Summary collapse
- #id ⇒ String
-
#metadata ⇒ Hash{Symbol=>Object}?
A JSON object of custom metadata to set on the lead, replacing any existing metadata.
-
#referrer ⇒ String?
The updated referral URL for the lead, such as ‘example.com/landing’.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, metadata: nil, referrer: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see LeadUpdateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, metadata: nil, referrer: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::LeadUpdateParams for more details.
|
|
# File 'lib/whop_sdk/models/lead_update_params.rb', line 28
|
Instance Attribute Details
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/lead_update_params.rb', line 13 required :id, String |
#metadata ⇒ Hash{Symbol=>Object}?
A JSON object of custom metadata to set on the lead, replacing any existing metadata.
20 |
# File 'lib/whop_sdk/models/lead_update_params.rb', line 20 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#referrer ⇒ String?
The updated referral URL for the lead, such as ‘example.com/landing’.
26 |
# File 'lib/whop_sdk/models/lead_update_params.rb', line 26 optional :referrer, String, nil?: true |