Class: WhopSDK::Models::Lesson::VideoAsset
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Lesson::VideoAsset
- Defined in:
- lib/whop_sdk/models/lesson.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#asset_id ⇒ String?
The Mux-provided ID of the asset.
-
#audio_only ⇒ Boolean
Whether this asset contains only audio.
-
#created_at ⇒ Time
The datetime the mux asset was created.
-
#duration_seconds ⇒ Integer?
The duration of the video in seconds.
-
#finished_uploading_at ⇒ Time?
The time at which the video finished uploading.
-
#id ⇒ String
The unique identifier for the mux asset.
-
#playback_id ⇒ String?
The public playback ID of the Mux asset.
-
#signed_playback_id ⇒ String?
The signed playback ID of the Mux asset.
-
#signed_storyboard_playback_token ⇒ String?
The signed storyboard playback token of the Mux asset.
-
#signed_thumbnail_playback_token ⇒ String?
The signed thumbnail playback token of the Mux asset.
-
#signed_video_playback_token ⇒ String?
The signed video playback token of the Mux asset.
-
#status ⇒ Symbol, WhopSDK::Models::Lesson::VideoAsset::Status
The status of the Mux asset.
-
#updated_at ⇒ Time
The datetime the mux asset was last updated.
Instance Method Summary collapse
-
#initialize(id:, asset_id:, audio_only:, created_at:, duration_seconds:, finished_uploading_at:, playback_id:, signed_playback_id:, signed_storyboard_playback_token:, signed_thumbnail_playback_token:, signed_video_playback_token:, status:, updated_at:) ⇒ Object
constructor
The Mux video asset for video-type lessons, used for streaming playback.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, asset_id:, audio_only:, created_at:, duration_seconds:, finished_uploading_at:, playback_id:, signed_playback_id:, signed_storyboard_playback_token:, signed_thumbnail_playback_token:, signed_video_playback_token:, status:, updated_at:) ⇒ Object
The Mux video asset for video-type lessons, used for streaming playback. Null if this lesson has no hosted video.
|
|
# File 'lib/whop_sdk/models/lesson.rb', line 495
|
Instance Attribute Details
#asset_id ⇒ String?
The Mux-provided ID of the asset
427 |
# File 'lib/whop_sdk/models/lesson.rb', line 427 required :asset_id, String, nil?: true |
#audio_only ⇒ Boolean
Whether this asset contains only audio
433 |
# File 'lib/whop_sdk/models/lesson.rb', line 433 required :audio_only, WhopSDK::Internal::Type::Boolean |
#created_at ⇒ Time
The datetime the mux asset was created.
439 |
# File 'lib/whop_sdk/models/lesson.rb', line 439 required :created_at, Time |
#duration_seconds ⇒ Integer?
The duration of the video in seconds
445 |
# File 'lib/whop_sdk/models/lesson.rb', line 445 required :duration_seconds, Integer, nil?: true |
#finished_uploading_at ⇒ Time?
The time at which the video finished uploading
451 |
# File 'lib/whop_sdk/models/lesson.rb', line 451 required :finished_uploading_at, Time, nil?: true |
#id ⇒ String
The unique identifier for the mux asset.
421 |
# File 'lib/whop_sdk/models/lesson.rb', line 421 required :id, String |
#playback_id ⇒ String?
The public playback ID of the Mux asset
457 |
# File 'lib/whop_sdk/models/lesson.rb', line 457 required :playback_id, String, nil?: true |
#signed_playback_id ⇒ String?
The signed playback ID of the Mux asset
463 |
# File 'lib/whop_sdk/models/lesson.rb', line 463 required :signed_playback_id, String, nil?: true |
#signed_storyboard_playback_token ⇒ String?
The signed storyboard playback token of the Mux asset
469 |
# File 'lib/whop_sdk/models/lesson.rb', line 469 required :signed_storyboard_playback_token, String, nil?: true |
#signed_thumbnail_playback_token ⇒ String?
The signed thumbnail playback token of the Mux asset
475 |
# File 'lib/whop_sdk/models/lesson.rb', line 475 required :signed_thumbnail_playback_token, String, nil?: true |
#signed_video_playback_token ⇒ String?
The signed video playback token of the Mux asset
481 |
# File 'lib/whop_sdk/models/lesson.rb', line 481 required :signed_video_playback_token, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::Lesson::VideoAsset::Status
The status of the Mux asset
487 |
# File 'lib/whop_sdk/models/lesson.rb', line 487 required :status, enum: -> { WhopSDK::Lesson::VideoAsset::Status } |
#updated_at ⇒ Time
The datetime the mux asset was last updated.
493 |
# File 'lib/whop_sdk/models/lesson.rb', line 493 required :updated_at, Time |