Class: WhopSDK::Models::Lesson::VideoAsset

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/lesson.rb

Overview

See Also:

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , asset_id: , audio_only: , created_at: , duration_seconds: , finished_uploading_at: , playback_id: , signed_playback_id: , signed_storyboard_playback_token: , signed_thumbnail_playback_token: , signed_video_playback_token: , status: , updated_at: ) ⇒ Object

The associated Mux asset for video lessons

Parameters:

  • id (String) (defaults to: )

    The ID of the Mux asset

  • asset_id (String, nil) (defaults to: )

    The Mux-provided ID of the asset

  • audio_only (Boolean) (defaults to: )

    Whether this asset contains only audio

  • created_at (Time) (defaults to: )

    The time at which the Mux asset was created

  • duration_seconds (Integer, nil) (defaults to: )

    The duration of the video in seconds

  • finished_uploading_at (Time, nil) (defaults to: )

    The time at which the video finished uploading

  • playback_id (String, nil) (defaults to: )

    The public playback ID of the Mux asset

  • signed_playback_id (String, nil) (defaults to: )

    The signed playback ID of the Mux asset

  • signed_storyboard_playback_token (String, nil) (defaults to: )

    The signed storyboard playback token of the Mux asset

  • signed_thumbnail_playback_token (String, nil) (defaults to: )

    The signed thumbnail playback token of the Mux asset

  • signed_video_playback_token (String, nil) (defaults to: )

    The signed video playback token of the Mux asset

  • status (Symbol, WhopSDK::Models::Lesson::VideoAsset::Status) (defaults to: )

    The status of the Mux asset

  • updated_at (Time) (defaults to: )

    The time at which the Mux asset was last updated



# File 'lib/whop_sdk/models/lesson.rb', line 472

Instance Attribute Details

#asset_idString?

The Mux-provided ID of the asset

Returns:

  • (String, nil)


404
# File 'lib/whop_sdk/models/lesson.rb', line 404

required :asset_id, String, nil?: true

#audio_onlyBoolean

Whether this asset contains only audio

Returns:

  • (Boolean)


410
# File 'lib/whop_sdk/models/lesson.rb', line 410

required :audio_only, WhopSDK::Internal::Type::Boolean

#created_atTime

The time at which the Mux asset was created

Returns:

  • (Time)


416
# File 'lib/whop_sdk/models/lesson.rb', line 416

required :created_at, Time

#duration_secondsInteger?

The duration of the video in seconds

Returns:

  • (Integer, nil)


422
# File 'lib/whop_sdk/models/lesson.rb', line 422

required :duration_seconds, Integer, nil?: true

#finished_uploading_atTime?

The time at which the video finished uploading

Returns:

  • (Time, nil)


428
# File 'lib/whop_sdk/models/lesson.rb', line 428

required :finished_uploading_at, Time, nil?: true

#idString

The ID of the Mux asset

Returns:

  • (String)


398
# File 'lib/whop_sdk/models/lesson.rb', line 398

required :id, String

#playback_idString?

The public playback ID of the Mux asset

Returns:

  • (String, nil)


434
# File 'lib/whop_sdk/models/lesson.rb', line 434

required :playback_id, String, nil?: true

#signed_playback_idString?

The signed playback ID of the Mux asset

Returns:

  • (String, nil)


440
# File 'lib/whop_sdk/models/lesson.rb', line 440

required :signed_playback_id, String, nil?: true

#signed_storyboard_playback_tokenString?

The signed storyboard playback token of the Mux asset

Returns:

  • (String, nil)


446
# File 'lib/whop_sdk/models/lesson.rb', line 446

required :signed_storyboard_playback_token, String, nil?: true

#signed_thumbnail_playback_tokenString?

The signed thumbnail playback token of the Mux asset

Returns:

  • (String, nil)


452
# File 'lib/whop_sdk/models/lesson.rb', line 452

required :signed_thumbnail_playback_token, String, nil?: true

#signed_video_playback_tokenString?

The signed video playback token of the Mux asset

Returns:

  • (String, nil)


458
# File 'lib/whop_sdk/models/lesson.rb', line 458

required :signed_video_playback_token, String, nil?: true

#statusSymbol, WhopSDK::Models::Lesson::VideoAsset::Status

The status of the Mux asset



464
# File 'lib/whop_sdk/models/lesson.rb', line 464

required :status, enum: -> { WhopSDK::Lesson::VideoAsset::Status }

#updated_atTime

The time at which the Mux asset was last updated

Returns:

  • (Time)


470
# File 'lib/whop_sdk/models/lesson.rb', line 470

required :updated_at, Time