Class: WhopSDK::Models::Lesson::VideoAsset
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Lesson::VideoAsset
- Defined in:
- lib/whop_sdk/models/lesson.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#asset_id ⇒ String?
The Mux-provided ID of the asset.
-
#audio_only ⇒ Boolean
Whether this asset contains only audio.
-
#created_at ⇒ Time
The time at which the Mux asset was created.
-
#duration_seconds ⇒ Integer?
The duration of the video in seconds.
-
#finished_uploading_at ⇒ Time?
The time at which the video finished uploading.
-
#id ⇒ String
The ID of the Mux asset.
-
#playback_id ⇒ String?
The public playback ID of the Mux asset.
-
#signed_playback_id ⇒ String?
The signed playback ID of the Mux asset.
-
#signed_storyboard_playback_token ⇒ String?
The signed storyboard playback token of the Mux asset.
-
#signed_thumbnail_playback_token ⇒ String?
The signed thumbnail playback token of the Mux asset.
-
#signed_video_playback_token ⇒ String?
The signed video playback token of the Mux asset.
-
#status ⇒ Symbol, WhopSDK::Models::Lesson::VideoAsset::Status
The status of the Mux asset.
-
#updated_at ⇒ Time
The time at which the Mux asset was last updated.
Instance Method Summary collapse
-
#initialize(id: , asset_id: , audio_only: , created_at: , duration_seconds: , finished_uploading_at: , playback_id: , signed_playback_id: , signed_storyboard_playback_token: , signed_thumbnail_playback_token: , signed_video_playback_token: , status: , updated_at: ) ⇒ Object
constructor
The associated Mux asset for video lessons.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , asset_id: , audio_only: , created_at: , duration_seconds: , finished_uploading_at: , playback_id: , signed_playback_id: , signed_storyboard_playback_token: , signed_thumbnail_playback_token: , signed_video_playback_token: , status: , updated_at: ) ⇒ Object
The associated Mux asset for video lessons
|
|
# File 'lib/whop_sdk/models/lesson.rb', line 472
|
Instance Attribute Details
#asset_id ⇒ String?
The Mux-provided ID of the asset
404 |
# File 'lib/whop_sdk/models/lesson.rb', line 404 required :asset_id, String, nil?: true |
#audio_only ⇒ Boolean
Whether this asset contains only audio
410 |
# File 'lib/whop_sdk/models/lesson.rb', line 410 required :audio_only, WhopSDK::Internal::Type::Boolean |
#created_at ⇒ Time
The time at which the Mux asset was created
416 |
# File 'lib/whop_sdk/models/lesson.rb', line 416 required :created_at, Time |
#duration_seconds ⇒ Integer?
The duration of the video in seconds
422 |
# File 'lib/whop_sdk/models/lesson.rb', line 422 required :duration_seconds, Integer, nil?: true |
#finished_uploading_at ⇒ Time?
The time at which the video finished uploading
428 |
# File 'lib/whop_sdk/models/lesson.rb', line 428 required :finished_uploading_at, Time, nil?: true |
#id ⇒ String
The ID of the Mux asset
398 |
# File 'lib/whop_sdk/models/lesson.rb', line 398 required :id, String |
#playback_id ⇒ String?
The public playback ID of the Mux asset
434 |
# File 'lib/whop_sdk/models/lesson.rb', line 434 required :playback_id, String, nil?: true |
#signed_playback_id ⇒ String?
The signed playback ID of the Mux asset
440 |
# File 'lib/whop_sdk/models/lesson.rb', line 440 required :signed_playback_id, String, nil?: true |
#signed_storyboard_playback_token ⇒ String?
The signed storyboard playback token of the Mux asset
446 |
# File 'lib/whop_sdk/models/lesson.rb', line 446 required :signed_storyboard_playback_token, String, nil?: true |
#signed_thumbnail_playback_token ⇒ String?
The signed thumbnail playback token of the Mux asset
452 |
# File 'lib/whop_sdk/models/lesson.rb', line 452 required :signed_thumbnail_playback_token, String, nil?: true |
#signed_video_playback_token ⇒ String?
The signed video playback token of the Mux asset
458 |
# File 'lib/whop_sdk/models/lesson.rb', line 458 required :signed_video_playback_token, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::Lesson::VideoAsset::Status
The status of the Mux asset
464 |
# File 'lib/whop_sdk/models/lesson.rb', line 464 required :status, enum: -> { WhopSDK::Lesson::VideoAsset::Status } |
#updated_at ⇒ Time
The time at which the Mux asset was last updated
470 |
# File 'lib/whop_sdk/models/lesson.rb', line 470 required :updated_at, Time |