Class: WhopSDK::Models::MemberListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/member_list_params.rb

Overview

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id: , access_level: nil, after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, most_recent_actions: nil, order: nil, plan_ids: nil, product_ids: nil, promo_code_ids: nil, query: nil, statuses: nil, user_ids: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::MemberListParams for more details.

Parameters:

  • company_id (String) (defaults to: )

    The ID of the company to list members for

  • access_level (Symbol, WhopSDK::Models::AccessLevel, nil) (defaults to: nil)

    The access level a given user (or company) has to a product or company.

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • created_after (Time, nil) (defaults to: nil)

    The minimum creation date to filter by

  • created_before (Time, nil) (defaults to: nil)

    The maximum creation date to filter by

  • direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • most_recent_actions (Array<Symbol, WhopSDK::Models::MemberMostRecentActions>, nil) (defaults to: nil)

    The most recent actions to filter the members by

  • order (Symbol, WhopSDK::Models::MemberListParams::Order, nil) (defaults to: nil)

    Which columns can be used to sort.

  • plan_ids (Array<String>, nil) (defaults to: nil)

    The plan IDs to filter the members by

  • product_ids (Array<String>, nil) (defaults to: nil)

    The product IDs to filter the members by

  • promo_code_ids (Array<String>, nil) (defaults to: nil)

    The promo code IDs to filter the members by

  • query (String, nil) (defaults to: nil)

    The name, username, or email to filter the members by. The email filter will onl

  • statuses (Array<Symbol, WhopSDK::Models::MemberStatuses>, nil) (defaults to: nil)

    The statuses to filter the members by

  • user_ids (Array<String>, nil) (defaults to: nil)

    The user IDs to filter the members by

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/member_list_params.rb', line 115

Instance Attribute Details

#access_levelSymbol, ...

The access level a given user (or company) has to a product or company.

Returns:



20
# File 'lib/whop_sdk/models/member_list_params.rb', line 20

optional :access_level, enum: -> { WhopSDK::AccessLevel }, nil?: true

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/member_list_params.rb', line 26

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/member_list_params.rb', line 32

optional :before, String, nil?: true

#company_idString

The ID of the company to list members for

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/member_list_params.rb', line 14

required :company_id, String

#created_afterTime?

The minimum creation date to filter by

Returns:

  • (Time, nil)


38
# File 'lib/whop_sdk/models/member_list_params.rb', line 38

optional :created_after, Time, nil?: true

#created_beforeTime?

The maximum creation date to filter by

Returns:

  • (Time, nil)


44
# File 'lib/whop_sdk/models/member_list_params.rb', line 44

optional :created_before, Time, nil?: true

#directionSymbol, ...

The direction of the sort.

Returns:



50
# File 'lib/whop_sdk/models/member_list_params.rb', line 50

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


56
# File 'lib/whop_sdk/models/member_list_params.rb', line 56

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


62
# File 'lib/whop_sdk/models/member_list_params.rb', line 62

optional :last, Integer, nil?: true

#most_recent_actionsArray<Symbol, WhopSDK::Models::MemberMostRecentActions>?

The most recent actions to filter the members by

Returns:



68
69
70
# File 'lib/whop_sdk/models/member_list_params.rb', line 68

optional :most_recent_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MemberMostRecentActions] },
nil?: true

#orderSymbol, ...

Which columns can be used to sort.



76
# File 'lib/whop_sdk/models/member_list_params.rb', line 76

optional :order, enum: -> { WhopSDK::MemberListParams::Order }, nil?: true

#plan_idsArray<String>?

The plan IDs to filter the members by

Returns:

  • (Array<String>, nil)


82
# File 'lib/whop_sdk/models/member_list_params.rb', line 82

optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#product_idsArray<String>?

The product IDs to filter the members by

Returns:

  • (Array<String>, nil)


88
# File 'lib/whop_sdk/models/member_list_params.rb', line 88

optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#promo_code_idsArray<String>?

The promo code IDs to filter the members by

Returns:

  • (Array<String>, nil)


94
# File 'lib/whop_sdk/models/member_list_params.rb', line 94

optional :promo_code_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#queryString?

The name, username, or email to filter the members by. The email filter will only apply if the current actor has the ‘member:email:read` permission.

Returns:

  • (String, nil)


101
# File 'lib/whop_sdk/models/member_list_params.rb', line 101

optional :query, String, nil?: true

#statusesArray<Symbol, WhopSDK::Models::MemberStatuses>?

The statuses to filter the members by

Returns:



107
# File 'lib/whop_sdk/models/member_list_params.rb', line 107

optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MemberStatuses] }, nil?: true

#user_idsArray<String>?

The user IDs to filter the members by

Returns:

  • (Array<String>, nil)


113
# File 'lib/whop_sdk/models/member_list_params.rb', line 113

optional :user_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true