Class: WhopSDK::Models::MemberListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MemberListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/member_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#access_level ⇒ Symbol, ...
The access level a given user (or company) has to an access pass or company.
-
#access_pass_ids ⇒ Array<String>?
The access pass IDs to filter the members by.
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#company_id ⇒ String
The ID of the company to list members for.
-
#created_after ⇒ Time?
The minimum creation date to filter by.
-
#created_before ⇒ Time?
The maximum creation date to filter by.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#most_recent_actions ⇒ Array<Symbol, WhopSDK::Models::MemberMostRecentActions>?
The most recent actions to filter the members by.
-
#order ⇒ Symbol, ...
Which columns can be used to sort.
-
#plan_ids ⇒ Array<String>?
The plan IDs to filter the members by.
-
#promo_code_ids ⇒ Array<String>?
The promo code IDs to filter the members by.
-
#query ⇒ String?
The name, username, or email to filter the members by.
-
#statuses ⇒ Array<Symbol, WhopSDK::Models::MemberStatuses>?
The statuses to filter the members by.
-
#user_ids ⇒ Array<String>?
The user IDs to filter the members by.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(company_id: , access_level: nil, access_pass_ids: nil, after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, most_recent_actions: nil, order: nil, plan_ids: nil, promo_code_ids: nil, query: nil, statuses: nil, user_ids: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see MemberListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id: , access_level: nil, access_pass_ids: nil, after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, most_recent_actions: nil, order: nil, plan_ids: nil, promo_code_ids: nil, query: nil, statuses: nil, user_ids: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::MemberListParams for more details.
|
|
# File 'lib/whop_sdk/models/member_list_params.rb', line 115
|
Instance Attribute Details
#access_level ⇒ Symbol, ...
The access level a given user (or company) has to an access pass or company.
20 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 20 optional :access_level, enum: -> { WhopSDK::AccessLevel }, nil?: true |
#access_pass_ids ⇒ Array<String>?
The access pass IDs to filter the members by
26 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 26 optional :access_pass_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
32 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 32 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
38 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 38 optional :before, String, nil?: true |
#company_id ⇒ String
The ID of the company to list members for
14 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 14 required :company_id, String |
#created_after ⇒ Time?
The minimum creation date to filter by
44 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 44 optional :created_after, Time, nil?: true |
#created_before ⇒ Time?
The maximum creation date to filter by
50 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 50 optional :created_before, Time, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
56 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 56 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
62 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 62 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
68 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 68 optional :last, Integer, nil?: true |
#most_recent_actions ⇒ Array<Symbol, WhopSDK::Models::MemberMostRecentActions>?
The most recent actions to filter the members by
74 75 76 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 74 optional :most_recent_actions, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MemberMostRecentActions] }, nil?: true |
#order ⇒ Symbol, ...
Which columns can be used to sort.
82 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 82 optional :order, enum: -> { WhopSDK::MemberListParams::Order }, nil?: true |
#plan_ids ⇒ Array<String>?
The plan IDs to filter the members by
88 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 88 optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#promo_code_ids ⇒ Array<String>?
The promo code IDs to filter the members by
94 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 94 optional :promo_code_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#query ⇒ String?
The name, username, or email to filter the members by. The email filter will only apply if the current actor has the ‘member:email:read` permission.
101 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 101 optional :query, String, nil?: true |
#statuses ⇒ Array<Symbol, WhopSDK::Models::MemberStatuses>?
The statuses to filter the members by
107 |
# File 'lib/whop_sdk/models/member_list_params.rb', line 107 optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MemberStatuses] }, nil?: true |