Class: WhopSDK::Models::MemberListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MemberListResponse
- Defined in:
- lib/whop_sdk/models/member_list_response.rb
Overview
Defined Under Namespace
Classes: User
Instance Attribute Summary collapse
-
#access_level ⇒ Symbol, WhopSDK::Models::AccessLevel
The access level of the product member.
-
#created_at ⇒ Time
When the member was created.
-
#id ⇒ String
The ID of the member.
-
#joined_at ⇒ Time
When the member joined the company.
-
#most_recent_action ⇒ Symbol, ...
The different most recent actions a member can have.
-
#most_recent_action_at ⇒ Time?
The time for the most recent action, if applicable.
-
#phone ⇒ String?
The phone number for the member, if available.
-
#status ⇒ Symbol, WhopSDK::Models::MemberStatuses
The status of the member.
-
#updated_at ⇒ Time
The timestamp of when this member was last updated.
-
#usd_total_spent ⇒ Float
How much money this customer has spent on the company’s products and plans.
-
#user ⇒ WhopSDK::Models::MemberListResponse::User?
The user for this member, if any.
Instance Method Summary collapse
-
#initialize(id: , access_level: , created_at: , joined_at: , most_recent_action: , most_recent_action_at: , phone: , status: , updated_at: , usd_total_spent: , user: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see MemberListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , access_level: , created_at: , joined_at: , most_recent_action: , most_recent_action_at: , phone: , status: , updated_at: , usd_total_spent: , user: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::MemberListResponse for more details.
An object representing a connection between a creator and a user/company_buyer. This type should only be made visible to the user/company_buyer who is a part of the connection.
|
|
# File 'lib/whop_sdk/models/member_list_response.rb', line 76
|
Instance Attribute Details
#access_level ⇒ Symbol, WhopSDK::Models::AccessLevel
The access level of the product member. If its admin, the member is an authorized user of the company. If its customer, the member has a valid membership to any product on the company. If its no_access, the member does not have access to the product.
20 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 20 required :access_level, enum: -> { WhopSDK::AccessLevel } |
#created_at ⇒ Time
When the member was created
26 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 26 required :created_at, Time |
#id ⇒ String
The ID of the member
11 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 11 required :id, String |
#joined_at ⇒ Time
When the member joined the company
32 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 32 required :joined_at, Time |
#most_recent_action ⇒ Symbol, ...
The different most recent actions a member can have.
38 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 38 required :most_recent_action, enum: -> { WhopSDK::MemberMostRecentActions }, nil?: true |
#most_recent_action_at ⇒ Time?
The time for the most recent action, if applicable.
44 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 44 required :most_recent_action_at, Time, nil?: true |
#phone ⇒ String?
The phone number for the member, if available.
50 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 50 required :phone, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::MemberStatuses
The status of the member
56 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 56 required :status, enum: -> { WhopSDK::MemberStatuses } |
#updated_at ⇒ Time
The timestamp of when this member was last updated
62 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 62 required :updated_at, Time |
#usd_total_spent ⇒ Float
How much money this customer has spent on the company’s products and plans
68 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 68 required :usd_total_spent, Float |
#user ⇒ WhopSDK::Models::MemberListResponse::User?
The user for this member, if any.
74 |
# File 'lib/whop_sdk/models/member_list_response.rb', line 74 required :user, -> { WhopSDK::Models::MemberListResponse::User }, nil?: true |