Class: WhopSDK::Models::MemberRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/member_retrieve_response.rb

Overview

Defined Under Namespace

Classes: Company, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, route:, title:) ⇒ Object

The company for the member.

Parameters:

  • id (String)

    The unique identifier for the company.

  • route (String)

    The slug/route of the company on the Whop site.

  • title (String)

    The written name of the company.



# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 88

Instance Attribute Details

#access_levelSymbol, WhopSDK::Models::AccessLevel

The access level of the product member. If its admin, the member is an authorized user of the company. If its customer, the member has a valid membership to any product on the company. If its no_access, the member does not have access to the product.

Returns:



20
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 20

required :access_level, enum: -> { WhopSDK::AccessLevel }

#companyWhopSDK::Models::MemberRetrieveResponse::Company

The company for the member.



26
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 26

required :company, -> { WhopSDK::Models::MemberRetrieveResponse::Company }

#company_token_balanceFloat

The member’s token balance for this company

Returns:

  • (Float)


32
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 32

required :company_token_balance, Float

#created_atTime

The datetime the company member was created.

Returns:

  • (Time)


38
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 38

required :created_at, Time

#idString

The unique identifier for the company member.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 11

required :id, String

#joined_atTime

When the member joined the company

Returns:

  • (Time)


44
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 44

required :joined_at, Time

#most_recent_actionSymbol, ...

The different most recent actions a member can have.



50
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 50

required :most_recent_action, enum: -> { WhopSDK::MemberMostRecentActions }, nil?: true

#most_recent_action_atTime?

The time for the most recent action, if applicable.

Returns:

  • (Time, nil)


56
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 56

required :most_recent_action_at, Time, nil?: true

#phoneString?

The phone number for the member, if available.

Returns:

  • (String, nil)


62
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 62

required :phone, String, nil?: true

#statusSymbol, WhopSDK::Models::MemberStatuses

The status of the member

Returns:



68
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 68

required :status, enum: -> { WhopSDK::MemberStatuses }

#updated_atTime

The datetime the company member was last updated.

Returns:

  • (Time)


74
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 74

required :updated_at, Time

#usd_total_spentFloat

How much money this customer has spent on the company’s products and plans

Returns:

  • (Float)


80
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 80

required :usd_total_spent, Float

#userWhopSDK::Models::MemberRetrieveResponse::User?

The user for this member, if any.



86
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 86

required :user, -> { WhopSDK::Models::MemberRetrieveResponse::User }, nil?: true