Class: WhopSDK::Models::MemberRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MemberRetrieveResponse
- Defined in:
- lib/whop_sdk/models/member_retrieve_response.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#access_level ⇒ Symbol, WhopSDK::Models::AccessLevel
The access level of the product member.
-
#company ⇒ WhopSDK::Models::MemberRetrieveResponse::Company
The company for the member.
-
#created_at ⇒ Time
When the member was created.
-
#id ⇒ String
The ID of the member.
-
#joined_at ⇒ Time
When the member joined the company.
-
#most_recent_action ⇒ Symbol, ...
The different most recent actions a member can have.
-
#most_recent_action_at ⇒ Time?
The time for the most recent action, if applicable.
-
#phone ⇒ String?
The phone number for the member, if available.
-
#status ⇒ Symbol, WhopSDK::Models::MemberStatuses
The status of the member.
-
#updated_at ⇒ Time
The timestamp of when this member was last updated.
-
#usd_total_spent ⇒ Float
How much money this customer has spent on the company’s products and plans.
-
#user ⇒ WhopSDK::Models::MemberRetrieveResponse::User?
The user for this member, if any.
Instance Method Summary collapse
-
#initialize(id: , route: , title: ) ⇒ Object
constructor
The company for the member.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , route: , title: ) ⇒ Object
The company for the member.
|
|
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 82
|
Instance Attribute Details
#access_level ⇒ Symbol, WhopSDK::Models::AccessLevel
The access level of the product member. If its admin, the member is an authorized user of the company. If its customer, the member has a valid membership to any product on the company. If its no_access, the member does not have access to the product.
20 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 20 required :access_level, enum: -> { WhopSDK::AccessLevel } |
#company ⇒ WhopSDK::Models::MemberRetrieveResponse::Company
The company for the member.
26 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 26 required :company, -> { WhopSDK::Models::MemberRetrieveResponse::Company } |
#created_at ⇒ Time
When the member was created
32 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 32 required :created_at, Time |
#id ⇒ String
The ID of the member
11 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 11 required :id, String |
#joined_at ⇒ Time
When the member joined the company
38 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 38 required :joined_at, Time |
#most_recent_action ⇒ Symbol, ...
The different most recent actions a member can have.
44 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 44 required :most_recent_action, enum: -> { WhopSDK::MemberMostRecentActions }, nil?: true |
#most_recent_action_at ⇒ Time?
The time for the most recent action, if applicable.
50 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 50 required :most_recent_action_at, Time, nil?: true |
#phone ⇒ String?
The phone number for the member, if available.
56 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 56 required :phone, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::MemberStatuses
The status of the member
62 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 62 required :status, enum: -> { WhopSDK::MemberStatuses } |
#updated_at ⇒ Time
The timestamp of when this member was last updated
68 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 68 required :updated_at, Time |
#usd_total_spent ⇒ Float
How much money this customer has spent on the company’s products and plans
74 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 74 required :usd_total_spent, Float |
#user ⇒ WhopSDK::Models::MemberRetrieveResponse::User?
The user for this member, if any.
80 |
# File 'lib/whop_sdk/models/member_retrieve_response.rb', line 80 required :user, -> { WhopSDK::Models::MemberRetrieveResponse::User }, nil?: true |