Class: WhopSDK::Models::MembershipListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/membership_list_params.rb

Overview

Defined Under Namespace

Modules: CancelOption, Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(after: nil, before: nil, cancel_options: nil, company_id: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, plan_ids: nil, product_ids: nil, promo_code_ids: nil, statuses: nil, user_ids: nil, request_options: {}) ⇒ Object

Parameters:

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • cancel_options (Array<Symbol, WhopSDK::Models::MembershipListParams::CancelOption>, nil) (defaults to: nil)

    The cancel options to filter the memberships by

  • company_id (String, nil) (defaults to: nil)

    The ID of the company to list memberships for

  • created_after (Time, nil) (defaults to: nil)

    The minimum creation date to filter by

  • created_before (Time, nil) (defaults to: nil)

    The maximum creation date to filter by

  • direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • order (Symbol, WhopSDK::Models::MembershipListParams::Order, nil) (defaults to: nil)

    Which columns can be used to sort.

  • plan_ids (Array<String>, nil) (defaults to: nil)

    The plan IDs to filter the memberships by

  • product_ids (Array<String>, nil) (defaults to: nil)

    The product IDs to filter the memberships by

  • promo_code_ids (Array<String>, nil) (defaults to: nil)

    The promo code IDs to filter the memberships by

  • statuses (Array<Symbol, WhopSDK::Models::MembershipStatus>, nil) (defaults to: nil)

    The membership status to filter the memberships by

  • user_ids (Array<String>, nil) (defaults to: nil)

    Only return memberships from these whop user ids

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/membership_list_params.rb', line 102

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


14
# File 'lib/whop_sdk/models/membership_list_params.rb', line 14

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/membership_list_params.rb', line 20

optional :before, String, nil?: true

#cancel_optionsArray<Symbol, WhopSDK::Models::MembershipListParams::CancelOption>?

The cancel options to filter the memberships by



26
27
28
# File 'lib/whop_sdk/models/membership_list_params.rb', line 26

optional :cancel_options,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MembershipListParams::CancelOption] },
nil?: true

#company_idString?

The ID of the company to list memberships for

Returns:

  • (String, nil)


34
# File 'lib/whop_sdk/models/membership_list_params.rb', line 34

optional :company_id, String, nil?: true

#created_afterTime?

The minimum creation date to filter by

Returns:

  • (Time, nil)


40
# File 'lib/whop_sdk/models/membership_list_params.rb', line 40

optional :created_after, Time, nil?: true

#created_beforeTime?

The maximum creation date to filter by

Returns:

  • (Time, nil)


46
# File 'lib/whop_sdk/models/membership_list_params.rb', line 46

optional :created_before, Time, nil?: true

#directionSymbol, ...

The direction of the sort.

Returns:



52
# File 'lib/whop_sdk/models/membership_list_params.rb', line 52

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


58
# File 'lib/whop_sdk/models/membership_list_params.rb', line 58

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


64
# File 'lib/whop_sdk/models/membership_list_params.rb', line 64

optional :last, Integer, nil?: true

#orderSymbol, ...

Which columns can be used to sort.



70
# File 'lib/whop_sdk/models/membership_list_params.rb', line 70

optional :order, enum: -> { WhopSDK::MembershipListParams::Order }, nil?: true

#plan_idsArray<String>?

The plan IDs to filter the memberships by

Returns:

  • (Array<String>, nil)


76
# File 'lib/whop_sdk/models/membership_list_params.rb', line 76

optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#product_idsArray<String>?

The product IDs to filter the memberships by

Returns:

  • (Array<String>, nil)


82
# File 'lib/whop_sdk/models/membership_list_params.rb', line 82

optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#promo_code_idsArray<String>?

The promo code IDs to filter the memberships by

Returns:

  • (Array<String>, nil)


88
# File 'lib/whop_sdk/models/membership_list_params.rb', line 88

optional :promo_code_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#statusesArray<Symbol, WhopSDK::Models::MembershipStatus>?

The membership status to filter the memberships by

Returns:



94
# File 'lib/whop_sdk/models/membership_list_params.rb', line 94

optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MembershipStatus] }, nil?: true

#user_idsArray<String>?

Only return memberships from these whop user ids

Returns:

  • (Array<String>, nil)


100
# File 'lib/whop_sdk/models/membership_list_params.rb', line 100

optional :user_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/whop_sdk/models/membership_list_params.rb', line 148