Class: WhopSDK::Models::MembershipListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MembershipListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/membership_list_params.rb
Overview
Defined Under Namespace
Modules: CancelOption, Order
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#cancel_options ⇒ Array<Symbol, WhopSDK::Models::MembershipListParams::CancelOption>?
The cancel options to filter the memberships by.
-
#company_id ⇒ String?
The ID of the company to list memberships for.
-
#created_after ⇒ Time?
The minimum creation date to filter by.
-
#created_before ⇒ Time?
The maximum creation date to filter by.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#order ⇒ Symbol, ...
Which columns can be used to sort.
-
#plan_ids ⇒ Array<String>?
The plan IDs to filter the memberships by.
-
#product_ids ⇒ Array<String>?
The product IDs to filter the memberships by.
-
#promo_code_ids ⇒ Array<String>?
The promo code IDs to filter the memberships by.
-
#statuses ⇒ Array<Symbol, WhopSDK::Models::MembershipStatus>?
The membership status to filter the memberships by.
-
#user_ids ⇒ Array<String>?
Only return memberships from these whop user ids.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, cancel_options: nil, company_id: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, plan_ids: nil, product_ids: nil, promo_code_ids: nil, statuses: nil, user_ids: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/membership_list_params.rb', line 102
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
14 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 14 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
20 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 20 optional :before, String, nil?: true |
#cancel_options ⇒ Array<Symbol, WhopSDK::Models::MembershipListParams::CancelOption>?
The cancel options to filter the memberships by
26 27 28 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 26 optional :cancel_options, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MembershipListParams::CancelOption] }, nil?: true |
#company_id ⇒ String?
The ID of the company to list memberships for
34 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 34 optional :company_id, String, nil?: true |
#created_after ⇒ Time?
The minimum creation date to filter by
40 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 40 optional :created_after, Time, nil?: true |
#created_before ⇒ Time?
The maximum creation date to filter by
46 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 46 optional :created_before, Time, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
52 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 52 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
58 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 58 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
64 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 64 optional :last, Integer, nil?: true |
#order ⇒ Symbol, ...
Which columns can be used to sort.
70 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 70 optional :order, enum: -> { WhopSDK::MembershipListParams::Order }, nil?: true |
#plan_ids ⇒ Array<String>?
The plan IDs to filter the memberships by
76 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 76 optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#product_ids ⇒ Array<String>?
The product IDs to filter the memberships by
82 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 82 optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#promo_code_ids ⇒ Array<String>?
The promo code IDs to filter the memberships by
88 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 88 optional :promo_code_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#statuses ⇒ Array<Symbol, WhopSDK::Models::MembershipStatus>?
The membership status to filter the memberships by
94 |
# File 'lib/whop_sdk/models/membership_list_params.rb', line 94 optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::MembershipStatus] }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/membership_list_params.rb', line 148
|