Class: WhopSDK::Models::MembershipListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MembershipListResponse
- Defined in:
- lib/whop_sdk/models/membership_list_response.rb
Overview
Defined Under Namespace
Classes: Company, Member, Plan, Product, PromoCode, User
Instance Attribute Summary collapse
-
#cancel_at_period_end ⇒ Boolean
Whether this Membership is set to cancel at the end of the current billing cycle.
-
#canceled_at ⇒ Time?
The epoch timestamp of when the customer initiated a cancellation.
-
#cancellation_reason ⇒ String?
The reason that the member canceled the membership (filled out by the member).
-
#company ⇒ WhopSDK::Models::MembershipListResponse::Company
The Company this Membership belongs to.
-
#created_at ⇒ Time
The timestamp, in seconds, that this Membership was created at.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#id ⇒ String
The ID of the membership.
-
#license_key ⇒ String?
The license key for this Membership.
-
#manage_url ⇒ String?
The URL for the customer to manage their membership.
-
#member ⇒ WhopSDK::Models::MembershipListResponse::Member?
The Member that this Membership belongs to.
-
#metadata ⇒ Hash{Symbol=>Object}
A JSON object used to store software licensing information.
-
#payment_collection_paused ⇒ Boolean
Whether the membership’s payments are currently paused.
-
#plan ⇒ WhopSDK::Models::MembershipListResponse::Plan
The Plan this Membership is for.
-
#product ⇒ WhopSDK::Models::MembershipListResponse::Product
The Product this Membership grants access to.
-
#promo_code ⇒ WhopSDK::Models::MembershipListResponse::PromoCode?
The Promo Code that is currently applied to this Membership.
-
#renewal_period_end ⇒ Time?
The timestamp in seconds at which the current billing cycle for this subscription ends.
-
#renewal_period_start ⇒ Time?
The timestamp in seconds at which the current billing cycle for this subscription start.
-
#status ⇒ Symbol, WhopSDK::Models::MembershipStatus
The status of the membership.
-
#updated_at ⇒ Time
A timestamp of when the membership was last updated.
-
#user ⇒ WhopSDK::Models::MembershipListResponse::User?
The user this membership belongs to.
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
The Promo Code that is currently applied to this Membership.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
The Promo Code that is currently applied to this Membership.
|
|
# File 'lib/whop_sdk/models/membership_list_response.rb', line 131
|
Instance Attribute Details
#cancel_at_period_end ⇒ Boolean
Whether this Membership is set to cancel at the end of the current billing cycle. Only applies for memberships that have a renewal plan.
18 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 18 required :cancel_at_period_end, WhopSDK::Internal::Type::Boolean |
#canceled_at ⇒ Time?
The epoch timestamp of when the customer initiated a cancellation.
24 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 24 required :canceled_at, Time, nil?: true |
#cancellation_reason ⇒ String?
The reason that the member canceled the membership (filled out by the member).
30 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 30 required :cancellation_reason, String, nil?: true |
#company ⇒ WhopSDK::Models::MembershipListResponse::Company
The Company this Membership belongs to.
36 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 36 required :company, -> { WhopSDK::Models::MembershipListResponse::Company } |
#created_at ⇒ Time
The timestamp, in seconds, that this Membership was created at.
42 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 42 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
48 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 48 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#id ⇒ String
The ID of the membership
11 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 11 required :id, String |
#license_key ⇒ String?
The license key for this Membership. This is only present if the membership grants access to an instance of the Whop Software app.
55 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 55 required :license_key, String, nil?: true |
#manage_url ⇒ String?
The URL for the customer to manage their membership.
61 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 61 required :manage_url, String, nil?: true |
#member ⇒ WhopSDK::Models::MembershipListResponse::Member?
The Member that this Membership belongs to.
67 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 67 required :member, -> { WhopSDK::Models::MembershipListResponse::Member }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}
A JSON object used to store software licensing information. Ex. HWID
73 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 73 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown] |
#payment_collection_paused ⇒ Boolean
Whether the membership’s payments are currently paused.
79 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 79 required :payment_collection_paused, WhopSDK::Internal::Type::Boolean |
#plan ⇒ WhopSDK::Models::MembershipListResponse::Plan
The Plan this Membership is for.
85 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 85 required :plan, -> { WhopSDK::Models::MembershipListResponse::Plan } |
#product ⇒ WhopSDK::Models::MembershipListResponse::Product
The Product this Membership grants access to.
91 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 91 required :product, -> { WhopSDK::Models::MembershipListResponse::Product } |
#promo_code ⇒ WhopSDK::Models::MembershipListResponse::PromoCode?
The Promo Code that is currently applied to this Membership.
97 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 97 required :promo_code, -> { WhopSDK::Models::MembershipListResponse::PromoCode }, nil?: true |
#renewal_period_end ⇒ Time?
The timestamp in seconds at which the current billing cycle for this subscription ends. Only applies for memberships that have a renewal plan.
104 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 104 required :renewal_period_end, Time, nil?: true |
#renewal_period_start ⇒ Time?
The timestamp in seconds at which the current billing cycle for this subscription start. Only applies for memberships that have a renewal plan.
111 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 111 required :renewal_period_start, Time, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::MembershipStatus
The status of the membership.
117 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 117 required :status, enum: -> { WhopSDK::MembershipStatus } |
#updated_at ⇒ Time
A timestamp of when the membership was last updated
123 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 123 required :updated_at, Time |
#user ⇒ WhopSDK::Models::MembershipListResponse::User?
The user this membership belongs to
129 |
# File 'lib/whop_sdk/models/membership_list_response.rb', line 129 required :user, -> { WhopSDK::Models::MembershipListResponse::User }, nil?: true |