Class: WhopSDK::Models::Message
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Message
- Defined in:
- lib/whop_sdk/models/message.rb
Defined Under Namespace
Classes: Poll, PollVote, ReactionCount, User
Instance Attribute Summary collapse
-
#content ⇒ String?
The content of the message in Markdown format.
-
#created_at ⇒ Time
The timestamp when the post was created.
-
#id ⇒ String
The unique identifier of the resource.
-
#is_edited ⇒ Boolean
Whether the message has been edited.
-
#is_pinned ⇒ Boolean
Whether this message is pinned.
-
#message_type ⇒ Symbol, WhopSDK::Models::DmsPostTypes
The type of post.
-
#poll ⇒ WhopSDK::Models::Message::Poll?
The poll for this message.
-
#poll_votes ⇒ Array<WhopSDK::Models::Message::PollVote>
The reaction counts for this message.
-
#reaction_counts ⇒ Array<WhopSDK::Models::Message::ReactionCount>
The reaction counts for this message.
-
#replying_to_message_id ⇒ String?
The ID of the message this is replying to, if applicable.
-
#updated_at ⇒ Time
The timestamp when the post was last updated.
-
#user ⇒ WhopSDK::Models::Message::User
The user who sent this message.
-
#view_count ⇒ Integer?
The number of times this message has been viewed.
Instance Method Summary collapse
-
#initialize(count: , emoji: ) ⇒ Object
constructor
Represents a reaction count for a feed post.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(count: , emoji: ) ⇒ Object
Represents a reaction count for a feed post
|
|
# File 'lib/whop_sdk/models/message.rb', line 84
|
Instance Attribute Details
#content ⇒ String?
The content of the message in Markdown format
16 |
# File 'lib/whop_sdk/models/message.rb', line 16 required :content, String, nil?: true |
#created_at ⇒ Time
The timestamp when the post was created
22 |
# File 'lib/whop_sdk/models/message.rb', line 22 required :created_at, Time |
#id ⇒ String
The unique identifier of the resource.
10 |
# File 'lib/whop_sdk/models/message.rb', line 10 required :id, String |
#is_edited ⇒ Boolean
Whether the message has been edited
28 |
# File 'lib/whop_sdk/models/message.rb', line 28 required :is_edited, WhopSDK::Internal::Type::Boolean |
#is_pinned ⇒ Boolean
Whether this message is pinned
34 |
# File 'lib/whop_sdk/models/message.rb', line 34 required :is_pinned, WhopSDK::Internal::Type::Boolean |
#message_type ⇒ Symbol, WhopSDK::Models::DmsPostTypes
The type of post
40 |
# File 'lib/whop_sdk/models/message.rb', line 40 required :message_type, enum: -> { WhopSDK::DmsPostTypes } |
#poll ⇒ WhopSDK::Models::Message::Poll?
The poll for this message
46 |
# File 'lib/whop_sdk/models/message.rb', line 46 required :poll, -> { WhopSDK::Message::Poll }, nil?: true |
#poll_votes ⇒ Array<WhopSDK::Models::Message::PollVote>
The reaction counts for this message
52 |
# File 'lib/whop_sdk/models/message.rb', line 52 required :poll_votes, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Message::PollVote] } |
#reaction_counts ⇒ Array<WhopSDK::Models::Message::ReactionCount>
The reaction counts for this message
58 |
# File 'lib/whop_sdk/models/message.rb', line 58 required :reaction_counts, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Message::ReactionCount] } |
#replying_to_message_id ⇒ String?
The ID of the message this is replying to, if applicable
64 |
# File 'lib/whop_sdk/models/message.rb', line 64 required :replying_to_message_id, String, nil?: true |
#updated_at ⇒ Time
The timestamp when the post was last updated
70 |
# File 'lib/whop_sdk/models/message.rb', line 70 required :updated_at, Time |
#user ⇒ WhopSDK::Models::Message::User
The user who sent this message
76 |
# File 'lib/whop_sdk/models/message.rb', line 76 required :user, -> { WhopSDK::Message::User } |
#view_count ⇒ Integer?
The number of times this message has been viewed
82 |
# File 'lib/whop_sdk/models/message.rb', line 82 required :view_count, Integer, nil?: true |