Class: WhopSDK::Models::MessageCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MessageCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/message_create_params.rb
Overview
Defined Under Namespace
Classes: Attachment, Poll
Instance Attribute Summary collapse
-
#attachments ⇒ Array<WhopSDK::Models::MessageCreateParams::Attachment>?
A list of file attachments to include with the message, such as images or videos.
-
#auto_detect_links ⇒ Boolean?
Automatically detect URLs in the message and generate link previews.
-
#channel_id ⇒ String
The unique identifier of the channel or experience to send the message in.
-
#content ⇒ String
The body of the message in Markdown format.
-
#poll ⇒ WhopSDK::Models::MessageCreateParams::Poll?
A poll to attach to this message, allowing recipients to vote on options.
-
#replying_to_message_id ⇒ String?
The unique identifier of the message this is replying to, creating a threaded reply.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
Input for an attachment.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
Input for an attachment
|
|
# File 'lib/whop_sdk/models/message_create_params.rb', line 76
|
Instance Attribute Details
#attachments ⇒ Array<WhopSDK::Models::MessageCreateParams::Attachment>?
A list of file attachments to include with the message, such as images or videos.
28 29 30 |
# File 'lib/whop_sdk/models/message_create_params.rb', line 28 optional :attachments, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::MessageCreateParams::Attachment] }, nil?: true |
#auto_detect_links ⇒ Boolean?
Automatically detect URLs in the message and generate link previews.
36 |
# File 'lib/whop_sdk/models/message_create_params.rb', line 36 optional :auto_detect_links, WhopSDK::Internal::Type::Boolean, nil?: true |
#channel_id ⇒ String
The unique identifier of the channel or experience to send the message in. For example, ‘exp_xxxxx’ or ‘feed_xxxxx’.
15 |
# File 'lib/whop_sdk/models/message_create_params.rb', line 15 required :channel_id, String |
#content ⇒ String
The body of the message in Markdown format. For example, ‘Hello world’.
21 |
# File 'lib/whop_sdk/models/message_create_params.rb', line 21 required :content, String |
#poll ⇒ WhopSDK::Models::MessageCreateParams::Poll?
A poll to attach to this message, allowing recipients to vote on options.
42 |
# File 'lib/whop_sdk/models/message_create_params.rb', line 42 optional :poll, -> { WhopSDK::MessageCreateParams::Poll }, nil?: true |
#replying_to_message_id ⇒ String?
The unique identifier of the message this is replying to, creating a threaded reply.
49 |
# File 'lib/whop_sdk/models/message_create_params.rb', line 49 optional :replying_to_message_id, String, nil?: true |