Class: WhopSDK::Models::MessageCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/message_create_params.rb

Overview

Defined Under Namespace

Classes: Attachment, Poll

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, direct_upload_id: nil) ⇒ Object

Some parameter documentations has been truncated, see Attachment for more details.

Input for an attachment

Parameters:

  • id (String, nil) (defaults to: nil)

    The ID of an existing attachment object. Use this when updating a resource and k

  • direct_upload_id (String, nil) (defaults to: nil)

    This ID should be used the first time you upload an attachment. It is the ID of



# File 'lib/whop_sdk/models/message_create_params.rb', line 64

Instance Attribute Details

#attachmentsArray<WhopSDK::Models::MessageCreateParams::Attachment>?

The attachments for this message, such as videos or images.



26
27
28
# File 'lib/whop_sdk/models/message_create_params.rb', line 26

optional :attachments,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::MessageCreateParams::Attachment] },
nil?: true

#channel_idString

The ID of the channel or experience to send to.

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/message_create_params.rb', line 14

required :channel_id, String

#contentString

The content of the message in Markdown format.

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/message_create_params.rb', line 20

required :content, String

#pollWhopSDK::Models::MessageCreateParams::Poll?

The poll for this message



34
# File 'lib/whop_sdk/models/message_create_params.rb', line 34

optional :poll, -> { WhopSDK::MessageCreateParams::Poll }, nil?: true