Class: WhopSDK::Models::MessageListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MessageListResponse
- Defined in:
- lib/whop_sdk/models/message_list_response.rb
Overview
Defined Under Namespace
Classes: Poll, PollVote, ReactionCount, User
Instance Attribute Summary collapse
-
#content ⇒ String?
The message content formatted as Markdown.
-
#created_at ⇒ Time
The timestamp when this message was originally created.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#is_edited ⇒ Boolean
Whether the message content has been edited after it was originally sent.
-
#is_pinned ⇒ Boolean
Whether this message is pinned to the top of the channel for easy access.
-
#mentions ⇒ Array<String>
A list of user IDs that are explicitly mentioned in this message.
-
#mentions_everyone ⇒ Boolean
Whether the message includes an @everyone mention that notifies all channel members.
-
#message_type ⇒ Symbol, WhopSDK::Models::DmsPostTypes
The classification of this message: regular, system, or automated.
-
#poll ⇒ WhopSDK::Models::MessageListResponse::Poll?
A poll attached to this message.
-
#poll_votes ⇒ Array<WhopSDK::Models::MessageListResponse::PollVote>
Aggregated reaction counts on this message, filtered to a specific reaction type.
-
#reaction_counts ⇒ Array<WhopSDK::Models::MessageListResponse::ReactionCount>
Aggregated reaction counts on this message, filtered to a specific reaction type.
-
#replying_to_message_id ⇒ String?
The unique identifier of the message this post is replying to.
-
#updated_at ⇒ Time
The timestamp when this message was last modified.
-
#user ⇒ WhopSDK::Models::MessageListResponse::User
The user who authored this message.
-
#view_count ⇒ Integer?
The number of unique views this message has received.
Instance Method Summary collapse
-
#initialize(count:, emoji:) ⇒ Object
constructor
Represents a reaction count for a feed post.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(count:, emoji:) ⇒ Object
Represents a reaction count for a feed post
|
|
# File 'lib/whop_sdk/models/message_list_response.rb', line 109
|
Instance Attribute Details
#content ⇒ String?
The message content formatted as Markdown. Null if the message has no text content.
22 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 22 required :content, String, nil?: true |
#created_at ⇒ Time
The timestamp when this message was originally created.
28 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 28 required :created_at, Time |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.
15 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 15 required :id, String |
#is_edited ⇒ Boolean
Whether the message content has been edited after it was originally sent.
34 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 34 required :is_edited, WhopSDK::Internal::Type::Boolean |
#is_pinned ⇒ Boolean
Whether this message is pinned to the top of the channel for easy access.
40 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 40 required :is_pinned, WhopSDK::Internal::Type::Boolean |
#mentions ⇒ Array<String>
A list of user IDs that are explicitly mentioned in this message.
46 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 46 required :mentions, WhopSDK::Internal::Type::ArrayOf[String] |
#mentions_everyone ⇒ Boolean
Whether the message includes an @everyone mention that notifies all channel members.
53 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 53 required :mentions_everyone, WhopSDK::Internal::Type::Boolean |
#message_type ⇒ Symbol, WhopSDK::Models::DmsPostTypes
The classification of this message: regular, system, or automated.
59 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 59 required :message_type, enum: -> { WhopSDK::DmsPostTypes } |
#poll ⇒ WhopSDK::Models::MessageListResponse::Poll?
A poll attached to this message. Null if the message does not contain a poll.
65 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 65 required :poll, -> { WhopSDK::Models::MessageListResponse::Poll }, nil?: true |
#poll_votes ⇒ Array<WhopSDK::Models::MessageListResponse::PollVote>
Aggregated reaction counts on this message, filtered to a specific reaction type.
72 73 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 72 required :poll_votes, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::MessageListResponse::PollVote] } |
#reaction_counts ⇒ Array<WhopSDK::Models::MessageListResponse::ReactionCount>
Aggregated reaction counts on this message, filtered to a specific reaction type.
80 81 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 80 required :reaction_counts, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::MessageListResponse::ReactionCount] } |
#replying_to_message_id ⇒ String?
The unique identifier of the message this post is replying to. Null if this is not a reply.
88 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 88 required :replying_to_message_id, String, nil?: true |
#updated_at ⇒ Time
The timestamp when this message was last modified.
94 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 94 required :updated_at, Time |
#user ⇒ WhopSDK::Models::MessageListResponse::User
The user who authored this message.
100 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 100 required :user, -> { WhopSDK::Models::MessageListResponse::User } |
#view_count ⇒ Integer?
The number of unique views this message has received. Null if view tracking is not enabled for this channel.
107 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 107 required :view_count, Integer, nil?: true |