Class: WhopSDK::Models::MessageListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::MessageListResponse
- Defined in:
- lib/whop_sdk/models/message_list_response.rb
Overview
Defined Under Namespace
Classes: Poll, PollVote, ReactionCount, User
Instance Attribute Summary collapse
-
#content ⇒ String?
The content of the message in Markdown format.
-
#created_at ⇒ Time
The timestamp when the post was created.
-
#id ⇒ String
The unique identifier of the resource.
-
#is_edited ⇒ Boolean
Whether the message has been edited.
-
#is_pinned ⇒ Boolean
Whether this message is pinned.
-
#message_type ⇒ Symbol, WhopSDK::Models::DmsPostTypes
The type of post.
-
#poll ⇒ WhopSDK::Models::MessageListResponse::Poll?
The poll for this message.
-
#poll_votes ⇒ Array<WhopSDK::Models::MessageListResponse::PollVote>
The reaction counts for this message.
-
#reaction_counts ⇒ Array<WhopSDK::Models::MessageListResponse::ReactionCount>
The reaction counts for this message.
-
#replying_to_message_id ⇒ String?
The ID of the message this is replying to, if applicable.
-
#updated_at ⇒ Time
The timestamp when the post was last updated.
-
#user ⇒ WhopSDK::Models::MessageListResponse::User
The user who sent this message.
-
#view_count ⇒ Integer?
The number of times this message has been viewed.
Instance Method Summary collapse
-
#initialize(count: , emoji: ) ⇒ Object
constructor
Represents a reaction count for a feed post.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(count: , emoji: ) ⇒ Object
Represents a reaction count for a feed post
|
|
# File 'lib/whop_sdk/models/message_list_response.rb', line 87
|
Instance Attribute Details
#content ⇒ String?
The content of the message in Markdown format
17 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 17 required :content, String, nil?: true |
#created_at ⇒ Time
The timestamp when the post was created
23 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 23 required :created_at, Time |
#id ⇒ String
The unique identifier of the resource.
11 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 11 required :id, String |
#is_edited ⇒ Boolean
Whether the message has been edited
29 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 29 required :is_edited, WhopSDK::Internal::Type::Boolean |
#is_pinned ⇒ Boolean
Whether this message is pinned
35 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 35 required :is_pinned, WhopSDK::Internal::Type::Boolean |
#message_type ⇒ Symbol, WhopSDK::Models::DmsPostTypes
The type of post
41 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 41 required :message_type, enum: -> { WhopSDK::DmsPostTypes } |
#poll ⇒ WhopSDK::Models::MessageListResponse::Poll?
The poll for this message
47 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 47 required :poll, -> { WhopSDK::Models::MessageListResponse::Poll }, nil?: true |
#poll_votes ⇒ Array<WhopSDK::Models::MessageListResponse::PollVote>
The reaction counts for this message
53 54 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 53 required :poll_votes, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::MessageListResponse::PollVote] } |
#reaction_counts ⇒ Array<WhopSDK::Models::MessageListResponse::ReactionCount>
The reaction counts for this message
60 61 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 60 required :reaction_counts, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::MessageListResponse::ReactionCount] } |
#replying_to_message_id ⇒ String?
The ID of the message this is replying to, if applicable
67 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 67 required :replying_to_message_id, String, nil?: true |
#updated_at ⇒ Time
The timestamp when the post was last updated
73 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 73 required :updated_at, Time |
#user ⇒ WhopSDK::Models::MessageListResponse::User
The user who sent this message
79 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 79 required :user, -> { WhopSDK::Models::MessageListResponse::User } |
#view_count ⇒ Integer?
The number of times this message has been viewed
85 |
# File 'lib/whop_sdk/models/message_list_response.rb', line 85 required :view_count, Integer, nil?: true |