Class: WhopSDK::Models::MessageListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/message_list_response.rb

Overview

Defined Under Namespace

Classes: Poll, PollVote, ReactionCount, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(count: , emoji: ) ⇒ Object

Represents a reaction count for a feed post

Parameters:

  • count (Integer) (defaults to: )

    The number of users who reacted

  • emoji (String, nil) (defaults to: )

    The emoji that was used in shortcode format (:heart:)



# File 'lib/whop_sdk/models/message_list_response.rb', line 87

Instance Attribute Details

#contentString?

The content of the message in Markdown format

Returns:

  • (String, nil)


17
# File 'lib/whop_sdk/models/message_list_response.rb', line 17

required :content, String, nil?: true

#created_atTime

The timestamp when the post was created

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/message_list_response.rb', line 23

required :created_at, Time

#idString

The unique identifier for the entity

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/message_list_response.rb', line 11

required :id, String

#is_editedBoolean

Whether the message has been edited

Returns:

  • (Boolean)


29
# File 'lib/whop_sdk/models/message_list_response.rb', line 29

required :is_edited, WhopSDK::Internal::Type::Boolean

#is_pinnedBoolean

Whether this message is pinned

Returns:

  • (Boolean)


35
# File 'lib/whop_sdk/models/message_list_response.rb', line 35

required :is_pinned, WhopSDK::Internal::Type::Boolean

#message_typeSymbol, WhopSDK::Models::DmsPostTypes

The type of post

Returns:



41
# File 'lib/whop_sdk/models/message_list_response.rb', line 41

required :message_type, enum: -> { WhopSDK::DmsPostTypes }

#pollWhopSDK::Models::MessageListResponse::Poll?

The poll for this message



47
# File 'lib/whop_sdk/models/message_list_response.rb', line 47

required :poll, -> { WhopSDK::Models::MessageListResponse::Poll }, nil?: true

#poll_votesArray<WhopSDK::Models::MessageListResponse::PollVote>

The reaction counts for this message



53
54
# File 'lib/whop_sdk/models/message_list_response.rb', line 53

required :poll_votes,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::MessageListResponse::PollVote] }

#reaction_countsArray<WhopSDK::Models::MessageListResponse::ReactionCount>

The reaction counts for this message



60
61
# File 'lib/whop_sdk/models/message_list_response.rb', line 60

required :reaction_counts,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::MessageListResponse::ReactionCount] }

#replying_to_message_idString?

The ID of the message this is replying to, if applicable

Returns:

  • (String, nil)


67
# File 'lib/whop_sdk/models/message_list_response.rb', line 67

required :replying_to_message_id, String, nil?: true

#updated_atTime

The timestamp when the post was last updated

Returns:

  • (Time)


73
# File 'lib/whop_sdk/models/message_list_response.rb', line 73

required :updated_at, Time

#userWhopSDK::Models::MessageListResponse::User

The user who sent this message



79
# File 'lib/whop_sdk/models/message_list_response.rb', line 79

required :user, -> { WhopSDK::Models::MessageListResponse::User }

#view_countInteger?

The number of times this message has been viewed

Returns:

  • (Integer, nil)


85
# File 'lib/whop_sdk/models/message_list_response.rb', line 85

required :view_count, Integer, nil?: true