Class: WhopSDK::Models::NotificationCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::NotificationCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/notification_create_params.rb
Overview
Instance Attribute Summary collapse
-
#company_id ⇒ String
The id of the company to target.
-
#content ⇒ String
The content of the notification.
-
#experience_id ⇒ String
The id of the experience to target.
-
#icon_user_id ⇒ String?
Optional: ID of a Whop user whose profile picture will be used as the notification icon.
-
#rest_path ⇒ String?
The rest path to append to the generated deep link that opens your app.
-
#subtitle ⇒ String?
The subtitle of the notification.
-
#title ⇒ String
The title of the notification.
-
#user_ids ⇒ Array<String>?
If provided, this will only send to these users if they are also in the main scope (experience or company).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(company_id: , content: , title: , experience_id: , icon_user_id: nil, rest_path: nil, subtitle: nil, user_ids: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see NotificationCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id: , content: , title: , experience_id: , icon_user_id: nil, rest_path: nil, subtitle: nil, user_ids: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::NotificationCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/notification_create_params.rb', line 65
|
Instance Attribute Details
#company_id ⇒ String
The id of the company to target. Only team members of this company will receive the notification. When clicked will take the user to your dashboard app view.
15 |
# File 'lib/whop_sdk/models/notification_create_params.rb', line 15 required :company_id, String |
#content ⇒ String
The content of the notification
21 |
# File 'lib/whop_sdk/models/notification_create_params.rb', line 21 required :content, String |
#experience_id ⇒ String
The id of the experience to target. All users with access to this experience (customers and admins) will receive the notification. When clicked, open your experience view.
63 |
# File 'lib/whop_sdk/models/notification_create_params.rb', line 63 required :experience_id, String |
#icon_user_id ⇒ String?
Optional: ID of a Whop user whose profile picture will be used as the notification icon. If not provided, defaults to the experience or company avatar.
35 |
# File 'lib/whop_sdk/models/notification_create_params.rb', line 35 optional :icon_user_id, String, nil?: true |
#rest_path ⇒ String?
The rest path to append to the generated deep link that opens your app. Use
- restPath
-
in your app path in the dashboard to read this parameter.
42 |
# File 'lib/whop_sdk/models/notification_create_params.rb', line 42 optional :rest_path, String, nil?: true |
#subtitle ⇒ String?
The subtitle of the notification
48 |
# File 'lib/whop_sdk/models/notification_create_params.rb', line 48 optional :subtitle, String, nil?: true |
#title ⇒ String
The title of the notification
27 |
# File 'lib/whop_sdk/models/notification_create_params.rb', line 27 required :title, String |