Class: WhopSDK::Models::Payment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Payment
- Defined in:
- lib/whop_sdk/models/payment.rb
Defined Under Namespace
Classes: BillingAddress, Company, Member, Membership, Plan, Product, PromoCode, User
Instance Attribute Summary collapse
-
#amount_after_fees ⇒ Float
How much the payment is for after fees.
-
#auto_refunded ⇒ Boolean
Whether this payment was auto refunded or not.
-
#billing_address ⇒ WhopSDK::Models::Payment::BillingAddress?
The address of the user who made the payment.
-
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed.
-
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#card_last4 ⇒ String?
The last 4 digits of the card used to make the payment.
-
#company ⇒ WhopSDK::Models::Payment::Company?
The company for the payment.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed.
-
#failure_message ⇒ String?
If the payment failed, the reason for the failure.
-
#id ⇒ String
The payment ID.
-
#last_payment_attempt ⇒ Time?
The time of the last payment attempt.
-
#member ⇒ WhopSDK::Models::Payment::Member?
The member attached to this payment.
-
#membership ⇒ WhopSDK::Models::Payment::Membership?
The membership attached to this payment.
-
#paid_at ⇒ Time?
The datetime the payment was paid.
-
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
-
#plan ⇒ WhopSDK::Models::Payment::Plan?
The plan attached to this payment.
-
#product ⇒ WhopSDK::Models::Payment::Product?
The access pass attached to this payment.
-
#promo_code ⇒ WhopSDK::Models::Payment::PromoCode?
The promo code used for this payment.
-
#refundable ⇒ Boolean
True only for payments that are ‘paid`, have not been fully refunded, and were processed by a payment processor that allows refunds.
-
#refunded_amount ⇒ Float?
The payment refund amount(if applicable).
-
#refunded_at ⇒ Time?
When the payment was refunded (if applicable).
-
#retryable ⇒ Boolean
True when the payment status is ‘open` and its membership is in one of the retry-eligible states (`active`, `trialing`, `completed`, or `past_due`); otherwise false.
-
#status ⇒ Symbol, ...
The status of a receipt.
-
#substatus ⇒ Symbol, WhopSDK::Models::FriendlyReceiptStatus
The friendly status of the payment.
-
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
-
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
-
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
-
#user ⇒ WhopSDK::Models::Payment::User?
The user that made this payment.
-
#voidable ⇒ Boolean
True when the payment is tied to a membership in ‘past_due`, the payment status is `open`, and the processor allows voiding payments; otherwise false.
Instance Method Summary collapse
-
#initialize(id: , amount_off: , base_currency: , code: , number_of_intervals: , promo_type: ) ⇒ Object
constructor
The promo code used for this payment.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , amount_off: , base_currency: , code: , number_of_intervals: , promo_type: ) ⇒ Object
The promo code used for this payment.
|
|
# File 'lib/whop_sdk/models/payment.rb', line 196
|
Instance Attribute Details
#amount_after_fees ⇒ Float
How much the payment is for after fees
16 |
# File 'lib/whop_sdk/models/payment.rb', line 16 required :amount_after_fees, Float |
#auto_refunded ⇒ Boolean
Whether this payment was auto refunded or not
22 |
# File 'lib/whop_sdk/models/payment.rb', line 22 required :auto_refunded, WhopSDK::Internal::Type::Boolean |
#billing_address ⇒ WhopSDK::Models::Payment::BillingAddress?
The address of the user who made the payment.
28 |
# File 'lib/whop_sdk/models/payment.rb', line 28 required :billing_address, -> { WhopSDK::Payment::BillingAddress }, nil?: true |
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed
34 |
# File 'lib/whop_sdk/models/payment.rb', line 34 required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true |
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have
40 |
# File 'lib/whop_sdk/models/payment.rb', line 40 required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#card_last4 ⇒ String?
The last 4 digits of the card used to make the payment.
46 |
# File 'lib/whop_sdk/models/payment.rb', line 46 required :card_last4, String, nil?: true |
#company ⇒ WhopSDK::Models::Payment::Company?
The company for the payment.
52 |
# File 'lib/whop_sdk/models/payment.rb', line 52 required :company, -> { WhopSDK::Payment::Company }, nil?: true |
#created_at ⇒ Time
The datetime the payment was created
58 |
# File 'lib/whop_sdk/models/payment.rb', line 58 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
64 |
# File 'lib/whop_sdk/models/payment.rb', line 64 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed
70 |
# File 'lib/whop_sdk/models/payment.rb', line 70 required :dispute_alerted_at, Time, nil?: true |
#failure_message ⇒ String?
If the payment failed, the reason for the failure.
76 |
# File 'lib/whop_sdk/models/payment.rb', line 76 required :failure_message, String, nil?: true |
#id ⇒ String
The payment ID
10 |
# File 'lib/whop_sdk/models/payment.rb', line 10 required :id, String |
#last_payment_attempt ⇒ Time?
The time of the last payment attempt.
82 |
# File 'lib/whop_sdk/models/payment.rb', line 82 required :last_payment_attempt, Time, nil?: true |
#member ⇒ WhopSDK::Models::Payment::Member?
The member attached to this payment.
88 |
# File 'lib/whop_sdk/models/payment.rb', line 88 required :member, -> { WhopSDK::Payment::Member }, nil?: true |
#membership ⇒ WhopSDK::Models::Payment::Membership?
The membership attached to this payment.
94 |
# File 'lib/whop_sdk/models/payment.rb', line 94 required :membership, -> { WhopSDK::Payment::Membership }, nil?: true |
#paid_at ⇒ Time?
The datetime the payment was paid
100 |
# File 'lib/whop_sdk/models/payment.rb', line 100 required :paid_at, Time, nil?: true |
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
106 |
# File 'lib/whop_sdk/models/payment.rb', line 106 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true |
#plan ⇒ WhopSDK::Models::Payment::Plan?
The plan attached to this payment.
112 |
# File 'lib/whop_sdk/models/payment.rb', line 112 required :plan, -> { WhopSDK::Payment::Plan }, nil?: true |
#product ⇒ WhopSDK::Models::Payment::Product?
The access pass attached to this payment.
118 |
# File 'lib/whop_sdk/models/payment.rb', line 118 required :product, -> { WhopSDK::Payment::Product }, nil?: true |
#promo_code ⇒ WhopSDK::Models::Payment::PromoCode?
The promo code used for this payment.
124 |
# File 'lib/whop_sdk/models/payment.rb', line 124 required :promo_code, -> { WhopSDK::Payment::PromoCode }, nil?: true |
#refundable ⇒ Boolean
True only for payments that are ‘paid`, have not been fully refunded, and were processed by a payment processor that allows refunds.
131 |
# File 'lib/whop_sdk/models/payment.rb', line 131 required :refundable, WhopSDK::Internal::Type::Boolean |
#refunded_amount ⇒ Float?
The payment refund amount(if applicable).
137 |
# File 'lib/whop_sdk/models/payment.rb', line 137 required :refunded_amount, Float, nil?: true |
#refunded_at ⇒ Time?
When the payment was refunded (if applicable).
143 |
# File 'lib/whop_sdk/models/payment.rb', line 143 required :refunded_at, Time, nil?: true |
#retryable ⇒ Boolean
True when the payment status is ‘open` and its membership is in one of the retry-eligible states (`active`, `trialing`, `completed`, or `past_due`); otherwise false. Used to decide if Whop can attempt the charge again.
151 |
# File 'lib/whop_sdk/models/payment.rb', line 151 required :retryable, WhopSDK::Internal::Type::Boolean |
#status ⇒ Symbol, ...
The status of a receipt
157 |
# File 'lib/whop_sdk/models/payment.rb', line 157 required :status, enum: -> { WhopSDK::ReceiptStatus }, nil?: true |
#substatus ⇒ Symbol, WhopSDK::Models::FriendlyReceiptStatus
The friendly status of the payment.
163 |
# File 'lib/whop_sdk/models/payment.rb', line 163 required :substatus, enum: -> { WhopSDK::FriendlyReceiptStatus } |
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
169 |
# File 'lib/whop_sdk/models/payment.rb', line 169 required :subtotal, Float, nil?: true |
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
175 |
# File 'lib/whop_sdk/models/payment.rb', line 175 required :total, Float, nil?: true |
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
181 |
# File 'lib/whop_sdk/models/payment.rb', line 181 required :usd_total, Float, nil?: true |
#user ⇒ WhopSDK::Models::Payment::User?
The user that made this payment.
187 |
# File 'lib/whop_sdk/models/payment.rb', line 187 required :user, -> { WhopSDK::Payment::User }, nil?: true |