Class: WhopSDK::Models::Payment::ApplicationFee

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#amountFloat

The application fee amount.

Returns:

  • (Float)


392
# File 'lib/whop_sdk/models/payment.rb', line 392

required :amount, Float

#amount_capturedFloat

The amount of the application fee that has been captured.

Returns:

  • (Float)


398
# File 'lib/whop_sdk/models/payment.rb', line 398

required :amount_captured, Float

#amount_refundedFloat

The amount of the application fee that has been refunded.

Returns:

  • (Float)


404
# File 'lib/whop_sdk/models/payment.rb', line 404

required :amount_refunded, Float

#created_atTime

The datetime the application fee was created.

Returns:

  • (Time)


410
# File 'lib/whop_sdk/models/payment.rb', line 410

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The currency of the application fee.

Returns:



416
# File 'lib/whop_sdk/models/payment.rb', line 416

required :currency, enum: -> { WhopSDK::Currency }

#idString

The unique identifier for the application fee.

Returns:

  • (String)


386
# File 'lib/whop_sdk/models/payment.rb', line 386

required :id, String