Class: WhopSDK::Models::Payment::Dispute
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Payment::Dispute
- Defined in:
- lib/whop_sdk/models/payment.rb,
sig/whop_sdk/models/payment.rbs
Instance Attribute Summary collapse
-
#amount ⇒ Float
The disputed amount in the specified currency, formatted as a decimal.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The three-letter ISO currency code for the disputed amount.
-
#editable ⇒ Boolean?
Whether the dispute evidence can still be edited and submitted.
-
#id ⇒ String
The unique identifier for the dispute.
-
#needs_response_by ⇒ Time?
The deadline by which dispute evidence must be submitted.
-
#notes ⇒ String?
Additional freeform notes submitted by the company as part of the dispute evidence.
-
#reason ⇒ String?
A human-readable reason for the dispute.
-
#status ⇒ Symbol, WhopSDK::Models::DisputeStatuses
The current status of the dispute lifecycle, such as needs_response, under_review, won, or lost.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
411 |
# File 'sig/whop_sdk/models/payment.rbs', line 411
def initialize: (
|
Instance Attribute Details
#amount ⇒ Float
The disputed amount in the specified currency, formatted as a decimal.
617 |
# File 'lib/whop_sdk/models/payment.rb', line 617 required :amount, Float |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The three-letter ISO currency code for the disputed amount.
623 |
# File 'lib/whop_sdk/models/payment.rb', line 623 required :currency, enum: -> { WhopSDK::Currency } |
#editable ⇒ Boolean?
Whether the dispute evidence can still be edited and submitted.
629 |
# File 'lib/whop_sdk/models/payment.rb', line 629 required :editable, WhopSDK::Internal::Type::Boolean, nil?: true |
#id ⇒ String
The unique identifier for the dispute.
611 |
# File 'lib/whop_sdk/models/payment.rb', line 611 required :id, String |
#needs_response_by ⇒ Time?
The deadline by which dispute evidence must be submitted. Null if no response deadline is set.
636 |
# File 'lib/whop_sdk/models/payment.rb', line 636 required :needs_response_by, Time, nil?: true |
#notes ⇒ String?
Additional freeform notes submitted by the company as part of the dispute evidence.
643 |
# File 'lib/whop_sdk/models/payment.rb', line 643 required :notes, String, nil?: true |
#reason ⇒ String?
A human-readable reason for the dispute.
649 |
# File 'lib/whop_sdk/models/payment.rb', line 649 required :reason, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::DisputeStatuses
The current status of the dispute lifecycle, such as needs_response, under_review, won, or lost.
656 |
# File 'lib/whop_sdk/models/payment.rb', line 656 required :status, enum: -> { WhopSDK::DisputeStatuses } |
Instance Method Details
#to_hash ⇒ {
422 |
# File 'sig/whop_sdk/models/payment.rbs', line 422
def to_hash: -> {
|