Class: WhopSDK::Models::Payment::PaymentMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment.rb

Overview

See Also:

Defined Under Namespace

Classes: Card

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , card: , created_at: , payment_method_type: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::Payment::PaymentMethod for more details.

The payment method used for the payment, if available.

Parameters:

  • id (String) (defaults to: )

    The ID of the payment method

  • card (WhopSDK::Models::Payment::PaymentMethod::Card, nil) (defaults to: )

    The card data associated with the payment method, if its a debit or credit card.

  • created_at (Time) (defaults to: )

    The date and time the payment method was created

  • payment_method_type (Symbol, WhopSDK::Models::PaymentMethodTypes) (defaults to: )

    The payment method type of the payment method



# File 'lib/whop_sdk/models/payment.rb', line 443

Instance Attribute Details

#cardWhopSDK::Models::Payment::PaymentMethod::Card?

The card data associated with the payment method, if its a debit or credit card.



429
# File 'lib/whop_sdk/models/payment.rb', line 429

required :card, -> { WhopSDK::Payment::PaymentMethod::Card }, nil?: true

#created_atTime

The date and time the payment method was created

Returns:

  • (Time)


435
# File 'lib/whop_sdk/models/payment.rb', line 435

required :created_at, Time

#idString

The ID of the payment method

Returns:

  • (String)


423
# File 'lib/whop_sdk/models/payment.rb', line 423

required :id, String

#payment_method_typeSymbol, WhopSDK::Models::PaymentMethodTypes

The payment method type of the payment method



441
# File 'lib/whop_sdk/models/payment.rb', line 441

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }