Class: WhopSDK::Models::Payment::PromoCode
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Payment::PromoCode
- Defined in:
- lib/whop_sdk/models/payment.rb
Overview
Instance Attribute Summary collapse
-
#amount_off ⇒ Float
The amount off (% or flat amount) for the promo.
-
#base_currency ⇒ Symbol, WhopSDK::Models::Currency
The monetary currency of the promo code.
-
#code ⇒ String?
The specific code used to apply the promo at checkout.
-
#id ⇒ String
The ID of the promo.
-
#number_of_intervals ⇒ Integer?
The number of months the promo is applied for.
-
#promo_type ⇒ Symbol, WhopSDK::Models::PromoType
The type (% or flat amount) of the promo.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#amount_off ⇒ Float
The amount off (% or flat amount) for the promo.
456 |
# File 'lib/whop_sdk/models/payment.rb', line 456 required :amount_off, Float |
#base_currency ⇒ Symbol, WhopSDK::Models::Currency
The monetary currency of the promo code.
462 |
# File 'lib/whop_sdk/models/payment.rb', line 462 required :base_currency, enum: -> { WhopSDK::Currency } |
#code ⇒ String?
The specific code used to apply the promo at checkout.
468 |
# File 'lib/whop_sdk/models/payment.rb', line 468 required :code, String, nil?: true |
#id ⇒ String
The ID of the promo.
450 |
# File 'lib/whop_sdk/models/payment.rb', line 450 required :id, String |
#number_of_intervals ⇒ Integer?
The number of months the promo is applied for.
474 |
# File 'lib/whop_sdk/models/payment.rb', line 474 required :number_of_intervals, Integer, nil?: true |
#promo_type ⇒ Symbol, WhopSDK::Models::PromoType
The type (% or flat amount) of the promo.
480 |
# File 'lib/whop_sdk/models/payment.rb', line 480 required :promo_type, enum: -> { WhopSDK::PromoType } |