Class: WhopSDK::Models::Payment::Resolution

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#customer_appealedBoolean

Whether the customer has filed an appeal after the initial resolution decision.

Returns:

  • (Boolean)


948
# File 'lib/whop_sdk/models/payment.rb', line 948

required :customer_appealed, WhopSDK::Internal::Type::Boolean

#customer_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCaseCustomerResponse>

The list of actions currently available to the customer.



954
955
# File 'lib/whop_sdk/models/payment.rb', line 954

required :customer_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseCustomerResponse] }

#due_dateTime?

The deadline by which the next response is required. Null if no deadline is currently active. As a Unix timestamp.

Returns:

  • (Time, nil)


962
# File 'lib/whop_sdk/models/payment.rb', line 962

required :due_date, Time, nil?: true

#idString

The unique identifier for the resolution.

Returns:

  • (String)


942
# File 'lib/whop_sdk/models/payment.rb', line 942

required :id, String

#issueSymbol, WhopSDK::Models::ResolutionCenterCaseIssueType

The category of the dispute.



968
# File 'lib/whop_sdk/models/payment.rb', line 968

required :issue, enum: -> { WhopSDK::ResolutionCenterCaseIssueType }

#merchant_appealedBoolean

Whether the merchant has filed an appeal after the initial resolution decision.

Returns:

  • (Boolean)


974
# File 'lib/whop_sdk/models/payment.rb', line 974

required :merchant_appealed, WhopSDK::Internal::Type::Boolean

#merchant_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCaseMerchantResponse>

The list of actions currently available to the merchant.



980
981
# File 'lib/whop_sdk/models/payment.rb', line 980

required :merchant_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCaseMerchantResponse] }

#platform_response_actionsArray<Symbol, WhopSDK::Models::ResolutionCenterCasePlatformResponse>

The list of actions currently available to the Whop platform for moderating this resolution.



988
989
# File 'lib/whop_sdk/models/payment.rb', line 988

required :platform_response_actions,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ResolutionCenterCasePlatformResponse] }

#statusSymbol, WhopSDK::Models::ResolutionCenterCaseStatus

The current status of the resolution case, indicating which party needs to respond or if the case is closed.



996
# File 'lib/whop_sdk/models/payment.rb', line 996

required :status, enum: -> { WhopSDK::ResolutionCenterCaseStatus }