Module: WhopSDK::Models::PaymentCreateParams::Body
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/whop_sdk/models/payment_create_params.rb
Overview
Parameters for CreatePayment
Defined Under Namespace
Classes: CreatePaymentInputWithPlan, CreatePaymentInputWithPlanID
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(external_identifier:, title:, collect_shipping_address: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil) ⇒ Object
Some parameter documentations has been truncated, see CreatePaymentInputWithPlan::Plan::Product for more details.
Methods included from Internal::Type::Union
==, ===, coerce, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan, WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlanID)
|
|
# File 'lib/whop_sdk/models/payment_create_params.rb', line 384
|
Instance Method Details
#initialize(external_identifier:, title:, collect_shipping_address: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, visibility: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan::Plan::Product for more details.
Pass this object to create a new product for this plan. We will use the product external identifier to find or create an existing product.
betwee
|
|
# File 'lib/whop_sdk/models/payment_create_params.rb', line 298
|