Class: WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan
- Defined in:
- lib/whop_sdk/models/payment_create_params.rb,
sig/whop_sdk/models/payment_create_params.rbs
Defined Under Namespace
Classes: Plan
Instance Attribute Summary collapse
-
#company_id ⇒ String
The ID of the company to create the payment for.
-
#member_id ⇒ String
The ID of the member to create the payment for.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom metadata to attach to the payment.
-
#payment_method_id ⇒ String
The ID of the payment method to use for the payment.
-
#plan ⇒ WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan::Plan
Pass this object to create a new plan for this payment.
-
#promo_code_id ⇒ String?
The ID of an active promo code to apply to this payment.
Instance Method Summary collapse
-
#initialize(company_id:, member_id:, payment_method_id:, plan:, metadata: nil, promo_code_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CreatePaymentInputWithPlan for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, member_id:, payment_method_id:, plan:, metadata: nil, promo_code_id: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan for more details.
Autogenerated input type of CreatePayment
|
|
# File 'lib/whop_sdk/models/payment_create_params.rb', line 71
|
Instance Attribute Details
#company_id ⇒ String
The ID of the company to create the payment for.
36 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 36 required :company_id, String |
#member_id ⇒ String
The ID of the member to create the payment for.
42 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 42 required :member_id, String |
#metadata ⇒ Hash{Symbol=>Object}?
Custom metadata to attach to the payment.
61 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 61 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#payment_method_id ⇒ String
The ID of the payment method to use for the payment. It must be connected to the Member being charged.
49 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 49 required :payment_method_id, String |
#plan ⇒ WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan::Plan
Pass this object to create a new plan for this payment
55 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 55 required :plan, -> { WhopSDK::PaymentCreateParams::Body::CreatePaymentInputWithPlan::Plan } |
#promo_code_id ⇒ String?
The ID of an active promo code to apply to this payment. The promo code must belong to the company and be valid for the plan being purchased. The plan must be attached to a product — promo codes are not eligible for one-off purchases.
69 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 69 optional :promo_code_id, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
62 |
# File 'sig/whop_sdk/models/payment_create_params.rbs', line 62
def to_hash: -> {
|