Class: WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan::Plan::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlan::Plan::Product
- Defined in:
- lib/whop_sdk/models/payment_create_params.rb,
sig/whop_sdk/models/payment_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
-
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e.
-
#description ⇒ String?
A written description of the product.
-
#external_identifier ⇒ String
A unique ID used to find or create a product.
-
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
-
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
-
#headline ⇒ String?
The headline of the product.
-
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
-
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
-
#route ⇒ String?
The route of the product.
-
#title ⇒ String
The title of the product.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
198 |
# File 'sig/whop_sdk/models/payment_create_params.rbs', line 198
def initialize: (
|
Instance Attribute Details
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
250 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 250 optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true |
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ', "
258 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 258 optional :custom_statement_descriptor, String, nil?: true |
#description ⇒ String?
A written description of the product.
264 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 264 optional :description, String, nil?: true |
#external_identifier ⇒ String
A unique ID used to find or create a product. When provided during creation, we will look for an existing product with this external identifier — if found, it will be updated; otherwise, a new product will be created.
238 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 238 required :external_identifier, String |
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
270 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 270 optional :global_affiliate_percentage, Float, nil?: true |
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
276 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 276 optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true |
#headline ⇒ String?
The headline of the product.
282 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 282 optional :headline, String, nil?: true |
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
288 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 288 optional :product_tax_code_id, String, nil?: true |
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
294 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 294 optional :redirect_purchase_url, String, nil?: true |
#route ⇒ String?
The route of the product.
300 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 300 optional :route, String, nil?: true |
#title ⇒ String
The title of the product.
244 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 244 required :title, String |
#visibility ⇒ Symbol, ...
Visibility of a resource
306 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 306 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |
Instance Method Details
#to_hash ⇒ {
213 |
# File 'sig/whop_sdk/models/payment_create_params.rbs', line 213
def to_hash: -> {
|