Class: WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlanID

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_create_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id:, member_id:, payment_method_id:, plan_id:, metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlanID for more details.

Autogenerated input type of CreatePayment

Parameters:

  • company_id (String)

    The ID of the company to create the payment for.

  • member_id (String)

    The ID of the member to create the payment for.

  • payment_method_id (String)

    The ID of the payment method to use for the payment. It must be connected to the

  • plan_id (String)

    An ID of an existing plan to use for the payment.

  • metadata (Hash{Symbol=>Object}, nil) (defaults to: nil)

    Custom metadata to attach to the payment.



# File 'lib/whop_sdk/models/payment_create_params.rb', line 366

Instance Attribute Details

#company_idString

The ID of the company to create the payment for.

Returns:

  • (String)


339
# File 'lib/whop_sdk/models/payment_create_params.rb', line 339

required :company_id, String

#member_idString

The ID of the member to create the payment for.

Returns:

  • (String)


345
# File 'lib/whop_sdk/models/payment_create_params.rb', line 345

required :member_id, String

#metadataHash{Symbol=>Object}?

Custom metadata to attach to the payment.

Returns:

  • (Hash{Symbol=>Object}, nil)


364
# File 'lib/whop_sdk/models/payment_create_params.rb', line 364

optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#payment_method_idString

The ID of the payment method to use for the payment. It must be connected to the Member being charged.

Returns:

  • (String)


352
# File 'lib/whop_sdk/models/payment_create_params.rb', line 352

required :payment_method_id, String

#plan_idString

An ID of an existing plan to use for the payment.

Returns:

  • (String)


358
# File 'lib/whop_sdk/models/payment_create_params.rb', line 358

required :plan_id, String