Class: WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlanID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlanID
- Defined in:
- lib/whop_sdk/models/payment_create_params.rb
Instance Attribute Summary collapse
-
#company_id ⇒ String
The ID of the company to create the payment for.
-
#member_id ⇒ String
The ID of the member to create the payment for.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom metadata to attach to the payment.
-
#payment_method_id ⇒ String
The ID of the payment method to use for the payment.
-
#plan_id ⇒ String
An ID of an existing plan to use for the payment.
Instance Method Summary collapse
-
#initialize(company_id:, member_id:, payment_method_id:, plan_id:, metadata: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see CreatePaymentInputWithPlanID for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, member_id:, payment_method_id:, plan_id:, metadata: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentCreateParams::Body::CreatePaymentInputWithPlanID for more details.
Autogenerated input type of CreatePayment
|
|
# File 'lib/whop_sdk/models/payment_create_params.rb', line 366
|
Instance Attribute Details
#company_id ⇒ String
The ID of the company to create the payment for.
339 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 339 required :company_id, String |
#member_id ⇒ String
The ID of the member to create the payment for.
345 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 345 required :member_id, String |
#metadata ⇒ Hash{Symbol=>Object}?
Custom metadata to attach to the payment.
364 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 364 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#payment_method_id ⇒ String
The ID of the payment method to use for the payment. It must be connected to the Member being charged.
352 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 352 required :payment_method_id, String |
#plan_id ⇒ String
An ID of an existing plan to use for the payment.
358 |
# File 'lib/whop_sdk/models/payment_create_params.rb', line 358 required :plan_id, String |