Class: WhopSDK::Models::PaymentListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/payment_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#billing_reasons ⇒ Array<Symbol, WhopSDK::Models::BillingReasons>?
Filter payments by their billing reason.
-
#company_id ⇒ String?
The unique identifier of the company to list payments for.
-
#created_after ⇒ Time?
Only return payments created after this timestamp.
-
#created_before ⇒ Time?
Only return payments created before this timestamp.
-
#currencies ⇒ Array<Symbol, WhopSDK::Models::Currency>?
Filter payments by their currency code.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#include_free ⇒ Boolean?
Whether to include payments with a zero amount.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#order ⇒ Symbol, ...
The order to sort the results by.
-
#plan_ids ⇒ Array<String>?
Filter payments to only those associated with these specific plan identifiers.
-
#product_ids ⇒ Array<String>?
Filter payments to only those associated with these specific product identifiers.
-
#query ⇒ String?
Search payments by user ID, membership ID, user email, name, or username.
-
#statuses ⇒ Array<Symbol, WhopSDK::Models::ReceiptStatus>?
Filter payments by their current status.
-
#substatuses ⇒ Array<Symbol, WhopSDK::Models::FriendlyReceiptStatus>?
Filter payments by their current substatus for more granular filtering.
-
#updated_after ⇒ Time?
Only return payments last updated after this timestamp.
-
#updated_before ⇒ Time?
Only return payments last updated before this timestamp.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, before: nil, billing_reasons: nil, company_id: nil, created_after: nil, created_before: nil, currencies: nil, direction: nil, first: nil, include_free: nil, last: nil, order: nil, plan_ids: nil, product_ids: nil, query: nil, statuses: nil, substatuses: nil, updated_after: nil, updated_before: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, billing_reasons: nil, company_id: nil, created_after: nil, created_before: nil, currencies: nil, direction: nil, first: nil, include_free: nil, last: nil, order: nil, plan_ids: nil, product_ids: nil, query: nil, statuses: nil, substatuses: nil, updated_after: nil, updated_before: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentListParams for more details.
|
|
# File 'lib/whop_sdk/models/payment_list_params.rb', line 130
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
14 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 14 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
20 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 20 optional :before, String, nil?: true |
#billing_reasons ⇒ Array<Symbol, WhopSDK::Models::BillingReasons>?
Filter payments by their billing reason.
26 27 28 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 26 optional :billing_reasons, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::BillingReasons] }, nil?: true |
#company_id ⇒ String?
The unique identifier of the company to list payments for.
34 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 34 optional :company_id, String, nil?: true |
#created_after ⇒ Time?
Only return payments created after this timestamp.
40 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 40 optional :created_after, Time, nil?: true |
#created_before ⇒ Time?
Only return payments created before this timestamp.
46 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 46 optional :created_before, Time, nil?: true |
#currencies ⇒ Array<Symbol, WhopSDK::Models::Currency>?
Filter payments by their currency code.
52 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 52 optional :currencies, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::Currency] }, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
58 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 58 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
64 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 64 optional :first, Integer, nil?: true |
#include_free ⇒ Boolean?
Whether to include payments with a zero amount.
70 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 70 optional :include_free, WhopSDK::Internal::Type::Boolean, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
76 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 76 optional :last, Integer, nil?: true |
#order ⇒ Symbol, ...
The order to sort the results by.
82 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 82 optional :order, enum: -> { WhopSDK::PaymentListParams::Order }, nil?: true |
#plan_ids ⇒ Array<String>?
Filter payments to only those associated with these specific plan identifiers.
88 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 88 optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#product_ids ⇒ Array<String>?
Filter payments to only those associated with these specific product identifiers.
95 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 95 optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#query ⇒ String?
Search payments by user ID, membership ID, user email, name, or username. Email filtering requires the member:email:read permission.
102 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 102 optional :query, String, nil?: true |
#statuses ⇒ Array<Symbol, WhopSDK::Models::ReceiptStatus>?
Filter payments by their current status.
108 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 108 optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ReceiptStatus] }, nil?: true |
#substatuses ⇒ Array<Symbol, WhopSDK::Models::FriendlyReceiptStatus>?
Filter payments by their current substatus for more granular filtering.
114 115 116 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 114 optional :substatuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::FriendlyReceiptStatus] }, nil?: true |
#updated_after ⇒ Time?
Only return payments last updated after this timestamp.
122 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 122 optional :updated_after, Time, nil?: true |
#updated_before ⇒ Time?
Only return payments last updated before this timestamp.
128 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 128 optional :updated_before, Time, nil?: true |