Class: WhopSDK::Models::PaymentListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/payment_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#billing_reasons ⇒ Array<Symbol, WhopSDK::Models::BillingReasons>?
The billing reason for the payment.
-
#company_id ⇒ String
The ID of the company to list payments for.
-
#created_after ⇒ Time?
The minimum creation date to filter by.
-
#created_before ⇒ Time?
The maximum creation date to filter by.
-
#currencies ⇒ Array<Symbol, WhopSDK::Models::Currency>?
The currency of the payment.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#include_free ⇒ Boolean?
Whether to include free payments.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#order ⇒ Symbol, ...
The order to sort the results by.
-
#plan_ids ⇒ Array<String>?
A specific plan.
-
#product_ids ⇒ Array<String>?
A specific product.
-
#statuses ⇒ Array<Symbol, WhopSDK::Models::ReceiptStatus>?
The status of the payment.
-
#substatuses ⇒ Array<Symbol, WhopSDK::Models::FriendlyReceiptStatus>?
The substatus of the payment.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id: , after: nil, before: nil, billing_reasons: nil, created_after: nil, created_before: nil, currencies: nil, direction: nil, first: nil, include_free: nil, last: nil, order: nil, plan_ids: nil, product_ids: nil, statuses: nil, substatuses: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/payment_list_params.rb', line 110
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
20 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 20 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
26 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 26 optional :before, String, nil?: true |
#billing_reasons ⇒ Array<Symbol, WhopSDK::Models::BillingReasons>?
The billing reason for the payment
32 33 34 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 32 optional :billing_reasons, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::BillingReasons] }, nil?: true |
#company_id ⇒ String
The ID of the company to list payments for
14 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 14 required :company_id, String |
#created_after ⇒ Time?
The minimum creation date to filter by
40 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 40 optional :created_after, Time, nil?: true |
#created_before ⇒ Time?
The maximum creation date to filter by
46 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 46 optional :created_before, Time, nil?: true |
#currencies ⇒ Array<Symbol, WhopSDK::Models::Currency>?
The currency of the payment.
52 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 52 optional :currencies, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::Currency] }, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
58 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 58 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
64 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 64 optional :first, Integer, nil?: true |
#include_free ⇒ Boolean?
Whether to include free payments.
70 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 70 optional :include_free, WhopSDK::Internal::Type::Boolean, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
76 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 76 optional :last, Integer, nil?: true |
#order ⇒ Symbol, ...
The order to sort the results by.
82 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 82 optional :order, enum: -> { WhopSDK::PaymentListParams::Order }, nil?: true |
#plan_ids ⇒ Array<String>?
A specific plan.
88 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 88 optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#product_ids ⇒ Array<String>?
A specific product.
94 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 94 optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#statuses ⇒ Array<Symbol, WhopSDK::Models::ReceiptStatus>?
The status of the payment.
100 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 100 optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ReceiptStatus] }, nil?: true |
#substatuses ⇒ Array<Symbol, WhopSDK::Models::FriendlyReceiptStatus>?
The substatus of the payment.
106 107 108 |
# File 'lib/whop_sdk/models/payment_list_params.rb', line 106 optional :substatuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::FriendlyReceiptStatus] }, nil?: true |