Class: WhopSDK::Models::PaymentListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/payment_list_params.rb

Overview

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id: , after: nil, before: nil, billing_reasons: nil, created_after: nil, created_before: nil, currencies: nil, direction: nil, first: nil, include_free: nil, last: nil, order: nil, plan_ids: nil, product_ids: nil, statuses: nil, substatuses: nil, request_options: {}) ⇒ Object

Parameters:

  • company_id (String) (defaults to: )

    The ID of the company to list payments for

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • billing_reasons (Array<Symbol, WhopSDK::Models::BillingReasons>, nil) (defaults to: nil)

    The billing reason for the payment

  • created_after (Time, nil) (defaults to: nil)

    The minimum creation date to filter by

  • created_before (Time, nil) (defaults to: nil)

    The maximum creation date to filter by

  • currencies (Array<Symbol, WhopSDK::Models::Currency>, nil) (defaults to: nil)

    The currency of the payment.

  • direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • include_free (Boolean, nil) (defaults to: nil)

    Whether to include free payments.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • order (Symbol, WhopSDK::Models::PaymentListParams::Order, nil) (defaults to: nil)

    The order to sort the results by.

  • plan_ids (Array<String>, nil) (defaults to: nil)

    A specific plan.

  • product_ids (Array<String>, nil) (defaults to: nil)

    A specific product.

  • statuses (Array<Symbol, WhopSDK::Models::ReceiptStatus>, nil) (defaults to: nil)

    The status of the payment.

  • substatuses (Array<Symbol, WhopSDK::Models::FriendlyReceiptStatus>, nil) (defaults to: nil)

    The substatus of the payment.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/payment_list_params.rb', line 110

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/payment_list_params.rb', line 20

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/payment_list_params.rb', line 26

optional :before, String, nil?: true

#billing_reasonsArray<Symbol, WhopSDK::Models::BillingReasons>?

The billing reason for the payment

Returns:



32
33
34
# File 'lib/whop_sdk/models/payment_list_params.rb', line 32

optional :billing_reasons,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::BillingReasons] },
nil?: true

#company_idString

The ID of the company to list payments for

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/payment_list_params.rb', line 14

required :company_id, String

#created_afterTime?

The minimum creation date to filter by

Returns:

  • (Time, nil)


40
# File 'lib/whop_sdk/models/payment_list_params.rb', line 40

optional :created_after, Time, nil?: true

#created_beforeTime?

The maximum creation date to filter by

Returns:

  • (Time, nil)


46
# File 'lib/whop_sdk/models/payment_list_params.rb', line 46

optional :created_before, Time, nil?: true

#currenciesArray<Symbol, WhopSDK::Models::Currency>?

The currency of the payment.

Returns:



52
# File 'lib/whop_sdk/models/payment_list_params.rb', line 52

optional :currencies, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::Currency] }, nil?: true

#directionSymbol, ...

The direction of the sort.

Returns:



58
# File 'lib/whop_sdk/models/payment_list_params.rb', line 58

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


64
# File 'lib/whop_sdk/models/payment_list_params.rb', line 64

optional :first, Integer, nil?: true

#include_freeBoolean?

Whether to include free payments.

Returns:

  • (Boolean, nil)


70
# File 'lib/whop_sdk/models/payment_list_params.rb', line 70

optional :include_free, WhopSDK::Internal::Type::Boolean, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


76
# File 'lib/whop_sdk/models/payment_list_params.rb', line 76

optional :last, Integer, nil?: true

#orderSymbol, ...

The order to sort the results by.



82
# File 'lib/whop_sdk/models/payment_list_params.rb', line 82

optional :order, enum: -> { WhopSDK::PaymentListParams::Order }, nil?: true

#plan_idsArray<String>?

A specific plan.

Returns:

  • (Array<String>, nil)


88
# File 'lib/whop_sdk/models/payment_list_params.rb', line 88

optional :plan_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#product_idsArray<String>?

A specific product.

Returns:

  • (Array<String>, nil)


94
# File 'lib/whop_sdk/models/payment_list_params.rb', line 94

optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#statusesArray<Symbol, WhopSDK::Models::ReceiptStatus>?

The status of the payment.

Returns:



100
# File 'lib/whop_sdk/models/payment_list_params.rb', line 100

optional :statuses, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::ReceiptStatus] }, nil?: true

#substatusesArray<Symbol, WhopSDK::Models::FriendlyReceiptStatus>?

The substatus of the payment.

Returns:



106
107
108
# File 'lib/whop_sdk/models/payment_list_params.rb', line 106

optional :substatuses,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::FriendlyReceiptStatus] },
nil?: true