Class: WhopSDK::Models::PaymentListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentListResponse
- Defined in:
- lib/whop_sdk/models/payment_list_response.rb
Overview
Defined Under Namespace
Classes: ApplicationFee, BillingAddress, Company, Member, Membership, PaymentMethod, Plan, Product, PromoCode, User
Instance Attribute Summary collapse
-
#amount_after_fees ⇒ Float
How much the payment is for after fees.
-
#application_fee ⇒ WhopSDK::Models::PaymentListResponse::ApplicationFee?
The application fee charged on this payment.
-
#auto_refunded ⇒ Boolean
Whether this payment was auto refunded or not.
-
#billing_address ⇒ WhopSDK::Models::PaymentListResponse::BillingAddress?
The address of the user who made the payment.
-
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed.
-
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#card_last4 ⇒ String?
The last four digits of the card used to make this payment.
-
#company ⇒ WhopSDK::Models::PaymentListResponse::Company?
The company for the payment.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed.
-
#failure_message ⇒ String?
If the payment failed, the reason for the failure.
-
#id ⇒ String
The unique identifier for the payment.
-
#last_payment_attempt ⇒ Time?
The time of the last payment attempt.
-
#member ⇒ WhopSDK::Models::PaymentListResponse::Member?
The member attached to this payment.
-
#membership ⇒ WhopSDK::Models::PaymentListResponse::Membership?
The membership attached to this payment.
-
#metadata ⇒ Hash{Symbol=>Object}?
The custom metadata stored on this payment.
-
#next_payment_attempt ⇒ Time?
The time of the next schedule payment retry.
-
#paid_at ⇒ Time?
The time at which this payment was successfully collected.
-
#payment_method ⇒ WhopSDK::Models::PaymentListResponse::PaymentMethod?
The tokenized payment method reference used for this payment.
-
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
-
#payments_failed ⇒ Integer?
The number of failed payment attempts for the payment.
-
#plan ⇒ WhopSDK::Models::PaymentListResponse::Plan?
The plan attached to this payment.
-
#product ⇒ WhopSDK::Models::PaymentListResponse::Product?
The product this payment was made for.
-
#promo_code ⇒ WhopSDK::Models::PaymentListResponse::PromoCode?
The promo code used for this payment.
-
#refundable ⇒ Boolean
True only for payments that are ‘paid`, have not been fully refunded, and were processed by a payment processor that allows refunds.
-
#refunded_amount ⇒ Float?
The payment refund amount(if applicable).
-
#refunded_at ⇒ Time?
When the payment was refunded (if applicable).
-
#retryable ⇒ Boolean
True when the payment status is ‘open` and its membership is in one of the retry-eligible states (`active`, `trialing`, `completed`, or `past_due`); otherwise false.
-
#status ⇒ Symbol, ...
The status of a receipt.
-
#substatus ⇒ Symbol, WhopSDK::Models::FriendlyReceiptStatus
The friendly status of the payment.
-
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
-
#tax_amount ⇒ Float?
The calculated amount of the sales/VAT tax (if applicable).
-
#tax_behavior ⇒ Symbol, ...
The type of tax inclusivity applied to the receipt, for determining whether the tax is included in the final price, or paid on top.
-
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
-
#updated_at ⇒ Time
The datetime the payment was last updated.
-
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
-
#user ⇒ WhopSDK::Models::PaymentListResponse::User?
The user that made this payment.
-
#voidable ⇒ Boolean
True when the payment is tied to a membership in ‘past_due`, the payment status is `open`, and the processor allows voiding payments; otherwise false.
Instance Method Summary collapse
-
#initialize(id:, amount_off:, base_currency:, code:, number_of_intervals:, promo_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PromoCode for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount_off:, base_currency:, code:, number_of_intervals:, promo_type:) ⇒ Object
Some parameter documentations has been truncated, see PromoCode for more details.
The promo code used for this payment.
|
|
# File 'lib/whop_sdk/models/payment_list_response.rb', line 250
|
Instance Attribute Details
#amount_after_fees ⇒ Float
How much the payment is for after fees
17 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 17 required :amount_after_fees, Float |
#application_fee ⇒ WhopSDK::Models::PaymentListResponse::ApplicationFee?
The application fee charged on this payment.
23 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 23 required :application_fee, -> { WhopSDK::Models::PaymentListResponse::ApplicationFee }, nil?: true |
#auto_refunded ⇒ Boolean
Whether this payment was auto refunded or not
29 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 29 required :auto_refunded, WhopSDK::Internal::Type::Boolean |
#billing_address ⇒ WhopSDK::Models::PaymentListResponse::BillingAddress?
The address of the user who made the payment.
35 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 35 required :billing_address, -> { WhopSDK::Models::PaymentListResponse::BillingAddress }, nil?: true |
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed
41 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 41 required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true |
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have
47 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 47 required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#card_last4 ⇒ String?
The last four digits of the card used to make this payment. Null if the payment was not made with a card.
54 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 54 required :card_last4, String, nil?: true |
#company ⇒ WhopSDK::Models::PaymentListResponse::Company?
The company for the payment.
60 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 60 required :company, -> { WhopSDK::Models::PaymentListResponse::Company }, nil?: true |
#created_at ⇒ Time
The datetime the payment was created.
66 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 66 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
72 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 72 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed
78 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 78 required :dispute_alerted_at, Time, nil?: true |
#failure_message ⇒ String?
If the payment failed, the reason for the failure.
84 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 84 required :failure_message, String, nil?: true |
#id ⇒ String
The unique identifier for the payment.
11 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 11 required :id, String |
#last_payment_attempt ⇒ Time?
The time of the last payment attempt.
90 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 90 required :last_payment_attempt, Time, nil?: true |
#member ⇒ WhopSDK::Models::PaymentListResponse::Member?
The member attached to this payment.
96 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 96 required :member, -> { WhopSDK::Models::PaymentListResponse::Member }, nil?: true |
#membership ⇒ WhopSDK::Models::PaymentListResponse::Membership?
The membership attached to this payment.
102 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 102 required :membership, -> { WhopSDK::Models::PaymentListResponse::Membership }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
The custom metadata stored on this payment. This will be copied over to the checkout configuration for which this payment was made
109 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 109 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#next_payment_attempt ⇒ Time?
The time of the next schedule payment retry.
115 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 115 required :next_payment_attempt, Time, nil?: true |
#paid_at ⇒ Time?
The time at which this payment was successfully collected. Null if the payment has not yet succeeded. As a Unix timestamp.
122 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 122 required :paid_at, Time, nil?: true |
#payment_method ⇒ WhopSDK::Models::PaymentListResponse::PaymentMethod?
The tokenized payment method reference used for this payment. Null if no token was used.
129 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 129 required :payment_method, -> { WhopSDK::Models::PaymentListResponse::PaymentMethod }, nil?: true |
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
135 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 135 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true |
#payments_failed ⇒ Integer?
The number of failed payment attempts for the payment.
141 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 141 required :payments_failed, Integer, nil?: true |
#plan ⇒ WhopSDK::Models::PaymentListResponse::Plan?
The plan attached to this payment.
147 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 147 required :plan, -> { WhopSDK::Models::PaymentListResponse::Plan }, nil?: true |
#product ⇒ WhopSDK::Models::PaymentListResponse::Product?
The product this payment was made for
153 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 153 required :product, -> { WhopSDK::Models::PaymentListResponse::Product }, nil?: true |
#promo_code ⇒ WhopSDK::Models::PaymentListResponse::PromoCode?
The promo code used for this payment.
159 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 159 required :promo_code, -> { WhopSDK::Models::PaymentListResponse::PromoCode }, nil?: true |
#refundable ⇒ Boolean
True only for payments that are ‘paid`, have not been fully refunded, and were processed by a payment processor that allows refunds.
166 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 166 required :refundable, WhopSDK::Internal::Type::Boolean |
#refunded_amount ⇒ Float?
The payment refund amount(if applicable).
172 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 172 required :refunded_amount, Float, nil?: true |
#refunded_at ⇒ Time?
When the payment was refunded (if applicable).
178 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 178 required :refunded_at, Time, nil?: true |
#retryable ⇒ Boolean
True when the payment status is ‘open` and its membership is in one of the retry-eligible states (`active`, `trialing`, `completed`, or `past_due`); otherwise false. Used to decide if Whop can attempt the charge again.
186 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 186 required :retryable, WhopSDK::Internal::Type::Boolean |
#status ⇒ Symbol, ...
The status of a receipt
192 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 192 required :status, enum: -> { WhopSDK::ReceiptStatus }, nil?: true |
#substatus ⇒ Symbol, WhopSDK::Models::FriendlyReceiptStatus
The friendly status of the payment.
198 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 198 required :substatus, enum: -> { WhopSDK::FriendlyReceiptStatus } |
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
204 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 204 required :subtotal, Float, nil?: true |
#tax_amount ⇒ Float?
The calculated amount of the sales/VAT tax (if applicable).
210 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 210 required :tax_amount, Float, nil?: true |
#tax_behavior ⇒ Symbol, ...
The type of tax inclusivity applied to the receipt, for determining whether the tax is included in the final price, or paid on top.
217 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 217 required :tax_behavior, enum: -> { WhopSDK::ReceiptTaxBehavior }, nil?: true |
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
223 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 223 required :total, Float, nil?: true |
#updated_at ⇒ Time
The datetime the payment was last updated.
229 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 229 required :updated_at, Time |
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
235 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 235 required :usd_total, Float, nil?: true |
#user ⇒ WhopSDK::Models::PaymentListResponse::User?
The user that made this payment.
241 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 241 required :user, -> { WhopSDK::Models::PaymentListResponse::User }, nil?: true |