Class: WhopSDK::Models::PaymentListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentListResponse
- Defined in:
- lib/whop_sdk/models/payment_list_response.rb
Overview
Defined Under Namespace
Classes: BillingAddress, Company, Member, Membership, Plan, Product, PromoCode, User
Instance Attribute Summary collapse
-
#amount_after_fees ⇒ Float
How much the payment is for after fees.
-
#auto_refunded ⇒ Boolean
Whether this payment was auto refunded or not.
-
#billing_address ⇒ WhopSDK::Models::PaymentListResponse::BillingAddress?
The address of the user who made the payment.
-
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed.
-
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#card_last4 ⇒ String?
The last 4 digits of the card used to make the payment.
-
#company ⇒ WhopSDK::Models::PaymentListResponse::Company?
The company for the payment.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed.
-
#failure_message ⇒ String?
If the payment failed, the reason for the failure.
-
#id ⇒ String
The payment ID.
-
#last_payment_attempt ⇒ Time?
The time of the last payment attempt.
-
#member ⇒ WhopSDK::Models::PaymentListResponse::Member?
The member attached to this payment.
-
#membership ⇒ WhopSDK::Models::PaymentListResponse::Membership?
The membership attached to this payment.
-
#paid_at ⇒ Time?
The datetime the payment was paid.
-
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
-
#plan ⇒ WhopSDK::Models::PaymentListResponse::Plan?
The plan attached to this payment.
-
#product ⇒ WhopSDK::Models::PaymentListResponse::Product?
The access pass attached to this payment.
-
#promo_code ⇒ WhopSDK::Models::PaymentListResponse::PromoCode?
The promo code used for this payment.
-
#refundable ⇒ Boolean
True only for payments that are ‘paid`, have not been fully refunded, and were processed by a payment processor that allows refunds.
-
#refunded_amount ⇒ Float?
The payment refund amount(if applicable).
-
#refunded_at ⇒ Time?
When the payment was refunded (if applicable).
-
#retryable ⇒ Boolean
True when the payment status is ‘open` and its membership is in one of the retry-eligible states (`active`, `trialing`, `completed`, or `past_due`); otherwise false.
-
#status ⇒ Symbol, ...
The status of a receipt.
-
#substatus ⇒ Symbol, WhopSDK::Models::FriendlyReceiptStatus
The friendly status of the payment.
-
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
-
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
-
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
-
#user ⇒ WhopSDK::Models::PaymentListResponse::User?
The user that made this payment.
-
#voidable ⇒ Boolean
True when the payment is tied to a membership in ‘past_due`, the payment status is `open`, and the processor allows voiding payments; otherwise false.
Instance Method Summary collapse
-
#initialize(id: , amount_off: , base_currency: , code: , number_of_intervals: , promo_type: ) ⇒ Object
constructor
The promo code used for this payment.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , amount_off: , base_currency: , code: , number_of_intervals: , promo_type: ) ⇒ Object
The promo code used for this payment.
|
|
# File 'lib/whop_sdk/models/payment_list_response.rb', line 197
|
Instance Attribute Details
#amount_after_fees ⇒ Float
How much the payment is for after fees
17 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 17 required :amount_after_fees, Float |
#auto_refunded ⇒ Boolean
Whether this payment was auto refunded or not
23 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 23 required :auto_refunded, WhopSDK::Internal::Type::Boolean |
#billing_address ⇒ WhopSDK::Models::PaymentListResponse::BillingAddress?
The address of the user who made the payment.
29 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 29 required :billing_address, -> { WhopSDK::Models::PaymentListResponse::BillingAddress }, nil?: true |
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed
35 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 35 required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true |
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have
41 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 41 required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#card_last4 ⇒ String?
The last 4 digits of the card used to make the payment.
47 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 47 required :card_last4, String, nil?: true |
#company ⇒ WhopSDK::Models::PaymentListResponse::Company?
The company for the payment.
53 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 53 required :company, -> { WhopSDK::Models::PaymentListResponse::Company }, nil?: true |
#created_at ⇒ Time
The datetime the payment was created
59 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 59 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
65 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 65 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed
71 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 71 required :dispute_alerted_at, Time, nil?: true |
#failure_message ⇒ String?
If the payment failed, the reason for the failure.
77 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 77 required :failure_message, String, nil?: true |
#id ⇒ String
The payment ID
11 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 11 required :id, String |
#last_payment_attempt ⇒ Time?
The time of the last payment attempt.
83 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 83 required :last_payment_attempt, Time, nil?: true |
#member ⇒ WhopSDK::Models::PaymentListResponse::Member?
The member attached to this payment.
89 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 89 required :member, -> { WhopSDK::Models::PaymentListResponse::Member }, nil?: true |
#membership ⇒ WhopSDK::Models::PaymentListResponse::Membership?
The membership attached to this payment.
95 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 95 required :membership, -> { WhopSDK::Models::PaymentListResponse::Membership }, nil?: true |
#paid_at ⇒ Time?
The datetime the payment was paid
101 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 101 required :paid_at, Time, nil?: true |
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
107 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 107 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true |
#plan ⇒ WhopSDK::Models::PaymentListResponse::Plan?
The plan attached to this payment.
113 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 113 required :plan, -> { WhopSDK::Models::PaymentListResponse::Plan }, nil?: true |
#product ⇒ WhopSDK::Models::PaymentListResponse::Product?
The access pass attached to this payment.
119 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 119 required :product, -> { WhopSDK::Models::PaymentListResponse::Product }, nil?: true |
#promo_code ⇒ WhopSDK::Models::PaymentListResponse::PromoCode?
The promo code used for this payment.
125 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 125 required :promo_code, -> { WhopSDK::Models::PaymentListResponse::PromoCode }, nil?: true |
#refundable ⇒ Boolean
True only for payments that are ‘paid`, have not been fully refunded, and were processed by a payment processor that allows refunds.
132 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 132 required :refundable, WhopSDK::Internal::Type::Boolean |
#refunded_amount ⇒ Float?
The payment refund amount(if applicable).
138 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 138 required :refunded_amount, Float, nil?: true |
#refunded_at ⇒ Time?
When the payment was refunded (if applicable).
144 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 144 required :refunded_at, Time, nil?: true |
#retryable ⇒ Boolean
True when the payment status is ‘open` and its membership is in one of the retry-eligible states (`active`, `trialing`, `completed`, or `past_due`); otherwise false. Used to decide if Whop can attempt the charge again.
152 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 152 required :retryable, WhopSDK::Internal::Type::Boolean |
#status ⇒ Symbol, ...
The status of a receipt
158 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 158 required :status, enum: -> { WhopSDK::ReceiptStatus }, nil?: true |
#substatus ⇒ Symbol, WhopSDK::Models::FriendlyReceiptStatus
The friendly status of the payment.
164 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 164 required :substatus, enum: -> { WhopSDK::FriendlyReceiptStatus } |
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
170 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 170 required :subtotal, Float, nil?: true |
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
176 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 176 required :total, Float, nil?: true |
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
182 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 182 required :usd_total, Float, nil?: true |
#user ⇒ WhopSDK::Models::PaymentListResponse::User?
The user that made this payment.
188 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 188 required :user, -> { WhopSDK::Models::PaymentListResponse::User }, nil?: true |