Class: WhopSDK::Models::PaymentListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_list_response.rb

Overview

Defined Under Namespace

Classes: BillingAddress, Company, Member, Membership, Plan, Product, PromoCode, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , amount_off: , base_currency: , code: , number_of_intervals: , promo_type: ) ⇒ Object

The promo code used for this payment.

Parameters:

  • id (String) (defaults to: )

    The ID of the promo.

  • amount_off (Float) (defaults to: )

    The amount off (% or flat amount) for the promo.

  • base_currency (Symbol, WhopSDK::Models::Currency) (defaults to: )

    The monetary currency of the promo code.

  • code (String, nil) (defaults to: )

    The specific code used to apply the promo at checkout.

  • number_of_intervals (Integer, nil) (defaults to: )

    The number of billing cycles the promo is applied for.

  • promo_type (Symbol, WhopSDK::Models::PromoType) (defaults to: )

    The type (% or flat amount) of the promo.



# File 'lib/whop_sdk/models/payment_list_response.rb', line 194

Instance Attribute Details

#amount_after_feesFloat

How much the payment is for after fees

Returns:

  • (Float)


17
# File 'lib/whop_sdk/models/payment_list_response.rb', line 17

required :amount_after_fees, Float

#auto_refundedBoolean

Whether this payment was auto refunded or not

Returns:

  • (Boolean)


23
# File 'lib/whop_sdk/models/payment_list_response.rb', line 23

required :auto_refunded, WhopSDK::Internal::Type::Boolean

#billing_addressWhopSDK::Models::PaymentListResponse::BillingAddress?

The address of the user who made the payment.



29
# File 'lib/whop_sdk/models/payment_list_response.rb', line 29

required :billing_address, -> { WhopSDK::Models::PaymentListResponse::BillingAddress }, nil?: true

#billing_reasonString?

The billing reason

Returns:

  • (String, nil)


35
# File 'lib/whop_sdk/models/payment_list_response.rb', line 35

required :billing_reason, String, nil?: true

#card_brandString?

The type of card used as the payment method.

Returns:

  • (String, nil)


41
# File 'lib/whop_sdk/models/payment_list_response.rb', line 41

required :card_brand, String, nil?: true

#card_last4String?

The last 4 digits of the card used to make the payment.

Returns:

  • (String, nil)


47
# File 'lib/whop_sdk/models/payment_list_response.rb', line 47

required :card_last4, String, nil?: true

#companyWhopSDK::Models::PaymentListResponse::Company?

The company for the payment.



53
# File 'lib/whop_sdk/models/payment_list_response.rb', line 53

required :company, -> { WhopSDK::Models::PaymentListResponse::Company }, nil?: true

#created_atTime

The datetime the payment was created

Returns:

  • (Time)


59
# File 'lib/whop_sdk/models/payment_list_response.rb', line 59

required :created_at, Time

#currencySymbol, ...

The available currencies on the platform

Returns:



65
# File 'lib/whop_sdk/models/payment_list_response.rb', line 65

required :currency, enum: -> { WhopSDK::Currency }, nil?: true

#dispute_alerted_atTime?

When an alert came in that this transaction will be disputed

Returns:

  • (Time, nil)


71
# File 'lib/whop_sdk/models/payment_list_response.rb', line 71

required :dispute_alerted_at, Time, nil?: true

#failure_messageString?

If the payment failed, the reason for the failure.

Returns:

  • (String, nil)


77
# File 'lib/whop_sdk/models/payment_list_response.rb', line 77

required :failure_message, String, nil?: true

#idString

The payment ID

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/payment_list_response.rb', line 11

required :id, String

#last_payment_attemptTime?

The time of the last payment attempt.

Returns:

  • (Time, nil)


83
# File 'lib/whop_sdk/models/payment_list_response.rb', line 83

required :last_payment_attempt, Time, nil?: true

#memberWhopSDK::Models::PaymentListResponse::Member?

The member attached to this payment.



89
# File 'lib/whop_sdk/models/payment_list_response.rb', line 89

required :member, -> { WhopSDK::Models::PaymentListResponse::Member }, nil?: true

#membershipWhopSDK::Models::PaymentListResponse::Membership?

The membership attached to this payment.



95
# File 'lib/whop_sdk/models/payment_list_response.rb', line 95

required :membership, -> { WhopSDK::Models::PaymentListResponse::Membership }, nil?: true

The datetime the payment was paid

Returns:

  • (Time, nil)


101
# File 'lib/whop_sdk/models/payment_list_response.rb', line 101

required :paid_at, Time, nil?: true

#payment_method_typeString?

Returns the type of payment method used for the payment, if available. Ex. klarna, affirm, card, cashapp

Returns:

  • (String, nil)


108
# File 'lib/whop_sdk/models/payment_list_response.rb', line 108

required :payment_method_type, String, nil?: true

#planWhopSDK::Models::PaymentListResponse::Plan?

The plan attached to this payment.



114
# File 'lib/whop_sdk/models/payment_list_response.rb', line 114

required :plan, -> { WhopSDK::Models::PaymentListResponse::Plan }, nil?: true

#productWhopSDK::Models::PaymentListResponse::Product?

The access pass attached to this payment.



120
# File 'lib/whop_sdk/models/payment_list_response.rb', line 120

required :product, -> { WhopSDK::Models::PaymentListResponse::Product }, nil?: true

#promo_codeWhopSDK::Models::PaymentListResponse::PromoCode?

The promo code used for this payment.



126
# File 'lib/whop_sdk/models/payment_list_response.rb', line 126

required :promo_code, -> { WhopSDK::Models::PaymentListResponse::PromoCode }, nil?: true

#refundableBoolean

Whether the payment can be refunded.

Returns:

  • (Boolean)


132
# File 'lib/whop_sdk/models/payment_list_response.rb', line 132

required :refundable, WhopSDK::Internal::Type::Boolean

#refunded_amountFloat?

The payment refund amount(if applicable).

Returns:

  • (Float, nil)


138
# File 'lib/whop_sdk/models/payment_list_response.rb', line 138

required :refunded_amount, Float, nil?: true

#refunded_atTime?

When the payment was refunded (if applicable).

Returns:

  • (Time, nil)


144
# File 'lib/whop_sdk/models/payment_list_response.rb', line 144

required :refunded_at, Time, nil?: true

#retryableBoolean

Whether the payment can be retried.

Returns:

  • (Boolean)


150
# File 'lib/whop_sdk/models/payment_list_response.rb', line 150

required :retryable, WhopSDK::Internal::Type::Boolean

#statusSymbol, ...

The status of a receipt

Returns:



156
# File 'lib/whop_sdk/models/payment_list_response.rb', line 156

required :status, enum: -> { WhopSDK::ReceiptStatus }, nil?: true

#substatusSymbol, WhopSDK::Models::FriendlyReceiptStatus

The friendly status of the payment.



162
# File 'lib/whop_sdk/models/payment_list_response.rb', line 162

required :substatus, enum: -> { WhopSDK::FriendlyReceiptStatus }

#subtotalFloat?

The subtotal to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


168
# File 'lib/whop_sdk/models/payment_list_response.rb', line 168

required :subtotal, Float, nil?: true

#totalFloat?

The total to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


174
# File 'lib/whop_sdk/models/payment_list_response.rb', line 174

required :total, Float, nil?: true

#usd_totalFloat?

The total in USD to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


180
# File 'lib/whop_sdk/models/payment_list_response.rb', line 180

required :usd_total, Float, nil?: true

#userWhopSDK::Models::PaymentListResponse::User?

The user that made this payment.



186
# File 'lib/whop_sdk/models/payment_list_response.rb', line 186

required :user, -> { WhopSDK::Models::PaymentListResponse::User }, nil?: true

#voidableBoolean

Whether the payment can be voided.

Returns:

  • (Boolean)


192
# File 'lib/whop_sdk/models/payment_list_response.rb', line 192

required :voidable, WhopSDK::Internal::Type::Boolean