Class: WhopSDK::Models::PaymentListResponse::ApplicationFee
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentListResponse::ApplicationFee
- Defined in:
- lib/whop_sdk/models/payment_list_response.rb,
sig/whop_sdk/models/payment_list_response.rbs
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
The application fee amount.
-
#amount_captured ⇒ Float
The amount of the application fee that has been captured.
-
#amount_refunded ⇒ Float
The amount of the application fee that has been refunded.
-
#created_at ⇒ Time
The datetime the application fee was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the application fee.
-
#id ⇒ String
The unique identifier for the application fee.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
247 |
# File 'sig/whop_sdk/models/payment_list_response.rbs', line 247
def initialize: (
|
Instance Attribute Details
#amount ⇒ Float
The application fee amount.
373 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 373 required :amount, Float |
#amount_captured ⇒ Float
The amount of the application fee that has been captured.
379 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 379 required :amount_captured, Float |
#amount_refunded ⇒ Float
The amount of the application fee that has been refunded.
385 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 385 required :amount_refunded, Float |
#created_at ⇒ Time
The datetime the application fee was created.
391 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 391 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the application fee.
397 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 397 required :currency, enum: -> { WhopSDK::Currency } |
#id ⇒ String
The unique identifier for the application fee.
367 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 367 required :id, String |
Instance Method Details
#to_hash ⇒ {
256 |
# File 'sig/whop_sdk/models/payment_list_response.rbs', line 256
def to_hash: -> {
|