Class: WhopSDK::Models::PaymentListResponse::PaymentMethod
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentListResponse::PaymentMethod
- Defined in:
- lib/whop_sdk/models/payment_list_response.rb
Overview
Defined Under Namespace
Classes: Card
Instance Attribute Summary collapse
-
#card ⇒ WhopSDK::Models::PaymentListResponse::PaymentMethod::Card?
The card data associated with the payment method, if its a debit or credit card.
-
#created_at ⇒ Time
The datetime the payment token was created.
-
#id ⇒ String
The unique identifier for the payment token.
-
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The payment method type of the payment method.
Instance Method Summary collapse
-
#initialize(id:, card:, created_at:, payment_method_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethod for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, card:, created_at:, payment_method_type:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PaymentListResponse::PaymentMethod for more details.
The tokenized payment method reference used for this payment. Null if no token was used.
|
|
# File 'lib/whop_sdk/models/payment_list_response.rb', line 551
|
Instance Attribute Details
#card ⇒ WhopSDK::Models::PaymentListResponse::PaymentMethod::Card?
The card data associated with the payment method, if its a debit or credit card.
537 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 537 required :card, -> { WhopSDK::Models::PaymentListResponse::PaymentMethod::Card }, nil?: true |
#created_at ⇒ Time
The datetime the payment token was created.
543 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 543 required :created_at, Time |
#id ⇒ String
The unique identifier for the payment token.
531 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 531 required :id, String |
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The payment method type of the payment method
549 |
# File 'lib/whop_sdk/models/payment_list_response.rb', line 549 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes } |