Class: WhopSDK::Models::PaymentMethodListResponse::BasePaymentMethod
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PaymentMethodListResponse::BasePaymentMethod
- Defined in:
- lib/whop_sdk/models/payment_method_list_response.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The time of the event in ISO 8601 UTC format with millisecond precision.
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).
-
#typename ⇒ Symbol, :BasePaymentMethod
The typename of this object.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#created_at ⇒ Time
The time of the event in ISO 8601 UTC format with millisecond precision
47 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 47 required :created_at, Time |
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.
41 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 41 required :id, String |
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).
54 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 54 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes } |
#typename ⇒ Symbol, :BasePaymentMethod
The typename of this object
60 |
# File 'lib/whop_sdk/models/payment_method_list_response.rb', line 60 required :typename, const: :BasePaymentMethod |