Class: WhopSDK::Models::PaymentMethodRetrieveResponse::BasePaymentMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/payment_method_retrieve_response.rb

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#created_atTime

The time of the event in ISO 8601 UTC format with millisecond precision

Returns:

  • (Time)


48
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 48

required :created_at, Time

#idString

Represents a unique identifier that is Base64 obfuscated. It is often used to refetch an object or as key for a cache. The ID type appears in a JSON response as a String; however, it is not intended to be human-readable. When expected as an input type, any string (such as ‘“VXNlci0xMA==”`) or integer (such as `4`) input value will be accepted as an ID.

Returns:

  • (String)


42
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 42

required :id, String

#payment_method_typeSymbol, WhopSDK::Models::PaymentMethodTypes

The type of payment instrument stored on file (e.g., card, us_bank_account, cashapp, ideal, sepa_debit).



55
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 55

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }

#typenameSymbol, :BasePaymentMethod

The typename of this object

Returns:

  • (Symbol, :BasePaymentMethod)


61
# File 'lib/whop_sdk/models/payment_method_retrieve_response.rb', line 61

required :typename, const: :BasePaymentMethod