Class: WhopSDK::Models::Payouts::MethodListResponse::Quote
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Payouts::MethodListResponse::Quote
- Defined in:
- lib/whop_sdk/models/payouts/method_list_response.rb,
sig/whop_sdk/models/payouts/method_list_response.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ Float
The withdrawal amount the quote is for.
-
#currency ⇒ String
Currency of the quoted amount.
-
#exchange_rate ⇒ Float
Exchange rate from the withdrawal currency to the destination currency.
-
#instant ⇒ WhopSDK::Models::Payouts::MethodListResponse::Quote::Instant?
Instant-delivery estimate.
-
#max_limit ⇒ Float?
Maximum withdrawal amount for this method, in the withdrawal currency.
-
#min_limit ⇒ Float
Minimum withdrawal amount for this method, in the withdrawal currency.
-
#standard ⇒ WhopSDK::Models::Payouts::MethodListResponse::Quote::Standard?
Standard-delivery estimate.
Instance Method Summary collapse
-
#initialize(estimated_arrival:, fee:, total_received:) ⇒ Object
constructor
Instant-delivery estimate.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(estimated_arrival:, fee:, total_received:) ⇒ Object
Instant-delivery estimate. Null if the method does not support instant delivery, instant delivery is unavailable for the account, or the amount does not cover the fee.
|
|
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 213
|
Instance Attribute Details
#amount ⇒ Float
The withdrawal amount the quote is for.
172 |
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 172 required :amount, Float |
#currency ⇒ String
Currency of the quoted amount.
178 |
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 178 required :currency, String |
#exchange_rate ⇒ Float
Exchange rate from the withdrawal currency to the destination currency.
184 |
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 184 required :exchange_rate, Float |
#instant ⇒ WhopSDK::Models::Payouts::MethodListResponse::Quote::Instant?
Instant-delivery estimate. Null if the method does not support instant delivery, instant delivery is unavailable for the account, or the amount does not cover the fee.
192 |
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 192 required :instant, -> { WhopSDK::Models::Payouts::MethodListResponse::Quote::Instant }, nil?: true |
#max_limit ⇒ Float?
Maximum withdrawal amount for this method, in the withdrawal currency.
198 |
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 198 required :max_limit, Float, nil?: true |
#min_limit ⇒ Float
Minimum withdrawal amount for this method, in the withdrawal currency.
204 |
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 204 required :min_limit, Float |
#standard ⇒ WhopSDK::Models::Payouts::MethodListResponse::Quote::Standard?
Standard-delivery estimate. Null if the method does not support standard delivery, or the amount does not cover the fee.
211 |
# File 'lib/whop_sdk/models/payouts/method_list_response.rb', line 211 required :standard, -> { WhopSDK::Models::Payouts::MethodListResponse::Quote::Standard }, nil?: true |
Instance Method Details
#to_hash ⇒ {
158 |
# File 'sig/whop_sdk/models/payouts/method_list_response.rbs', line 158
def to_hash: -> {
|