Class: WhopSDK::Models::Plan
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Plan
- Defined in:
- lib/whop_sdk/models/plan.rb
Defined Under Namespace
Classes: Company, CustomField, Invoice, Product
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
-
#collect_tax ⇒ Boolean
Whether or not the plan collects tax.
-
#company ⇒ WhopSDK::Models::Plan::Company?
The company for the plan.
-
#created_at ⇒ Time
When the plan was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
-
#custom_fields ⇒ Array<WhopSDK::Models::Plan::CustomField>
The custom fields for the plan.
-
#description ⇒ String?
The description of the plan.
-
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
-
#id ⇒ String
The internal ID of the plan.
-
#initial_price ⇒ Float
The price a person has to pay for a plan on the initial purchase.
-
#internal_notes ⇒ String?
A personal description or notes section for the business.
-
#invoice ⇒ WhopSDK::Models::Plan::Invoice?
The invoice associated with this plan.
-
#member_count ⇒ Integer?
The number of members for the plan.
-
#plan_type ⇒ Symbol, WhopSDK::Models::PlanType
Indicates if the plan is a one time payment or recurring.
-
#product ⇒ WhopSDK::Models::Plan::Product?
The access pass for the plan.
-
#purchase_url ⇒ String
The direct link to purchase the product.
-
#release_method ⇒ Symbol, WhopSDK::Models::ReleaseMethod
This is the release method the business uses to sell this plan.
-
#renewal_price ⇒ Float
The price a person has to pay for a plan on the renewal purchase.
-
#stock ⇒ Integer?
The number of units available for purchase.
-
#tax_type ⇒ Symbol, WhopSDK::Models::TaxType
The tax type for the plan.
-
#title ⇒ String?
The title of the plan.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#unlimited_stock ⇒ Boolean
Limits/doesn’t limit the number of units available for purchase.
-
#updated_at ⇒ Time
When the plan was last updated.
-
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Shows or hides the plan from public/business view.
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
The invoice associated with this plan.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
The invoice associated with this plan.
|
|
# File 'lib/whop_sdk/models/plan.rb', line 156
|
Instance Attribute Details
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
16 |
# File 'lib/whop_sdk/models/plan.rb', line 16 required :billing_period, Integer, nil?: true |
#collect_tax ⇒ Boolean
Whether or not the plan collects tax.
22 |
# File 'lib/whop_sdk/models/plan.rb', line 22 required :collect_tax, WhopSDK::Internal::Type::Boolean |
#company ⇒ WhopSDK::Models::Plan::Company?
The company for the plan.
28 |
# File 'lib/whop_sdk/models/plan.rb', line 28 required :company, -> { WhopSDK::Plan::Company }, nil?: true |
#created_at ⇒ Time
When the plan was created.
34 |
# File 'lib/whop_sdk/models/plan.rb', line 34 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
40 |
# File 'lib/whop_sdk/models/plan.rb', line 40 required :currency, enum: -> { WhopSDK::Currency } |
#custom_fields ⇒ Array<WhopSDK::Models::Plan::CustomField>
The custom fields for the plan.
46 |
# File 'lib/whop_sdk/models/plan.rb', line 46 required :custom_fields, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Plan::CustomField] } |
#description ⇒ String?
The description of the plan.
52 |
# File 'lib/whop_sdk/models/plan.rb', line 52 required :description, String, nil?: true |
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
58 |
# File 'lib/whop_sdk/models/plan.rb', line 58 required :expiration_days, Integer, nil?: true |
#id ⇒ String
The internal ID of the plan.
10 |
# File 'lib/whop_sdk/models/plan.rb', line 10 required :id, String |
#initial_price ⇒ Float
The price a person has to pay for a plan on the initial purchase.
64 |
# File 'lib/whop_sdk/models/plan.rb', line 64 required :initial_price, Float |
#internal_notes ⇒ String?
A personal description or notes section for the business.
70 |
# File 'lib/whop_sdk/models/plan.rb', line 70 required :internal_notes, String, nil?: true |
#invoice ⇒ WhopSDK::Models::Plan::Invoice?
The invoice associated with this plan.
76 |
# File 'lib/whop_sdk/models/plan.rb', line 76 required :invoice, -> { WhopSDK::Plan::Invoice }, nil?: true |
#member_count ⇒ Integer?
The number of members for the plan.
82 |
# File 'lib/whop_sdk/models/plan.rb', line 82 required :member_count, Integer, nil?: true |
#plan_type ⇒ Symbol, WhopSDK::Models::PlanType
Indicates if the plan is a one time payment or recurring.
88 |
# File 'lib/whop_sdk/models/plan.rb', line 88 required :plan_type, enum: -> { WhopSDK::PlanType } |
#product ⇒ WhopSDK::Models::Plan::Product?
The access pass for the plan.
94 |
# File 'lib/whop_sdk/models/plan.rb', line 94 required :product, -> { WhopSDK::Plan::Product }, nil?: true |
#purchase_url ⇒ String
The direct link to purchase the product.
100 |
# File 'lib/whop_sdk/models/plan.rb', line 100 required :purchase_url, String |
#release_method ⇒ Symbol, WhopSDK::Models::ReleaseMethod
This is the release method the business uses to sell this plan.
106 |
# File 'lib/whop_sdk/models/plan.rb', line 106 required :release_method, enum: -> { WhopSDK::ReleaseMethod } |
#renewal_price ⇒ Float
The price a person has to pay for a plan on the renewal purchase.
112 |
# File 'lib/whop_sdk/models/plan.rb', line 112 required :renewal_price, Float |
#stock ⇒ Integer?
The number of units available for purchase. Only displayed to authorized actors
118 |
# File 'lib/whop_sdk/models/plan.rb', line 118 required :stock, Integer, nil?: true |
#tax_type ⇒ Symbol, WhopSDK::Models::TaxType
The tax type for the plan.
124 |
# File 'lib/whop_sdk/models/plan.rb', line 124 required :tax_type, enum: -> { WhopSDK::TaxType } |
#title ⇒ String?
The title of the plan. This will be visible on the product page to customers.
130 |
# File 'lib/whop_sdk/models/plan.rb', line 130 required :title, String, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
136 |
# File 'lib/whop_sdk/models/plan.rb', line 136 required :trial_period_days, Integer, nil?: true |
#unlimited_stock ⇒ Boolean
Limits/doesn’t limit the number of units available for purchase.
142 |
# File 'lib/whop_sdk/models/plan.rb', line 142 required :unlimited_stock, WhopSDK::Internal::Type::Boolean |
#updated_at ⇒ Time
When the plan was last updated.
148 |
# File 'lib/whop_sdk/models/plan.rb', line 148 required :updated_at, Time |
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Shows or hides the plan from public/business view.
154 |
# File 'lib/whop_sdk/models/plan.rb', line 154 required :visibility, enum: -> { WhopSDK::Visibility } |