Class: WhopSDK::Models::Plan::CustomField
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Plan::CustomField
- Defined in:
- lib/whop_sdk/models/plan.rb,
sig/whop_sdk/models/plan.rbs
Defined Under Namespace
Modules: FieldType
Instance Attribute Summary collapse
-
#field_type ⇒ Symbol, WhopSDK::Models::Plan::CustomField::FieldType
Custom field input type.
-
#id ⇒ String
Custom field ID.
-
#name ⇒ String
Field label shown to customer at checkout.
-
#order ⇒ Float
Field position on checkout form.
-
#placeholder ⇒ String?
Placeholder text shown in empty field.
-
#required ⇒ Boolean
Whether the customer must complete this field to check out.
Instance Method Summary collapse
-
#initialize(id:, field_type:, name:, order:, placeholder:, required:) ⇒ Object
constructor
Custom input fields collected on the checkout form.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, field_type:, name:, order:, placeholder:, required:) ⇒ Object
Custom input fields collected on the checkout form.
|
|
# File 'lib/whop_sdk/models/plan.rb', line 391
|
Instance Attribute Details
#field_type ⇒ Symbol, WhopSDK::Models::Plan::CustomField::FieldType
Custom field input type.
365 |
# File 'lib/whop_sdk/models/plan.rb', line 365 required :field_type, enum: -> { WhopSDK::Plan::CustomField::FieldType } |
#id ⇒ String
Custom field ID.
359 |
# File 'lib/whop_sdk/models/plan.rb', line 359 required :id, String |
#name ⇒ String
Field label shown to customer at checkout.
371 |
# File 'lib/whop_sdk/models/plan.rb', line 371 required :name, String |
#order ⇒ Float
Field position on checkout form.
377 |
# File 'lib/whop_sdk/models/plan.rb', line 377 required :order, Float |
#placeholder ⇒ String?
Placeholder text shown in empty field.
383 |
# File 'lib/whop_sdk/models/plan.rb', line 383 required :placeholder, String, nil?: true |
#required ⇒ Boolean
Whether the customer must complete this field to check out.
389 |
# File 'lib/whop_sdk/models/plan.rb', line 389 required :required, WhopSDK::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ {
385 |
# File 'sig/whop_sdk/models/plan.rbs', line 385
def to_hash: -> {
|