Class: WhopSDK::Models::Plan::CustomField
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Plan::CustomField
- Defined in:
- lib/whop_sdk/models/plan.rb
Instance Attribute Summary collapse
-
#field_type ⇒ Symbol, :text
What type of input field to use.
-
#id ⇒ String
The internal ID of the given custom field.
-
#name ⇒ String
The title/header of the custom field.
-
#order ⇒ Integer?
How the custom field should be ordered when rendered on the checkout page.
-
#placeholder ⇒ String?
An example response displayed in the input field.
-
#required ⇒ Boolean
Whether or not the custom field is required.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#field_type ⇒ Symbol, :text
What type of input field to use.
250 |
# File 'lib/whop_sdk/models/plan.rb', line 250 required :field_type, const: :text |
#id ⇒ String
The internal ID of the given custom field
244 |
# File 'lib/whop_sdk/models/plan.rb', line 244 required :id, String |
#name ⇒ String
The title/header of the custom field.
256 |
# File 'lib/whop_sdk/models/plan.rb', line 256 required :name, String |
#order ⇒ Integer?
How the custom field should be ordered when rendered on the checkout page.
262 |
# File 'lib/whop_sdk/models/plan.rb', line 262 required :order, Integer, nil?: true |
#placeholder ⇒ String?
An example response displayed in the input field.
268 |
# File 'lib/whop_sdk/models/plan.rb', line 268 required :placeholder, String, nil?: true |