Class: WhopSDK::Models::PlanCalculateTaxParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanCalculateTaxParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/plan_calculate_tax_params.rb,
sig/whop_sdk/models/plan_calculate_tax_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#address ⇒ WhopSDK::Models::PlanCalculateTaxParams::Address?
Buyer billing address used for tax calculation.
- #id ⇒ String
-
#ip_address ⇒ String?
Buyer IP address used to infer location when no billing address is provided.
-
#tax_ids ⇒ Array<WhopSDK::Models::PlanCalculateTaxParams::TaxID>?
Optional buyer tax ID for B2B exemptions.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(country:, city: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
constructor
Buyer billing address used for tax calculation.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(country:, city: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
Buyer billing address used for tax calculation. Provide either address.country
or ip_address; include state and postal code when available for more accurate
results.
|
|
# File 'lib/whop_sdk/models/plan_calculate_tax_params.rb', line 88
|
Instance Attribute Details
#address ⇒ WhopSDK::Models::PlanCalculateTaxParams::Address?
Buyer billing address used for tax calculation. Provide either address.country
or ip_address; include state and postal code when available for more accurate
results.
21 |
# File 'lib/whop_sdk/models/plan_calculate_tax_params.rb', line 21 optional :address, -> { WhopSDK::PlanCalculateTaxParams::Address }, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/plan_calculate_tax_params.rb', line 13 required :id, String |
#ip_address ⇒ String?
Buyer IP address used to infer location when no billing address is provided.
27 |
# File 'lib/whop_sdk/models/plan_calculate_tax_params.rb', line 27 optional :ip_address, String |
#tax_ids ⇒ Array<WhopSDK::Models::PlanCalculateTaxParams::TaxID>?
Optional buyer tax ID for B2B exemptions. At most one entry is supported.
33 34 35 |
# File 'lib/whop_sdk/models/plan_calculate_tax_params.rb', line 33 optional :tax_ids, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::PlanCalculateTaxParams::TaxID] }, nil?: true |
Instance Method Details
#to_hash ⇒ {
34 |
# File 'sig/whop_sdk/models/plan_calculate_tax_params.rbs', line 34
def to_hash: -> {
|