Class: WhopSDK::Models::PlanCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/plan_create_params.rb
Overview
Defined Under Namespace
Modules: Image Classes: CustomField, PaymentMethodConfiguration
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The interval in days at which the plan charges (renewal plans).
-
#company_id ⇒ String
The company the plan should be created for.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#custom_fields ⇒ Array<WhopSDK::Models::PlanCreateParams::CustomField>?
An array of custom field objects.
-
#description ⇒ String?
The description of the plan.
-
#expiration_days ⇒ Integer?
The interval at which the plan expires and revokes access (expiration plans).
-
#image ⇒ WhopSDK::Models::PlanCreateParams::Image::AttachmentInputWithDirectUploadID, ...
An image for the plan.
-
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
-
#internal_notes ⇒ String?
A personal description or notes section for the business.
-
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up).
-
#payment_method_configuration ⇒ WhopSDK::Models::PlanCreateParams::PaymentMethodConfiguration?
The explicit payment method configuration for the plan.
-
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to a product.
-
#product_id ⇒ String
The product the plan is related to.
-
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
-
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
-
#stock ⇒ Integer?
The number of units available for purchase.
-
#title ⇒ String?
The title of the plan.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#unlimited_stock ⇒ Boolean?
Limits/doesn’t limit the number of units available for purchase.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Image::AttachmentInputWithID for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PlanCreateParams::Image::AttachmentInputWithID for more details.
Input for an attachment
|
|
# File 'lib/whop_sdk/models/plan_create_params.rb', line 222
|
Instance Attribute Details
#billing_period ⇒ Integer?
The interval in days at which the plan charges (renewal plans).
26 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 26 optional :billing_period, Integer, nil?: true |
#company_id ⇒ String
The company the plan should be created for.
14 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 14 required :company_id, String |
#currency ⇒ Symbol, ...
The available currencies on the platform
32 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 32 optional :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#custom_fields ⇒ Array<WhopSDK::Models::PlanCreateParams::CustomField>?
An array of custom field objects.
38 39 40 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 38 optional :custom_fields, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::PlanCreateParams::CustomField] }, nil?: true |
#description ⇒ String?
The description of the plan.
46 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 46 optional :description, String, nil?: true |
#expiration_days ⇒ Integer?
The interval at which the plan expires and revokes access (expiration plans).
52 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 52 optional :expiration_days, Integer, nil?: true |
#image ⇒ WhopSDK::Models::PlanCreateParams::Image::AttachmentInputWithDirectUploadID, ...
An image for the plan. This will be visible on the product page to customers.
58 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 58 optional :image, union: -> { WhopSDK::PlanCreateParams::Image }, nil?: true |
#initial_price ⇒ Float?
An additional amount charged upon first purchase. Use only if a one time payment OR you want to charge an additional amount on top of the renewal price. Provided as a number in dollars. Eg: 10.43 for $10.43
66 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 66 optional :initial_price, Float, nil?: true |
#internal_notes ⇒ String?
A personal description or notes section for the business.
72 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 72 optional :internal_notes, String, nil?: true |
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up)
79 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 79 optional :override_tax_type, enum: -> { WhopSDK::TaxType }, nil?: true |
#payment_method_configuration ⇒ WhopSDK::Models::PlanCreateParams::PaymentMethodConfiguration?
The explicit payment method configuration for the plan. If not provided, the platform or company’s defaults will apply.
86 87 88 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 86 optional :payment_method_configuration, -> { WhopSDK::PlanCreateParams::PaymentMethodConfiguration }, nil?: true |
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to a product
94 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 94 optional :plan_type, enum: -> { WhopSDK::PlanType }, nil?: true |
#product_id ⇒ String
The product the plan is related to.
20 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 20 required :product_id, String |
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
100 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 100 optional :release_method, enum: -> { WhopSDK::ReleaseMethod }, nil?: true |
#renewal_price ⇒ Float?
The amount the customer is charged every billing period. Use only if a recurring payment. Provided as a number in dollars. Eg: 10.43 for $10.43
107 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 107 optional :renewal_price, Float, nil?: true |
#stock ⇒ Integer?
The number of units available for purchase.
113 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 113 optional :stock, Integer, nil?: true |
#title ⇒ String?
The title of the plan. This will be visible on the product page to customers.
119 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 119 optional :title, String, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
125 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 125 optional :trial_period_days, Integer, nil?: true |
#unlimited_stock ⇒ Boolean?
Limits/doesn’t limit the number of units available for purchase.
131 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 131 optional :unlimited_stock, WhopSDK::Internal::Type::Boolean, nil?: true |
#visibility ⇒ Symbol, ...
Visibility of a resource
137 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 137 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |
Class Method Details
.variants ⇒ Array(WhopSDK::Models::PlanCreateParams::Image::AttachmentInputWithDirectUploadID, WhopSDK::Models::PlanCreateParams::Image::AttachmentInputWithID)
|
|
# File 'lib/whop_sdk/models/plan_create_params.rb', line 284
|