Class: WhopSDK::Models::PlanCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/plan_create_params.rb
Overview
Defined Under Namespace
Classes: CustomField, Image
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The interval in days at which the plan charges (renewal plans).
-
#company_id ⇒ String
The company the plan should be created for.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#custom_fields ⇒ Array<WhopSDK::Models::PlanCreateParams::CustomField>?
An array of custom field objects.
-
#description ⇒ String?
The description of the plan.
-
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
-
#image ⇒ WhopSDK::Models::PlanCreateParams::Image?
An image for the plan.
-
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
-
#internal_notes ⇒ String?
A personal description or notes section for the business.
-
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up).
-
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to an access pass.
-
#product_id ⇒ String
The product the plan is related to.
-
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
-
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
-
#stock ⇒ Integer?
The number of units available for purchase.
-
#strike_through_initial_price ⇒ Float?
The price to display with a strikethrough for the initial price.
-
#strike_through_renewal_price ⇒ Float?
The price to display with a strikethrough for the renewal price.
-
#title ⇒ String?
The title of the plan.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#unlimited_stock ⇒ Boolean?
Limits/doesn’t limit the number of units available for purchase.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object
|
|
# File 'lib/whop_sdk/models/plan_create_params.rb', line 229
|
Instance Attribute Details
#billing_period ⇒ Integer?
The interval in days at which the plan charges (renewal plans).
26 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 26 optional :billing_period, Integer, nil?: true |
#company_id ⇒ String
The company the plan should be created for.
14 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 14 required :company_id, String |
#currency ⇒ Symbol, ...
The available currencies on the platform
32 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 32 optional :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#custom_fields ⇒ Array<WhopSDK::Models::PlanCreateParams::CustomField>?
An array of custom field objects.
38 39 40 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 38 optional :custom_fields, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::PlanCreateParams::CustomField] }, nil?: true |
#description ⇒ String?
The description of the plan.
46 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 46 optional :description, String, nil?: true |
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
52 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 52 optional :expiration_days, Integer, nil?: true |
#image ⇒ WhopSDK::Models::PlanCreateParams::Image?
An image for the plan. This will be visible on the product page to customers.
58 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 58 optional :image, -> { WhopSDK::PlanCreateParams::Image }, nil?: true |
#initial_price ⇒ Float?
An additional amount charged upon first purchase. Use only if a one time payment OR you want to charge an additional amount on top of the renewal price. Provided as a number in dollars. Eg: 10.43 for $10.43
66 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 66 optional :initial_price, Float, nil?: true |
#internal_notes ⇒ String?
A personal description or notes section for the business.
72 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 72 optional :internal_notes, String, nil?: true |
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up)
79 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 79 optional :override_tax_type, enum: -> { WhopSDK::TaxType }, nil?: true |
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to an access pass
85 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 85 optional :plan_type, enum: -> { WhopSDK::PlanType }, nil?: true |
#product_id ⇒ String
The product the plan is related to.
20 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 20 required :product_id, String |
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
91 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 91 optional :release_method, enum: -> { WhopSDK::ReleaseMethod }, nil?: true |
#renewal_price ⇒ Float?
The amount the customer is charged every billing period. Use only if a recurring payment. Provided as a number in dollars. Eg: 10.43 for $10.43
98 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 98 optional :renewal_price, Float, nil?: true |
#stock ⇒ Integer?
The number of units available for purchase.
104 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 104 optional :stock, Integer, nil?: true |
#strike_through_initial_price ⇒ Float?
The price to display with a strikethrough for the initial price. Provided as a number in dollars. Eg: 19.99 for $19.99
111 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 111 optional :strike_through_initial_price, Float, nil?: true |
#strike_through_renewal_price ⇒ Float?
The price to display with a strikethrough for the renewal price. Provided as a number in dollars. Eg: 19.99 for $19.99
118 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 118 optional :strike_through_renewal_price, Float, nil?: true |
#title ⇒ String?
The title of the plan. This will be visible on the product page to customers.
124 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 124 optional :title, String, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
130 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 130 optional :trial_period_days, Integer, nil?: true |
#unlimited_stock ⇒ Boolean?
Limits/doesn’t limit the number of units available for purchase.
136 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 136 optional :unlimited_stock, WhopSDK::Internal::Type::Boolean, nil?: true |
#visibility ⇒ Symbol, ...
Visibility of a resource
142 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 142 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |