Class: WhopSDK::Models::PlanCreateParams::CheckoutStyling
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanCreateParams::CheckoutStyling
- Defined in:
- lib/whop_sdk/models/plan_create_params.rb
Instance Attribute Summary collapse
-
#background_color ⇒ String?
A hex color code for the checkout page background, applied to the order summary panel (e.g. #F4F4F5).
-
#border_style ⇒ Symbol, ...
The different border-radius styles available for checkout pages.
-
#button_color ⇒ String?
A hex color code for the button color (e.g. #FF5733).
-
#font_family ⇒ Symbol, ...
The different font families available for checkout pages.
Instance Method Summary collapse
-
#initialize(company_id:, product_id:, adaptive_pricing_enabled: nil, billing_period: nil, checkout_styling: nil, currency: nil, custom_fields: nil, description: nil, expiration_days: nil, image: nil, initial_price: nil, internal_notes: nil, legacy_payment_method_controls: nil, metadata: nil, override_tax_type: nil, payment_method_configuration: nil, plan_type: nil, release_method: nil, renewal_price: nil, split_pay_required_payments: nil, stock: nil, three_ds_level: nil, title: nil, trial_period_days: nil, unlimited_stock: nil, visibility: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhopSDK::Models::PlanCreateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, product_id:, adaptive_pricing_enabled: nil, billing_period: nil, checkout_styling: nil, currency: nil, custom_fields: nil, description: nil, expiration_days: nil, image: nil, initial_price: nil, internal_notes: nil, legacy_payment_method_controls: nil, metadata: nil, override_tax_type: nil, payment_method_configuration: nil, plan_type: nil, release_method: nil, renewal_price: nil, split_pay_required_payments: nil, stock: nil, three_ds_level: nil, title: nil, trial_period_days: nil, unlimited_stock: nil, visibility: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PlanCreateParams for more details.
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 240 class CheckoutStyling < WhopSDK::Internal::Type::BaseModel # @!attribute background_color # A hex color code for the checkout page background, applied to the order summary # panel (e.g. #F4F4F5). # # @return [String, nil] optional :background_color, String, nil?: true # @!attribute border_style # The different border-radius styles available for checkout pages. # # @return [Symbol, WhopSDK::Models::CheckoutShape, nil] optional :border_style, enum: -> { WhopSDK::CheckoutShape }, nil?: true # @!attribute button_color # A hex color code for the button color (e.g. #FF5733). # # @return [String, nil] optional :button_color, String, nil?: true # @!attribute font_family # The different font families available for checkout pages. # # @return [Symbol, WhopSDK::Models::CheckoutFont, nil] optional :font_family, enum: -> { WhopSDK::CheckoutFont }, nil?: true # @!method initialize(background_color: nil, border_style: nil, button_color: nil, font_family: nil) # Some parameter documentations has been truncated, see # {WhopSDK::Models::PlanCreateParams::CheckoutStyling} for more details. # # Checkout styling overrides for this plan. Pass null to inherit from the company # default. # # @param background_color [String, nil] A hex color code for the checkout page background, applied to the order summary # # @param border_style [Symbol, WhopSDK::Models::CheckoutShape, nil] The different border-radius styles available for checkout pages. # # @param button_color [String, nil] A hex color code for the button color (e.g. #FF5733). # # @param font_family [Symbol, WhopSDK::Models::CheckoutFont, nil] The different font families available for checkout pages. end |
Instance Attribute Details
#background_color ⇒ String?
A hex color code for the checkout page background, applied to the order summary panel (e.g. #F4F4F5).
246 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 246 optional :background_color, String, nil?: true |
#border_style ⇒ Symbol, ...
The different border-radius styles available for checkout pages.
252 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 252 optional :border_style, enum: -> { WhopSDK::CheckoutShape }, nil?: true |
#button_color ⇒ String?
A hex color code for the button color (e.g. #FF5733).
258 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 258 optional :button_color, String, nil?: true |
#font_family ⇒ Symbol, ...
The different font families available for checkout pages.
264 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 264 optional :font_family, enum: -> { WhopSDK::CheckoutFont }, nil?: true |