Class: WhopSDK::Models::PlanCreateParams::CheckoutStyling
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanCreateParams::CheckoutStyling
- Defined in:
- lib/whop_sdk/models/plan_create_params.rb
Instance Attribute Summary collapse
-
#border_style ⇒ Symbol, ...
The different border-radius styles available for checkout pages.
-
#button_color ⇒ String?
A hex color code for the button color (e.g. #FF5733).
-
#font_family ⇒ Symbol, ...
The different font families available for checkout pages.
Instance Method Summary collapse
-
#initialize(company_id:, product_id:, billing_period: nil, checkout_styling: nil, currency: nil, custom_fields: nil, description: nil, expiration_days: nil, image: nil, initial_price: nil, internal_notes: nil, legacy_payment_method_controls: nil, override_tax_type: nil, payment_method_configuration: nil, plan_type: nil, release_method: nil, renewal_price: nil, split_pay_required_payments: nil, stock: nil, title: nil, trial_period_days: nil, unlimited_stock: nil, visibility: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WhopSDK::Models::PlanCreateParams for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, product_id:, billing_period: nil, checkout_styling: nil, currency: nil, custom_fields: nil, description: nil, expiration_days: nil, image: nil, initial_price: nil, internal_notes: nil, legacy_payment_method_controls: nil, override_tax_type: nil, payment_method_configuration: nil, plan_type: nil, release_method: nil, renewal_price: nil, split_pay_required_payments: nil, stock: nil, title: nil, trial_period_days: nil, unlimited_stock: nil, visibility: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PlanCreateParams for more details.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 214 class CheckoutStyling < WhopSDK::Internal::Type::BaseModel # @!attribute border_style # The different border-radius styles available for checkout pages. # # @return [Symbol, WhopSDK::Models::CheckoutShape, nil] optional :border_style, enum: -> { WhopSDK::CheckoutShape }, nil?: true # @!attribute button_color # A hex color code for the button color (e.g. #FF5733). # # @return [String, nil] optional :button_color, String, nil?: true # @!attribute font_family # The different font families available for checkout pages. # # @return [Symbol, WhopSDK::Models::CheckoutFont, nil] optional :font_family, enum: -> { WhopSDK::CheckoutFont }, nil?: true # @!method initialize(border_style: nil, button_color: nil, font_family: nil) # Checkout styling overrides for this plan. Pass null to inherit from the company # default. # # @param border_style [Symbol, WhopSDK::Models::CheckoutShape, nil] The different border-radius styles available for checkout pages. # # @param button_color [String, nil] A hex color code for the button color (e.g. #FF5733). # # @param font_family [Symbol, WhopSDK::Models::CheckoutFont, nil] The different font families available for checkout pages. end |
Instance Attribute Details
#border_style ⇒ Symbol, ...
The different border-radius styles available for checkout pages.
219 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 219 optional :border_style, enum: -> { WhopSDK::CheckoutShape }, nil?: true |
#button_color ⇒ String?
A hex color code for the button color (e.g. #FF5733).
225 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 225 optional :button_color, String, nil?: true |
#font_family ⇒ Symbol, ...
The different font families available for checkout pages.
231 |
# File 'lib/whop_sdk/models/plan_create_params.rb', line 231 optional :font_family, enum: -> { WhopSDK::CheckoutFont }, nil?: true |