Class: WhopSDK::Models::PlanListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/plan_list_params.rb,
sig/whop_sdk/models/plan_list_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#account_id ⇒ String
The unique identifier of the account to list plans for.
-
#after ⇒ String?
A cursor; returns plans after this position.
-
#before ⇒ String?
A cursor; returns plans before this position.
-
#created_after ⇒ String?
Only return plans created after this timestamp.
-
#created_before ⇒ String?
Only return plans created before this timestamp.
-
#direction ⇒ Symbol, ...
The sort direction for results.
-
#first ⇒ Integer?
The number of plans to return (default and max 100).
-
#last ⇒ Integer?
The number of plans to return from the end of the range.
-
#order ⇒ Symbol, ...
The field to sort results by.
-
#plan_types ⇒ Array<String>?
Filter to only plans matching these billing types.
-
#product_ids ⇒ Array<String>?
Filter to only plans belonging to these product identifiers.
-
#release_methods ⇒ Array<String>?
Filter to only plans matching these release methods.
-
#visibilities ⇒ Array<String>?
Filter to only plans matching these visibility states.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(account_id:, after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, plan_types: nil, product_ids: nil, release_methods: nil, visibilities: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id:, after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, plan_types: nil, product_ids: nil, release_methods: nil, visibilities: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/plan_list_params.rb', line 88
|
Instance Attribute Details
#account_id ⇒ String
The unique identifier of the account to list plans for.
14 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 14 required :account_id, String |
#after ⇒ String?
A cursor; returns plans after this position.
20 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 20 optional :after, String |
#before ⇒ String?
A cursor; returns plans before this position.
26 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 26 optional :before, String |
#created_after ⇒ String?
Only return plans created after this timestamp.
32 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 32 optional :created_after, String |
#created_before ⇒ String?
Only return plans created before this timestamp.
38 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 38 optional :created_before, String |
#direction ⇒ Symbol, ...
The sort direction for results. Defaults to descending.
44 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 44 optional :direction, enum: -> { WhopSDK::PlanListParams::Direction } |
#first ⇒ Integer?
The number of plans to return (default and max 100).
50 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 50 optional :first, Integer |
#last ⇒ Integer?
The number of plans to return from the end of the range.
56 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 56 optional :last, Integer |
#order ⇒ Symbol, ...
The field to sort results by. Defaults to created_at.
62 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 62 optional :order, enum: -> { WhopSDK::PlanListParams::Order } |
#plan_types ⇒ Array<String>?
Filter to only plans matching these billing types.
68 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 68 optional :plan_types, WhopSDK::Internal::Type::ArrayOf[String] |
#product_ids ⇒ Array<String>?
Filter to only plans belonging to these product identifiers.
74 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 74 optional :product_ids, WhopSDK::Internal::Type::ArrayOf[String] |
#release_methods ⇒ Array<String>?
Filter to only plans matching these release methods.
80 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 80 optional :release_methods, WhopSDK::Internal::Type::ArrayOf[String] |
#visibilities ⇒ Array<String>?
Filter to only plans matching these visibility states.
86 |
# File 'lib/whop_sdk/models/plan_list_params.rb', line 86 optional :visibilities, WhopSDK::Internal::Type::ArrayOf[String] |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/plan_list_params.rb', line 124
|
Instance Method Details
#to_hash ⇒ {
96 |
# File 'sig/whop_sdk/models/plan_list_params.rbs', line 96
def to_hash: -> {
|