Class: WhopSDK::Models::PlanListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/plan_list_response.rb

Overview

Defined Under Namespace

Classes: Company, Invoice, PaymentMethodConfiguration, Product

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object

Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.

The explicit payment method configuration for the plan, if any.

Parameters:

  • disabled (Array<Symbol, WhopSDK::Models::PaymentMethodTypes>) (defaults to: )

    An array of payment method identifiers that are explicitly disabled. Only applie

  • enabled (Array<Symbol, WhopSDK::Models::PaymentMethodTypes>) (defaults to: )

    An array of payment method identifiers that are explicitly enabled. This means t

  • include_platform_defaults (Boolean) (defaults to: )

    Whether Whop’s platform default payment method enablement settings are included



# File 'lib/whop_sdk/models/plan_list_response.rb', line 147

Instance Attribute Details

#billing_periodInteger?

The interval at which the plan charges (renewal plans).

Returns:

  • (Integer, nil)


17
# File 'lib/whop_sdk/models/plan_list_response.rb', line 17

required :billing_period, Integer, nil?: true

#companyWhopSDK::Models::PlanListResponse::Company?

The company for the plan.



23
# File 'lib/whop_sdk/models/plan_list_response.rb', line 23

required :company, -> { WhopSDK::Models::PlanListResponse::Company }, nil?: true

#created_atTime

When the plan was created.

Returns:

  • (Time)


29
# File 'lib/whop_sdk/models/plan_list_response.rb', line 29

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The respective currency identifier for the plan.

Returns:



35
# File 'lib/whop_sdk/models/plan_list_response.rb', line 35

required :currency, enum: -> { WhopSDK::Currency }

#descriptionString?

The description of the plan.

Returns:

  • (String, nil)


41
# File 'lib/whop_sdk/models/plan_list_response.rb', line 41

required :description, String, nil?: true

#expiration_daysInteger?

The interval at which the plan charges (expiration plans).

Returns:

  • (Integer, nil)


47
# File 'lib/whop_sdk/models/plan_list_response.rb', line 47

required :expiration_days, Integer, nil?: true

#idString

The internal ID of the plan.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/plan_list_response.rb', line 11

required :id, String

#initial_priceFloat

The price a person has to pay for a plan on the initial purchase.

Returns:

  • (Float)


53
# File 'lib/whop_sdk/models/plan_list_response.rb', line 53

required :initial_price, Float

#internal_notesString?

A personal description or notes section for the business.

Returns:

  • (String, nil)


59
# File 'lib/whop_sdk/models/plan_list_response.rb', line 59

required :internal_notes, String, nil?: true

#invoiceWhopSDK::Models::PlanListResponse::Invoice?

The invoice associated with this plan.



65
# File 'lib/whop_sdk/models/plan_list_response.rb', line 65

required :invoice, -> { WhopSDK::Models::PlanListResponse::Invoice }, nil?: true

#member_countInteger?

The number of members for the plan.

Returns:

  • (Integer, nil)


71
# File 'lib/whop_sdk/models/plan_list_response.rb', line 71

required :member_count, Integer, nil?: true

#payment_method_configurationWhopSDK::Models::PlanListResponse::PaymentMethodConfiguration?

The explicit payment method configuration for the plan, if any.



77
78
79
# File 'lib/whop_sdk/models/plan_list_response.rb', line 77

required :payment_method_configuration,
-> { WhopSDK::Models::PlanListResponse::PaymentMethodConfiguration },
nil?: true

#plan_typeSymbol, WhopSDK::Models::PlanType

Indicates if the plan is a one time payment or recurring.

Returns:



85
# File 'lib/whop_sdk/models/plan_list_response.rb', line 85

required :plan_type, enum: -> { WhopSDK::PlanType }

#productWhopSDK::Models::PlanListResponse::Product?

The product that this plan belongs to.



91
# File 'lib/whop_sdk/models/plan_list_response.rb', line 91

required :product, -> { WhopSDK::Models::PlanListResponse::Product }, nil?: true

#purchase_urlString

The direct link to purchase the product.

Returns:

  • (String)


97
# File 'lib/whop_sdk/models/plan_list_response.rb', line 97

required :purchase_url, String

#release_methodSymbol, WhopSDK::Models::ReleaseMethod

This is the release method the business uses to sell this plan.

Returns:



103
# File 'lib/whop_sdk/models/plan_list_response.rb', line 103

required :release_method, enum: -> { WhopSDK::ReleaseMethod }

#renewal_priceFloat

The price a person has to pay for a plan on the renewal purchase.

Returns:

  • (Float)


109
# File 'lib/whop_sdk/models/plan_list_response.rb', line 109

required :renewal_price, Float

#stockInteger?

The number of units available for purchase. Only displayed to authorized actors

Returns:

  • (Integer, nil)


115
# File 'lib/whop_sdk/models/plan_list_response.rb', line 115

required :stock, Integer, nil?: true

#titleString?

The title of the plan. This will be visible on the product page to customers.

Returns:

  • (String, nil)


121
# File 'lib/whop_sdk/models/plan_list_response.rb', line 121

required :title, String, nil?: true

#trial_period_daysInteger?

The number of free trial days added before a renewal plan.

Returns:

  • (Integer, nil)


127
# File 'lib/whop_sdk/models/plan_list_response.rb', line 127

required :trial_period_days, Integer, nil?: true

#unlimited_stockBoolean

Limits/doesn’t limit the number of units available for purchase.

Returns:

  • (Boolean)


133
# File 'lib/whop_sdk/models/plan_list_response.rb', line 133

required :unlimited_stock, WhopSDK::Internal::Type::Boolean

#updated_atTime

When the plan was last updated.

Returns:

  • (Time)


139
# File 'lib/whop_sdk/models/plan_list_response.rb', line 139

required :updated_at, Time

#visibilitySymbol, WhopSDK::Models::Visibility

Shows or hides the plan from public/business view.

Returns:



145
# File 'lib/whop_sdk/models/plan_list_response.rb', line 145

required :visibility, enum: -> { WhopSDK::Visibility }