Class: WhopSDK::Models::PlanListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanListResponse
- Defined in:
- lib/whop_sdk/models/plan_list_response.rb
Overview
Defined Under Namespace
Classes: Company, Invoice, PaymentMethodConfiguration, Product
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
-
#company ⇒ WhopSDK::Models::PlanListResponse::Company?
The company for the plan.
-
#created_at ⇒ Time
When the plan was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
-
#description ⇒ String?
The description of the plan.
-
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
-
#id ⇒ String
The internal ID of the plan.
-
#initial_price ⇒ Float
The price a person has to pay for a plan on the initial purchase.
-
#internal_notes ⇒ String?
A personal description or notes section for the business.
-
#invoice ⇒ WhopSDK::Models::PlanListResponse::Invoice?
The invoice associated with this plan.
-
#member_count ⇒ Integer?
The number of members for the plan.
-
#payment_method_configuration ⇒ WhopSDK::Models::PlanListResponse::PaymentMethodConfiguration?
The explicit payment method configuration for the plan, if any.
-
#plan_type ⇒ Symbol, WhopSDK::Models::PlanType
Indicates if the plan is a one time payment or recurring.
-
#product ⇒ WhopSDK::Models::PlanListResponse::Product?
The product that this plan belongs to.
-
#purchase_url ⇒ String
The direct link to purchase the product.
-
#release_method ⇒ Symbol, WhopSDK::Models::ReleaseMethod
This is the release method the business uses to sell this plan.
-
#renewal_price ⇒ Float
The price a person has to pay for a plan on the renewal purchase.
-
#stock ⇒ Integer?
The number of units available for purchase.
-
#title ⇒ String?
The title of the plan.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#unlimited_stock ⇒ Boolean
Limits/doesn’t limit the number of units available for purchase.
-
#updated_at ⇒ Time
When the plan was last updated.
-
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Shows or hides the plan from public/business view.
Instance Method Summary collapse
-
#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(disabled: , enabled: , include_platform_defaults: ) ⇒ Object
Some parameter documentations has been truncated, see PaymentMethodConfiguration for more details.
The explicit payment method configuration for the plan, if any.
|
|
# File 'lib/whop_sdk/models/plan_list_response.rb', line 147
|
Instance Attribute Details
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
17 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 17 required :billing_period, Integer, nil?: true |
#company ⇒ WhopSDK::Models::PlanListResponse::Company?
The company for the plan.
23 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 23 required :company, -> { WhopSDK::Models::PlanListResponse::Company }, nil?: true |
#created_at ⇒ Time
When the plan was created.
29 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 29 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
35 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 35 required :currency, enum: -> { WhopSDK::Currency } |
#description ⇒ String?
The description of the plan.
41 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 41 required :description, String, nil?: true |
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
47 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 47 required :expiration_days, Integer, nil?: true |
#id ⇒ String
The internal ID of the plan.
11 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 11 required :id, String |
#initial_price ⇒ Float
The price a person has to pay for a plan on the initial purchase.
53 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 53 required :initial_price, Float |
#internal_notes ⇒ String?
A personal description or notes section for the business.
59 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 59 required :internal_notes, String, nil?: true |
#invoice ⇒ WhopSDK::Models::PlanListResponse::Invoice?
The invoice associated with this plan.
65 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 65 required :invoice, -> { WhopSDK::Models::PlanListResponse::Invoice }, nil?: true |
#member_count ⇒ Integer?
The number of members for the plan.
71 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 71 required :member_count, Integer, nil?: true |
#payment_method_configuration ⇒ WhopSDK::Models::PlanListResponse::PaymentMethodConfiguration?
The explicit payment method configuration for the plan, if any.
77 78 79 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 77 required :payment_method_configuration, -> { WhopSDK::Models::PlanListResponse::PaymentMethodConfiguration }, nil?: true |
#plan_type ⇒ Symbol, WhopSDK::Models::PlanType
Indicates if the plan is a one time payment or recurring.
85 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 85 required :plan_type, enum: -> { WhopSDK::PlanType } |
#product ⇒ WhopSDK::Models::PlanListResponse::Product?
The product that this plan belongs to.
91 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 91 required :product, -> { WhopSDK::Models::PlanListResponse::Product }, nil?: true |
#purchase_url ⇒ String
The direct link to purchase the product.
97 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 97 required :purchase_url, String |
#release_method ⇒ Symbol, WhopSDK::Models::ReleaseMethod
This is the release method the business uses to sell this plan.
103 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 103 required :release_method, enum: -> { WhopSDK::ReleaseMethod } |
#renewal_price ⇒ Float
The price a person has to pay for a plan on the renewal purchase.
109 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 109 required :renewal_price, Float |
#stock ⇒ Integer?
The number of units available for purchase. Only displayed to authorized actors
115 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 115 required :stock, Integer, nil?: true |
#title ⇒ String?
The title of the plan. This will be visible on the product page to customers.
121 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 121 required :title, String, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
127 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 127 required :trial_period_days, Integer, nil?: true |
#unlimited_stock ⇒ Boolean
Limits/doesn’t limit the number of units available for purchase.
133 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 133 required :unlimited_stock, WhopSDK::Internal::Type::Boolean |
#updated_at ⇒ Time
When the plan was last updated.
139 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 139 required :updated_at, Time |
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Shows or hides the plan from public/business view.
145 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 145 required :visibility, enum: -> { WhopSDK::Visibility } |