Class: WhopSDK::Models::PlanListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanListResponse
- Defined in:
- lib/whop_sdk/models/plan_list_response.rb
Overview
Defined Under Namespace
Classes: Company, Invoice, Product
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
-
#company ⇒ WhopSDK::Models::PlanListResponse::Company?
The company for the plan.
-
#created_at ⇒ Time
When the plan was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
-
#description ⇒ String?
The description of the plan.
-
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
-
#id ⇒ String
The internal ID of the plan.
-
#initial_price ⇒ Float
The price a person has to pay for a plan on the initial purchase.
-
#internal_notes ⇒ String?
A personal description or notes section for the business.
-
#invoice ⇒ WhopSDK::Models::PlanListResponse::Invoice?
The invoice associated with this plan.
-
#member_count ⇒ Integer?
The number of members for the plan.
-
#plan_type ⇒ Symbol, WhopSDK::Models::PlanType
Indicates if the plan is a one time payment or recurring.
-
#product ⇒ WhopSDK::Models::PlanListResponse::Product?
The access pass for the plan.
-
#purchase_url ⇒ String
The direct link to purchase the product.
-
#release_method ⇒ Symbol, WhopSDK::Models::ReleaseMethod
This is the release method the business uses to sell this plan.
-
#renewal_price ⇒ Float
The price a person has to pay for a plan on the renewal purchase.
-
#stock ⇒ Integer?
The number of units available for purchase.
-
#title ⇒ String?
The title of the plan.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#unlimited_stock ⇒ Boolean
Limits/doesn’t limit the number of units available for purchase.
-
#updated_at ⇒ Time
When the plan was last updated.
-
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Shows or hides the plan from public/business view.
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
The invoice associated with this plan.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
The invoice associated with this plan.
|
|
# File 'lib/whop_sdk/models/plan_list_response.rb', line 139
|
Instance Attribute Details
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
17 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 17 required :billing_period, Integer, nil?: true |
#company ⇒ WhopSDK::Models::PlanListResponse::Company?
The company for the plan.
23 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 23 required :company, -> { WhopSDK::Models::PlanListResponse::Company }, nil?: true |
#created_at ⇒ Time
When the plan was created.
29 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 29 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The respective currency identifier for the plan.
35 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 35 required :currency, enum: -> { WhopSDK::Currency } |
#description ⇒ String?
The description of the plan.
41 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 41 required :description, String, nil?: true |
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
47 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 47 required :expiration_days, Integer, nil?: true |
#id ⇒ String
The internal ID of the plan.
11 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 11 required :id, String |
#initial_price ⇒ Float
The price a person has to pay for a plan on the initial purchase.
53 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 53 required :initial_price, Float |
#internal_notes ⇒ String?
A personal description or notes section for the business.
59 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 59 required :internal_notes, String, nil?: true |
#invoice ⇒ WhopSDK::Models::PlanListResponse::Invoice?
The invoice associated with this plan.
65 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 65 required :invoice, -> { WhopSDK::Models::PlanListResponse::Invoice }, nil?: true |
#member_count ⇒ Integer?
The number of members for the plan.
71 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 71 required :member_count, Integer, nil?: true |
#plan_type ⇒ Symbol, WhopSDK::Models::PlanType
Indicates if the plan is a one time payment or recurring.
77 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 77 required :plan_type, enum: -> { WhopSDK::PlanType } |
#product ⇒ WhopSDK::Models::PlanListResponse::Product?
The access pass for the plan.
83 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 83 required :product, -> { WhopSDK::Models::PlanListResponse::Product }, nil?: true |
#purchase_url ⇒ String
The direct link to purchase the product.
89 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 89 required :purchase_url, String |
#release_method ⇒ Symbol, WhopSDK::Models::ReleaseMethod
This is the release method the business uses to sell this plan.
95 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 95 required :release_method, enum: -> { WhopSDK::ReleaseMethod } |
#renewal_price ⇒ Float
The price a person has to pay for a plan on the renewal purchase.
101 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 101 required :renewal_price, Float |
#stock ⇒ Integer?
The number of units available for purchase. Only displayed to authorized actors
107 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 107 required :stock, Integer, nil?: true |
#title ⇒ String?
The title of the plan. This will be visible on the product page to customers.
113 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 113 required :title, String, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
119 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 119 required :trial_period_days, Integer, nil?: true |
#unlimited_stock ⇒ Boolean
Limits/doesn’t limit the number of units available for purchase.
125 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 125 required :unlimited_stock, WhopSDK::Internal::Type::Boolean |
#updated_at ⇒ Time
When the plan was last updated.
131 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 131 required :updated_at, Time |
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
Shows or hides the plan from public/business view.
137 |
# File 'lib/whop_sdk/models/plan_list_response.rb', line 137 required :visibility, enum: -> { WhopSDK::Visibility } |