Class: WhopSDK::Models::PlanUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/plan_update_params.rb
Overview
Defined Under Namespace
Classes: CheckoutStyling, CustomField, Image, PaymentMethodConfiguration
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The number of days between recurring charges.
-
#checkout_styling ⇒ WhopSDK::Models::PlanUpdateParams::CheckoutStyling?
Checkout styling overrides for this plan.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#custom_fields ⇒ Array<WhopSDK::Models::PlanUpdateParams::CustomField>?
An array of custom field definitions to collect from customers at checkout.
-
#description ⇒ String?
A text description of the plan displayed to customers on the product page.
-
#expiration_days ⇒ Integer?
The number of days until the membership expires and access is revoked.
- #id ⇒ String
-
#image ⇒ WhopSDK::Models::PlanUpdateParams::Image?
An image displayed on the product page to represent this plan.
-
#initial_price ⇒ Float?
The amount charged on the first purchase.
-
#internal_notes ⇒ String?
Private notes visible only to the business owner.
-
#legacy_payment_method_controls ⇒ Boolean?
Whether this plan uses legacy payment method controls.
-
#offer_cancel_discount ⇒ Boolean?
Whether to offer a retention discount when a customer attempts to cancel.
-
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up).
-
#payment_method_configuration ⇒ WhopSDK::Models::PlanUpdateParams::PaymentMethodConfiguration?
Explicit payment method configuration for the plan.
-
#renewal_price ⇒ Float?
The amount charged each billing period for recurring plans.
-
#stock ⇒ Integer?
The maximum number of units available for purchase.
-
#strike_through_initial_price ⇒ Float?
A comparison price displayed with a strikethrough for the initial price.
-
#strike_through_renewal_price ⇒ Float?
A comparison price displayed with a strikethrough for the renewal price.
-
#title ⇒ String?
The display name of the plan shown to customers on the product page.
-
#trial_period_days ⇒ Integer?
The number of free trial days before the first charge on a recurring plan.
-
#unlimited_stock ⇒ Boolean?
Whether the plan has unlimited stock.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:) ⇒ Object
constructor
An image displayed on the product page to represent this plan.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:) ⇒ Object
An image displayed on the product page to represent this plan.
|
|
# File 'lib/whop_sdk/models/plan_update_params.rb', line 224
|
Instance Attribute Details
#billing_period ⇒ Integer?
The number of days between recurring charges. For example, 30 for monthly or 365 for yearly.
20 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 20 optional :billing_period, Integer, nil?: true |
#checkout_styling ⇒ WhopSDK::Models::PlanUpdateParams::CheckoutStyling?
Checkout styling overrides for this plan. Pass null to remove all overrides and inherit from the company default.
27 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 27 optional :checkout_styling, -> { WhopSDK::PlanUpdateParams::CheckoutStyling }, nil?: true |
#currency ⇒ Symbol, ...
The available currencies on the platform
33 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 33 optional :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#custom_fields ⇒ Array<WhopSDK::Models::PlanUpdateParams::CustomField>?
An array of custom field definitions to collect from customers at checkout.
39 40 41 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 39 optional :custom_fields, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::PlanUpdateParams::CustomField] }, nil?: true |
#description ⇒ String?
A text description of the plan displayed to customers on the product page.
47 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 47 optional :description, String, nil?: true |
#expiration_days ⇒ Integer?
The number of days until the membership expires and access is revoked. For example, 365 for one-year access.
54 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 54 optional :expiration_days, Integer, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 13 required :id, String |
#image ⇒ WhopSDK::Models::PlanUpdateParams::Image?
An image displayed on the product page to represent this plan.
60 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 60 optional :image, -> { WhopSDK::PlanUpdateParams::Image }, nil?: true |
#initial_price ⇒ Float?
The amount charged on the first purchase. Provided in the plan’s currency (e.g., 10.43 for $10.43).
67 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 67 optional :initial_price, Float, nil?: true |
#internal_notes ⇒ String?
Private notes visible only to the business owner. Not shown to customers.
73 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 73 optional :internal_notes, String, nil?: true |
#legacy_payment_method_controls ⇒ Boolean?
Whether this plan uses legacy payment method controls.
79 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 79 optional :legacy_payment_method_controls, WhopSDK::Internal::Type::Boolean, nil?: true |
#offer_cancel_discount ⇒ Boolean?
Whether to offer a retention discount when a customer attempts to cancel.
85 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 85 optional :offer_cancel_discount, WhopSDK::Internal::Type::Boolean, nil?: true |
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up)
92 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 92 optional :override_tax_type, enum: -> { WhopSDK::TaxType }, nil?: true |
#payment_method_configuration ⇒ WhopSDK::Models::PlanUpdateParams::PaymentMethodConfiguration?
Explicit payment method configuration for the plan. Sending null removes any custom configuration.
99 100 101 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 99 optional :payment_method_configuration, -> { WhopSDK::PlanUpdateParams::PaymentMethodConfiguration }, nil?: true |
#renewal_price ⇒ Float?
The amount charged each billing period for recurring plans. Provided in the plan’s currency (e.g., 10.43 for $10.43).
108 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 108 optional :renewal_price, Float, nil?: true |
#stock ⇒ Integer?
The maximum number of units available for purchase. Ignored when unlimited_stock is true.
115 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 115 optional :stock, Integer, nil?: true |
#strike_through_initial_price ⇒ Float?
A comparison price displayed with a strikethrough for the initial price. Provided in the plan’s currency (e.g., 19.99 for $19.99).
122 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 122 optional :strike_through_initial_price, Float, nil?: true |
#strike_through_renewal_price ⇒ Float?
A comparison price displayed with a strikethrough for the renewal price. Provided in the plan’s currency (e.g., 19.99 for $19.99).
129 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 129 optional :strike_through_renewal_price, Float, nil?: true |
#title ⇒ String?
The display name of the plan shown to customers on the product page.
135 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 135 optional :title, String, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days before the first charge on a recurring plan.
141 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 141 optional :trial_period_days, Integer, nil?: true |
#unlimited_stock ⇒ Boolean?
Whether the plan has unlimited stock. When true, the stock field is ignored.
147 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 147 optional :unlimited_stock, WhopSDK::Internal::Type::Boolean, nil?: true |
#visibility ⇒ Symbol, ...
Visibility of a resource
153 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 153 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |