Class: WhopSDK::Models::PlanUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/plan_update_params.rb
Overview
Defined Under Namespace
Modules: Image Classes: CustomField, PaymentMethodConfiguration
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#custom_fields ⇒ Array<WhopSDK::Models::PlanUpdateParams::CustomField>?
An array of custom field objects.
-
#description ⇒ String?
The description of the plan.
-
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
-
#image ⇒ WhopSDK::Models::PlanUpdateParams::Image::AttachmentInputWithDirectUploadID, ...
An image for the plan.
-
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
-
#internal_notes ⇒ String?
A personal description or notes section for the business.
-
#offer_cancel_discount ⇒ Boolean?
Whether or not to offer a discount to cancel a subscription.
-
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up).
-
#payment_method_configuration ⇒ WhopSDK::Models::PlanUpdateParams::PaymentMethodConfiguration?
The explicit payment method configuration for the plan.
-
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
-
#stock ⇒ Integer?
The number of units available for purchase.
-
#strike_through_initial_price ⇒ Float?
The price to display with a strikethrough for the initial price.
-
#strike_through_renewal_price ⇒ Float?
The price to display with a strikethrough for the renewal price.
-
#title ⇒ String?
The title of the plan.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#unlimited_stock ⇒ Boolean?
Limits/doesn’t limit the number of units available for purchase.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see Image::AttachmentInputWithID for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::PlanUpdateParams::Image::AttachmentInputWithID for more details.
Input for an attachment
|
|
# File 'lib/whop_sdk/models/plan_update_params.rb', line 213
|
Instance Attribute Details
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
14 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 14 optional :billing_period, Integer, nil?: true |
#currency ⇒ Symbol, ...
The available currencies on the platform
20 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 20 optional :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#custom_fields ⇒ Array<WhopSDK::Models::PlanUpdateParams::CustomField>?
An array of custom field objects.
26 27 28 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 26 optional :custom_fields, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::PlanUpdateParams::CustomField] }, nil?: true |
#description ⇒ String?
The description of the plan.
34 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 34 optional :description, String, nil?: true |
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
40 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 40 optional :expiration_days, Integer, nil?: true |
#image ⇒ WhopSDK::Models::PlanUpdateParams::Image::AttachmentInputWithDirectUploadID, ...
An image for the plan. This will be visible on the product page to customers.
46 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 46 optional :image, union: -> { WhopSDK::PlanUpdateParams::Image }, nil?: true |
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
52 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 52 optional :initial_price, Float, nil?: true |
#internal_notes ⇒ String?
A personal description or notes section for the business.
58 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 58 optional :internal_notes, String, nil?: true |
#offer_cancel_discount ⇒ Boolean?
Whether or not to offer a discount to cancel a subscription.
64 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 64 optional :offer_cancel_discount, WhopSDK::Internal::Type::Boolean, nil?: true |
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up)
71 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 71 optional :override_tax_type, enum: -> { WhopSDK::TaxType }, nil?: true |
#payment_method_configuration ⇒ WhopSDK::Models::PlanUpdateParams::PaymentMethodConfiguration?
The explicit payment method configuration for the plan. If sent as null, the custom configuration will be removed.
78 79 80 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 78 optional :payment_method_configuration, -> { WhopSDK::PlanUpdateParams::PaymentMethodConfiguration }, nil?: true |
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
86 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 86 optional :renewal_price, Float, nil?: true |
#stock ⇒ Integer?
The number of units available for purchase.
92 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 92 optional :stock, Integer, nil?: true |
#strike_through_initial_price ⇒ Float?
The price to display with a strikethrough for the initial price. Provided as a number in dollars. Eg: 19.99 for $19.99
99 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 99 optional :strike_through_initial_price, Float, nil?: true |
#strike_through_renewal_price ⇒ Float?
The price to display with a strikethrough for the renewal price. Provided as a number in dollars. Eg: 19.99 for $19.99
106 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 106 optional :strike_through_renewal_price, Float, nil?: true |
#title ⇒ String?
The title of the plan. This will be visible on the product page to customers.
112 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 112 optional :title, String, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
118 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 118 optional :trial_period_days, Integer, nil?: true |
#unlimited_stock ⇒ Boolean?
Limits/doesn’t limit the number of units available for purchase.
124 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 124 optional :unlimited_stock, WhopSDK::Internal::Type::Boolean, nil?: true |
#visibility ⇒ Symbol, ...
Visibility of a resource
130 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 130 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |
Class Method Details
.variants ⇒ Array(WhopSDK::Models::PlanUpdateParams::Image::AttachmentInputWithDirectUploadID, WhopSDK::Models::PlanUpdateParams::Image::AttachmentInputWithID)
|
|
# File 'lib/whop_sdk/models/plan_update_params.rb', line 275
|