Class: WhopSDK::Models::PlanUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/plan_update_params.rb

Overview

Defined Under Namespace

Classes: CustomField, Image

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object

Parameters:

  • name (String) (defaults to: )

    The name of the custom field.

  • id (String, nil) (defaults to: nil)

    The ID of the custom field (if being updated)

  • order (Integer, nil) (defaults to: nil)

    The order of the field.

  • placeholder (String, nil) (defaults to: nil)

    The placeholder value of the field.

  • required (Boolean, nil) (defaults to: nil)

    Whether or not the field is required.

  • field_type (Symbol, :text) (defaults to: :text)

    The type of the custom field.



# File 'lib/whop_sdk/models/plan_update_params.rb', line 202

Instance Attribute Details

#billing_periodInteger?

The interval at which the plan charges (renewal plans).

Returns:

  • (Integer, nil)


14
# File 'lib/whop_sdk/models/plan_update_params.rb', line 14

optional :billing_period, Integer, nil?: true

#currencySymbol, ...

The available currencies on the platform

Returns:



20
# File 'lib/whop_sdk/models/plan_update_params.rb', line 20

optional :currency, enum: -> { WhopSDK::Currency }, nil?: true

#custom_fieldsArray<WhopSDK::Models::PlanUpdateParams::CustomField>?

An array of custom field objects.



26
27
28
# File 'lib/whop_sdk/models/plan_update_params.rb', line 26

optional :custom_fields,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::PlanUpdateParams::CustomField] },
nil?: true

#descriptionString?

The description of the plan.

Returns:

  • (String, nil)


34
# File 'lib/whop_sdk/models/plan_update_params.rb', line 34

optional :description, String, nil?: true

#expiration_daysInteger?

The interval at which the plan charges (expiration plans).

Returns:

  • (Integer, nil)


40
# File 'lib/whop_sdk/models/plan_update_params.rb', line 40

optional :expiration_days, Integer, nil?: true

#imageWhopSDK::Models::PlanUpdateParams::Image?

An image for the plan. This will be visible on the product page to customers.



46
# File 'lib/whop_sdk/models/plan_update_params.rb', line 46

optional :image, -> { WhopSDK::PlanUpdateParams::Image }, nil?: true

#initial_priceFloat?

An additional amount charged upon first purchase.

Returns:

  • (Float, nil)


52
# File 'lib/whop_sdk/models/plan_update_params.rb', line 52

optional :initial_price, Float, nil?: true

#internal_notesString?

A personal description or notes section for the business.

Returns:

  • (String, nil)


58
# File 'lib/whop_sdk/models/plan_update_params.rb', line 58

optional :internal_notes, String, nil?: true

#offer_cancel_discountBoolean?

Whether or not to offer a discount to cancel a subscription.

Returns:

  • (Boolean, nil)


64
# File 'lib/whop_sdk/models/plan_update_params.rb', line 64

optional :offer_cancel_discount, WhopSDK::Internal::Type::Boolean, nil?: true

#override_tax_typeSymbol, ...

Whether or not the tax is included in a plan’s price (or if it hasn’t been set up)

Returns:



71
# File 'lib/whop_sdk/models/plan_update_params.rb', line 71

optional :override_tax_type, enum: -> { WhopSDK::TaxType }, nil?: true

#renewal_priceFloat?

The amount the customer is charged every billing period.

Returns:

  • (Float, nil)


77
# File 'lib/whop_sdk/models/plan_update_params.rb', line 77

optional :renewal_price, Float, nil?: true

#stockInteger?

The number of units available for purchase.

Returns:

  • (Integer, nil)


83
# File 'lib/whop_sdk/models/plan_update_params.rb', line 83

optional :stock, Integer, nil?: true

#strike_through_initial_priceFloat?

The price to display with a strikethrough for the initial price. Provided as a number in dollars. Eg: 19.99 for $19.99

Returns:

  • (Float, nil)


90
# File 'lib/whop_sdk/models/plan_update_params.rb', line 90

optional :strike_through_initial_price, Float, nil?: true

#strike_through_renewal_priceFloat?

The price to display with a strikethrough for the renewal price. Provided as a number in dollars. Eg: 19.99 for $19.99

Returns:

  • (Float, nil)


97
# File 'lib/whop_sdk/models/plan_update_params.rb', line 97

optional :strike_through_renewal_price, Float, nil?: true

#titleString?

The title of the plan. This will be visible on the product page to customers.

Returns:

  • (String, nil)


103
# File 'lib/whop_sdk/models/plan_update_params.rb', line 103

optional :title, String, nil?: true

#trial_period_daysInteger?

The number of free trial days added before a renewal plan.

Returns:

  • (Integer, nil)


109
# File 'lib/whop_sdk/models/plan_update_params.rb', line 109

optional :trial_period_days, Integer, nil?: true

#unlimited_stockBoolean?

Limits/doesn’t limit the number of units available for purchase.

Returns:

  • (Boolean, nil)


115
# File 'lib/whop_sdk/models/plan_update_params.rb', line 115

optional :unlimited_stock, WhopSDK::Internal::Type::Boolean, nil?: true

#visibilitySymbol, ...

Visibility of a resource

Returns:



121
# File 'lib/whop_sdk/models/plan_update_params.rb', line 121

optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true