Class: WhopSDK::Models::PlanUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::PlanUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/plan_update_params.rb
Overview
Defined Under Namespace
Classes: CustomField, Image
Instance Attribute Summary collapse
-
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#custom_fields ⇒ Array<WhopSDK::Models::PlanUpdateParams::CustomField>?
An array of custom field objects.
-
#description ⇒ String?
The description of the plan.
-
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
-
#image ⇒ WhopSDK::Models::PlanUpdateParams::Image?
An image for the plan.
-
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
-
#internal_notes ⇒ String?
A personal description or notes section for the business.
-
#offer_cancel_discount ⇒ Boolean?
Whether or not to offer a discount to cancel a subscription.
-
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up).
-
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
-
#stock ⇒ Integer?
The number of units available for purchase.
-
#strike_through_initial_price ⇒ Float?
The price to display with a strikethrough for the initial price.
-
#strike_through_renewal_price ⇒ Float?
The price to display with a strikethrough for the renewal price.
-
#title ⇒ String?
The title of the plan.
-
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
-
#unlimited_stock ⇒ Boolean?
Limits/doesn’t limit the number of units available for purchase.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object
|
|
# File 'lib/whop_sdk/models/plan_update_params.rb', line 202
|
Instance Attribute Details
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
14 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 14 optional :billing_period, Integer, nil?: true |
#currency ⇒ Symbol, ...
The available currencies on the platform
20 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 20 optional :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#custom_fields ⇒ Array<WhopSDK::Models::PlanUpdateParams::CustomField>?
An array of custom field objects.
26 27 28 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 26 optional :custom_fields, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::PlanUpdateParams::CustomField] }, nil?: true |
#description ⇒ String?
The description of the plan.
34 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 34 optional :description, String, nil?: true |
#expiration_days ⇒ Integer?
The interval at which the plan charges (expiration plans).
40 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 40 optional :expiration_days, Integer, nil?: true |
#image ⇒ WhopSDK::Models::PlanUpdateParams::Image?
An image for the plan. This will be visible on the product page to customers.
46 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 46 optional :image, -> { WhopSDK::PlanUpdateParams::Image }, nil?: true |
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
52 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 52 optional :initial_price, Float, nil?: true |
#internal_notes ⇒ String?
A personal description or notes section for the business.
58 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 58 optional :internal_notes, String, nil?: true |
#offer_cancel_discount ⇒ Boolean?
Whether or not to offer a discount to cancel a subscription.
64 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 64 optional :offer_cancel_discount, WhopSDK::Internal::Type::Boolean, nil?: true |
#override_tax_type ⇒ Symbol, ...
Whether or not the tax is included in a plan’s price (or if it hasn’t been set up)
71 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 71 optional :override_tax_type, enum: -> { WhopSDK::TaxType }, nil?: true |
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
77 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 77 optional :renewal_price, Float, nil?: true |
#stock ⇒ Integer?
The number of units available for purchase.
83 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 83 optional :stock, Integer, nil?: true |
#strike_through_initial_price ⇒ Float?
The price to display with a strikethrough for the initial price. Provided as a number in dollars. Eg: 19.99 for $19.99
90 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 90 optional :strike_through_initial_price, Float, nil?: true |
#strike_through_renewal_price ⇒ Float?
The price to display with a strikethrough for the renewal price. Provided as a number in dollars. Eg: 19.99 for $19.99
97 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 97 optional :strike_through_renewal_price, Float, nil?: true |
#title ⇒ String?
The title of the plan. This will be visible on the product page to customers.
103 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 103 optional :title, String, nil?: true |
#trial_period_days ⇒ Integer?
The number of free trial days added before a renewal plan.
109 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 109 optional :trial_period_days, Integer, nil?: true |
#unlimited_stock ⇒ Boolean?
Limits/doesn’t limit the number of units available for purchase.
115 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 115 optional :unlimited_stock, WhopSDK::Internal::Type::Boolean, nil?: true |
#visibility ⇒ Symbol, ...
Visibility of a resource
121 |
# File 'lib/whop_sdk/models/plan_update_params.rb', line 121 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |