Class: WhopSDK::Models::Product
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Product
- Defined in:
- lib/whop_sdk/models/product.rb
Defined Under Namespace
Classes: Company, OwnerUser, ProductTaxCode
Instance Attribute Summary collapse
-
#business_type ⇒ Symbol, ...
The different business types a company can be.
-
#company ⇒ WhopSDK::Models::Product::Company
A short type of the company that this product belongs to.
-
#created_at ⇒ Time
When the product was created.
-
#custom_cta ⇒ Symbol, WhopSDK::Models::CustomCta
The custom call to action for the product.
-
#custom_cta_url ⇒ String?
The custom call to action URL for the product, if any.
-
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product.
-
#description ⇒ String?
A short description of what the company offers or does.
-
#external_identifier ⇒ String?
A unique identifier used to create or update products.
-
#global_affiliate_percentage ⇒ Float?
The percentage of a transaction a user is eligible to earn from the whop marketplace global affiliate program.
-
#global_affiliate_status ⇒ Symbol, WhopSDK::Models::GlobalAffiliateStatus
The status of the global affiliate program for this product.
-
#headline ⇒ String?
The headline of the product.
-
#id ⇒ String
The internal ID of the public product.
-
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
-
#member_affiliate_percentage ⇒ Float?
The percentage of a transaction a user is eligible to earn from the whop marketplace member affiliate program.
-
#member_affiliate_status ⇒ Symbol, WhopSDK::Models::GlobalAffiliateStatus
The status of the member affiliate program for this product.
-
#member_count ⇒ Integer
The number of active users for this product.
-
#owner_user ⇒ WhopSDK::Models::Product::OwnerUser
The user that owns the product (company owner).
-
#product_tax_code ⇒ WhopSDK::Models::Product::ProductTaxCode?
The product tax code for the product, if any.
-
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the product.
-
#route ⇒ String
The route of the product.
-
#title ⇒ String
The title of the product.
-
#updated_at ⇒ Time
When the product was updated.
-
#verified ⇒ Boolean
Whether this product is Whop verified.
-
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
This product will/will not be displayed publicly.
Instance Method Summary collapse
-
#initialize(id: , name: , username: ) ⇒ Object
constructor
The user that owns the product (company owner).
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , name: , username: ) ⇒ Object
The user that owns the product (company owner).
|
|
# File 'lib/whop_sdk/models/product.rb', line 154
|
Instance Attribute Details
#business_type ⇒ Symbol, ...
The different business types a company can be.
16 |
# File 'lib/whop_sdk/models/product.rb', line 16 required :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true |
#company ⇒ WhopSDK::Models::Product::Company
A short type of the company that this product belongs to.
22 |
# File 'lib/whop_sdk/models/product.rb', line 22 required :company, -> { WhopSDK::Product::Company } |
#created_at ⇒ Time
When the product was created.
28 |
# File 'lib/whop_sdk/models/product.rb', line 28 required :created_at, Time |
#custom_cta ⇒ Symbol, WhopSDK::Models::CustomCta
The custom call to action for the product.
34 |
# File 'lib/whop_sdk/models/product.rb', line 34 required :custom_cta, enum: -> { WhopSDK::CustomCta } |
#custom_cta_url ⇒ String?
The custom call to action URL for the product, if any.
40 |
# File 'lib/whop_sdk/models/product.rb', line 40 required :custom_cta_url, String, nil?: true |
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product.
46 |
# File 'lib/whop_sdk/models/product.rb', line 46 required :custom_statement_descriptor, String, nil?: true |
#description ⇒ String?
A short description of what the company offers or does.
52 |
# File 'lib/whop_sdk/models/product.rb', line 52 required :description, String, nil?: true |
#external_identifier ⇒ String?
A unique identifier used to create or update products. When provided on product creation endpoints, we’ll look up an existing product by this identifier — if it exists, we’ll update it; if not, we’ll create a new one.
60 |
# File 'lib/whop_sdk/models/product.rb', line 60 required :external_identifier, String, nil?: true |
#global_affiliate_percentage ⇒ Float?
The percentage of a transaction a user is eligible to earn from the whop marketplace global affiliate program.
67 |
# File 'lib/whop_sdk/models/product.rb', line 67 required :global_affiliate_percentage, Float, nil?: true |
#global_affiliate_status ⇒ Symbol, WhopSDK::Models::GlobalAffiliateStatus
The status of the global affiliate program for this product.
73 |
# File 'lib/whop_sdk/models/product.rb', line 73 required :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus } |
#headline ⇒ String?
The headline of the product.
79 |
# File 'lib/whop_sdk/models/product.rb', line 79 required :headline, String, nil?: true |
#id ⇒ String
The internal ID of the public product.
10 |
# File 'lib/whop_sdk/models/product.rb', line 10 required :id, String |
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
85 |
# File 'lib/whop_sdk/models/product.rb', line 85 required :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true |
#member_affiliate_percentage ⇒ Float?
The percentage of a transaction a user is eligible to earn from the whop marketplace member affiliate program.
92 |
# File 'lib/whop_sdk/models/product.rb', line 92 required :member_affiliate_percentage, Float, nil?: true |
#member_affiliate_status ⇒ Symbol, WhopSDK::Models::GlobalAffiliateStatus
The status of the member affiliate program for this product.
98 |
# File 'lib/whop_sdk/models/product.rb', line 98 required :member_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus } |
#member_count ⇒ Integer
The number of active users for this product.
104 |
# File 'lib/whop_sdk/models/product.rb', line 104 required :member_count, Integer |
#owner_user ⇒ WhopSDK::Models::Product::OwnerUser
The user that owns the product (company owner).
110 |
# File 'lib/whop_sdk/models/product.rb', line 110 required :owner_user, -> { WhopSDK::Product::OwnerUser } |
#product_tax_code ⇒ WhopSDK::Models::Product::ProductTaxCode?
The product tax code for the product, if any.
116 |
# File 'lib/whop_sdk/models/product.rb', line 116 required :product_tax_code, -> { WhopSDK::Product::ProductTaxCode }, nil?: true |
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the product.
122 |
# File 'lib/whop_sdk/models/product.rb', line 122 required :published_reviews_count, Integer |
#route ⇒ String
The route of the product.
128 |
# File 'lib/whop_sdk/models/product.rb', line 128 required :route, String |
#title ⇒ String
The title of the product. Use for Whop 4.0.
134 |
# File 'lib/whop_sdk/models/product.rb', line 134 required :title, String |
#updated_at ⇒ Time
When the product was updated.
140 |
# File 'lib/whop_sdk/models/product.rb', line 140 required :updated_at, Time |
#verified ⇒ Boolean
Whether this product is Whop verified.
146 |
# File 'lib/whop_sdk/models/product.rb', line 146 required :verified, WhopSDK::Internal::Type::Boolean |
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
This product will/will not be displayed publicly.
152 |
# File 'lib/whop_sdk/models/product.rb', line 152 required :visibility, enum: -> { WhopSDK::Visibility } |