Class: WhopSDK::Models::Product::GalleryImage
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Product::GalleryImage
- Defined in:
- lib/whop_sdk/models/product.rb,
sig/whop_sdk/models/product.rbs
Instance Attribute Summary collapse
-
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated.
-
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client.
Instance Method Summary collapse
-
#initialize ⇒ GalleryImage
constructor
A new instance of GalleryImage.
- #to_hash ⇒ { id: String, url: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ GalleryImage
Returns a new instance of GalleryImage.
155 |
# File 'sig/whop_sdk/models/product.rbs', line 155
def initialize: (id: String, url: String?) -> void
|
Instance Attribute Details
#id ⇒ String
Represents a unique identifier that is Base64 obfuscated. It is often used to
refetch an object or as key for a cache. The ID type appears in a JSON response
as a String; however, it is not intended to be human-readable. When expected as
an input type, any string (such as "VXNlci0xMA==") or integer (such as 4)
input value will be accepted as an ID.
258 |
# File 'lib/whop_sdk/models/product.rb', line 258 required :id, String |
#url ⇒ String?
A pre-optimized URL for rendering this attachment on the client. This should be used for displaying attachments in apps.
265 |
# File 'lib/whop_sdk/models/product.rb', line 265 required :url, String, nil?: true |
Instance Method Details
#to_hash ⇒ { id: String, url: String? }
157 |
# File 'sig/whop_sdk/models/product.rbs', line 157
def to_hash: -> { id: String, url: String? }
|