Class: WhopSDK::Models::Product::ProductTaxCode
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Product::ProductTaxCode
- Defined in:
- lib/whop_sdk/models/product.rb,
sig/whop_sdk/models/product.rbs
Overview
Defined Under Namespace
Modules: ProductType
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the product tax code.
-
#name ⇒ String
Human-readable name of this tax classification, such as 'Digital - SaaS'.
-
#product_type ⇒ Symbol, WhopSDK::Models::Product::ProductTaxCode::ProductType
Broad product category this tax code covers, such as physical goods or digital services.
Instance Method Summary collapse
-
#initialize(id:, name:, product_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProductTaxCode for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, name:, product_type:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Product::ProductTaxCode for more details.
The tax classification code applied to purchases of this product for sales tax calculation. Null if no tax code is assigned.
|
|
# File 'lib/whop_sdk/models/product.rb', line 329
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the product tax code.
314 |
# File 'lib/whop_sdk/models/product.rb', line 314 required :id, String |
#name ⇒ String
Human-readable name of this tax classification, such as 'Digital - SaaS'.
320 |
# File 'lib/whop_sdk/models/product.rb', line 320 required :name, String |
#product_type ⇒ Symbol, WhopSDK::Models::Product::ProductTaxCode::ProductType
Broad product category this tax code covers, such as physical goods or digital services.
327 |
# File 'lib/whop_sdk/models/product.rb', line 327 required :product_type, enum: -> { WhopSDK::Product::ProductTaxCode::ProductType } |
Instance Method Details
#to_hash ⇒ {
194 |
# File 'sig/whop_sdk/models/product.rbs', line 194
def to_hash: -> {
|