Class: WhopSDK::Models::Product::ProductTaxCode

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product.rb

Overview

See Also:

Defined Under Namespace

Modules: ProductType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, name:, product_type:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::Product::ProductTaxCode for more details.

The tax classification code applied to purchases of this product for sales tax calculation. Null if no tax code is assigned.

Parameters:

  • id (String)

    The unique identifier for the product tax code.

  • name (String)

    The human-readable name of this tax classification (e.g., ‘Digital - SaaS’).

  • product_type (Symbol, WhopSDK::Models::Product::ProductTaxCode::ProductType)

    The broad product category this tax code covers (e.g., physical goods, digital s



# File 'lib/whop_sdk/models/product.rb', line 326

Instance Attribute Details

#idString

The unique identifier for the product tax code.

Returns:

  • (String)


311
# File 'lib/whop_sdk/models/product.rb', line 311

required :id, String

#nameString

The human-readable name of this tax classification (e.g., ‘Digital - SaaS’).

Returns:

  • (String)


317
# File 'lib/whop_sdk/models/product.rb', line 317

required :name, String

#product_typeSymbol, WhopSDK::Models::Product::ProductTaxCode::ProductType

The broad product category this tax code covers (e.g., physical goods, digital services).



324
# File 'lib/whop_sdk/models/product.rb', line 324

required :product_type, enum: -> { WhopSDK::Product::ProductTaxCode::ProductType }