Class: WhopSDK::Models::Product::ProductTaxCode
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Product::ProductTaxCode
- Defined in:
- lib/whop_sdk/models/product.rb
Overview
Defined Under Namespace
Modules: ProductType
Instance Attribute Summary collapse
-
#id ⇒ String
The internal ID of the product tax code.
-
#name ⇒ String
The name of the product tax code.
-
#product_type ⇒ Symbol, WhopSDK::Models::Product::ProductTaxCode::ProductType
The type of product this tax code applies to.
Instance Method Summary collapse
-
#initialize(id: , name: , product_type: ) ⇒ Object
constructor
The product tax code for the product, if any.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , name: , product_type: ) ⇒ Object
The product tax code for the product, if any.
|
|
# File 'lib/whop_sdk/models/product.rb', line 288
|
Instance Attribute Details
#id ⇒ String
The internal ID of the product tax code.
274 |
# File 'lib/whop_sdk/models/product.rb', line 274 required :id, String |
#name ⇒ String
The name of the product tax code.
280 |
# File 'lib/whop_sdk/models/product.rb', line 280 required :name, String |
#product_type ⇒ Symbol, WhopSDK::Models::Product::ProductTaxCode::ProductType
The type of product this tax code applies to.
286 |
# File 'lib/whop_sdk/models/product.rb', line 286 required :product_type, enum: -> { WhopSDK::Product::ProductTaxCode::ProductType } |