Class: WhopSDK::Models::Product::ProductTaxCode

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product.rb

Overview

See Also:

Defined Under Namespace

Modules: ProductType

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , name: , product_type: ) ⇒ Object

The product tax code for the product, if any.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the product tax code.

  • name (String) (defaults to: )

    The name of the product tax code.

  • product_type (Symbol, WhopSDK::Models::Product::ProductTaxCode::ProductType) (defaults to: )

    The type of product this tax code applies to.



# File 'lib/whop_sdk/models/product.rb', line 288

Instance Attribute Details

#idString

The internal ID of the product tax code.

Returns:

  • (String)


274
# File 'lib/whop_sdk/models/product.rb', line 274

required :id, String

#nameString

The name of the product tax code.

Returns:

  • (String)


280
# File 'lib/whop_sdk/models/product.rb', line 280

required :name, String

#product_typeSymbol, WhopSDK::Models::Product::ProductTaxCode::ProductType

The type of product this tax code applies to.



286
# File 'lib/whop_sdk/models/product.rb', line 286

required :product_type, enum: -> { WhopSDK::Product::ProductTaxCode::ProductType }