Class: WhopSDK::Models::ProductCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/product_create_params.rb,
sig/whop_sdk/models/product_create_params.rbs
Overview
Instance Attribute Summary collapse
-
#collect_shipping_address ⇒ Boolean?
Whether to collect a shipping address at checkout.
-
#company_id ⇒ String?
The unique identifier of the company to create this product for.
-
#custom_cta ⇒ String?
The call-to-action button label.
-
#custom_cta_url ⇒ String?
A URL the call-to-action button links to.
-
#custom_statement_descriptor ⇒ String?
Custom bank statement descriptor.
-
#description ⇒ String?
A written description displayed on the product page.
-
#global_affiliate_percentage ⇒ Float?
The commission rate affiliates earn.
-
#global_affiliate_status ⇒ String?
The enrollment status in the global affiliate program.
-
#headline ⇒ String?
A short marketing headline for the product page.
-
#member_affiliate_percentage ⇒ Float?
The commission rate members earn.
-
#member_affiliate_status ⇒ String?
The enrollment status in the member affiliate program.
-
#metadata ⇒ Object?
Custom key-value pairs to store on the product.
-
#product_tax_code_id ⇒ String?
The unique identifier of the tax classification code.
-
#redirect_purchase_url ⇒ String?
A URL to redirect the customer to after purchase.
-
#route ⇒ String?
The URL slug for the product's public link.
-
#send_welcome_message ⇒ Boolean?
Whether to send an automated welcome message via support chat when a user joins this product.
-
#title ⇒ String
The display name of the product.
-
#visibility ⇒ String?
Whether the product is visible to customers.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(title:, collect_shipping_address: nil, company_id: nil, custom_cta: nil, custom_cta_url: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, member_affiliate_percentage: nil, member_affiliate_status: nil, metadata: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, send_welcome_message: nil, visibility: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProductCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(title:, collect_shipping_address: nil, company_id: nil, custom_cta: nil, custom_cta_url: nil, custom_statement_descriptor: nil, description: nil, global_affiliate_percentage: nil, global_affiliate_status: nil, headline: nil, member_affiliate_percentage: nil, member_affiliate_status: nil, metadata: nil, product_tax_code_id: nil, redirect_purchase_url: nil, route: nil, send_welcome_message: nil, visibility: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ProductCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/product_create_params.rb', line 120
|
Instance Attribute Details
#collect_shipping_address ⇒ Boolean?
Whether to collect a shipping address at checkout.
20 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 20 optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true |
#company_id ⇒ String?
The unique identifier of the company to create this product for.
26 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 26 optional :company_id, String |
#custom_cta ⇒ String?
The call-to-action button label.
32 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 32 optional :custom_cta, String, nil?: true |
#custom_cta_url ⇒ String?
A URL the call-to-action button links to.
38 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 38 optional :custom_cta_url, String, nil?: true |
#custom_statement_descriptor ⇒ String?
Custom bank statement descriptor. Must start with WHOP*.
44 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 44 optional :custom_statement_descriptor, String, nil?: true |
#description ⇒ String?
A written description displayed on the product page.
50 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 50 optional :description, String, nil?: true |
#global_affiliate_percentage ⇒ Float?
The commission rate affiliates earn.
56 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 56 optional :global_affiliate_percentage, Float, nil?: true |
#global_affiliate_status ⇒ String?
The enrollment status in the global affiliate program.
62 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 62 optional :global_affiliate_status, String |
#headline ⇒ String?
A short marketing headline for the product page.
68 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 68 optional :headline, String, nil?: true |
#member_affiliate_percentage ⇒ Float?
The commission rate members earn.
74 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 74 optional :member_affiliate_percentage, Float, nil?: true |
#member_affiliate_status ⇒ String?
The enrollment status in the member affiliate program.
80 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 80 optional :member_affiliate_status, String |
#metadata ⇒ Object?
Custom key-value pairs to store on the product.
86 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 86 optional :metadata, WhopSDK::Internal::Type::Unknown, nil?: true |
#product_tax_code_id ⇒ String?
The unique identifier of the tax classification code. See the available product categories.
93 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 93 optional :product_tax_code_id, String, nil?: true |
#redirect_purchase_url ⇒ String?
A URL to redirect the customer to after purchase.
99 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 99 optional :redirect_purchase_url, String, nil?: true |
#route ⇒ String?
The URL slug for the product's public link.
105 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 105 optional :route, String, nil?: true |
#send_welcome_message ⇒ Boolean?
Whether to send an automated welcome message via support chat when a user joins this product. Defaults to true.
112 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 112 optional :send_welcome_message, WhopSDK::Internal::Type::Boolean, nil?: true |
#title ⇒ String
The display name of the product. Maximum 80 characters.
14 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 14 required :title, String |
#visibility ⇒ String?
Whether the product is visible to customers.
118 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 118 optional :visibility, String |
Instance Method Details
#to_hash ⇒ {
96 |
# File 'sig/whop_sdk/models/product_create_params.rbs', line 96
def to_hash: -> {
|