Class: WhopSDK::Models::ProductCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/product_create_params.rb

Overview

Defined Under Namespace

Classes: PlanOptions

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#collect_shipping_addressBoolean?

Whether the checkout flow collects a shipping address from the customer.

Returns:

  • (Boolean, nil)


26
# File 'lib/whop_sdk/models/product_create_params.rb', line 26

optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true

#company_idString

The unique identifier of the company to create this product for.

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/product_create_params.rb', line 14

required :company_id, String

#custom_ctaSymbol, ...

The different types of custom CTAs that can be selected.

Returns:



32
# File 'lib/whop_sdk/models/product_create_params.rb', line 32

optional :custom_cta, enum: -> { WhopSDK::CustomCta }, nil?: true

#custom_cta_urlString?

A URL that the call-to-action button links to instead of the default checkout flow.

Returns:

  • (String, nil)


39
# File 'lib/whop_sdk/models/product_create_params.rb', line 39

optional :custom_cta_url, String, nil?: true

#custom_statement_descriptorString?

A custom text label that appears on the customer’s bank statement. Must be 5-22 characters, contain at least one letter, and not contain <, >, , ‘, or “ characters.

Returns:

  • (String, nil)


47
# File 'lib/whop_sdk/models/product_create_params.rb', line 47

optional :custom_statement_descriptor, String, nil?: true

#descriptionString?

A written description of the product displayed on its product page.

Returns:

  • (String, nil)


53
# File 'lib/whop_sdk/models/product_create_params.rb', line 53

optional :description, String, nil?: true

#experience_idsArray<String>?

The unique identifiers of experiences to connect to this product.

Returns:

  • (Array<String>, nil)


59
# File 'lib/whop_sdk/models/product_create_params.rb', line 59

optional :experience_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#global_affiliate_percentageFloat?

The commission rate as a percentage that affiliates earn through the global affiliate program.

Returns:

  • (Float, nil)


66
# File 'lib/whop_sdk/models/product_create_params.rb', line 66

optional :global_affiliate_percentage, Float, nil?: true

#global_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for a product.

Returns:



72
# File 'lib/whop_sdk/models/product_create_params.rb', line 72

optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#headlineString?

A short marketing headline displayed prominently on the product page.

Returns:

  • (String, nil)


78
# File 'lib/whop_sdk/models/product_create_params.rb', line 78

optional :headline, String, nil?: true

#member_affiliate_percentageFloat?

The commission rate as a percentage that members earn through the member affiliate program.

Returns:

  • (Float, nil)


85
# File 'lib/whop_sdk/models/product_create_params.rb', line 85

optional :member_affiliate_percentage, Float, nil?: true

#member_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for a product.

Returns:



91
# File 'lib/whop_sdk/models/product_create_params.rb', line 91

optional :member_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#plan_optionsWhopSDK::Models::ProductCreateParams::PlanOptions?

Configuration for an automatically generated plan to attach to this product.



97
# File 'lib/whop_sdk/models/product_create_params.rb', line 97

optional :plan_options, -> { WhopSDK::ProductCreateParams::PlanOptions }, nil?: true

#product_tax_code_idString?

The unique identifier of the tax classification code to apply to this product.

Returns:

  • (String, nil)


103
# File 'lib/whop_sdk/models/product_create_params.rb', line 103

optional :product_tax_code_id, String, nil?: true

#redirect_purchase_urlString?

A URL to redirect the customer to after completing a purchase.

Returns:

  • (String, nil)


109
# File 'lib/whop_sdk/models/product_create_params.rb', line 109

optional :redirect_purchase_url, String, nil?: true

#routeString?

The URL slug for the product’s public link.

Returns:

  • (String, nil)


115
# File 'lib/whop_sdk/models/product_create_params.rb', line 115

optional :route, String, nil?: true

#send_welcome_messageBoolean?

Whether to send an automated welcome message via support chat when a user joins this product. Defaults to true.

Returns:

  • (Boolean, nil)


122
# File 'lib/whop_sdk/models/product_create_params.rb', line 122

optional :send_welcome_message, WhopSDK::Internal::Type::Boolean, nil?: true

#titleString

The display name of the product. Maximum 80 characters.

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/product_create_params.rb', line 20

required :title, String

#visibilitySymbol, ...

Visibility of a resource

Returns:



128
# File 'lib/whop_sdk/models/product_create_params.rb', line 128

optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true