Class: WhopSDK::Models::ProductCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/product_create_params.rb
Overview
Defined Under Namespace
Classes: PlanOptions
Instance Attribute Summary collapse
-
#collect_shipping_address ⇒ Boolean?
Whether the checkout flow collects a shipping address from the customer.
-
#company_id ⇒ String
The unique identifier of the company to create this product for.
-
#custom_cta ⇒ Symbol, ...
The different types of custom CTAs that can be selected.
-
#custom_cta_url ⇒ String?
A URL that the call-to-action button links to instead of the default checkout flow.
-
#custom_statement_descriptor ⇒ String?
A custom text label that appears on the customer’s bank statement.
-
#description ⇒ String?
A written description of the product displayed on its product page.
-
#experience_ids ⇒ Array<String>?
The unique identifiers of experiences to connect to this product.
-
#global_affiliate_percentage ⇒ Float?
The commission rate as a percentage that affiliates earn through the global affiliate program.
-
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
-
#headline ⇒ String?
A short marketing headline displayed prominently on the product page.
-
#member_affiliate_percentage ⇒ Float?
The commission rate as a percentage that members earn through the member affiliate program.
-
#member_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
-
#plan_options ⇒ WhopSDK::Models::ProductCreateParams::PlanOptions?
Configuration for an automatically generated plan to attach to this product.
-
#product_tax_code_id ⇒ String?
The unique identifier of the tax classification code to apply to this product.
-
#redirect_purchase_url ⇒ String?
A URL to redirect the customer to after completing a purchase.
-
#route ⇒ String?
The URL slug for the product’s public link.
-
#send_welcome_message ⇒ Boolean?
Whether to send an automated welcome message via support chat when a user joins this product.
-
#title ⇒ String
The display name of the product.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#collect_shipping_address ⇒ Boolean?
Whether the checkout flow collects a shipping address from the customer.
26 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 26 optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true |
#company_id ⇒ String
The unique identifier of the company to create this product for.
14 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 14 required :company_id, String |
#custom_cta ⇒ Symbol, ...
The different types of custom CTAs that can be selected.
32 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 32 optional :custom_cta, enum: -> { WhopSDK::CustomCta }, nil?: true |
#custom_cta_url ⇒ String?
A URL that the call-to-action button links to instead of the default checkout flow.
39 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 39 optional :custom_cta_url, String, nil?: true |
#custom_statement_descriptor ⇒ String?
A custom text label that appears on the customer’s bank statement. Must be 5-22 characters, contain at least one letter, and not contain <, >, , ‘, or “ characters.
47 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 47 optional :custom_statement_descriptor, String, nil?: true |
#description ⇒ String?
A written description of the product displayed on its product page.
53 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 53 optional :description, String, nil?: true |
#experience_ids ⇒ Array<String>?
The unique identifiers of experiences to connect to this product.
59 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 59 optional :experience_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#global_affiliate_percentage ⇒ Float?
The commission rate as a percentage that affiliates earn through the global affiliate program.
66 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 66 optional :global_affiliate_percentage, Float, nil?: true |
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
72 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 72 optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true |
#headline ⇒ String?
A short marketing headline displayed prominently on the product page.
78 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 78 optional :headline, String, nil?: true |
#member_affiliate_percentage ⇒ Float?
The commission rate as a percentage that members earn through the member affiliate program.
85 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 85 optional :member_affiliate_percentage, Float, nil?: true |
#member_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
91 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 91 optional :member_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true |
#plan_options ⇒ WhopSDK::Models::ProductCreateParams::PlanOptions?
Configuration for an automatically generated plan to attach to this product.
97 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 97 optional :plan_options, -> { WhopSDK::ProductCreateParams::PlanOptions }, nil?: true |
#product_tax_code_id ⇒ String?
The unique identifier of the tax classification code to apply to this product.
103 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 103 optional :product_tax_code_id, String, nil?: true |
#redirect_purchase_url ⇒ String?
A URL to redirect the customer to after completing a purchase.
109 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 109 optional :redirect_purchase_url, String, nil?: true |
#route ⇒ String?
The URL slug for the product’s public link.
115 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 115 optional :route, String, nil?: true |
#send_welcome_message ⇒ Boolean?
Whether to send an automated welcome message via support chat when a user joins this product. Defaults to true.
122 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 122 optional :send_welcome_message, WhopSDK::Internal::Type::Boolean, nil?: true |
#title ⇒ String
The display name of the product. Maximum 80 characters.
20 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 20 required :title, String |
#visibility ⇒ Symbol, ...
Visibility of a resource
128 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 128 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |