Class: WhopSDK::Models::ProductCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/product_create_params.rb

Overview

Defined Under Namespace

Classes: PlanOptions, ProductHighlight

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object

Parameters:

  • name (String) (defaults to: )

    The name of the custom field.

  • id (String, nil) (defaults to: nil)

    The ID of the custom field (if being updated)

  • order (Integer, nil) (defaults to: nil)

    The order of the field.

  • placeholder (String, nil) (defaults to: nil)

    The placeholder value of the field.

  • required (Boolean, nil) (defaults to: nil)

    Whether or not the field is required.

  • field_type (Symbol, :text) (defaults to: :text)

    The type of the custom field.



# File 'lib/whop_sdk/models/product_create_params.rb', line 298

Instance Attribute Details

#business_typeSymbol, ...

The different business types a company can be.

Returns:



26
# File 'lib/whop_sdk/models/product_create_params.rb', line 26

optional :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true

#collect_shipping_addressBoolean?

Whether or not to collect shipping information at checkout from the customer.

Returns:

  • (Boolean, nil)


32
# File 'lib/whop_sdk/models/product_create_params.rb', line 32

optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true

#company_idString

The ID of the company to create the product for.

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/product_create_params.rb', line 14

required :company_id, String

#custom_ctaSymbol, ...

The different types of custom CTAs that can be selected.

Returns:



38
# File 'lib/whop_sdk/models/product_create_params.rb', line 38

optional :custom_cta, enum: -> { WhopSDK::CustomCta }, nil?: true

#custom_cta_urlString?

The custom call to action URL for the product.

Returns:

  • (String, nil)


44
# File 'lib/whop_sdk/models/product_create_params.rb', line 44

optional :custom_cta_url, String, nil?: true

#custom_statement_descriptorString?

The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ‘, “

Returns:

  • (String, nil)


52
# File 'lib/whop_sdk/models/product_create_params.rb', line 52

optional :custom_statement_descriptor, String, nil?: true

#descriptionString?

A written description of the product.

Returns:

  • (String, nil)


58
# File 'lib/whop_sdk/models/product_create_params.rb', line 58

optional :description, String, nil?: true

#experience_idsArray<String>?

An array of experience IDs that this pass has

Returns:

  • (Array<String>, nil)


64
# File 'lib/whop_sdk/models/product_create_params.rb', line 64

optional :experience_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true

#global_affiliate_percentageFloat?

The percentage of the revenue that goes to the global affiliate program.

Returns:

  • (Float, nil)


70
# File 'lib/whop_sdk/models/product_create_params.rb', line 70

optional :global_affiliate_percentage, Float, nil?: true

#global_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for an access pass.

Returns:



76
# File 'lib/whop_sdk/models/product_create_params.rb', line 76

optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#headlineString?

The headline of the product.

Returns:

  • (String, nil)


82
# File 'lib/whop_sdk/models/product_create_params.rb', line 82

optional :headline, String, nil?: true

#industry_typeSymbol, ...

The different industry types a company can be in.

Returns:



88
# File 'lib/whop_sdk/models/product_create_params.rb', line 88

optional :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true

#member_affiliate_percentageFloat?

The percentage of the revenue that goes to the member affiliate program.

Returns:

  • (Float, nil)


94
# File 'lib/whop_sdk/models/product_create_params.rb', line 94

optional :member_affiliate_percentage, Float, nil?: true

#member_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for an access pass.

Returns:



100
# File 'lib/whop_sdk/models/product_create_params.rb', line 100

optional :member_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#plan_optionsWhopSDK::Models::ProductCreateParams::PlanOptions?

The details to assign an autogenerated plan.



106
# File 'lib/whop_sdk/models/product_create_params.rb', line 106

optional :plan_options, -> { WhopSDK::ProductCreateParams::PlanOptions }, nil?: true

#product_highlightsArray<WhopSDK::Models::ProductCreateParams::ProductHighlight>?

The product highlights for the product.



112
113
114
# File 'lib/whop_sdk/models/product_create_params.rb', line 112

optional :product_highlights,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::ProductCreateParams::ProductHighlight] },
nil?: true

#product_tax_code_idString?

The ID of the product tax code to apply to this product.

Returns:

  • (String, nil)


120
# File 'lib/whop_sdk/models/product_create_params.rb', line 120

optional :product_tax_code_id, String, nil?: true

#redirect_purchase_urlString?

The URL to redirect the customer to after a purchase.

Returns:

  • (String, nil)


126
# File 'lib/whop_sdk/models/product_create_params.rb', line 126

optional :redirect_purchase_url, String, nil?: true

#routeString?

The route of the product.

Returns:

  • (String, nil)


132
# File 'lib/whop_sdk/models/product_create_params.rb', line 132

optional :route, String, nil?: true

#titleString

The title of the product.

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/product_create_params.rb', line 20

required :title, String

#visibilitySymbol, ...

Visibility of a resource

Returns:



138
# File 'lib/whop_sdk/models/product_create_params.rb', line 138

optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true