Class: WhopSDK::Models::ProductCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/product_create_params.rb
Overview
Defined Under Namespace
Classes: PlanOptions, ProductHighlight
Instance Attribute Summary collapse
-
#business_type ⇒ Symbol, ...
The different business types a company can be.
-
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
-
#company_id ⇒ String
The ID of the company to create the product for.
-
#custom_cta ⇒ Symbol, ...
The different types of custom CTAs that can be selected.
-
#custom_cta_url ⇒ String?
The custom call to action URL for the product.
-
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e.
-
#description ⇒ String?
A written description of the product.
-
#experience_ids ⇒ Array<String>?
An array of experience IDs that this pass has.
-
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
-
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for an access pass.
-
#headline ⇒ String?
The headline of the product.
-
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
-
#member_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the member affiliate program.
-
#member_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for an access pass.
-
#plan_options ⇒ WhopSDK::Models::ProductCreateParams::PlanOptions?
The details to assign an autogenerated plan.
-
#product_highlights ⇒ Array<WhopSDK::Models::ProductCreateParams::ProductHighlight>?
The product highlights for the product.
-
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
-
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
-
#route ⇒ String?
The route of the product.
-
#title ⇒ String
The title of the product.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(name: , id: nil, order: nil, placeholder: nil, required: nil, field_type: :text) ⇒ Object
|
|
# File 'lib/whop_sdk/models/product_create_params.rb', line 298
|
Instance Attribute Details
#business_type ⇒ Symbol, ...
The different business types a company can be.
26 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 26 optional :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true |
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
32 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 32 optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true |
#company_id ⇒ String
The ID of the company to create the product for.
14 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 14 required :company_id, String |
#custom_cta ⇒ Symbol, ...
The different types of custom CTAs that can be selected.
38 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 38 optional :custom_cta, enum: -> { WhopSDK::CustomCta }, nil?: true |
#custom_cta_url ⇒ String?
The custom call to action URL for the product.
44 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 44 optional :custom_cta_url, String, nil?: true |
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ‘, “
52 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 52 optional :custom_statement_descriptor, String, nil?: true |
#description ⇒ String?
A written description of the product.
58 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 58 optional :description, String, nil?: true |
#experience_ids ⇒ Array<String>?
An array of experience IDs that this pass has
64 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 64 optional :experience_ids, WhopSDK::Internal::Type::ArrayOf[String], nil?: true |
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
70 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 70 optional :global_affiliate_percentage, Float, nil?: true |
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for an access pass.
76 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 76 optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true |
#headline ⇒ String?
The headline of the product.
82 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 82 optional :headline, String, nil?: true |
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
88 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 88 optional :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true |
#member_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the member affiliate program.
94 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 94 optional :member_affiliate_percentage, Float, nil?: true |
#member_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for an access pass.
100 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 100 optional :member_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true |
#plan_options ⇒ WhopSDK::Models::ProductCreateParams::PlanOptions?
The details to assign an autogenerated plan.
106 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 106 optional :plan_options, -> { WhopSDK::ProductCreateParams::PlanOptions }, nil?: true |
#product_highlights ⇒ Array<WhopSDK::Models::ProductCreateParams::ProductHighlight>?
The product highlights for the product.
112 113 114 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 112 optional :product_highlights, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::ProductCreateParams::ProductHighlight] }, nil?: true |
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
120 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 120 optional :product_tax_code_id, String, nil?: true |
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
126 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 126 optional :redirect_purchase_url, String, nil?: true |
#route ⇒ String?
The route of the product.
132 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 132 optional :route, String, nil?: true |
#title ⇒ String
The title of the product.
20 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 20 required :title, String |
#visibility ⇒ Symbol, ...
Visibility of a resource
138 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 138 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |