Class: WhopSDK::Models::ProductCreateParams::PlanOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductCreateParams::PlanOptions
- Defined in:
- lib/whop_sdk/models/product_create_params.rb
Defined Under Namespace
Classes: CustomField
Instance Attribute Summary collapse
-
#base_currency ⇒ Symbol, ...
The available currencies on the platform.
-
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
-
#custom_fields ⇒ Array<WhopSDK::Models::ProductCreateParams::PlanOptions::CustomField>?
An array of custom field objects.
-
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
-
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to an access pass.
-
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
-
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#base_currency ⇒ Symbol, ...
The available currencies on the platform
238 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 238 optional :base_currency, enum: -> { WhopSDK::Currency }, nil?: true |
#billing_period ⇒ Integer?
The interval at which the plan charges (renewal plans).
244 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 244 optional :billing_period, Integer, nil?: true |
#custom_fields ⇒ Array<WhopSDK::Models::ProductCreateParams::PlanOptions::CustomField>?
An array of custom field objects.
250 251 252 253 254 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 250 optional :custom_fields, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::ProductCreateParams::PlanOptions::CustomField] }, nil?: true |
#initial_price ⇒ Float?
An additional amount charged upon first purchase.
260 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 260 optional :initial_price, Float, nil?: true |
#plan_type ⇒ Symbol, ...
The type of plan that can be attached to an access pass
266 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 266 optional :plan_type, enum: -> { WhopSDK::PlanType }, nil?: true |
#release_method ⇒ Symbol, ...
The methods of how a plan can be released.
272 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 272 optional :release_method, enum: -> { WhopSDK::ReleaseMethod }, nil?: true |
#renewal_price ⇒ Float?
The amount the customer is charged every billing period.
278 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 278 optional :renewal_price, Float, nil?: true |
#visibility ⇒ Symbol, ...
Visibility of a resource
284 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 284 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |