Class: WhopSDK::Models::ProductCreateParams::ProductHighlight
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductCreateParams::ProductHighlight
- Defined in:
- lib/whop_sdk/models/product_create_params.rb
Defined Under Namespace
Modules: HighlightType
Instance Attribute Summary collapse
-
#content ⇒ String
Text to display to describe the product highlight (max length 250 for qualification or benefits, 170 for who this is for, 140 for pricing features).
-
#highlight_type ⇒ Symbol, WhopSDK::Models::ProductCreateParams::ProductHighlight::HighlightType
The type of this highlight.
-
#title ⇒ String?
The title of the product highlight, if applicable.
Instance Method Summary collapse
-
#initialize(content: , highlight_type: , title: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProductHighlight for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(content: , highlight_type: , title: nil) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ProductCreateParams::ProductHighlight for more details.
Input for creating a product highlight
|
|
# File 'lib/whop_sdk/models/product_create_params.rb', line 333
|
Instance Attribute Details
#content ⇒ String
Text to display to describe the product highlight (max length 250 for qualification or benefits, 170 for who this is for, 140 for pricing features).
319 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 319 required :content, String |
#highlight_type ⇒ Symbol, WhopSDK::Models::ProductCreateParams::ProductHighlight::HighlightType
The type of this highlight.
325 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 325 required :highlight_type, enum: -> { WhopSDK::ProductCreateParams::ProductHighlight::HighlightType } |
#title ⇒ String?
The title of the product highlight, if applicable.
331 |
# File 'lib/whop_sdk/models/product_create_params.rb', line 331 optional :title, String, nil?: true |