Class: WhopSDK::Models::ProductListItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product_list_item.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, external_identifier:, headline:, member_count:, published_reviews_count:, route:, title:, updated_at:, verified:, visibility:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ProductListItem for more details.

A product is a digital good or service sold on Whop. Products contain plans for pricing and experiences for content delivery.

Parameters:

  • id (String)

    The unique identifier for the product.

  • created_at (Time)

    The datetime the product was created.

  • external_identifier (String, nil)

    A unique identifier used to create or update products via the API. When provided

  • headline (String, nil)

    A short marketing headline displayed prominently on the product’s product page.

  • member_count (Integer)

    The number of users who currently hold an active membership to this product. Ret

  • published_reviews_count (Integer)

    The total number of published customer reviews for this product’s company.

  • route (String)

    The URL slug used in the product’s public link (e.g., ‘my-product’ in whop.com/c

  • title (String)

    The display name of the product shown to customers on the product page and in se

  • updated_at (Time)

    The datetime the product was last updated.

  • verified (Boolean)

    Whether this company has been verified by Whop’s trust and safety team.

  • visibility (Symbol, WhopSDK::Models::Visibility)

    Controls whether the product is visible to customers. When set to ‘hidden’, the



# File 'lib/whop_sdk/models/product_list_item.rb', line 78

Instance Attribute Details

#created_atTime

The datetime the product was created.

Returns:

  • (Time)


16
# File 'lib/whop_sdk/models/product_list_item.rb', line 16

required :created_at, Time

#external_identifierString?

A unique identifier used to create or update products via the API. When provided on product creation endpoints, an existing product with this identifier will be updated instead of creating a new one.

Returns:

  • (String, nil)


24
# File 'lib/whop_sdk/models/product_list_item.rb', line 24

required :external_identifier, String, nil?: true

#headlineString?

A short marketing headline displayed prominently on the product’s product page.

Returns:

  • (String, nil)


30
# File 'lib/whop_sdk/models/product_list_item.rb', line 30

required :headline, String, nil?: true

#idString

The unique identifier for the product.

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/product_list_item.rb', line 10

required :id, String

#member_countInteger

The number of users who currently hold an active membership to this product. Returns 0 if the company has disabled public member counts.

Returns:

  • (Integer)


37
# File 'lib/whop_sdk/models/product_list_item.rb', line 37

required :member_count, Integer

#published_reviews_countInteger

The total number of published customer reviews for this product’s company.

Returns:

  • (Integer)


43
# File 'lib/whop_sdk/models/product_list_item.rb', line 43

required :published_reviews_count, Integer

#routeString

The URL slug used in the product’s public link (e.g., ‘my-product’ in whop.com/company/my-product).

Returns:

  • (String)


50
# File 'lib/whop_sdk/models/product_list_item.rb', line 50

required :route, String

#titleString

The display name of the product shown to customers on the product page and in search results.

Returns:

  • (String)


57
# File 'lib/whop_sdk/models/product_list_item.rb', line 57

required :title, String

#updated_atTime

The datetime the product was last updated.

Returns:

  • (Time)


63
# File 'lib/whop_sdk/models/product_list_item.rb', line 63

required :updated_at, Time

#verifiedBoolean

Whether this company has been verified by Whop’s trust and safety team.

Returns:

  • (Boolean)


69
# File 'lib/whop_sdk/models/product_list_item.rb', line 69

required :verified, WhopSDK::Internal::Type::Boolean

#visibilitySymbol, WhopSDK::Models::Visibility

Controls whether the product is visible to customers. When set to ‘hidden’, the product is only accessible via direct link.

Returns:



76
# File 'lib/whop_sdk/models/product_list_item.rb', line 76

required :visibility, enum: -> { WhopSDK::Visibility }