Class: WhopSDK::Models::ProductListItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product_list_item.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , business_type: , created_at: , external_identifier: , headline: , industry_type: , member_count: , published_reviews_count: , route: , title: , updated_at: , verified: , visibility: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ProductListItem for more details.

Represents a product on whop. Use products to sell anything on the platform.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the public product.

  • business_type (Symbol, WhopSDK::Models::BusinessTypes, nil) (defaults to: )

    The different business types a company can be.

  • created_at (Time) (defaults to: )

    When the product was created.

  • external_identifier (String, nil) (defaults to: )

    A unique identifier used to create or update products. When provided on product

  • headline (String, nil) (defaults to: )

    The headline of the product.

  • industry_type (Symbol, WhopSDK::Models::IndustryTypes, nil) (defaults to: )

    The different industry types a company can be in.

  • member_count (Integer) (defaults to: )

    The number of active users for this product.

  • published_reviews_count (Integer) (defaults to: )

    The number of reviews that have been published for the product.

  • route (String) (defaults to: )

    The route of the product.

  • title (String) (defaults to: )

    The title of the product. Use for Whop 4.0.

  • updated_at (Time) (defaults to: )

    When the product was updated.

  • verified (Boolean) (defaults to: )

    Whether this product is Whop verified.

  • visibility (Symbol, WhopSDK::Models::Visibility) (defaults to: )

    This product will/will not be displayed publicly.



# File 'lib/whop_sdk/models/product_list_item.rb', line 86

Instance Attribute Details

#business_typeSymbol, ...

The different business types a company can be.

Returns:



16
# File 'lib/whop_sdk/models/product_list_item.rb', line 16

required :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true

#created_atTime

When the product was created.

Returns:

  • (Time)


22
# File 'lib/whop_sdk/models/product_list_item.rb', line 22

required :created_at, Time

#external_identifierString?

A unique identifier used to create or update products. When provided on product creation endpoints, we’ll look up an existing product by this identifier — if it exists, we’ll update it; if not, we’ll create a new one.

Returns:

  • (String, nil)


30
# File 'lib/whop_sdk/models/product_list_item.rb', line 30

required :external_identifier, String, nil?: true

#headlineString?

The headline of the product.

Returns:

  • (String, nil)


36
# File 'lib/whop_sdk/models/product_list_item.rb', line 36

required :headline, String, nil?: true

#idString

The internal ID of the public product.

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/product_list_item.rb', line 10

required :id, String

#industry_typeSymbol, ...

The different industry types a company can be in.

Returns:



42
# File 'lib/whop_sdk/models/product_list_item.rb', line 42

required :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true

#member_countInteger

The number of active users for this product.

Returns:

  • (Integer)


48
# File 'lib/whop_sdk/models/product_list_item.rb', line 48

required :member_count, Integer

#published_reviews_countInteger

The number of reviews that have been published for the product.

Returns:

  • (Integer)


54
# File 'lib/whop_sdk/models/product_list_item.rb', line 54

required :published_reviews_count, Integer

#routeString

The route of the product.

Returns:

  • (String)


60
# File 'lib/whop_sdk/models/product_list_item.rb', line 60

required :route, String

#titleString

The title of the product. Use for Whop 4.0.

Returns:

  • (String)


66
# File 'lib/whop_sdk/models/product_list_item.rb', line 66

required :title, String

#updated_atTime

When the product was updated.

Returns:

  • (Time)


72
# File 'lib/whop_sdk/models/product_list_item.rb', line 72

required :updated_at, Time

#verifiedBoolean

Whether this product is Whop verified.

Returns:

  • (Boolean)


78
# File 'lib/whop_sdk/models/product_list_item.rb', line 78

required :verified, WhopSDK::Internal::Type::Boolean

#visibilitySymbol, WhopSDK::Models::Visibility

This product will/will not be displayed publicly.

Returns:



84
# File 'lib/whop_sdk/models/product_list_item.rb', line 84

required :visibility, enum: -> { WhopSDK::Visibility }