Class: WhopSDK::Models::ProductListItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductListItem
- Defined in:
- lib/whop_sdk/models/product_list_item.rb
Instance Attribute Summary collapse
-
#business_type ⇒ Symbol, ...
The different business types a company can be.
-
#created_at ⇒ Time
When the product was created.
-
#external_identifier ⇒ String?
A unique identifier used to create or update products.
-
#headline ⇒ String?
The headline of the product.
-
#id ⇒ String
The internal ID of the public product.
-
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
-
#member_count ⇒ Integer
The number of active users for this product.
-
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the product.
-
#route ⇒ String
The route of the product.
-
#title ⇒ String
The title of the product.
-
#updated_at ⇒ Time
When the product was updated.
-
#verified ⇒ Boolean
Whether this product is Whop verified.
-
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
This product will/will not be displayed publicly.
Instance Method Summary collapse
-
#initialize(id: , business_type: , created_at: , external_identifier: , headline: , industry_type: , member_count: , published_reviews_count: , route: , title: , updated_at: , verified: , visibility: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProductListItem for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , business_type: , created_at: , external_identifier: , headline: , industry_type: , member_count: , published_reviews_count: , route: , title: , updated_at: , verified: , visibility: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ProductListItem for more details.
Represents a product on whop. Use products to sell anything on the platform.
|
|
# File 'lib/whop_sdk/models/product_list_item.rb', line 86
|
Instance Attribute Details
#business_type ⇒ Symbol, ...
The different business types a company can be.
16 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 16 required :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true |
#created_at ⇒ Time
When the product was created.
22 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 22 required :created_at, Time |
#external_identifier ⇒ String?
A unique identifier used to create or update products. When provided on product creation endpoints, we’ll look up an existing product by this identifier — if it exists, we’ll update it; if not, we’ll create a new one.
30 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 30 required :external_identifier, String, nil?: true |
#headline ⇒ String?
The headline of the product.
36 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 36 required :headline, String, nil?: true |
#id ⇒ String
The internal ID of the public product.
10 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 10 required :id, String |
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
42 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 42 required :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true |
#member_count ⇒ Integer
The number of active users for this product.
48 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 48 required :member_count, Integer |
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the product.
54 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 54 required :published_reviews_count, Integer |
#route ⇒ String
The route of the product.
60 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 60 required :route, String |
#title ⇒ String
The title of the product. Use for Whop 4.0.
66 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 66 required :title, String |
#updated_at ⇒ Time
When the product was updated.
72 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 72 required :updated_at, Time |
#verified ⇒ Boolean
Whether this product is Whop verified.
78 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 78 required :verified, WhopSDK::Internal::Type::Boolean |
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
This product will/will not be displayed publicly.
84 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 84 required :visibility, enum: -> { WhopSDK::Visibility } |