Class: WhopSDK::Models::ProductListItem

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product_list_item.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , business_type: , created_at: , headline: , industry_type: , member_count: , published_reviews_count: , route: , title: , updated_at: , verified: , visibility: ) ⇒ Object

An object representing a (sanitized) access pass.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the public product.

  • business_type (Symbol, WhopSDK::Models::BusinessTypes, nil) (defaults to: )

    The different business types a company can be.

  • created_at (Time) (defaults to: )

    When the product was created.

  • headline (String, nil) (defaults to: )

    The headline of the product.

  • industry_type (Symbol, WhopSDK::Models::IndustryTypes, nil) (defaults to: )

    The different industry types a company can be in.

  • member_count (Integer) (defaults to: )

    The number of active users for this product.

  • published_reviews_count (Integer) (defaults to: )

    The number of reviews that have been published for the product.

  • route (String) (defaults to: )

    The route of the product.

  • title (String) (defaults to: )

    The title of the product. Use for Whop 4.0.

  • updated_at (Time) (defaults to: )

    When the product was updated.

  • verified (Boolean) (defaults to: )

    Whether this product is Whop verified.

  • visibility (Symbol, WhopSDK::Models::Visibility) (defaults to: )

    This product will/will not be displayed publicly.



# File 'lib/whop_sdk/models/product_list_item.rb', line 78

Instance Attribute Details

#business_typeSymbol, ...

The different business types a company can be.

Returns:



16
# File 'lib/whop_sdk/models/product_list_item.rb', line 16

required :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true

#created_atTime

When the product was created.

Returns:

  • (Time)


22
# File 'lib/whop_sdk/models/product_list_item.rb', line 22

required :created_at, Time

#headlineString?

The headline of the product.

Returns:

  • (String, nil)


28
# File 'lib/whop_sdk/models/product_list_item.rb', line 28

required :headline, String, nil?: true

#idString

The internal ID of the public product.

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/product_list_item.rb', line 10

required :id, String

#industry_typeSymbol, ...

The different industry types a company can be in.

Returns:



34
# File 'lib/whop_sdk/models/product_list_item.rb', line 34

required :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true

#member_countInteger

The number of active users for this product.

Returns:

  • (Integer)


40
# File 'lib/whop_sdk/models/product_list_item.rb', line 40

required :member_count, Integer

#published_reviews_countInteger

The number of reviews that have been published for the product.

Returns:

  • (Integer)


46
# File 'lib/whop_sdk/models/product_list_item.rb', line 46

required :published_reviews_count, Integer

#routeString

The route of the product.

Returns:

  • (String)


52
# File 'lib/whop_sdk/models/product_list_item.rb', line 52

required :route, String

#titleString

The title of the product. Use for Whop 4.0.

Returns:

  • (String)


58
# File 'lib/whop_sdk/models/product_list_item.rb', line 58

required :title, String

#updated_atTime

When the product was updated.

Returns:

  • (Time)


64
# File 'lib/whop_sdk/models/product_list_item.rb', line 64

required :updated_at, Time

#verifiedBoolean

Whether this product is Whop verified.

Returns:

  • (Boolean)


70
# File 'lib/whop_sdk/models/product_list_item.rb', line 70

required :verified, WhopSDK::Internal::Type::Boolean

#visibilitySymbol, WhopSDK::Models::Visibility

This product will/will not be displayed publicly.

Returns:



76
# File 'lib/whop_sdk/models/product_list_item.rb', line 76

required :visibility, enum: -> { WhopSDK::Visibility }