Class: WhopSDK::Models::ProductListItem
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductListItem
- Defined in:
- lib/whop_sdk/models/product_list_item.rb
Instance Attribute Summary collapse
-
#business_type ⇒ Symbol, ...
The different business types a company can be.
-
#created_at ⇒ Time
When the product was created.
-
#headline ⇒ String?
The headline of the product.
-
#id ⇒ String
The internal ID of the public product.
-
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
-
#member_count ⇒ Integer
The number of active users for this product.
-
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the product.
-
#route ⇒ String
The route of the product.
-
#title ⇒ String
The title of the product.
-
#updated_at ⇒ Time
When the product was updated.
-
#verified ⇒ Boolean
Whether this product is Whop verified.
-
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
This product will/will not be displayed publicly.
Instance Method Summary collapse
-
#initialize(id: , business_type: , created_at: , headline: , industry_type: , member_count: , published_reviews_count: , route: , title: , updated_at: , verified: , visibility: ) ⇒ Object
constructor
An object representing a (sanitized) access pass.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , business_type: , created_at: , headline: , industry_type: , member_count: , published_reviews_count: , route: , title: , updated_at: , verified: , visibility: ) ⇒ Object
An object representing a (sanitized) access pass.
|
|
# File 'lib/whop_sdk/models/product_list_item.rb', line 78
|
Instance Attribute Details
#business_type ⇒ Symbol, ...
The different business types a company can be.
16 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 16 required :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true |
#created_at ⇒ Time
When the product was created.
22 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 22 required :created_at, Time |
#headline ⇒ String?
The headline of the product.
28 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 28 required :headline, String, nil?: true |
#id ⇒ String
The internal ID of the public product.
10 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 10 required :id, String |
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
34 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 34 required :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true |
#member_count ⇒ Integer
The number of active users for this product.
40 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 40 required :member_count, Integer |
#published_reviews_count ⇒ Integer
The number of reviews that have been published for the product.
46 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 46 required :published_reviews_count, Integer |
#route ⇒ String
The route of the product.
52 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 52 required :route, String |
#title ⇒ String
The title of the product. Use for Whop 4.0.
58 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 58 required :title, String |
#updated_at ⇒ Time
When the product was updated.
64 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 64 required :updated_at, Time |
#verified ⇒ Boolean
Whether this product is Whop verified.
70 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 70 required :verified, WhopSDK::Internal::Type::Boolean |
#visibility ⇒ Symbol, WhopSDK::Models::Visibility
This product will/will not be displayed publicly.
76 |
# File 'lib/whop_sdk/models/product_list_item.rb', line 76 required :visibility, enum: -> { WhopSDK::Visibility } |