Class: WhopSDK::Models::ProductListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/product_list_params.rb,
sig/whop_sdk/models/product_list_params.rbs
Overview
Defined Under Namespace
Modules: Direction
Instance Attribute Summary collapse
-
#access_pass_types ⇒ Array<String>?
Filter to only products matching these types.
-
#after ⇒ String?
A cursor; returns products after this position.
-
#before ⇒ String?
A cursor; returns products before this position.
-
#company_id ⇒ String
The unique identifier of the company to list products for.
-
#direction ⇒ Symbol, ...
The sort direction for results.
-
#first ⇒ Integer?
The number of products to return (default and max 100).
-
#last ⇒ Integer?
The number of products to return from the end of the range.
-
#order ⇒ String?
The field to sort results by.
-
#visibilities ⇒ Array<String>?
Filter to only products matching these visibility states.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(company_id:, access_pass_types: nil, after: nil, before: nil, direction: nil, first: nil, last: nil, order: nil, visibilities: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id:, access_pass_types: nil, after: nil, before: nil, direction: nil, first: nil, last: nil, order: nil, visibilities: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/product_list_params.rb', line 64
|
Instance Attribute Details
#access_pass_types ⇒ Array<String>?
Filter to only products matching these types.
20 |
# File 'lib/whop_sdk/models/product_list_params.rb', line 20 optional :access_pass_types, WhopSDK::Internal::Type::ArrayOf[String] |
#after ⇒ String?
A cursor; returns products after this position.
26 |
# File 'lib/whop_sdk/models/product_list_params.rb', line 26 optional :after, String |
#before ⇒ String?
A cursor; returns products before this position.
32 |
# File 'lib/whop_sdk/models/product_list_params.rb', line 32 optional :before, String |
#company_id ⇒ String
The unique identifier of the company to list products for.
14 |
# File 'lib/whop_sdk/models/product_list_params.rb', line 14 required :company_id, String |
#direction ⇒ Symbol, ...
The sort direction for results. Defaults to descending.
38 |
# File 'lib/whop_sdk/models/product_list_params.rb', line 38 optional :direction, enum: -> { WhopSDK::ProductListParams::Direction } |
#first ⇒ Integer?
The number of products to return (default and max 100).
44 |
# File 'lib/whop_sdk/models/product_list_params.rb', line 44 optional :first, Integer |
#last ⇒ Integer?
The number of products to return from the end of the range.
50 |
# File 'lib/whop_sdk/models/product_list_params.rb', line 50 optional :last, Integer |
#order ⇒ String?
The field to sort results by. Defaults to created_at.
56 |
# File 'lib/whop_sdk/models/product_list_params.rb', line 56 optional :order, String |
#visibilities ⇒ Array<String>?
Filter to only products matching these visibility states.
62 |
# File 'lib/whop_sdk/models/product_list_params.rb', line 62 optional :visibilities, WhopSDK::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
70 |
# File 'sig/whop_sdk/models/product_list_params.rbs', line 70
def to_hash: -> {
|