Class: WhopSDK::Models::ProductListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/product_list_params.rb

Overview

Defined Under Namespace

Modules: Order

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id: , after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, product_types: nil, visibilities: nil, request_options: {}) ⇒ Object

Parameters:

  • company_id (String) (defaults to: )

    The ID of the company to filter products by

  • after (String, nil) (defaults to: nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil) (defaults to: nil)

    Returns the elements in the list that come before the specified cursor.

  • created_after (Time, nil) (defaults to: nil)

    The minimum creation date to filter by

  • created_before (Time, nil) (defaults to: nil)

    The maximum creation date to filter by

  • direction (Symbol, WhopSDK::Models::Direction, nil) (defaults to: nil)

    The direction of the sort.

  • first (Integer, nil) (defaults to: nil)

    Returns the first n elements from the list.

  • last (Integer, nil) (defaults to: nil)

    Returns the last n elements from the list.

  • order (Symbol, WhopSDK::Models::ProductListParams::Order, nil) (defaults to: nil)

    The ways a relation of AccessPasses can be ordered

  • product_types (Array<Symbol, WhopSDK::Models::AccessPassType>, nil) (defaults to: nil)

    The type of products to filter by

  • visibilities (Array<Symbol, WhopSDK::Models::VisibilityFilter>, nil) (defaults to: nil)

    The visibility of the products to filter by

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/product_list_params.rb', line 80

Instance Attribute Details

#afterString?

Returns the elements in the list that come after the specified cursor.

Returns:

  • (String, nil)


20
# File 'lib/whop_sdk/models/product_list_params.rb', line 20

optional :after, String, nil?: true

#beforeString?

Returns the elements in the list that come before the specified cursor.

Returns:

  • (String, nil)


26
# File 'lib/whop_sdk/models/product_list_params.rb', line 26

optional :before, String, nil?: true

#company_idString

The ID of the company to filter products by

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/product_list_params.rb', line 14

required :company_id, String

#created_afterTime?

The minimum creation date to filter by

Returns:

  • (Time, nil)


32
# File 'lib/whop_sdk/models/product_list_params.rb', line 32

optional :created_after, Time, nil?: true

#created_beforeTime?

The maximum creation date to filter by

Returns:

  • (Time, nil)


38
# File 'lib/whop_sdk/models/product_list_params.rb', line 38

optional :created_before, Time, nil?: true

#directionSymbol, ...

The direction of the sort.

Returns:



44
# File 'lib/whop_sdk/models/product_list_params.rb', line 44

optional :direction, enum: -> { WhopSDK::Direction }, nil?: true

#firstInteger?

Returns the first n elements from the list.

Returns:

  • (Integer, nil)


50
# File 'lib/whop_sdk/models/product_list_params.rb', line 50

optional :first, Integer, nil?: true

#lastInteger?

Returns the last n elements from the list.

Returns:

  • (Integer, nil)


56
# File 'lib/whop_sdk/models/product_list_params.rb', line 56

optional :last, Integer, nil?: true

#orderSymbol, ...

The ways a relation of AccessPasses can be ordered



62
# File 'lib/whop_sdk/models/product_list_params.rb', line 62

optional :order, enum: -> { WhopSDK::ProductListParams::Order }, nil?: true

#product_typesArray<Symbol, WhopSDK::Models::AccessPassType>?

The type of products to filter by

Returns:



68
69
70
# File 'lib/whop_sdk/models/product_list_params.rb', line 68

optional :product_types,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::AccessPassType] },
nil?: true

#visibilitiesArray<Symbol, WhopSDK::Models::VisibilityFilter>?

The visibility of the products to filter by

Returns:



76
77
78
# File 'lib/whop_sdk/models/product_list_params.rb', line 76

optional :visibilities,
-> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::VisibilityFilter] },
nil?: true