Class: WhopSDK::Models::ProductUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/product_update_params.rb,
sig/whop_sdk/models/product_update_params.rbs
Overview
Instance Attribute Summary collapse
-
#description ⇒ String?
A written description displayed on the product page.
-
#headline ⇒ String?
A short marketing headline for the product page.
- #id ⇒ String
-
#metadata ⇒ Object?
Custom key-value pairs to store on the product.
-
#product_tax_code_id ⇒ String?
The unique identifier of the tax classification code.
-
#send_welcome_message ⇒ Boolean?
Whether to send an automated welcome message via support chat when a user joins this product.
-
#title ⇒ String?
The display name of the product.
-
#visibility ⇒ String?
Whether the product is visible to customers.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, description: nil, headline: nil, metadata: nil, product_tax_code_id: nil, send_welcome_message: nil, title: nil, visibility: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProductUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, description: nil, headline: nil, metadata: nil, product_tax_code_id: nil, send_welcome_message: nil, title: nil, visibility: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ProductUpdateParams for more details.
|
|
# File 'lib/whop_sdk/models/product_update_params.rb', line 59
|
Instance Attribute Details
#description ⇒ String?
A written description displayed on the product page.
19 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 19 optional :description, String, nil?: true |
#headline ⇒ String?
A short marketing headline for the product page.
25 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 25 optional :headline, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 13 required :id, String |
#metadata ⇒ Object?
Custom key-value pairs to store on the product.
31 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 31 optional :metadata, WhopSDK::Internal::Type::Unknown, nil?: true |
#product_tax_code_id ⇒ String?
The unique identifier of the tax classification code. See the available product categories.
38 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 38 optional :product_tax_code_id, String, nil?: true |
#send_welcome_message ⇒ Boolean?
Whether to send an automated welcome message via support chat when a user joins this product.
45 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 45 optional :send_welcome_message, WhopSDK::Internal::Type::Boolean, nil?: true |
#title ⇒ String?
The display name of the product.
51 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 51 optional :title, String |
#visibility ⇒ String?
Whether the product is visible to customers.
57 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 57 optional :visibility, String |
Instance Method Details
#to_hash ⇒ {
52 |
# File 'sig/whop_sdk/models/product_update_params.rbs', line 52
def to_hash: -> {
|