Class: WhopSDK::Models::ProductUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/product_update_params.rb

Overview

Defined Under Namespace

Classes: GalleryImage, StorePageConfig

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:) ⇒ Object

Input for an attachment

Parameters:

  • id (String)

    The ID of an existing file object.



# File 'lib/whop_sdk/models/product_update_params.rb', line 182

Instance Attribute Details

#collect_shipping_addressBoolean?

Whether the checkout flow collects a shipping address from the customer.

Returns:

  • (Boolean, nil)


19
# File 'lib/whop_sdk/models/product_update_params.rb', line 19

optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true

#custom_ctaSymbol, ...

The different types of custom CTAs that can be selected.

Returns:



25
# File 'lib/whop_sdk/models/product_update_params.rb', line 25

optional :custom_cta, enum: -> { WhopSDK::CustomCta }, nil?: true

#custom_cta_urlString?

A URL that the call-to-action button links to instead of the default checkout flow.

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/product_update_params.rb', line 32

optional :custom_cta_url, String, nil?: true

#custom_statement_descriptorString?

A custom text label that appears on the customer’s bank statement. Must be 5-22 characters, contain at least one letter, and not contain <, >, , ‘, or “ characters.

Returns:

  • (String, nil)


40
# File 'lib/whop_sdk/models/product_update_params.rb', line 40

optional :custom_statement_descriptor, String, nil?: true

#descriptionString?

A written description of the product displayed on its product page.

Returns:

  • (String, nil)


46
# File 'lib/whop_sdk/models/product_update_params.rb', line 46

optional :description, String, nil?: true

The gallery images for the product.



52
53
54
# File 'lib/whop_sdk/models/product_update_params.rb', line 52

optional :gallery_images,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::ProductUpdateParams::GalleryImage] },
nil?: true

#global_affiliate_percentageFloat?

The commission rate as a percentage that affiliates earn through the global affiliate program.

Returns:

  • (Float, nil)


61
# File 'lib/whop_sdk/models/product_update_params.rb', line 61

optional :global_affiliate_percentage, Float, nil?: true

#global_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for a product.

Returns:



67
# File 'lib/whop_sdk/models/product_update_params.rb', line 67

optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#headlineString?

A short marketing headline displayed prominently on the product page.

Returns:

  • (String, nil)


73
# File 'lib/whop_sdk/models/product_update_params.rb', line 73

optional :headline, String, nil?: true

#idString

Returns:

  • (String)


13
# File 'lib/whop_sdk/models/product_update_params.rb', line 13

required :id, String

#member_affiliate_percentageFloat?

The commission rate as a percentage that members earn through the member affiliate program.

Returns:

  • (Float, nil)


80
# File 'lib/whop_sdk/models/product_update_params.rb', line 80

optional :member_affiliate_percentage, Float, nil?: true

#member_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for a product.

Returns:



86
# File 'lib/whop_sdk/models/product_update_params.rb', line 86

optional :member_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#product_tax_code_idString?

The unique identifier of the tax classification code to apply to this product.

Returns:

  • (String, nil)


92
# File 'lib/whop_sdk/models/product_update_params.rb', line 92

optional :product_tax_code_id, String, nil?: true

#redirect_purchase_urlString?

A URL to redirect the customer to after completing a purchase.

Returns:

  • (String, nil)


98
# File 'lib/whop_sdk/models/product_update_params.rb', line 98

optional :redirect_purchase_url, String, nil?: true

#routeString?

The URL slug for the product’s public link.

Returns:

  • (String, nil)


104
# File 'lib/whop_sdk/models/product_update_params.rb', line 104

optional :route, String, nil?: true

#send_welcome_messageBoolean?

Whether to send an automated welcome message via support chat when a user joins this product.

Returns:

  • (Boolean, nil)


111
# File 'lib/whop_sdk/models/product_update_params.rb', line 111

optional :send_welcome_message, WhopSDK::Internal::Type::Boolean, nil?: true

#store_page_configWhopSDK::Models::ProductUpdateParams::StorePageConfig?

Layout and display configuration for this product on the company’s store page.



117
# File 'lib/whop_sdk/models/product_update_params.rb', line 117

optional :store_page_config, -> { WhopSDK::ProductUpdateParams::StorePageConfig }, nil?: true

#titleString?

The display name of the product. Maximum 80 characters.

Returns:

  • (String, nil)


123
# File 'lib/whop_sdk/models/product_update_params.rb', line 123

optional :title, String, nil?: true

#visibilitySymbol, ...

Visibility of a resource

Returns:



129
# File 'lib/whop_sdk/models/product_update_params.rb', line 129

optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true