Class: WhopSDK::Models::ProductUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/product_update_params.rb

Overview

Defined Under Namespace

Classes: StorePageConfig

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Method Summary

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from WhopSDK::Internal::Type::BaseModel

Instance Attribute Details

#business_typeSymbol, ...

The different business types a company can be.

Returns:



14
# File 'lib/whop_sdk/models/product_update_params.rb', line 14

optional :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true

#collect_shipping_addressBoolean?

Whether or not to collect shipping information at checkout from the customer.

Returns:

  • (Boolean, nil)


20
# File 'lib/whop_sdk/models/product_update_params.rb', line 20

optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true

#custom_ctaSymbol, ...

The different types of custom CTAs that can be selected.

Returns:



26
# File 'lib/whop_sdk/models/product_update_params.rb', line 26

optional :custom_cta, enum: -> { WhopSDK::CustomCta }, nil?: true

#custom_cta_urlString?

The custom call to action URL for the product.

Returns:

  • (String, nil)


32
# File 'lib/whop_sdk/models/product_update_params.rb', line 32

optional :custom_cta_url, String, nil?: true

#custom_statement_descriptorString?

The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ‘, “

Returns:

  • (String, nil)


40
# File 'lib/whop_sdk/models/product_update_params.rb', line 40

optional :custom_statement_descriptor, String, nil?: true

#descriptionString?

A written description of the product.

Returns:

  • (String, nil)


46
# File 'lib/whop_sdk/models/product_update_params.rb', line 46

optional :description, String, nil?: true

#global_affiliate_percentageFloat?

The percentage of the revenue that goes to the global affiliate program.

Returns:

  • (Float, nil)


52
# File 'lib/whop_sdk/models/product_update_params.rb', line 52

optional :global_affiliate_percentage, Float, nil?: true

#global_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for a product.

Returns:



58
# File 'lib/whop_sdk/models/product_update_params.rb', line 58

optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#headlineString?

The headline of the product.

Returns:

  • (String, nil)


64
# File 'lib/whop_sdk/models/product_update_params.rb', line 64

optional :headline, String, nil?: true

#industry_typeSymbol, ...

The different industry types a company can be in.

Returns:



70
# File 'lib/whop_sdk/models/product_update_params.rb', line 70

optional :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true

#member_affiliate_percentageFloat?

The percentage of the revenue that goes to the member affiliate program.

Returns:

  • (Float, nil)


76
# File 'lib/whop_sdk/models/product_update_params.rb', line 76

optional :member_affiliate_percentage, Float, nil?: true

#member_affiliate_statusSymbol, ...

The different statuses of the global affiliate program for a product.

Returns:



82
# File 'lib/whop_sdk/models/product_update_params.rb', line 82

optional :member_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true

#product_tax_code_idString?

The ID of the product tax code to apply to this product.

Returns:

  • (String, nil)


88
# File 'lib/whop_sdk/models/product_update_params.rb', line 88

optional :product_tax_code_id, String, nil?: true

#redirect_purchase_urlString?

The URL to redirect the customer to after a purchase.

Returns:

  • (String, nil)


94
# File 'lib/whop_sdk/models/product_update_params.rb', line 94

optional :redirect_purchase_url, String, nil?: true

#routeString?

The route of the product.

Returns:

  • (String, nil)


100
# File 'lib/whop_sdk/models/product_update_params.rb', line 100

optional :route, String, nil?: true

#store_page_configWhopSDK::Models::ProductUpdateParams::StorePageConfig?

Configuration for a product on the company’s store page.



106
# File 'lib/whop_sdk/models/product_update_params.rb', line 106

optional :store_page_config, -> { WhopSDK::ProductUpdateParams::StorePageConfig }, nil?: true

#titleString?

The title of the product.

Returns:

  • (String, nil)


112
# File 'lib/whop_sdk/models/product_update_params.rb', line 112

optional :title, String, nil?: true

#visibilitySymbol, ...

Visibility of a resource

Returns:



118
# File 'lib/whop_sdk/models/product_update_params.rb', line 118

optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true