Class: WhopSDK::Models::ProductUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ProductUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/product_update_params.rb
Overview
Defined Under Namespace
Classes: StorePageConfig
Instance Attribute Summary collapse
-
#business_type ⇒ Symbol, ...
The different business types a company can be.
-
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
-
#custom_cta ⇒ Symbol, ...
The different types of custom CTAs that can be selected.
-
#custom_cta_url ⇒ String?
The custom call to action URL for the product.
-
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e.
-
#description ⇒ String?
A written description of the product.
-
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
-
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
-
#headline ⇒ String?
The headline of the product.
-
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
-
#member_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the member affiliate program.
-
#member_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
-
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
-
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
-
#route ⇒ String?
The route of the product.
-
#store_page_config ⇒ WhopSDK::Models::ProductUpdateParams::StorePageConfig?
Configuration for a product on the company’s store page.
-
#title ⇒ String?
The title of the product.
-
#visibility ⇒ Symbol, ...
Visibility of a resource.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#business_type ⇒ Symbol, ...
The different business types a company can be.
14 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 14 optional :business_type, enum: -> { WhopSDK::BusinessTypes }, nil?: true |
#collect_shipping_address ⇒ Boolean?
Whether or not to collect shipping information at checkout from the customer.
20 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 20 optional :collect_shipping_address, WhopSDK::Internal::Type::Boolean, nil?: true |
#custom_cta ⇒ Symbol, ...
The different types of custom CTAs that can be selected.
26 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 26 optional :custom_cta, enum: -> { WhopSDK::CustomCta }, nil?: true |
#custom_cta_url ⇒ String?
The custom call to action URL for the product.
32 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 32 optional :custom_cta_url, String, nil?: true |
#custom_statement_descriptor ⇒ String?
The custom statement descriptor for the product i.e. WHOP*SPORTS, must be between 5 and 22 characters, contain at least one letter, and not contain any of the following characters: <, >, , ‘, “
40 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 40 optional :custom_statement_descriptor, String, nil?: true |
#description ⇒ String?
A written description of the product.
46 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 46 optional :description, String, nil?: true |
#global_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the global affiliate program.
52 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 52 optional :global_affiliate_percentage, Float, nil?: true |
#global_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
58 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 58 optional :global_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true |
#headline ⇒ String?
The headline of the product.
64 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 64 optional :headline, String, nil?: true |
#industry_type ⇒ Symbol, ...
The different industry types a company can be in.
70 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 70 optional :industry_type, enum: -> { WhopSDK::IndustryTypes }, nil?: true |
#member_affiliate_percentage ⇒ Float?
The percentage of the revenue that goes to the member affiliate program.
76 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 76 optional :member_affiliate_percentage, Float, nil?: true |
#member_affiliate_status ⇒ Symbol, ...
The different statuses of the global affiliate program for a product.
82 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 82 optional :member_affiliate_status, enum: -> { WhopSDK::GlobalAffiliateStatus }, nil?: true |
#product_tax_code_id ⇒ String?
The ID of the product tax code to apply to this product.
88 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 88 optional :product_tax_code_id, String, nil?: true |
#redirect_purchase_url ⇒ String?
The URL to redirect the customer to after a purchase.
94 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 94 optional :redirect_purchase_url, String, nil?: true |
#route ⇒ String?
The route of the product.
100 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 100 optional :route, String, nil?: true |
#store_page_config ⇒ WhopSDK::Models::ProductUpdateParams::StorePageConfig?
Configuration for a product on the company’s store page.
106 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 106 optional :store_page_config, -> { WhopSDK::ProductUpdateParams::StorePageConfig }, nil?: true |
#title ⇒ String?
The title of the product.
112 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 112 optional :title, String, nil?: true |
#visibility ⇒ Symbol, ...
Visibility of a resource
118 |
# File 'lib/whop_sdk/models/product_update_params.rb', line 118 optional :visibility, enum: -> { WhopSDK::Visibility }, nil?: true |