Class: WhopSDK::Models::ProductUpdateParams::BannerImage

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: nil, direct_upload_id: nil) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ProductUpdateParams::BannerImage for more details.

A banner image for the product in png, jpeg format

Parameters:

  • id (String, nil) (defaults to: nil)

    The ID of an existing attachment object. Use this when updating a resource and k

  • direct_upload_id (String, nil) (defaults to: nil)

    This ID should be used the first time you upload an attachment. It is the ID of



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/whop_sdk/models/product_update_params.rb', line 163

class BannerImage < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of an existing attachment object. Use this when updating a resource and
  #   keeping a subset of the attachments. Don't use this unless you know what you're
  #   doing.
  #
  #   @return [String, nil]
  optional :id, String, nil?: true

  # @!attribute direct_upload_id
  #   This ID should be used the first time you upload an attachment. It is the ID of
  #   the direct upload that was created when uploading the file to S3 via the
  #   mediaDirectUpload mutation.
  #
  #   @return [String, nil]
  optional :direct_upload_id, String, nil?: true

  # @!method initialize(id: nil, direct_upload_id: nil)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::ProductUpdateParams::BannerImage} for more details.
  #
  #   A banner image for the product in png, jpeg format
  #
  #   @param id [String, nil] The ID of an existing attachment object. Use this when updating a resource and k
  #
  #   @param direct_upload_id [String, nil] This ID should be used the first time you upload an attachment. It is the ID of
end

Instance Attribute Details

#direct_upload_idString?

This ID should be used the first time you upload an attachment. It is the ID of the direct upload that was created when uploading the file to S3 via the mediaDirectUpload mutation.

Returns:

  • (String, nil)


178
# File 'lib/whop_sdk/models/product_update_params.rb', line 178

optional :direct_upload_id, String, nil?: true

#idString?

The ID of an existing attachment object. Use this when updating a resource and keeping a subset of the attachments. Don’t use this unless you know what you’re doing.

Returns:

  • (String, nil)


170
# File 'lib/whop_sdk/models/product_update_params.rb', line 170

optional :id, String, nil?: true