Class: WhopSDK::Models::ProductUpdateParams::StorePageConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/product_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(custom_cta: nil, show_price: nil) ⇒ Object

Configuration for a product on the company’s store page.

Parameters:

  • custom_cta (String, nil) (defaults to: nil)

    Custom call-to-action text for the product’s store page.

  • show_price (Boolean, nil) (defaults to: nil)

    Whether or not to show the price on the product’s store page.



# File 'lib/whop_sdk/models/product_update_params.rb', line 212

Instance Attribute Details

#custom_ctaString?

Custom call-to-action text for the product’s store page.

Returns:

  • (String, nil)


204
# File 'lib/whop_sdk/models/product_update_params.rb', line 204

optional :custom_cta, String, nil?: true

#show_priceBoolean?

Whether or not to show the price on the product’s store page.

Returns:

  • (Boolean, nil)


210
# File 'lib/whop_sdk/models/product_update_params.rb', line 210

optional :show_price, WhopSDK::Internal::Type::Boolean, nil?: true