Class: WhopSDK::Models::Reaction

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/reaction.rb

Defined Under Namespace

Classes: User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , emoji: , resource_id: , user: ) ⇒ Object

Represents a reaction to a feed post

Parameters:

  • id (String) (defaults to: )

    The unique identifier for the entity

  • emoji (String, nil) (defaults to: )

    The emoji that was used in shortcode format (:heart:)

  • resource_id (String) (defaults to: )

    The ID of the post this reaction belongs to

  • user (WhopSDK::Models::Reaction::User) (defaults to: )

    The user who reacted to the post



# File 'lib/whop_sdk/models/reaction.rb', line 30

Instance Attribute Details

#emojiString?

The emoji that was used in shortcode format (:heart:)

Returns:

  • (String, nil)


16
# File 'lib/whop_sdk/models/reaction.rb', line 16

required :emoji, String, nil?: true

#idString

The unique identifier for the entity

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/reaction.rb', line 10

required :id, String

#resource_idString

The ID of the post this reaction belongs to

Returns:

  • (String)


22
# File 'lib/whop_sdk/models/reaction.rb', line 22

required :resource_id, String

#userWhopSDK::Models::Reaction::User

The user who reacted to the post



28
# File 'lib/whop_sdk/models/reaction.rb', line 28

required :user, -> { WhopSDK::Reaction::User }