Class: WhopSDK::Models::Reaction
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Reaction
- Defined in:
- lib/whop_sdk/models/reaction.rb
Defined Under Namespace
Classes: User
Instance Attribute Summary collapse
-
#emoji ⇒ String?
The emoji that was used in shortcode format (:heart:).
-
#id ⇒ String
The unique identifier for the entity.
-
#resource_id ⇒ String
The ID of the post this reaction belongs to.
-
#user ⇒ WhopSDK::Models::Reaction::User
The user who reacted to the post.
Instance Method Summary collapse
-
#initialize(id: , emoji: , resource_id: , user: ) ⇒ Object
constructor
Represents a reaction to a feed post.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , emoji: , resource_id: , user: ) ⇒ Object
Represents a reaction to a feed post
|
|
# File 'lib/whop_sdk/models/reaction.rb', line 30
|
Instance Attribute Details
#emoji ⇒ String?
The emoji that was used in shortcode format (:heart:)
16 |
# File 'lib/whop_sdk/models/reaction.rb', line 16 required :emoji, String, nil?: true |
#id ⇒ String
The unique identifier for the entity
10 |
# File 'lib/whop_sdk/models/reaction.rb', line 10 required :id, String |
#resource_id ⇒ String
The ID of the post this reaction belongs to
22 |
# File 'lib/whop_sdk/models/reaction.rb', line 22 required :resource_id, String |
#user ⇒ WhopSDK::Models::Reaction::User
The user who reacted to the post
28 |
# File 'lib/whop_sdk/models/reaction.rb', line 28 required :user, -> { WhopSDK::Reaction::User } |