Class: WhopSDK::Models::ReactionCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ReactionCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/reaction_create_params.rb
Overview
Instance Attribute Summary collapse
-
#emoji ⇒ String?
The emoji to react with, in shortcode or unicode format.
-
#poll_option_id ⇒ String?
The unique identifier of a poll option to vote for.
-
#resource_id ⇒ String
The unique identifier of the message or forum post to react to.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(resource_id:, emoji: nil, poll_option_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ReactionCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(resource_id:, emoji: nil, poll_option_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ReactionCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/reaction_create_params.rb', line 30
|
Instance Attribute Details
#emoji ⇒ String?
The emoji to react with, in shortcode or unicode format. For example, ‘:heart:’ or a unicode emoji. Ignored in forums where reactions are always likes.
21 |
# File 'lib/whop_sdk/models/reaction_create_params.rb', line 21 optional :emoji, String, nil?: true |
#poll_option_id ⇒ String?
The unique identifier of a poll option to vote for. Only valid when the target message or post contains a poll.
28 |
# File 'lib/whop_sdk/models/reaction_create_params.rb', line 28 optional :poll_option_id, String, nil?: true |
#resource_id ⇒ String
The unique identifier of the message or forum post to react to.
14 |
# File 'lib/whop_sdk/models/reaction_create_params.rb', line 14 required :resource_id, String |