Module: WhopSDK::Models::ReceiptTaxBehavior
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/whop_sdk/models/receipt_tax_behavior.rb
Overview
The type of tax inclusivity applied to the receipt, for determining whether the tax is included in the final price, or paid on top.
Constant Summary collapse
- EXCLUSIVE =
:exclusive- INCLUSIVE =
:inclusive- UNSPECIFIED =
:unspecified- UNABLE_TO_COLLECT =
:unable_to_collect
Class Method Summary collapse
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/receipt_tax_behavior.rb', line 15
|