Class: WhopSDK::Models::RefundRetrieveResponse::Payment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/refund_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Classes: Member, Membership, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, status:) ⇒ Object

The membership attached to this payment.

Parameters:



# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 220

Instance Attribute Details

#billing_reasonSymbol, ...

The reason why a specific payment was billed

Returns:



119
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 119

required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true

#card_brandSymbol, ...

Possible card brands that a payment token can have

Returns:



125
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 125

required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true

#card_last4String?

The last four digits of the card used to make this payment. Null if the payment was not made with a card.

Returns:

  • (String, nil)


132
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 132

required :card_last4, String, nil?: true

#created_atTime

The datetime the payment was created.

Returns:

  • (Time)


138
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 138

required :created_at, Time

#currencySymbol, ...

The available currencies on the platform

Returns:



144
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 144

required :currency, enum: -> { WhopSDK::Currency }, nil?: true

#dispute_alerted_atTime?

When an alert came in that this transaction will be disputed

Returns:

  • (Time, nil)


150
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 150

required :dispute_alerted_at, Time, nil?: true

#idString

The unique identifier for the payment.

Returns:

  • (String)


113
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 113

required :id, String

#memberWhopSDK::Models::RefundRetrieveResponse::Payment::Member?

The member attached to this payment.



156
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 156

required :member, -> { WhopSDK::Models::RefundRetrieveResponse::Payment::Member }, nil?: true

#membershipWhopSDK::Models::RefundRetrieveResponse::Payment::Membership?

The membership attached to this payment.



162
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 162

required :membership, -> { WhopSDK::Models::RefundRetrieveResponse::Payment::Membership }, nil?: true

The time at which this payment was successfully collected. Null if the payment has not yet succeeded. As a Unix timestamp.

Returns:

  • (Time, nil)


169
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 169

required :paid_at, Time, nil?: true

#payment_method_typeSymbol, ...

The different types of payment methods that can be used.

Returns:



175
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 175

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true

#subtotalFloat?

The subtotal to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


181
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 181

required :subtotal, Float, nil?: true

#tax_amountFloat?

The calculated amount of the sales/VAT tax (if applicable).

Returns:

  • (Float, nil)


187
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 187

required :tax_amount, Float, nil?: true

#tax_behaviorSymbol, ...

The type of tax inclusivity applied to the receipt, for determining whether the tax is included in the final price, or paid on top.

Returns:



194
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 194

required :tax_behavior, enum: -> { WhopSDK::ReceiptTaxBehavior }, nil?: true

#tax_refunded_amountFloat?

The amount of tax that has been refunded (if applicable).

Returns:

  • (Float, nil)


200
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 200

required :tax_refunded_amount, Float, nil?: true

#totalFloat?

The total to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


206
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 206

required :total, Float, nil?: true

#usd_totalFloat?

The total in USD to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


212
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 212

required :usd_total, Float, nil?: true

#userWhopSDK::Models::RefundRetrieveResponse::Payment::User?

The user that made this payment.



218
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 218

required :user, -> { WhopSDK::Models::RefundRetrieveResponse::Payment::User }, nil?: true