Class: WhopSDK::Models::RefundRetrieveResponse::Payment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/refund_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Classes: Member, Membership, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , status: ) ⇒ Object

The membership attached to this payment.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the membership.

  • status (Symbol, WhopSDK::Models::MembershipStatus) (defaults to: )

    The state of the membership.



# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 190

Instance Attribute Details

#billing_reasonSymbol, ...

The reason why a specific payment was billed

Returns:



110
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 110

required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true

#card_brandSymbol, ...

Possible card brands that a payment token can have

Returns:



116
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 116

required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true

#card_last4String?

The last 4 digits of the card used to make the payment.

Returns:

  • (String, nil)


122
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 122

required :card_last4, String, nil?: true

#created_atTime

The datetime the payment was created

Returns:

  • (Time)


128
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 128

required :created_at, Time

#currencySymbol, ...

The available currencies on the platform

Returns:



134
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 134

required :currency, enum: -> { WhopSDK::Currency }, nil?: true

#dispute_alerted_atTime?

When an alert came in that this transaction will be disputed

Returns:

  • (Time, nil)


140
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 140

required :dispute_alerted_at, Time, nil?: true

#idString

The payment ID

Returns:

  • (String)


104
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 104

required :id, String

#memberWhopSDK::Models::RefundRetrieveResponse::Payment::Member?

The member attached to this payment.



146
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 146

required :member, -> { WhopSDK::Models::RefundRetrieveResponse::Payment::Member }, nil?: true

#membershipWhopSDK::Models::RefundRetrieveResponse::Payment::Membership?

The membership attached to this payment.



152
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 152

required :membership, -> { WhopSDK::Models::RefundRetrieveResponse::Payment::Membership }, nil?: true

The datetime the payment was paid

Returns:

  • (Time, nil)


158
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 158

required :paid_at, Time, nil?: true

#payment_method_typeSymbol, ...

The different types of payment methods that can be used.

Returns:



164
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 164

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true

#subtotalFloat?

The subtotal to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


170
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 170

required :subtotal, Float, nil?: true

#totalFloat?

The total to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


176
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 176

required :total, Float, nil?: true

#usd_totalFloat?

The total in USD to show to the creator (excluding buyer fees).

Returns:

  • (Float, nil)


182
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 182

required :usd_total, Float, nil?: true

#userWhopSDK::Models::RefundRetrieveResponse::Payment::User?

The user that made this payment.



188
# File 'lib/whop_sdk/models/refund_retrieve_response.rb', line 188

required :user, -> { WhopSDK::Models::RefundRetrieveResponse::Payment::User }, nil?: true