Class: WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment
- Defined in:
- lib/whop_sdk/models/refund_updated_webhook_event.rb
Overview
Defined Under Namespace
Classes: Member, Membership, User
Instance Attribute Summary collapse
-
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed.
-
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have.
-
#card_last4 ⇒ String?
The last 4 digits of the card used to make the payment.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed.
-
#id ⇒ String
The payment ID.
-
#member ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Member?
The member attached to this payment.
-
#membership ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Membership?
The membership attached to this payment.
-
#paid_at ⇒ Time?
The datetime the payment was paid.
-
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
-
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
-
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
-
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
-
#user ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::User?
The user that made this payment.
Instance Method Summary collapse
-
#initialize(id: , status: ) ⇒ Object
constructor
The membership attached to this payment.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , status: ) ⇒ Object
The membership attached to this payment.
|
|
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 236
|
Instance Attribute Details
#billing_reason ⇒ Symbol, ...
The reason why a specific payment was billed
152 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 152 required :billing_reason, enum: -> { WhopSDK::BillingReasons }, nil?: true |
#card_brand ⇒ Symbol, ...
Possible card brands that a payment token can have
158 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 158 required :card_brand, enum: -> { WhopSDK::CardBrands }, nil?: true |
#card_last4 ⇒ String?
The last 4 digits of the card used to make the payment.
164 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 164 required :card_last4, String, nil?: true |
#created_at ⇒ Time
The datetime the payment was created
170 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 170 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
176 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 176 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#dispute_alerted_at ⇒ Time?
When an alert came in that this transaction will be disputed
182 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 182 required :dispute_alerted_at, Time, nil?: true |
#id ⇒ String
The payment ID
146 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 146 required :id, String |
#member ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Member?
The member attached to this payment.
188 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 188 required :member, -> { WhopSDK::RefundUpdatedWebhookEvent::Data::Payment::Member }, nil?: true |
#membership ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::Membership?
The membership attached to this payment.
194 195 196 197 198 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 194 required :membership, -> { WhopSDK::RefundUpdatedWebhookEvent::Data::Payment::Membership }, nil?: true |
#paid_at ⇒ Time?
The datetime the payment was paid
204 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 204 required :paid_at, Time, nil?: true |
#payment_method_type ⇒ Symbol, ...
The different types of payment methods that can be used.
210 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 210 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }, nil?: true |
#subtotal ⇒ Float?
The subtotal to show to the creator (excluding buyer fees).
216 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 216 required :subtotal, Float, nil?: true |
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
222 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 222 required :total, Float, nil?: true |
#usd_total ⇒ Float?
The total in USD to show to the creator (excluding buyer fees).
228 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 228 required :usd_total, Float, nil?: true |
#user ⇒ WhopSDK::Models::RefundUpdatedWebhookEvent::Data::Payment::User?
The user that made this payment.
234 |
# File 'lib/whop_sdk/models/refund_updated_webhook_event.rb', line 234 required :user, -> { WhopSDK::RefundUpdatedWebhookEvent::Data::Payment::User }, nil?: true |