Class: WhopSDK::Models::ResolutionCenterCaseDecidedWebhookEvent::Data::ResolutionEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ResolutionCenterCaseDecidedWebhookEvent::Data::ResolutionEvent
- Defined in:
- lib/whop_sdk/models/resolution_center_case_decided_webhook_event.rb
Defined Under Namespace
Modules: Action, ReporterType
Instance Attribute Summary collapse
-
#action ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseDecidedWebhookEvent::Data::ResolutionEvent::Action
The type of action recorded in this event.
-
#created_at ⇒ Time
The datetime the resolution event was created.
-
#details ⇒ String?
The message body or additional context provided with this resolution event.
-
#id ⇒ String
The unique identifier for the resolution event.
-
#reporter_type ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseDecidedWebhookEvent::Data::ResolutionEvent::ReporterType
The party who performed this action.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, action:, created_at:, details:, reporter_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResolutionEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, action:, created_at:, details:, reporter_type:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ResolutionCenterCaseDecidedWebhookEvent::Data::ResolutionEvent for more details.
A resolution event is a message or action within a resolution case, such as a response, escalation, or status change.
|
|
# File 'lib/whop_sdk/models/resolution_center_case_decided_webhook_event.rb', line 340
|
Instance Attribute Details
#action ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseDecidedWebhookEvent::Data::ResolutionEvent::Action
The type of action recorded in this event.
317 318 |
# File 'lib/whop_sdk/models/resolution_center_case_decided_webhook_event.rb', line 317 required :action, enum: -> { WhopSDK::ResolutionCenterCaseDecidedWebhookEvent::Data::ResolutionEvent::Action } |
#created_at ⇒ Time
The datetime the resolution event was created.
324 |
# File 'lib/whop_sdk/models/resolution_center_case_decided_webhook_event.rb', line 324 required :created_at, Time |
#details ⇒ String?
The message body or additional context provided with this resolution event. Null if no details were included.
331 |
# File 'lib/whop_sdk/models/resolution_center_case_decided_webhook_event.rb', line 331 required :details, String, nil?: true |
#id ⇒ String
The unique identifier for the resolution event.
311 |
# File 'lib/whop_sdk/models/resolution_center_case_decided_webhook_event.rb', line 311 required :id, String |
#reporter_type ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseDecidedWebhookEvent::Data::ResolutionEvent::ReporterType
The party who performed this action.
337 338 |
# File 'lib/whop_sdk/models/resolution_center_case_decided_webhook_event.rb', line 337 required :reporter_type, enum: -> { WhopSDK::ResolutionCenterCaseDecidedWebhookEvent::Data::ResolutionEvent::ReporterType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/resolution_center_case_decided_webhook_event.rb', line 376
|