Class: WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Payment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::Payment
- Defined in:
- lib/whop_sdk/models/resolution_center_case_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#id ⇒ String
The unique identifier for the payment.
-
#paid_at ⇒ Time?
The time at which this payment was successfully collected.
-
#subtotal ⇒ Float?
The payment amount before taxes and discounts are applied.
-
#total ⇒ Float
The total amount charged to the customer for this payment, including taxes and after any discounts.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#created_at ⇒ Time
The datetime the payment was created.
202 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 202 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
208 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 208 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#id ⇒ String
The unique identifier for the payment.
196 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 196 required :id, String |
#paid_at ⇒ Time?
The time at which this payment was successfully collected. Null if the payment has not yet succeeded. As a Unix timestamp.
215 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 215 required :paid_at, Time, nil?: true |
#subtotal ⇒ Float?
The payment amount before taxes and discounts are applied. In the currency specified by the currency field.
222 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 222 required :subtotal, Float, nil?: true |
#total ⇒ Float
The total amount charged to the customer for this payment, including taxes and after any discounts. In the currency specified by the currency field.
229 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 229 required :total, Float |