Class: WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent
- Defined in:
- lib/whop_sdk/models/resolution_center_case_retrieve_response.rb
Defined Under Namespace
Modules: Action, ReporterType
Instance Attribute Summary collapse
-
#action ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent::Action
The type of action recorded in this event.
-
#created_at ⇒ Time
The datetime the resolution event was created.
-
#details ⇒ String?
The message body or additional context provided with this resolution event.
-
#id ⇒ String
The unique identifier for the resolution event.
-
#reporter_type ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent::ReporterType
The party who performed this action.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, action:, created_at:, details:, reporter_type:) ⇒ Object
constructor
Some parameter documentations has been truncated, see ResolutionEvent for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, action:, created_at:, details:, reporter_type:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent for more details.
A resolution event is a message or action within a resolution case, such as a response, escalation, or status change.
|
|
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 285
|
Instance Attribute Details
#action ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent::Action
The type of action recorded in this event.
262 263 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 262 required :action, enum: -> { WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent::Action } |
#created_at ⇒ Time
The datetime the resolution event was created.
269 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 269 required :created_at, Time |
#details ⇒ String?
The message body or additional context provided with this resolution event. Null if no details were included.
276 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 276 required :details, String, nil?: true |
#id ⇒ String
The unique identifier for the resolution event.
256 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 256 required :id, String |
#reporter_type ⇒ Symbol, WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent::ReporterType
The party who performed this action.
282 283 |
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 282 required :reporter_type, enum: -> { WhopSDK::Models::ResolutionCenterCaseRetrieveResponse::ResolutionEvent::ReporterType } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/resolution_center_case_retrieve_response.rb', line 321
|