Class: WhopSDK::Models::ReviewListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/review_list_response.rb

Overview

Defined Under Namespace

Classes: Attachment, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , content_type: , filename: , url: ) ⇒ Object

Some parameter documentations has been truncated, see Attachment for more details.

Represents an image attachment

Parameters:

  • id (String) (defaults to: )

    The ID of the attachment

  • content_type (String, nil) (defaults to: )

    The attachment’s content type (e.g., image/jpg, video/mp4)

  • filename (String, nil) (defaults to: )

    The name of the file

  • url (String, nil) (defaults to: )

    This is the URL you use to render optimized attachments on the client. This shou



# File 'lib/whop_sdk/models/review_list_response.rb', line 137

Instance Attribute Details

#attachmentsArray<WhopSDK::Models::ReviewListResponse::Attachment>

The attachments attached to the review.



17
18
# File 'lib/whop_sdk/models/review_list_response.rb', line 17

required :attachments,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::ReviewListResponse::Attachment] }

#created_atTime

The timestamp of when the review was created.

Returns:

  • (Time)


24
# File 'lib/whop_sdk/models/review_list_response.rb', line 24

required :created_at, Time

#descriptionString?

The description of the review.

Returns:

  • (String, nil)


30
# File 'lib/whop_sdk/models/review_list_response.rb', line 30

required :description, String, nil?: true

#idString

The internal ID of the review.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/review_list_response.rb', line 11

required :id, String

#joined_atTime?

The timestamp of when the user joined the product.

Returns:

  • (Time, nil)


36
# File 'lib/whop_sdk/models/review_list_response.rb', line 36

required :joined_at, Time, nil?: true

Whether or not the user paid for the product. If null, the payment status is unknown.

Returns:

  • (Boolean, nil)


43
# File 'lib/whop_sdk/models/review_list_response.rb', line 43

required :paid_for_product, WhopSDK::Internal::Type::Boolean, nil?: true

#published_atTime?

The timestamp of when the review was published.

Returns:

  • (Time, nil)


49
# File 'lib/whop_sdk/models/review_list_response.rb', line 49

required :published_at, Time, nil?: true

#starsInteger

The number of stars the user gave the product.

Returns:

  • (Integer)


55
# File 'lib/whop_sdk/models/review_list_response.rb', line 55

required :stars, Integer

#statusSymbol, WhopSDK::Models::ReviewStatus

The status of the review.

Returns:



61
# File 'lib/whop_sdk/models/review_list_response.rb', line 61

required :status, enum: -> { WhopSDK::ReviewStatus }

#titleString?

The title of the review.

Returns:

  • (String, nil)


67
# File 'lib/whop_sdk/models/review_list_response.rb', line 67

required :title, String, nil?: true

#updated_atTime

The timestamp of when the review was last updated.

Returns:

  • (Time)


73
# File 'lib/whop_sdk/models/review_list_response.rb', line 73

required :updated_at, Time

#userWhopSDK::Models::ReviewListResponse::User

The user account that performed the action.



79
# File 'lib/whop_sdk/models/review_list_response.rb', line 79

required :user, -> { WhopSDK::Models::ReviewListResponse::User }