Class: WhopSDK::Models::ReviewListResponse::Attachment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/review_list_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , attachments: , created_at: , description: , joined_at: , paid_for_product: , published_at: , stars: , status: , title: , updated_at: , user: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::ReviewListResponse for more details.

An object representing a user review of a company.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the review.

  • attachments (Array<WhopSDK::Models::ReviewListResponse::Attachment>) (defaults to: )

    The attachments attached to the review.

  • created_at (Time) (defaults to: )

    The timestamp of when the review was created.

  • description (String, nil) (defaults to: )

    The description of the review.

  • joined_at (Time, nil) (defaults to: )

    The timestamp of when the user joined the product.

  • paid_for_product (Boolean, nil) (defaults to: )

    Whether or not the user paid for the product. If null, the payment status is unk

  • published_at (Time, nil) (defaults to: )

    The timestamp of when the review was published.

  • stars (Integer) (defaults to: )

    The number of stars the user gave the product.

  • status (Symbol, WhopSDK::Models::ReviewStatus) (defaults to: )

    The status of the review.

  • title (String, nil) (defaults to: )

    The title of the review.

  • updated_at (Time) (defaults to: )

    The timestamp of when the review was last updated.

  • user (WhopSDK::Models::ReviewListResponse::User) (defaults to: )

    The user account that performed the action.



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/whop_sdk/models/review_list_response.rb', line 111

class Attachment < WhopSDK::Internal::Type::BaseModel
  # @!attribute id
  #   The ID of the attachment
  #
  #   @return [String]
  required :id, String

  # @!attribute content_type
  #   The attachment's content type (e.g., image/jpg, video/mp4)
  #
  #   @return [String, nil]
  required :content_type, String, nil?: true

  # @!attribute filename
  #   The name of the file
  #
  #   @return [String, nil]
  required :filename, String, nil?: true

  # @!attribute url
  #   This is the URL you use to render optimized attachments on the client. This
  #   should be used for apps.
  #
  #   @return [String, nil]
  required :url, String, nil?: true

  # @!method initialize(id:, content_type:, filename:, url:)
  #   Some parameter documentations has been truncated, see
  #   {WhopSDK::Models::ReviewListResponse::Attachment} for more details.
  #
  #   Represents an image attachment
  #
  #   @param id [String] The ID of the attachment
  #
  #   @param content_type [String, nil] The attachment's content type (e.g., image/jpg, video/mp4)
  #
  #   @param filename [String, nil] The name of the file
  #
  #   @param url [String, nil] This is the URL you use to render optimized attachments on the client. This shou
end

Instance Attribute Details

#content_typeString?

The attachment’s content type (e.g., image/jpg, video/mp4)

Returns:

  • (String, nil)


122
# File 'lib/whop_sdk/models/review_list_response.rb', line 122

required :content_type, String, nil?: true

#filenameString?

The name of the file

Returns:

  • (String, nil)


128
# File 'lib/whop_sdk/models/review_list_response.rb', line 128

required :filename, String, nil?: true

#idString

The ID of the attachment

Returns:

  • (String)


116
# File 'lib/whop_sdk/models/review_list_response.rb', line 116

required :id, String

#urlString?

This is the URL you use to render optimized attachments on the client. This should be used for apps.

Returns:

  • (String, nil)


135
# File 'lib/whop_sdk/models/review_list_response.rb', line 135

required :url, String, nil?: true