Class: WhopSDK::Models::ReviewRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ReviewRetrieveResponse
- Defined in:
- lib/whop_sdk/models/review_retrieve_response.rb
Overview
Defined Under Namespace
Classes: Attachment, Company, Product, User
Instance Attribute Summary collapse
-
#attachments ⇒ Array<WhopSDK::Models::ReviewRetrieveResponse::Attachment>
A list of files and media attached to the review.
-
#company ⇒ WhopSDK::Models::ReviewRetrieveResponse::Company
The company that this review was written for.
-
#created_at ⇒ Time
The datetime the review was created.
-
#description ⇒ String?
The body text of the review containing the user’s detailed feedback.
-
#id ⇒ String
The unique identifier for the review.
-
#joined_at ⇒ Time?
The timestamp of when the reviewer first joined the product.
-
#paid_for_product ⇒ Boolean?
Whether the reviewer paid for the product.
-
#product ⇒ WhopSDK::Models::ReviewRetrieveResponse::Product
The product that this review was written for.
-
#published_at ⇒ Time?
The timestamp of when the review was published.
-
#stars ⇒ Integer
The star rating given by the reviewer, from 1 to 5.
-
#status ⇒ Symbol, WhopSDK::Models::ReviewStatus
The current moderation status of the review.
-
#title ⇒ String?
A short summary title for the review.
-
#updated_at ⇒ Time
The datetime the review was last updated.
-
#user ⇒ WhopSDK::Models::ReviewRetrieveResponse::User
The user account of the person who wrote this review.
Instance Method Summary collapse
-
#initialize(id:, title:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Product for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, title:) ⇒ Object
Some parameter documentations has been truncated, see Product for more details.
The product that this review was written for.
|
|
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 160
|
Instance Attribute Details
#attachments ⇒ Array<WhopSDK::Models::ReviewRetrieveResponse::Attachment>
A list of files and media attached to the review.
17 18 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 17 required :attachments, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::ReviewRetrieveResponse::Attachment] } |
#company ⇒ WhopSDK::Models::ReviewRetrieveResponse::Company
The company that this review was written for.
24 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 24 required :company, -> { WhopSDK::Models::ReviewRetrieveResponse::Company } |
#created_at ⇒ Time
The datetime the review was created.
30 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 30 required :created_at, Time |
#description ⇒ String?
The body text of the review containing the user’s detailed feedback. Returns an empty string if no description was provided.
37 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 37 required :description, String, nil?: true |
#id ⇒ String
The unique identifier for the review.
11 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 11 required :id, String |
#joined_at ⇒ Time?
The timestamp of when the reviewer first joined the product. Null if unknown.
43 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 43 required :joined_at, Time, nil?: true |
#paid_for_product ⇒ Boolean?
Whether the reviewer paid for the product. Null if the payment status is unknown.
50 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 50 required :paid_for_product, WhopSDK::Internal::Type::Boolean, nil?: true |
#product ⇒ WhopSDK::Models::ReviewRetrieveResponse::Product
The product that this review was written for.
56 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 56 required :product, -> { WhopSDK::Models::ReviewRetrieveResponse::Product } |
#published_at ⇒ Time?
The timestamp of when the review was published. Null if the review has not been published yet.
63 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 63 required :published_at, Time, nil?: true |
#stars ⇒ Integer
The star rating given by the reviewer, from 1 to 5.
69 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 69 required :stars, Integer |
#status ⇒ Symbol, WhopSDK::Models::ReviewStatus
The current moderation status of the review.
75 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 75 required :status, enum: -> { WhopSDK::ReviewStatus } |
#title ⇒ String?
A short summary title for the review. Null if the reviewer did not provide one.
81 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 81 required :title, String, nil?: true |
#updated_at ⇒ Time
The datetime the review was last updated.
87 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 87 required :updated_at, Time |
#user ⇒ WhopSDK::Models::ReviewRetrieveResponse::User
The user account of the person who wrote this review.
93 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 93 required :user, -> { WhopSDK::Models::ReviewRetrieveResponse::User } |