Class: WhopSDK::Models::ReviewRetrieveResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/review_retrieve_response.rb

Overview

Defined Under Namespace

Classes: Attachment, Company, Product, User

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , title: ) ⇒ Object

The product the review is for.

Parameters:

  • id (String) (defaults to: )

    The internal ID of the public product.

  • title (String) (defaults to: )

    The title of the product. Use for Whop 4.0.



# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 153

Instance Attribute Details

#attachmentsArray<WhopSDK::Models::ReviewRetrieveResponse::Attachment>

The attachments attached to the review.



17
18
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 17

required :attachments,
-> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::ReviewRetrieveResponse::Attachment] }

#companyWhopSDK::Models::ReviewRetrieveResponse::Company

The company the review is for.



24
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 24

required :company, -> { WhopSDK::Models::ReviewRetrieveResponse::Company }

#created_atTime

The timestamp of when the review was created.

Returns:

  • (Time)


30
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 30

required :created_at, Time

#descriptionString?

The description of the review.

Returns:

  • (String, nil)


36
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 36

required :description, String, nil?: true

#idString

The internal ID of the review.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 11

required :id, String

#joined_atTime?

The timestamp of when the user joined the product.

Returns:

  • (Time, nil)


42
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 42

required :joined_at, Time, nil?: true

Whether or not the user paid for the product. If null, the payment status is unknown.

Returns:

  • (Boolean, nil)


49
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 49

required :paid_for_product, WhopSDK::Internal::Type::Boolean, nil?: true

#productWhopSDK::Models::ReviewRetrieveResponse::Product

The product the review is for.



55
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 55

required :product, -> { WhopSDK::Models::ReviewRetrieveResponse::Product }

#published_atTime?

The timestamp of when the review was published.

Returns:

  • (Time, nil)


61
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 61

required :published_at, Time, nil?: true

#starsInteger

The number of stars the user gave the product.

Returns:

  • (Integer)


67
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 67

required :stars, Integer

#statusSymbol, WhopSDK::Models::ReviewStatus

The status of the review.

Returns:



73
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 73

required :status, enum: -> { WhopSDK::ReviewStatus }

#titleString?

The title of the review.

Returns:

  • (String, nil)


79
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 79

required :title, String, nil?: true

#updated_atTime

The timestamp of when the review was last updated.

Returns:

  • (Time)


85
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 85

required :updated_at, Time

#userWhopSDK::Models::ReviewRetrieveResponse::User

The user account that performed the action.



91
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 91

required :user, -> { WhopSDK::Models::ReviewRetrieveResponse::User }