Class: WhopSDK::Models::ReviewRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ReviewRetrieveResponse
- Defined in:
- lib/whop_sdk/models/review_retrieve_response.rb
Overview
Defined Under Namespace
Classes: Attachment, Company, Product, User
Instance Attribute Summary collapse
-
#attachments ⇒ Array<WhopSDK::Models::ReviewRetrieveResponse::Attachment>
The attachments attached to the review.
-
#company ⇒ WhopSDK::Models::ReviewRetrieveResponse::Company
The company the review is for.
-
#created_at ⇒ Time
The timestamp of when the review was created.
-
#description ⇒ String?
The description of the review.
-
#id ⇒ String
The internal ID of the review.
-
#joined_at ⇒ Time?
The timestamp of when the user joined the product.
-
#paid_for_product ⇒ Boolean?
Whether or not the user paid for the product.
-
#product ⇒ WhopSDK::Models::ReviewRetrieveResponse::Product
The product the review is for.
-
#published_at ⇒ Time?
The timestamp of when the review was published.
-
#stars ⇒ Integer
The number of stars the user gave the product.
-
#status ⇒ Symbol, WhopSDK::Models::ReviewStatus
The status of the review.
-
#title ⇒ String?
The title of the review.
-
#updated_at ⇒ Time
The timestamp of when the review was last updated.
-
#user ⇒ WhopSDK::Models::ReviewRetrieveResponse::User
The user account that performed the action.
Instance Method Summary collapse
-
#initialize(id: , title: ) ⇒ Object
constructor
The product the review is for.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , title: ) ⇒ Object
The product the review is for.
|
|
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 153
|
Instance Attribute Details
#attachments ⇒ Array<WhopSDK::Models::ReviewRetrieveResponse::Attachment>
The attachments attached to the review.
17 18 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 17 required :attachments, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::ReviewRetrieveResponse::Attachment] } |
#company ⇒ WhopSDK::Models::ReviewRetrieveResponse::Company
The company the review is for.
24 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 24 required :company, -> { WhopSDK::Models::ReviewRetrieveResponse::Company } |
#created_at ⇒ Time
The timestamp of when the review was created.
30 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 30 required :created_at, Time |
#description ⇒ String?
The description of the review.
36 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 36 required :description, String, nil?: true |
#id ⇒ String
The internal ID of the review.
11 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 11 required :id, String |
#joined_at ⇒ Time?
The timestamp of when the user joined the product.
42 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 42 required :joined_at, Time, nil?: true |
#paid_for_product ⇒ Boolean?
Whether or not the user paid for the product. If null, the payment status is unknown.
49 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 49 required :paid_for_product, WhopSDK::Internal::Type::Boolean, nil?: true |
#product ⇒ WhopSDK::Models::ReviewRetrieveResponse::Product
The product the review is for.
55 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 55 required :product, -> { WhopSDK::Models::ReviewRetrieveResponse::Product } |
#published_at ⇒ Time?
The timestamp of when the review was published.
61 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 61 required :published_at, Time, nil?: true |
#stars ⇒ Integer
The number of stars the user gave the product.
67 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 67 required :stars, Integer |
#status ⇒ Symbol, WhopSDK::Models::ReviewStatus
The status of the review.
73 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 73 required :status, enum: -> { WhopSDK::ReviewStatus } |
#title ⇒ String?
The title of the review.
79 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 79 required :title, String, nil?: true |
#updated_at ⇒ Time
The timestamp of when the review was last updated.
85 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 85 required :updated_at, Time |
#user ⇒ WhopSDK::Models::ReviewRetrieveResponse::User
The user account that performed the action.
91 |
# File 'lib/whop_sdk/models/review_retrieve_response.rb', line 91 required :user, -> { WhopSDK::Models::ReviewRetrieveResponse::User } |