Class: WhopSDK::Models::SetupIntent
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SetupIntent
- Defined in:
- lib/whop_sdk/models/setup_intent.rb
Overview
Defined Under Namespace
Classes: CheckoutConfiguration, Company, Member, PaymentMethod
Instance Attribute Summary collapse
-
#checkout_configuration ⇒ WhopSDK::Models::SetupIntent::CheckoutConfiguration?
The checkout configuration associated with the setup intent.
-
#company ⇒ WhopSDK::Models::SetupIntent::Company?
The company of the setup intent.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#error_message ⇒ String?
The error message, if any.
-
#id ⇒ String
The setup intent ID.
-
#member ⇒ WhopSDK::Models::SetupIntent::Member?
The member connected to the setup intent.
-
#metadata ⇒ Hash{Symbol=>Object}?
The metadata associated with the setup intent.
-
#payment_method ⇒ WhopSDK::Models::SetupIntent::PaymentMethod?
The payment method created during the setup, if available.
-
#status ⇒ Symbol, WhopSDK::Models::SetupIntentStatus
The status of the setup intent.
Instance Method Summary collapse
-
#initialize(id: , email: , name: , username: ) ⇒ Object
constructor
The user for this member, if any.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , email: , name: , username: ) ⇒ Object
The user for this member, if any.
|
|
# File 'lib/whop_sdk/models/setup_intent.rb', line 61
|
Instance Attribute Details
#checkout_configuration ⇒ WhopSDK::Models::SetupIntent::CheckoutConfiguration?
The checkout configuration associated with the setup intent
17 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 17 required :checkout_configuration, -> { WhopSDK::SetupIntent::CheckoutConfiguration }, nil?: true |
#company ⇒ WhopSDK::Models::SetupIntent::Company?
The company of the setup intent
23 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 23 required :company, -> { WhopSDK::SetupIntent::Company }, nil?: true |
#created_at ⇒ Time
The datetime the payment was created
29 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 29 required :created_at, Time |
#error_message ⇒ String?
The error message, if any.
35 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 35 required :error_message, String, nil?: true |
#id ⇒ String
The setup intent ID
11 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 11 required :id, String |
#member ⇒ WhopSDK::Models::SetupIntent::Member?
The member connected to the setup intent
41 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 41 required :member, -> { WhopSDK::SetupIntent::Member }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
The metadata associated with the setup intent
47 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 47 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#payment_method ⇒ WhopSDK::Models::SetupIntent::PaymentMethod?
The payment method created during the setup, if available.
53 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 53 required :payment_method, -> { WhopSDK::SetupIntent::PaymentMethod }, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::SetupIntentStatus
The status of the setup intent
59 |
# File 'lib/whop_sdk/models/setup_intent.rb', line 59 required :status, enum: -> { WhopSDK::SetupIntentStatus } |