Class: WhopSDK::Models::SetupIntent::PaymentMethod

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/setup_intent.rb

Overview

See Also:

Defined Under Namespace

Classes: Card, MailingAddress

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(brand:, exp_month:, exp_year:, last4:) ⇒ Object

Some parameter documentations has been truncated, see Card for more details.

The card data associated with the payment method, if its a debit or credit card.

Parameters:

  • brand (Symbol, WhopSDK::Models::CardBrands, nil)

    Possible card brands that a payment token can have

  • exp_month (Integer, nil)

    The two-digit expiration month of the card (1-12). Null if not available.

  • exp_year (Integer, nil)

    The two-digit expiration year of the card (e.g., 27 for 2027). Null if not avail

  • last4 (String, nil)

    The last four digits of the card number. Null if not available.



# File 'lib/whop_sdk/models/setup_intent.rb', line 215

Instance Attribute Details

#cardWhopSDK::Models::SetupIntent::PaymentMethod::Card?

The card data associated with the payment method, if its a debit or credit card.



195
# File 'lib/whop_sdk/models/setup_intent.rb', line 195

required :card, -> { WhopSDK::SetupIntent::PaymentMethod::Card }, nil?: true

#created_atTime

The datetime the payment token was created.

Returns:

  • (Time)


201
# File 'lib/whop_sdk/models/setup_intent.rb', line 201

required :created_at, Time

#idString

The unique identifier for the payment token.

Returns:

  • (String)


189
# File 'lib/whop_sdk/models/setup_intent.rb', line 189

required :id, String

#mailing_addressWhopSDK::Models::SetupIntent::PaymentMethod::MailingAddress?

The mailing address associated with the payment method’s user



207
# File 'lib/whop_sdk/models/setup_intent.rb', line 207

required :mailing_address, -> { WhopSDK::SetupIntent::PaymentMethod::MailingAddress }, nil?: true

#payment_method_typeSymbol, WhopSDK::Models::PaymentMethodTypes

The payment method type of the payment method



213
# File 'lib/whop_sdk/models/setup_intent.rb', line 213

required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes }