Class: WhopSDK::Models::SetupIntentListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SetupIntentListResponse
- Defined in:
- lib/whop_sdk/models/setup_intent_list_response.rb
Overview
Defined Under Namespace
Classes: CheckoutConfiguration, Company, Member, PaymentMethod
Instance Attribute Summary collapse
-
#checkout_configuration ⇒ WhopSDK::Models::SetupIntentListResponse::CheckoutConfiguration?
The checkout session configuration associated with this setup intent.
-
#company ⇒ WhopSDK::Models::SetupIntentListResponse::Company?
The company that initiated this setup intent.
-
#created_at ⇒ Time
The datetime the setup intent was created.
-
#error_message ⇒ String?
A human-readable error message explaining why the setup intent failed.
-
#id ⇒ String
The unique identifier for the setup intent.
-
#member ⇒ WhopSDK::Models::SetupIntentListResponse::Member?
The company member associated with this setup intent.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs attached to this setup intent.
-
#payment_method ⇒ WhopSDK::Models::SetupIntentListResponse::PaymentMethod?
The saved payment method created by this setup intent.
-
#status ⇒ Symbol, WhopSDK::Models::SetupIntentStatus
The current status of the setup intent.
Instance Method Summary collapse
-
#initialize(id:, email:, name:, username:) ⇒ Object
constructor
The user for this member, if any.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, email:, name:, username:) ⇒ Object
The user for this member, if any.
|
|
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 69
|
Instance Attribute Details
#checkout_configuration ⇒ WhopSDK::Models::SetupIntentListResponse::CheckoutConfiguration?
The checkout session configuration associated with this setup intent. Null if no checkout session was used.
18 19 20 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 18 required :checkout_configuration, -> { WhopSDK::Models::SetupIntentListResponse::CheckoutConfiguration }, nil?: true |
#company ⇒ WhopSDK::Models::SetupIntentListResponse::Company?
The company that initiated this setup intent. Null if the company has been deleted.
27 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 27 required :company, -> { WhopSDK::Models::SetupIntentListResponse::Company }, nil?: true |
#created_at ⇒ Time
The datetime the setup intent was created.
33 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 33 required :created_at, Time |
#error_message ⇒ String?
A human-readable error message explaining why the setup intent failed. Null if no error occurred.
40 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 40 required :error_message, String, nil?: true |
#id ⇒ String
The unique identifier for the setup intent.
11 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 11 required :id, String |
#member ⇒ WhopSDK::Models::SetupIntentListResponse::Member?
The company member associated with this setup intent. Null if the user is not a member.
47 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 47 required :member, -> { WhopSDK::Models::SetupIntentListResponse::Member }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs attached to this setup intent. Null if no metadata was provided.
54 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 54 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#payment_method ⇒ WhopSDK::Models::SetupIntentListResponse::PaymentMethod?
The saved payment method created by this setup intent. Null if the setup has not completed successfully.
61 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 61 required :payment_method, -> { WhopSDK::Models::SetupIntentListResponse::PaymentMethod }, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::SetupIntentStatus
The current status of the setup intent.
67 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 67 required :status, enum: -> { WhopSDK::SetupIntentStatus } |