Class: WhopSDK::Models::SetupIntentListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SetupIntentListResponse
- Defined in:
- lib/whop_sdk/models/setup_intent_list_response.rb
Overview
Defined Under Namespace
Classes: CheckoutConfiguration, Company, Member, PaymentMethod
Instance Attribute Summary collapse
-
#checkout_configuration ⇒ WhopSDK::Models::SetupIntentListResponse::CheckoutConfiguration?
The checkout configuration associated with the setup intent.
-
#company ⇒ WhopSDK::Models::SetupIntentListResponse::Company?
The company of the setup intent.
-
#created_at ⇒ Time
The datetime the payment was created.
-
#error_message ⇒ String?
The error message, if any.
-
#id ⇒ String
The setup intent ID.
-
#member ⇒ WhopSDK::Models::SetupIntentListResponse::Member?
The member connected to the setup intent.
-
#metadata ⇒ Hash{Symbol=>Object}?
The metadata associated with the setup intent.
-
#payment_method ⇒ WhopSDK::Models::SetupIntentListResponse::PaymentMethod?
The payment method created during the setup, if available.
-
#status ⇒ Symbol, WhopSDK::Models::SetupIntentStatus
The status of the setup intent.
Instance Method Summary collapse
-
#initialize(id: , email: , name: , username: ) ⇒ Object
constructor
The user for this member, if any.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , email: , name: , username: ) ⇒ Object
The user for this member, if any.
|
|
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 63
|
Instance Attribute Details
#checkout_configuration ⇒ WhopSDK::Models::SetupIntentListResponse::CheckoutConfiguration?
The checkout configuration associated with the setup intent
17 18 19 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 17 required :checkout_configuration, -> { WhopSDK::Models::SetupIntentListResponse::CheckoutConfiguration }, nil?: true |
#company ⇒ WhopSDK::Models::SetupIntentListResponse::Company?
The company of the setup intent
25 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 25 required :company, -> { WhopSDK::Models::SetupIntentListResponse::Company }, nil?: true |
#created_at ⇒ Time
The datetime the payment was created
31 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 31 required :created_at, Time |
#error_message ⇒ String?
The error message, if any.
37 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 37 required :error_message, String, nil?: true |
#id ⇒ String
The setup intent ID
11 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 11 required :id, String |
#member ⇒ WhopSDK::Models::SetupIntentListResponse::Member?
The member connected to the setup intent
43 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 43 required :member, -> { WhopSDK::Models::SetupIntentListResponse::Member }, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
The metadata associated with the setup intent
49 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 49 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#payment_method ⇒ WhopSDK::Models::SetupIntentListResponse::PaymentMethod?
The payment method created during the setup, if available.
55 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 55 required :payment_method, -> { WhopSDK::Models::SetupIntentListResponse::PaymentMethod }, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::SetupIntentStatus
The status of the setup intent
61 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 61 required :status, enum: -> { WhopSDK::SetupIntentStatus } |