Class: WhopSDK::Models::SetupIntentListResponse::PaymentMethod
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SetupIntentListResponse::PaymentMethod
- Defined in:
- lib/whop_sdk/models/setup_intent_list_response.rb
Overview
Defined Under Namespace
Classes: Card, MailingAddress
Instance Attribute Summary collapse
-
#card ⇒ WhopSDK::Models::SetupIntentListResponse::PaymentMethod::Card?
The card data associated with the payment method, if its a debit or credit card.
-
#created_at ⇒ Time
The datetime the payment token was created.
-
#id ⇒ String
The unique identifier for the payment token.
-
#mailing_address ⇒ WhopSDK::Models::SetupIntentListResponse::PaymentMethod::MailingAddress?
The mailing address associated with the payment method’s user.
-
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The payment method type of the payment method.
Instance Method Summary collapse
-
#initialize(brand:, exp_month:, exp_year:, last4:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Card for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(brand:, exp_month:, exp_year:, last4:) ⇒ Object
Some parameter documentations has been truncated, see Card for more details.
The card data associated with the payment method, if its a debit or credit card.
|
|
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 219
|
Instance Attribute Details
#card ⇒ WhopSDK::Models::SetupIntentListResponse::PaymentMethod::Card?
The card data associated with the payment method, if its a debit or credit card.
197 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 197 required :card, -> { WhopSDK::Models::SetupIntentListResponse::PaymentMethod::Card }, nil?: true |
#created_at ⇒ Time
The datetime the payment token was created.
203 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 203 required :created_at, Time |
#id ⇒ String
The unique identifier for the payment token.
191 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 191 required :id, String |
#mailing_address ⇒ WhopSDK::Models::SetupIntentListResponse::PaymentMethod::MailingAddress?
The mailing address associated with the payment method’s user
209 210 211 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 209 required :mailing_address, -> { WhopSDK::Models::SetupIntentListResponse::PaymentMethod::MailingAddress }, nil?: true |
#payment_method_type ⇒ Symbol, WhopSDK::Models::PaymentMethodTypes
The payment method type of the payment method
217 |
# File 'lib/whop_sdk/models/setup_intent_list_response.rb', line 217 required :payment_method_type, enum: -> { WhopSDK::PaymentMethodTypes } |