Class: WhopSDK::Models::Shipment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Shipment
- Defined in:
- lib/whop_sdk/models/shipment.rb
Defined Under Namespace
Classes: Payment
Instance Attribute Summary collapse
-
#carrier ⇒ Symbol, WhopSDK::Models::ShipmentCarrier
The shipping carrier responsible for delivering this shipment.
-
#created_at ⇒ Time
The datetime the shipment was created.
-
#delivery_estimate ⇒ Time?
The estimated delivery date for this shipment.
-
#id ⇒ String
The unique identifier for the shipment.
-
#payment ⇒ WhopSDK::Models::Shipment::Payment?
The payment associated with this shipment.
-
#service ⇒ String?
The shipping service level used for this shipment.
-
#status ⇒ Symbol, WhopSDK::Models::ShipmentStatus
The current delivery status of this shipment.
-
#substatus ⇒ Symbol, ...
The substatus of a shipment.
-
#tracking_code ⇒ String
The carrier-assigned tracking number used to look up shipment progress.
-
#updated_at ⇒ Time
The datetime the shipment was last updated.
Instance Method Summary collapse
-
#initialize(id:, carrier:, created_at:, delivery_estimate:, payment:, service:, status:, substatus:, tracking_code:, updated_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Shipment for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, carrier:, created_at:, delivery_estimate:, payment:, service:, status:, substatus:, tracking_code:, updated_at:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Shipment for more details.
A physical shipment associated with a payment, including carrier details and tracking information.
|
|
# File 'lib/whop_sdk/models/shipment.rb', line 69
|
Instance Attribute Details
#carrier ⇒ Symbol, WhopSDK::Models::ShipmentCarrier
The shipping carrier responsible for delivering this shipment.
16 |
# File 'lib/whop_sdk/models/shipment.rb', line 16 required :carrier, enum: -> { WhopSDK::ShipmentCarrier } |
#created_at ⇒ Time
The datetime the shipment was created.
22 |
# File 'lib/whop_sdk/models/shipment.rb', line 22 required :created_at, Time |
#delivery_estimate ⇒ Time?
The estimated delivery date for this shipment. Null if the carrier has not provided an estimate.
29 |
# File 'lib/whop_sdk/models/shipment.rb', line 29 required :delivery_estimate, Time, nil?: true |
#id ⇒ String
The unique identifier for the shipment.
10 |
# File 'lib/whop_sdk/models/shipment.rb', line 10 required :id, String |
#payment ⇒ WhopSDK::Models::Shipment::Payment?
The payment associated with this shipment. Null if the payment has been deleted or is inaccessible.
36 |
# File 'lib/whop_sdk/models/shipment.rb', line 36 required :payment, -> { WhopSDK::Shipment::Payment }, nil?: true |
#service ⇒ String?
The shipping service level used for this shipment. Null if the carrier does not specify a service tier.
43 |
# File 'lib/whop_sdk/models/shipment.rb', line 43 required :service, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::ShipmentStatus
The current delivery status of this shipment.
49 |
# File 'lib/whop_sdk/models/shipment.rb', line 49 required :status, enum: -> { WhopSDK::ShipmentStatus } |
#substatus ⇒ Symbol, ...
The substatus of a shipment
55 |
# File 'lib/whop_sdk/models/shipment.rb', line 55 required :substatus, enum: -> { WhopSDK::ShipmentSubstatus }, nil?: true |
#tracking_code ⇒ String
The carrier-assigned tracking number used to look up shipment progress.
61 |
# File 'lib/whop_sdk/models/shipment.rb', line 61 required :tracking_code, String |
#updated_at ⇒ Time
The datetime the shipment was last updated.
67 |
# File 'lib/whop_sdk/models/shipment.rb', line 67 required :updated_at, Time |