Class: WhopSDK::Models::Shipment

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/shipment.rb

Defined Under Namespace

Classes: Payment

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , carrier: , created_at: , delivery_estimate: , payment: , service: , status: , substatus: , tracking_code: , updated_at: ) ⇒ Object

A shipment

Parameters:

  • id (String) (defaults to: )

    The ID of the shipment

  • carrier (Symbol, WhopSDK::Models::ShipmentCarrier) (defaults to: )

    The carrier of the shipment

  • created_at (Time) (defaults to: )

    The date and time the shipment was created

  • delivery_estimate (Time, nil) (defaults to: )

    The delivery estimate of the shipment

  • payment (WhopSDK::Models::Shipment::Payment) (defaults to: )

    The payment of the shipment

  • service (String, nil) (defaults to: )

    The service of the shipment

  • status (Symbol, WhopSDK::Models::ShipmentStatus) (defaults to: )

    The status of the shipment

  • substatus (Symbol, WhopSDK::Models::ShipmentSubstatus, nil) (defaults to: )

    The substatus of a shipment

  • tracking_code (String) (defaults to: )

    The tracking code of the shipment

  • updated_at (Time) (defaults to: )

    The date and time the shipment was last updated



# File 'lib/whop_sdk/models/shipment.rb', line 66

Instance Attribute Details

#carrierSymbol, WhopSDK::Models::ShipmentCarrier

The carrier of the shipment



16
# File 'lib/whop_sdk/models/shipment.rb', line 16

required :carrier, enum: -> { WhopSDK::ShipmentCarrier }

#created_atTime

The date and time the shipment was created

Returns:

  • (Time)


22
# File 'lib/whop_sdk/models/shipment.rb', line 22

required :created_at, Time

#delivery_estimateTime?

The delivery estimate of the shipment

Returns:

  • (Time, nil)


28
# File 'lib/whop_sdk/models/shipment.rb', line 28

required :delivery_estimate, Time, nil?: true

#idString

The ID of the shipment

Returns:

  • (String)


10
# File 'lib/whop_sdk/models/shipment.rb', line 10

required :id, String

#paymentWhopSDK::Models::Shipment::Payment

The payment of the shipment



34
# File 'lib/whop_sdk/models/shipment.rb', line 34

required :payment, -> { WhopSDK::Shipment::Payment }

#serviceString?

The service of the shipment

Returns:

  • (String, nil)


40
# File 'lib/whop_sdk/models/shipment.rb', line 40

required :service, String, nil?: true

#statusSymbol, WhopSDK::Models::ShipmentStatus

The status of the shipment

Returns:



46
# File 'lib/whop_sdk/models/shipment.rb', line 46

required :status, enum: -> { WhopSDK::ShipmentStatus }

#substatusSymbol, ...

The substatus of a shipment

Returns:



52
# File 'lib/whop_sdk/models/shipment.rb', line 52

required :substatus, enum: -> { WhopSDK::ShipmentSubstatus }, nil?: true

#tracking_codeString

The tracking code of the shipment

Returns:

  • (String)


58
# File 'lib/whop_sdk/models/shipment.rb', line 58

required :tracking_code, String

#updated_atTime

The date and time the shipment was last updated

Returns:

  • (Time)


64
# File 'lib/whop_sdk/models/shipment.rb', line 64

required :updated_at, Time