Class: WhopSDK::Models::ShipmentCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ShipmentCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/shipment_create_params.rb
Overview
Instance Attribute Summary collapse
-
#company_id ⇒ String
The ID of the company to create the shipment for.
-
#payment_id ⇒ String
The ID of the payment to create the shipment for.
-
#tracking_code ⇒ String
The tracking code for the shipment.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(company_id: , payment_id: , tracking_code: , request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 28
|
Instance Attribute Details
#company_id ⇒ String
The ID of the company to create the shipment for
14 |
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 14 required :company_id, String |
#payment_id ⇒ String
The ID of the payment to create the shipment for
20 |
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 20 required :payment_id, String |
#tracking_code ⇒ String
The tracking code for the shipment
26 |
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 26 required :tracking_code, String |