Class: WhopSDK::Models::ShipmentCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/shipment_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(company_id: , payment_id: , tracking_code: , request_options: {}) ⇒ Object

Parameters:

  • company_id (String) (defaults to: )

    The ID of the company to create the shipment for

  • payment_id (String) (defaults to: )

    The ID of the payment to create the shipment for

  • tracking_code (String) (defaults to: )

    The tracking code for the shipment

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/shipment_create_params.rb', line 28

Instance Attribute Details

#company_idString

The ID of the company to create the shipment for

Returns:

  • (String)


14
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 14

required :company_id, String

#payment_idString

The ID of the payment to create the shipment for

Returns:

  • (String)


20
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 20

required :payment_id, String

#tracking_codeString

The tracking code for the shipment

Returns:

  • (String)


26
# File 'lib/whop_sdk/models/shipment_create_params.rb', line 26

required :tracking_code, String