Class: WhopSDK::Models::ShipmentListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::ShipmentListResponse
- Defined in:
- lib/whop_sdk/models/shipment_list_response.rb
Overview
Defined Under Namespace
Classes: Payment
Instance Attribute Summary collapse
-
#carrier ⇒ Symbol, WhopSDK::Models::ShipmentCarrier
The carrier of the shipment.
-
#created_at ⇒ Time
The date and time the shipment was created.
-
#delivery_estimate ⇒ Time?
The delivery estimate of the shipment.
-
#id ⇒ String
The ID of the shipment.
-
#payment ⇒ WhopSDK::Models::ShipmentListResponse::Payment?
The payment of the shipment.
-
#service ⇒ String?
The service of the shipment.
-
#status ⇒ Symbol, WhopSDK::Models::ShipmentStatus
The status of the shipment.
-
#substatus ⇒ Symbol, ...
The substatus of a shipment.
-
#tracking_code ⇒ String
The tracking code of the shipment.
-
#updated_at ⇒ Time
The date and time the shipment was last updated.
Instance Method Summary collapse
-
#initialize(id: , carrier: , created_at: , delivery_estimate: , payment: , service: , status: , substatus: , tracking_code: , updated_at: ) ⇒ Object
constructor
A shipment.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , carrier: , created_at: , delivery_estimate: , payment: , service: , status: , substatus: , tracking_code: , updated_at: ) ⇒ Object
A shipment
|
|
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 67
|
Instance Attribute Details
#carrier ⇒ Symbol, WhopSDK::Models::ShipmentCarrier
The carrier of the shipment
17 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 17 required :carrier, enum: -> { WhopSDK::ShipmentCarrier } |
#created_at ⇒ Time
The date and time the shipment was created
23 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 23 required :created_at, Time |
#delivery_estimate ⇒ Time?
The delivery estimate of the shipment
29 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 29 required :delivery_estimate, Time, nil?: true |
#id ⇒ String
The ID of the shipment
11 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 11 required :id, String |
#payment ⇒ WhopSDK::Models::ShipmentListResponse::Payment?
The payment of the shipment
35 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 35 required :payment, -> { WhopSDK::Models::ShipmentListResponse::Payment }, nil?: true |
#service ⇒ String?
The service of the shipment
41 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 41 required :service, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::ShipmentStatus
The status of the shipment
47 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 47 required :status, enum: -> { WhopSDK::ShipmentStatus } |
#substatus ⇒ Symbol, ...
The substatus of a shipment
53 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 53 required :substatus, enum: -> { WhopSDK::ShipmentSubstatus }, nil?: true |
#tracking_code ⇒ String
The tracking code of the shipment
59 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 59 required :tracking_code, String |
#updated_at ⇒ Time
The date and time the shipment was last updated
65 |
# File 'lib/whop_sdk/models/shipment_list_response.rb', line 65 required :updated_at, Time |