Class: WhopSDK::Models::SocialAccount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SocialAccount
- Defined in:
- lib/whop_sdk/models/social_account.rb,
sig/whop_sdk/models/social_account.rbs
Overview
Defined Under Namespace
Modules: Platform
Instance Attribute Summary collapse
-
#external_id ⇒ String?
The platform-specific ID for this social account.
-
#id ⇒ String
Unique identifier for the social account.
-
#name ⇒ String?
The display name of the social account on the platform.
-
#platform ⇒ Symbol, WhopSDK::Models::SocialAccount::Platform
The platform the social account exists on.
-
#profile_picture_url ⇒ String?
The URL where the profile picture of the social account can be accessed.
- #scopes ⇒ Array<String>
-
#url ⇒ String?
The URL where the social account can be accessed on the platform.
-
#username ⇒ String?
The username of the social account on the platform.
-
#verified ⇒ Boolean
Whether the social account is verified on the platform.
Instance Method Summary collapse
-
#initialize(id:, external_id:, name:, platform:, profile_picture_url:, scopes:, url:, username:, verified:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SocialAccount for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, external_id:, name:, platform:, profile_picture_url:, scopes:, url:, username:, verified:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::SocialAccount for more details.
|
|
# File 'lib/whop_sdk/models/social_account.rb', line 62
|
Instance Attribute Details
#external_id ⇒ String?
The platform-specific ID for this social account.
17 |
# File 'lib/whop_sdk/models/social_account.rb', line 17 required :external_id, String, nil?: true |
#id ⇒ String
Unique identifier for the social account.
11 |
# File 'lib/whop_sdk/models/social_account.rb', line 11 required :id, String |
#name ⇒ String?
The display name of the social account on the platform.
23 |
# File 'lib/whop_sdk/models/social_account.rb', line 23 required :name, String, nil?: true |
#platform ⇒ Symbol, WhopSDK::Models::SocialAccount::Platform
The platform the social account exists on.
29 |
# File 'lib/whop_sdk/models/social_account.rb', line 29 required :platform, enum: -> { WhopSDK::SocialAccount::Platform } |
#profile_picture_url ⇒ String?
The URL where the profile picture of the social account can be accessed.
35 |
# File 'lib/whop_sdk/models/social_account.rb', line 35 required :profile_picture_url, String, nil?: true |
#scopes ⇒ Array<String>
40 |
# File 'lib/whop_sdk/models/social_account.rb', line 40 required :scopes, WhopSDK::Internal::Type::ArrayOf[String] |
#url ⇒ String?
The URL where the social account can be accessed on the platform. Null while a Whop-owned page is still being provisioned.
47 |
# File 'lib/whop_sdk/models/social_account.rb', line 47 required :url, String, nil?: true |
#username ⇒ String?
The username of the social account on the platform. Null while a Whop-owned page is still being provisioned.
54 |
# File 'lib/whop_sdk/models/social_account.rb', line 54 required :username, String, nil?: true |
#verified ⇒ Boolean
Whether the social account is verified on the platform.
60 |
# File 'lib/whop_sdk/models/social_account.rb', line 60 required :verified, WhopSDK::Internal::Type::Boolean |
Instance Method Details
#to_hash ⇒ {
47 |
# File 'sig/whop_sdk/models/social_account.rbs', line 47
def to_hash: -> {
|