Class: WhopSDK::Models::SocialAccountListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SocialAccountListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/social_account_list_params.rb,
sig/whop_sdk/models/social_account_list_params.rbs
Overview
Defined Under Namespace
Modules: Direction, Order, Platform, Scope
Instance Attribute Summary collapse
-
#account_id ⇒ String?
The Account that the social accounts are connected to.
-
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
-
#before ⇒ String?
Cursor to fetch the page before (from page_info.start_cursor).
-
#direction ⇒ Symbol, ...
Sort direction.
-
#first ⇒ Integer?
The number of social accounts to return.
-
#last ⇒ Integer?
The number of social accounts to return from the end of the range.
-
#order ⇒ Symbol, ...
The field to sort social accounts by.
-
#platform ⇒ Symbol, ...
Only return social accounts for the platform that is specified.
-
#scopes ⇒ Array<Symbol, WhopSDK::Models::SocialAccountListParams::Scope>?
Only return social accounts that have these scopes.
-
#user_id ⇒ String?
The User that the social accounts are connected to.
-
#verified ⇒ Boolean?
Only return social accounts that are verified on the platform.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_id: nil, after: nil, before: nil, direction: nil, first: nil, last: nil, order: nil, platform: nil, scopes: nil, user_id: nil, verified: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SocialAccountListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id: nil, after: nil, before: nil, direction: nil, first: nil, last: nil, order: nil, platform: nil, scopes: nil, user_id: nil, verified: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::SocialAccountListParams for more details.
|
|
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 78
|
Instance Attribute Details
#account_id ⇒ String?
The Account that the social accounts are connected to. Provide either this or user_id.
15 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 15 optional :account_id, String |
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
21 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 21 optional :after, String |
#before ⇒ String?
Cursor to fetch the page before (from page_info.start_cursor).
27 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 27 optional :before, String |
#direction ⇒ Symbol, ...
Sort direction.
33 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 33 optional :direction, enum: -> { WhopSDK::SocialAccountListParams::Direction } |
#first ⇒ Integer?
The number of social accounts to return.
39 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 39 optional :first, Integer |
#last ⇒ Integer?
The number of social accounts to return from the end of the range.
45 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 45 optional :last, Integer |
#order ⇒ Symbol, ...
The field to sort social accounts by.
51 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 51 optional :order, enum: -> { WhopSDK::SocialAccountListParams::Order } |
#platform ⇒ Symbol, ...
Only return social accounts for the platform that is specified.
57 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 57 optional :platform, enum: -> { WhopSDK::SocialAccountListParams::Platform } |
#scopes ⇒ Array<Symbol, WhopSDK::Models::SocialAccountListParams::Scope>?
Only return social accounts that have these scopes.
63 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 63 optional :scopes, -> { WhopSDK::Internal::Type::ArrayOf[enum: WhopSDK::SocialAccountListParams::Scope] } |
#user_id ⇒ String?
The User that the social accounts are connected to. Provide either this or account_id.
70 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 70 optional :user_id, String |
#verified ⇒ Boolean?
Only return social accounts that are verified on the platform.
76 |
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 76 optional :verified, WhopSDK::Internal::Type::Boolean |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/social_account_list_params.rb', line 113
|
Instance Method Details
#to_hash ⇒ {
90 |
# File 'sig/whop_sdk/models/social_account_list_params.rbs', line 90
def to_hash: -> {
|