Class: WhopSDK::Models::SocialAccountPostsParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SocialAccountPostsParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/social_account_posts_params.rb,
sig/whop_sdk/models/social_account_posts_params.rbs
Overview
Instance Attribute Summary collapse
-
#account_id ⇒ String
The Account (a biz_ identifier) the social account is connected to.
-
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
-
#first ⇒ Integer?
The number of posts to return.
- #id ⇒ String
-
#post_id ⇒ String?
Return only the single post with this platform id, instead of the full list.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
- #initialize(id:, account_id:, after: nil, first: nil, post_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_id:, after: nil, first: nil, post_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 39
|
Instance Attribute Details
#account_id ⇒ String
The Account (a biz_ identifier) the social account is connected to.
19 |
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 19 required :account_id, String |
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
25 |
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 25 optional :after, String |
#first ⇒ Integer?
The number of posts to return.
31 |
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 31 optional :first, Integer |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 13 required :id, String |
#post_id ⇒ String?
Return only the single post with this platform id, instead of the full list.
37 |
# File 'lib/whop_sdk/models/social_account_posts_params.rb', line 37 optional :post_id, String |
Instance Method Details
#to_hash ⇒ {
42 |
# File 'sig/whop_sdk/models/social_account_posts_params.rbs', line 42
def to_hash: -> {
|