Class: WhopSDK::Models::SupportChannel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SupportChannel
- Defined in:
- lib/whop_sdk/models/support_channel.rb
Defined Under Namespace
Classes: CustomerUser
Instance Attribute Summary collapse
-
#company_id ⇒ String?
The unique identifier of the company associated with this channel.
-
#custom_name ⇒ String?
A custom display name assigned to this channel by the user.
-
#customer_user ⇒ WhopSDK::Models::SupportChannel::CustomerUser?
The customer who initiated this support conversation.
-
#id ⇒ String
The unique identifier for the entity.
-
#last_message_at ⇒ Time?
The timestamp when the most recent message was sent in this channel.
-
#resolved_at ⇒ Time?
The timestamp when the linked support ticket was marked as resolved.
Instance Method Summary collapse
-
#initialize(id:, company_id:, custom_name:, customer_user:, last_message_at:, resolved_at:) ⇒ Object
constructor
Some parameter documentations has been truncated, see SupportChannel for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, company_id:, custom_name:, customer_user:, last_message_at:, resolved_at:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::SupportChannel for more details.
A messaging channel that can be a one-on-one DM, group chat, company support conversation, or platform-level direct message.
|
|
# File 'lib/whop_sdk/models/support_channel.rb', line 47
|
Instance Attribute Details
#company_id ⇒ String?
The unique identifier of the company associated with this channel. Null if this is not a support or company-scoped conversation.
17 |
# File 'lib/whop_sdk/models/support_channel.rb', line 17 required :company_id, String, nil?: true |
#custom_name ⇒ String?
A custom display name assigned to this channel by the user. Null if no custom name has been set.
24 |
# File 'lib/whop_sdk/models/support_channel.rb', line 24 required :custom_name, String, nil?: true |
#customer_user ⇒ WhopSDK::Models::SupportChannel::CustomerUser?
The customer who initiated this support conversation. Null if this is not a support chat.
31 |
# File 'lib/whop_sdk/models/support_channel.rb', line 31 required :customer_user, -> { WhopSDK::SupportChannel::CustomerUser }, nil?: true |
#id ⇒ String
The unique identifier for the entity
10 |
# File 'lib/whop_sdk/models/support_channel.rb', line 10 required :id, String |
#last_message_at ⇒ Time?
The timestamp when the most recent message was sent in this channel. Null if no messages have been sent.
38 |
# File 'lib/whop_sdk/models/support_channel.rb', line 38 required :last_message_at, Time, nil?: true |
#resolved_at ⇒ Time?
The timestamp when the linked support ticket was marked as resolved. Null if unresolved or not a support chat.
45 |
# File 'lib/whop_sdk/models/support_channel.rb', line 45 required :resolved_at, Time, nil?: true |