Class: WhopSDK::Models::SwapCreateQuoteParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SwapCreateQuoteParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/swap_create_quote_params.rb,
sig/whop_sdk/models/swap_create_quote_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#amount ⇒ String
Source token amount.
-
#from_address ⇒ String?
Source wallet address used for the quote.
-
#from_chain ⇒ String, ...
Source chain name or chain ID.
-
#from_token ⇒ String
Source token contract address or ticker symbol, such as "USDT".
-
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to include with the quote response.
-
#slippage_bps ⇒ Integer?
Maximum slippage tolerance in basis points.
-
#to_address ⇒ String?
Destination wallet address used for the quote.
-
#to_chain ⇒ String, ...
Destination chain name or chain ID.
-
#to_token ⇒ String
Destination token contract address or ticker symbol, such as "XAUT".
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, from_token:, to_token:, from_address: nil, from_chain: nil, metadata: nil, slippage_bps: nil, to_address: nil, to_chain: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SwapCreateQuoteParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, from_token:, to_token:, from_address: nil, from_chain: nil, metadata: nil, slippage_bps: nil, to_address: nil, to_chain: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::SwapCreateQuoteParams for more details.
|
|
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 66
|
Instance Attribute Details
#amount ⇒ String
Source token amount.
14 |
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 14 required :amount, String |
#from_address ⇒ String?
Source wallet address used for the quote.
32 |
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 32 optional :from_address, String, nil?: true |
#from_chain ⇒ String, ...
Source chain name or chain ID. Defaults to the source token's chain when omitted.
39 |
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 39 optional :from_chain, union: -> { WhopSDK::SwapCreateQuoteParams::FromChain }, nil?: true |
#from_token ⇒ String
Source token contract address or ticker symbol, such as "USDT".
20 |
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 20 required :from_token, String |
#metadata ⇒ Hash{Symbol=>Object}?
Metadata to include with the quote response.
45 |
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 45 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown] |
#slippage_bps ⇒ Integer?
Maximum slippage tolerance in basis points.
51 |
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 51 optional :slippage_bps, Integer, nil?: true |
#to_address ⇒ String?
Destination wallet address used for the quote.
57 |
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 57 optional :to_address, String, nil?: true |
#to_chain ⇒ String, ...
Destination chain name or chain ID. Defaults to the destination token's chain when omitted.
64 |
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 64 optional :to_chain, union: -> { WhopSDK::SwapCreateQuoteParams::ToChain }, nil?: true |
#to_token ⇒ String
Destination token contract address or ticker symbol, such as "XAUT".
26 |
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 26 required :to_token, String |
Class Method Details
.variants ⇒ Array(String, Integer)
|
|
# File 'lib/whop_sdk/models/swap_create_quote_params.rb', line 99
|
Instance Method Details
#to_hash ⇒ {
54 |
# File 'sig/whop_sdk/models/swap_create_quote_params.rbs', line 54
def to_hash: -> {
|