Class: WhopSDK::Models::SwapCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SwapCreateResponse
- Defined in:
- lib/whop_sdk/models/swap_create_response.rb,
sig/whop_sdk/models/swap_create_response.rbs
Overview
Defined Under Namespace
Modules: Object
Instance Attribute Summary collapse
-
#account_id ⇒ String
Account ID that owns the wallet used for the swap.
-
#amount_out_expected ⇒ String?
Expected destination token amount.
-
#amount_out_min ⇒ String?
Minimum destination amount after slippage.
-
#id ⇒ String
Swap ID.
- #object ⇒ Symbol, WhopSDK::Models::SwapCreateResponse::Object
-
#rate ⇒ String?
Quoted exchange rate used to create the swap.
-
#status ⇒ String
Initial swap status.
-
#to_chain ⇒ String?
Destination chain for the swap.
Instance Method Summary collapse
- #initialize(id:, account_id:, object:, status:, amount_out_expected: nil, amount_out_min: nil, rate: nil, to_chain: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_id:, object:, status:, amount_out_expected: nil, amount_out_min: nil, rate: nil, to_chain: nil) ⇒ Object
|
|
# File 'lib/whop_sdk/models/swap_create_response.rb', line 54
|
Instance Attribute Details
#account_id ⇒ String
Account ID that owns the wallet used for the swap.
17 |
# File 'lib/whop_sdk/models/swap_create_response.rb', line 17 required :account_id, String |
#amount_out_expected ⇒ String?
Expected destination token amount.
34 |
# File 'lib/whop_sdk/models/swap_create_response.rb', line 34 optional :amount_out_expected, String |
#amount_out_min ⇒ String?
Minimum destination amount after slippage.
40 |
# File 'lib/whop_sdk/models/swap_create_response.rb', line 40 optional :amount_out_min, String |
#id ⇒ String
Swap ID. Poll GET /swaps/:id for status.
11 |
# File 'lib/whop_sdk/models/swap_create_response.rb', line 11 required :id, String |
#object ⇒ Symbol, WhopSDK::Models::SwapCreateResponse::Object
22 |
# File 'lib/whop_sdk/models/swap_create_response.rb', line 22 required :object, enum: -> { WhopSDK::Models::SwapCreateResponse::Object } |
#rate ⇒ String?
Quoted exchange rate used to create the swap.
46 |
# File 'lib/whop_sdk/models/swap_create_response.rb', line 46 optional :rate, String |
#status ⇒ String
Initial swap status.
28 |
# File 'lib/whop_sdk/models/swap_create_response.rb', line 28 required :status, String |
#to_chain ⇒ String?
Destination chain for the swap.
52 |
# File 'lib/whop_sdk/models/swap_create_response.rb', line 52 optional :to_chain, String |
Instance Method Details
#to_hash ⇒ {
51 |
# File 'sig/whop_sdk/models/swap_create_response.rbs', line 51
def to_hash: -> {
|