Class: WhopSDK::Models::SwapListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::SwapListResponse::Data
- Defined in:
- lib/whop_sdk/models/swap_list_response.rb,
sig/whop_sdk/models/swap_list_response.rbs
Defined Under Namespace
Modules: Object
Instance Attribute Summary collapse
-
#account_id ⇒ String
Account ID that owns the wallet used for the swap.
-
#error ⇒ String?
Latest error returned for a failed swap.
-
#id ⇒ String
Swap ID.
- #object ⇒ Symbol, WhopSDK::Models::SwapListResponse::Data::Object
-
#status ⇒ String
Current swap status.
-
#tx_hashes ⇒ Array<String>
On-chain transaction hashes produced by the swap.
Instance Method Summary collapse
- #initialize(id:, account_id:, object:, status:, tx_hashes:, error: nil) ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, account_id:, object:, status:, tx_hashes:, error: nil) ⇒ Object
16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/whop_sdk/models/swap_list_response.rb', line 16 class Data < WhopSDK::Internal::Type::BaseModel # @!attribute id # Swap ID. # # @return [String] required :id, String # @!attribute account_id # Account ID that owns the wallet used for the swap. # # @return [String] required :account_id, String # @!attribute object # # @return [Symbol, WhopSDK::Models::SwapListResponse::Data::Object] required :object, enum: -> { WhopSDK::Models::SwapListResponse::Data::Object } # @!attribute status # Current swap status. # # @return [String] required :status, String # @!attribute tx_hashes # On-chain transaction hashes produced by the swap. # # @return [Array<String>] required :tx_hashes, WhopSDK::Internal::Type::ArrayOf[String] # @!attribute error # Latest error returned for a failed swap. # # @return [String, nil] optional :error, String, nil?: true # @!method initialize(id:, account_id:, object:, status:, tx_hashes:, error: nil) # @param id [String] Swap ID. # # @param account_id [String] Account ID that owns the wallet used for the swap. # # @param object [Symbol, WhopSDK::Models::SwapListResponse::Data::Object] # # @param status [String] Current swap status. # # @param tx_hashes [Array<String>] On-chain transaction hashes produced by the swap. # # @param error [String, nil] Latest error returned for a failed swap. # @see WhopSDK::Models::SwapListResponse::Data#object module Object extend WhopSDK::Internal::Type::Enum SWAP = :swap # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#account_id ⇒ String
Account ID that owns the wallet used for the swap.
27 |
# File 'lib/whop_sdk/models/swap_list_response.rb', line 27 required :account_id, String |
#error ⇒ String?
Latest error returned for a failed swap.
50 |
# File 'lib/whop_sdk/models/swap_list_response.rb', line 50 optional :error, String, nil?: true |
#id ⇒ String
Swap ID.
21 |
# File 'lib/whop_sdk/models/swap_list_response.rb', line 21 required :id, String |
#object ⇒ Symbol, WhopSDK::Models::SwapListResponse::Data::Object
32 |
# File 'lib/whop_sdk/models/swap_list_response.rb', line 32 required :object, enum: -> { WhopSDK::Models::SwapListResponse::Data::Object } |
#status ⇒ String
Current swap status.
38 |
# File 'lib/whop_sdk/models/swap_list_response.rb', line 38 required :status, String |
#tx_hashes ⇒ Array<String>
On-chain transaction hashes produced by the swap.
44 |
# File 'lib/whop_sdk/models/swap_list_response.rb', line 44 required :tx_hashes, WhopSDK::Internal::Type::ArrayOf[String] |
Instance Method Details
#to_hash ⇒ {
47 |
# File 'sig/whop_sdk/models/swap_list_response.rbs', line 47
def to_hash: -> {
|