Class: WhopSDK::Models::TopupCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::TopupCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/topup_create_params.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
The amount to add to the balance in the specified currency.
-
#company_id ⇒ String
The unique identifier of the company to add funds to, starting with ‘biz_’.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency for the top-up amount, such as ‘usd’.
-
#payment_method_id ⇒ String
The unique identifier of the stored payment method to charge for the top-up.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(amount:, company_id:, currency:, payment_method_id:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TopupCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, company_id:, currency:, payment_method_id:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::TopupCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/topup_create_params.rb', line 35
|
Instance Attribute Details
#amount ⇒ Float
The amount to add to the balance in the specified currency. For example, 50.00 for $50.00 USD.
15 |
# File 'lib/whop_sdk/models/topup_create_params.rb', line 15 required :amount, Float |
#company_id ⇒ String
The unique identifier of the company to add funds to, starting with ‘biz_’.
21 |
# File 'lib/whop_sdk/models/topup_create_params.rb', line 21 required :company_id, String |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency for the top-up amount, such as ‘usd’.
27 |
# File 'lib/whop_sdk/models/topup_create_params.rb', line 27 required :currency, enum: -> { WhopSDK::Currency } |
#payment_method_id ⇒ String
The unique identifier of the stored payment method to charge for the top-up.
33 |
# File 'lib/whop_sdk/models/topup_create_params.rb', line 33 required :payment_method_id, String |