Class: WhopSDK::Models::TopupCreateResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::TopupCreateResponse
- Defined in:
- lib/whop_sdk/models/topup_create_response.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The datetime the payment was created.
-
#currency ⇒ Symbol, ...
The available currencies on the platform.
-
#failure_message ⇒ String?
If the payment failed, the reason for the failure.
-
#id ⇒ String
The unique identifier for the payment.
-
#paid_at ⇒ Time?
The time at which this payment was successfully collected.
-
#status ⇒ Symbol, ...
The status of a receipt.
-
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
Instance Method Summary collapse
-
#initialize(id:, created_at:, currency:, failure_message:, paid_at:, status:, total:) ⇒ Object
constructor
Some parameter documentations has been truncated, see TopupCreateResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, currency:, failure_message:, paid_at:, status:, total:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::TopupCreateResponse for more details.
A payment represents a completed or attempted charge. Payments track the amount, status, currency, and payment method used.
|
|
# File 'lib/whop_sdk/models/topup_create_response.rb', line 50
|
Instance Attribute Details
#created_at ⇒ Time
The datetime the payment was created.
17 |
# File 'lib/whop_sdk/models/topup_create_response.rb', line 17 required :created_at, Time |
#currency ⇒ Symbol, ...
The available currencies on the platform
23 |
# File 'lib/whop_sdk/models/topup_create_response.rb', line 23 required :currency, enum: -> { WhopSDK::Currency }, nil?: true |
#failure_message ⇒ String?
If the payment failed, the reason for the failure.
29 |
# File 'lib/whop_sdk/models/topup_create_response.rb', line 29 required :failure_message, String, nil?: true |
#id ⇒ String
The unique identifier for the payment.
11 |
# File 'lib/whop_sdk/models/topup_create_response.rb', line 11 required :id, String |
#paid_at ⇒ Time?
The time at which this payment was successfully collected. Null if the payment has not yet succeeded. As a Unix timestamp.
36 |
# File 'lib/whop_sdk/models/topup_create_response.rb', line 36 required :paid_at, Time, nil?: true |
#status ⇒ Symbol, ...
The status of a receipt
42 |
# File 'lib/whop_sdk/models/topup_create_response.rb', line 42 required :status, enum: -> { WhopSDK::ReceiptStatus }, nil?: true |
#total ⇒ Float?
The total to show to the creator (excluding buyer fees).
48 |
# File 'lib/whop_sdk/models/topup_create_response.rb', line 48 required :total, Float, nil?: true |