Class: WhopSDK::Models::Transfer
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Transfer
- Defined in:
- lib/whop_sdk/models/transfer.rb
Defined Under Namespace
Modules: Destination, Origin
Instance Attribute Summary collapse
-
#amount ⇒ Float
The transfer amount in the currency specified by the currency field.
-
#created_at ⇒ Time
The datetime the credit transaction transfer was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency in which this transfer amount is denominated.
-
#destination ⇒ WhopSDK::Models::Transfer::Destination::User, ...
The entity receiving the transferred funds.
-
#destination_ledger_account_id ⇒ String
The unique identifier of the ledger account receiving the funds.
-
#fee_amount ⇒ Float?
The flat fee amount deducted from this transfer, in the transfer’s currency.
-
#id ⇒ String
The unique identifier for the credit transaction transfer.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs attached to this transfer.
-
#notes ⇒ String?
A free-text note attached to this transfer by the sender.
-
#origin ⇒ WhopSDK::Models::Transfer::Origin::User, ...
The entity that sent the transferred funds.
-
#origin_ledger_account_id ⇒ String
The unique identifier of the ledger account that sent the funds.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, route:, title:, typename: :Company) ⇒ Object
constructor
Some parameter documentations has been truncated, see Destination::Company for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, route:, title:, typename: :Company) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Transfer::Destination::Company for more details.
A company is a seller on Whop. Companies own products, manage members, and receive payouts.
|
|
# File 'lib/whop_sdk/models/transfer.rb', line 76
|
Instance Attribute Details
#amount ⇒ Float
The transfer amount in the currency specified by the currency field. For example, 10.43 represents $10.43 USD.
17 |
# File 'lib/whop_sdk/models/transfer.rb', line 17 required :amount, Float |
#created_at ⇒ Time
The datetime the credit transaction transfer was created.
23 |
# File 'lib/whop_sdk/models/transfer.rb', line 23 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency in which this transfer amount is denominated.
29 |
# File 'lib/whop_sdk/models/transfer.rb', line 29 required :currency, enum: -> { WhopSDK::Currency } |
#destination ⇒ WhopSDK::Models::Transfer::Destination::User, ...
The entity receiving the transferred funds.
35 |
# File 'lib/whop_sdk/models/transfer.rb', line 35 required :destination, union: -> { WhopSDK::Transfer::Destination } |
#destination_ledger_account_id ⇒ String
The unique identifier of the ledger account receiving the funds.
41 |
# File 'lib/whop_sdk/models/transfer.rb', line 41 required :destination_ledger_account_id, String |
#fee_amount ⇒ Float?
The flat fee amount deducted from this transfer, in the transfer’s currency. Null if no flat fee was applied.
48 |
# File 'lib/whop_sdk/models/transfer.rb', line 48 required :fee_amount, Float, nil?: true |
#id ⇒ String
The unique identifier for the credit transaction transfer.
10 |
# File 'lib/whop_sdk/models/transfer.rb', line 10 required :id, String |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs attached to this transfer. Maximum 50 keys, 500 characters per key, 5000 characters per value.
55 |
# File 'lib/whop_sdk/models/transfer.rb', line 55 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#notes ⇒ String?
A free-text note attached to this transfer by the sender. Null if no note was provided.
62 |
# File 'lib/whop_sdk/models/transfer.rb', line 62 required :notes, String, nil?: true |
#origin ⇒ WhopSDK::Models::Transfer::Origin::User, ...
The entity that sent the transferred funds.
68 |
# File 'lib/whop_sdk/models/transfer.rb', line 68 required :origin, union: -> { WhopSDK::Transfer::Origin } |
#origin_ledger_account_id ⇒ String
The unique identifier of the ledger account that sent the funds.
74 |
# File 'lib/whop_sdk/models/transfer.rb', line 74 required :origin_ledger_account_id, String |
Class Method Details
.variants ⇒ Array(WhopSDK::Models::Transfer::Destination::User, WhopSDK::Models::Transfer::Destination::Company)
|
|
# File 'lib/whop_sdk/models/transfer.rb', line 197
|