Class: WhopSDK::Models::Transfer::Origin::Company
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Transfer::Origin::Company
- Defined in:
- lib/whop_sdk/models/transfer.rb
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier for the company.
-
#route ⇒ String
The URL slug for the company’s store page (e.g., ‘pickaxe’ in whop.com/pickaxe).
-
#title ⇒ String
The display name of the company shown to customers.
-
#typename ⇒ Symbol, :Company
The typename of this object.
Instance Method Summary collapse
-
#initialize(id:, route:, title:, typename: :Company) ⇒ Object
constructor
Some parameter documentations has been truncated, see Company for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, route:, title:, typename: :Company) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Transfer::Origin::Company for more details.
A company is a seller on Whop. Companies own products, manage members, and receive payouts.
|
|
# File 'lib/whop_sdk/models/transfer.rb', line 278
|
Instance Attribute Details
#id ⇒ String
The unique identifier for the company.
258 |
# File 'lib/whop_sdk/models/transfer.rb', line 258 required :id, String |
#route ⇒ String
The URL slug for the company’s store page (e.g., ‘pickaxe’ in whop.com/pickaxe).
264 |
# File 'lib/whop_sdk/models/transfer.rb', line 264 required :route, String |
#title ⇒ String
The display name of the company shown to customers.
270 |
# File 'lib/whop_sdk/models/transfer.rb', line 270 required :title, String |
#typename ⇒ Symbol, :Company
The typename of this object
276 |
# File 'lib/whop_sdk/models/transfer.rb', line 276 required :typename, const: :Company |