Class: WhopSDK::Models::TransferCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::TransferCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/transfer_create_params.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
The amount to transfer in the specified currency.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the transfer amount, such as ‘usd’.
-
#destination_id ⇒ String
The identifier of the account receiving the funds.
-
#idempotence_key ⇒ String?
A unique key to prevent duplicate transfers.
-
#metadata ⇒ Hash{Symbol=>Object}?
A JSON object of custom metadata to attach to the transfer for tracking purposes.
-
#notes ⇒ String?
A short note describing the transfer, up to 50 characters.
-
#origin_id ⇒ String
The identifier of the account sending the funds.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(amount:, currency:, destination_id:, origin_id:, idempotence_key: nil, metadata: nil, notes: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TransferCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency:, destination_id:, origin_id:, idempotence_key: nil, metadata: nil, notes: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::TransferCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 57
|
Instance Attribute Details
#amount ⇒ Float
The amount to transfer in the specified currency. For example, 25.00 for $25.00 USD.
15 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 15 required :amount, Float |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the transfer amount, such as ‘usd’.
21 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 21 required :currency, enum: -> { WhopSDK::Currency } |
#destination_id ⇒ String
The identifier of the account receiving the funds. Accepts a user ID (‘user_xxx’), company ID (‘biz_xxx’), or ledger account ID (‘ldgr_xxx’).
28 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 28 required :destination_id, String |
#idempotence_key ⇒ String?
A unique key to prevent duplicate transfers. Use a UUID or similar unique string.
42 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 42 optional :idempotence_key, String, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
A JSON object of custom metadata to attach to the transfer for tracking purposes.
49 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 49 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#notes ⇒ String?
A short note describing the transfer, up to 50 characters.
55 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 55 optional :notes, String, nil?: true |
#origin_id ⇒ String
The identifier of the account sending the funds. Accepts a user ID (‘user_xxx’), company ID (‘biz_xxx’), or ledger account ID (‘ldgr_xxx’).
35 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 35 required :origin_id, String |