Class: WhopSDK::Models::TransferCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::TransferCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/transfer_create_params.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
The amount to withdraw.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency that is being withdrawn.
-
#destination_id ⇒ String
The ID of the destination account which will receive the funds (either a User ID, Company ID, or LedgerAccount ID).
-
#idempotence_key ⇒ String?
A unique key to ensure idempotence.
-
#metadata ⇒ Hash{Symbol=>Object}?
A hash of metadata to attach to the transfer.
-
#notes ⇒ String?
Notes for the transfer.
-
#origin_id ⇒ String
The ID of the origin account which will send the funds (either a User ID, Company ID, or LedgerAccount ID).
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(amount: , currency: , destination_id: , origin_id: , idempotence_key: nil, metadata: nil, notes: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TransferCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: , currency: , destination_id: , origin_id: , idempotence_key: nil, metadata: nil, notes: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::TransferCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 54
|
Instance Attribute Details
#amount ⇒ Float
The amount to withdraw
14 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 14 required :amount, Float |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency that is being withdrawn.
20 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 20 required :currency, enum: -> { WhopSDK::Currency } |
#destination_id ⇒ String
The ID of the destination account which will receive the funds (either a User ID, Company ID, or LedgerAccount ID)
27 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 27 required :destination_id, String |
#idempotence_key ⇒ String?
A unique key to ensure idempotence. Use a UUID or similar.
40 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 40 optional :idempotence_key, String, nil?: true |
#metadata ⇒ Hash{Symbol=>Object}?
A hash of metadata to attach to the transfer.
46 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 46 optional :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#notes ⇒ String?
Notes for the transfer. Maximum of 50 characters.
52 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 52 optional :notes, String, nil?: true |
#origin_id ⇒ String
The ID of the origin account which will send the funds (either a User ID, Company ID, or LedgerAccount ID)
34 |
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 34 required :origin_id, String |