Class: WhopSDK::Models::TransferCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/whop_sdk/models/transfer_create_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount: , currency: , destination_id: , origin_id: , idempotence_key: nil, notes: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::TransferCreateParams for more details.

Parameters:

  • amount (Float) (defaults to: )

    The amount to withdraw

  • currency (Symbol, WhopSDK::Models::Currency) (defaults to: )

    The currency that is being withdrawn.

  • destination_id (String) (defaults to: )

    The ID of the destination account which will receive the funds (either a User ID

  • origin_id (String) (defaults to: )

    The ID of the origin account which will send the funds (either a User ID, Compan

  • idempotence_key (String, nil) (defaults to: nil)

    A unique key to ensure idempotence. Use a UUID or similar.

  • notes (String, nil) (defaults to: nil)

    Notes for the transfer. Maximum of 50 characters.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/whop_sdk/models/transfer_create_params.rb', line 48

Instance Attribute Details

#amountFloat

The amount to withdraw

Returns:

  • (Float)


14
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 14

required :amount, Float

#currencySymbol, WhopSDK::Models::Currency

The currency that is being withdrawn.

Returns:



20
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 20

required :currency, enum: -> { WhopSDK::Currency }

#destination_idString

The ID of the destination account which will receive the funds (either a User ID, Company ID, or LedgerAccount ID)

Returns:

  • (String)


27
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 27

required :destination_id, String

#idempotence_keyString?

A unique key to ensure idempotence. Use a UUID or similar.

Returns:

  • (String, nil)


40
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 40

optional :idempotence_key, String, nil?: true

#notesString?

Notes for the transfer. Maximum of 50 characters.

Returns:

  • (String, nil)


46
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 46

optional :notes, String, nil?: true

#origin_idString

The ID of the origin account which will send the funds (either a User ID, Company ID, or LedgerAccount ID)

Returns:

  • (String)


34
# File 'lib/whop_sdk/models/transfer_create_params.rb', line 34

required :origin_id, String