Class: WhopSDK::Models::TransferListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::TransferListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/transfer_list_params.rb,
sig/whop_sdk/models/transfer_list_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
-
#before ⇒ String?
Cursor to fetch the page before (from page_info.start_cursor).
-
#created_after ⇒ String?
Only transfers created strictly after this ISO 8601 timestamp.
-
#created_before ⇒ String?
Only transfers created strictly before this ISO 8601 timestamp.
-
#destination_id ⇒ String?
Filter to transfers received by this account.
-
#direction ⇒ Symbol, ...
Sort direction.
-
#first ⇒ Integer?
Number of transfers to return from the start of the window.
-
#last ⇒ Integer?
Number of transfers to return from the end of the window.
-
#order ⇒ Symbol, ...
Sort column.
-
#origin_id ⇒ String?
Filter to transfers sent from this account.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(after: nil, before: nil, created_after: nil, created_before: nil, destination_id: nil, direction: nil, first: nil, last: nil, order: nil, origin_id: nil, request_options: {}) ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, created_after: nil, created_before: nil, destination_id: nil, direction: nil, first: nil, last: nil, order: nil, origin_id: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 70
|
Instance Attribute Details
#after ⇒ String?
Cursor to fetch the page after (from page_info.end_cursor).
14 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 14 optional :after, String |
#before ⇒ String?
Cursor to fetch the page before (from page_info.start_cursor).
20 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 20 optional :before, String |
#created_after ⇒ String?
Only transfers created strictly after this ISO 8601 timestamp.
26 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 26 optional :created_after, String |
#created_before ⇒ String?
Only transfers created strictly before this ISO 8601 timestamp.
32 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 32 optional :created_before, String |
#destination_id ⇒ String?
Filter to transfers received by this account.
38 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 38 optional :destination_id, String |
#direction ⇒ Symbol, ...
Sort direction. Defaults to desc.
44 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 44 optional :direction, enum: -> { WhopSDK::TransferListParams::Direction } |
#first ⇒ Integer?
Number of transfers to return from the start of the window.
50 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 50 optional :first, Integer |
#last ⇒ Integer?
Number of transfers to return from the end of the window.
56 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 56 optional :last, Integer |
#order ⇒ Symbol, ...
Sort column. Defaults to created_at.
62 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 62 optional :order, enum: -> { WhopSDK::TransferListParams::Order } |
#origin_id ⇒ String?
Filter to transfers sent from this account.
68 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 68 optional :origin_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 100
|
Instance Method Details
#to_hash ⇒ {
80 |
# File 'sig/whop_sdk/models/transfer_list_params.rbs', line 80
def to_hash: -> {
|