Class: WhopSDK::Models::TransferListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::TransferListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/transfer_list_params.rb
Overview
Defined Under Namespace
Modules: Order
Instance Attribute Summary collapse
-
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
-
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
-
#destination_id ⇒ String?
Filter transfers to only those that were sent to this destination account.
-
#direction ⇒ Symbol, ...
The direction of the sort.
-
#first ⇒ Integer?
Returns the first n elements from the list.
-
#last ⇒ Integer?
Returns the last n elements from the list.
-
#order ⇒ Symbol, ...
Which columns can be used to sort.
-
#origin_id ⇒ String?
Filter transfers to only those that were sent from this origin account.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(after: nil, before: nil, destination_id: nil, direction: nil, first: nil, last: nil, order: nil, origin_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see TransferListParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(after: nil, before: nil, destination_id: nil, direction: nil, first: nil, last: nil, order: nil, origin_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::TransferListParams for more details.
|
|
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 60
|
Instance Attribute Details
#after ⇒ String?
Returns the elements in the list that come after the specified cursor.
14 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 14 optional :after, String, nil?: true |
#before ⇒ String?
Returns the elements in the list that come before the specified cursor.
20 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 20 optional :before, String, nil?: true |
#destination_id ⇒ String?
Filter transfers to only those that were sent to this destination account. (user_xxx, biz_xxx, ldgr_xxx)
27 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 27 optional :destination_id, String, nil?: true |
#direction ⇒ Symbol, ...
The direction of the sort.
33 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 33 optional :direction, enum: -> { WhopSDK::Direction }, nil?: true |
#first ⇒ Integer?
Returns the first n elements from the list.
39 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 39 optional :first, Integer, nil?: true |
#last ⇒ Integer?
Returns the last n elements from the list.
45 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 45 optional :last, Integer, nil?: true |
#order ⇒ Symbol, ...
Which columns can be used to sort.
51 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 51 optional :order, enum: -> { WhopSDK::TransferListParams::Order }, nil?: true |
#origin_id ⇒ String?
Filter transfers to only those that were sent from this origin account. (user_xxx, biz_xxx, ldgr_xxx)
58 |
# File 'lib/whop_sdk/models/transfer_list_params.rb', line 58 optional :origin_id, String, nil?: true |