Class: WhopSDK::Models::TransferListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::TransferListResponse
- Defined in:
- lib/whop_sdk/models/transfer_list_response.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
The transfer amount in the currency specified by the currency field.
-
#created_at ⇒ Time
The datetime the credit transaction transfer was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency in which this transfer amount is denominated.
-
#destination_ledger_account_id ⇒ String
The unique identifier of the ledger account receiving the funds.
-
#fee_amount ⇒ Float?
The flat fee amount deducted from this transfer, in the transfer’s currency.
-
#id ⇒ String
The unique identifier for the credit transaction transfer.
-
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs attached to this transfer.
-
#notes ⇒ String?
A free-text note attached to this transfer by the sender.
-
#origin_ledger_account_id ⇒ String
The unique identifier of the ledger account that sent the funds.
Instance Method Summary collapse
-
#initialize(id:, amount:, created_at:, currency:, destination_ledger_account_id:, fee_amount:, metadata:, notes:, origin_ledger_account_id:) ⇒ Object
constructor
Some parameter documentations has been truncated, see TransferListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, amount:, created_at:, currency:, destination_ledger_account_id:, fee_amount:, metadata:, notes:, origin_ledger_account_id:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::TransferListResponse for more details.
A transfer of credit between two ledger accounts.
|
|
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 65
|
Instance Attribute Details
#amount ⇒ Float
The transfer amount in the currency specified by the currency field. For example, 10.43 represents $10.43 USD.
18 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 18 required :amount, Float |
#created_at ⇒ Time
The datetime the credit transaction transfer was created.
24 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 24 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency in which this transfer amount is denominated.
30 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 30 required :currency, enum: -> { WhopSDK::Currency } |
#destination_ledger_account_id ⇒ String
The unique identifier of the ledger account receiving the funds.
36 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 36 required :destination_ledger_account_id, String |
#fee_amount ⇒ Float?
The flat fee amount deducted from this transfer, in the transfer’s currency. Null if no flat fee was applied.
43 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 43 required :fee_amount, Float, nil?: true |
#id ⇒ String
The unique identifier for the credit transaction transfer.
11 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 11 required :id, String |
#metadata ⇒ Hash{Symbol=>Object}?
Custom key-value pairs attached to this transfer. Maximum 50 keys, 500 characters per key, 5000 characters per value.
50 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 50 required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true |
#notes ⇒ String?
A free-text note attached to this transfer by the sender. Null if no note was provided.
57 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 57 required :notes, String, nil?: true |
#origin_ledger_account_id ⇒ String
The unique identifier of the ledger account that sent the funds.
63 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 63 required :origin_ledger_account_id, String |