Class: WhopSDK::Models::TransferListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/transfer_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , amount: , created_at: , currency: , destination_ledger_account_id: , fee_amount: , metadata: , notes: , origin_ledger_account_id: ) ⇒ Object

Credit Transaction Transfer

Parameters:

  • id (String) (defaults to: )

    The unique identifier of the credit transaction transfer

  • amount (Float) (defaults to: )

    The amount of the credit transaction transfer

  • created_at (Time) (defaults to: )

    The timestamp when the credit transaction transfer was created

  • currency (Symbol, WhopSDK::Models::Currency) (defaults to: )

    The currency of the credit transaction transfer

  • destination_ledger_account_id (String) (defaults to: )

    The ID of the destination ledger account

  • fee_amount (Float, nil) (defaults to: )

    The decimal fee of the credit transaction transfer

  • metadata (Hash{Symbol=>Object}, nil) (defaults to: )

    A hash of metadata attached to the transfer

  • notes (String, nil) (defaults to: )

    The notes of the credit transaction transfer

  • origin_ledger_account_id (String) (defaults to: )

    The ID of the origin ledger account



# File 'lib/whop_sdk/models/transfer_list_response.rb', line 61

Instance Attribute Details

#amountFloat

The amount of the credit transaction transfer

Returns:

  • (Float)


17
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 17

required :amount, Float

#created_atTime

The timestamp when the credit transaction transfer was created

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 23

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The currency of the credit transaction transfer

Returns:



29
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 29

required :currency, enum: -> { WhopSDK::Currency }

#destination_ledger_account_idString

The ID of the destination ledger account

Returns:

  • (String)


35
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 35

required :destination_ledger_account_id, String

#fee_amountFloat?

The decimal fee of the credit transaction transfer

Returns:

  • (Float, nil)


41
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 41

required :fee_amount, Float, nil?: true

#idString

The unique identifier of the credit transaction transfer

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 11

required :id, String

#metadataHash{Symbol=>Object}?

A hash of metadata attached to the transfer

Returns:

  • (Hash{Symbol=>Object}, nil)


47
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 47

required :metadata, WhopSDK::Internal::Type::HashOf[WhopSDK::Internal::Type::Unknown], nil?: true

#notesString?

The notes of the credit transaction transfer

Returns:

  • (String, nil)


53
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 53

required :notes, String, nil?: true

#origin_ledger_account_idString

The ID of the origin ledger account

Returns:

  • (String)


59
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 59

required :origin_ledger_account_id, String