Class: WhopSDK::Models::TransferListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::TransferListResponse
- Defined in:
- lib/whop_sdk/models/transfer_list_response.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
The amount of the credit transaction transfer.
-
#created_at ⇒ Time
The timestamp when the credit transaction transfer was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the credit transaction transfer.
-
#destination_ledger_account_id ⇒ String
The ID of the destination ledger account.
-
#fee_amount ⇒ Float?
The decimal fee of the credit transaction transfer.
-
#id ⇒ String
The unique identifier of the credit transaction transfer.
-
#notes ⇒ String?
The notes of the credit transaction transfer.
-
#origin_ledger_account_id ⇒ String
The ID of the origin ledger account.
Instance Method Summary collapse
-
#initialize(id: , amount: , created_at: , currency: , destination_ledger_account_id: , fee_amount: , notes: , origin_ledger_account_id: ) ⇒ Object
constructor
Credit Transaction Transfer.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , amount: , created_at: , currency: , destination_ledger_account_id: , fee_amount: , notes: , origin_ledger_account_id: ) ⇒ Object
Credit Transaction Transfer
|
|
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 55
|
Instance Attribute Details
#amount ⇒ Float
The amount of the credit transaction transfer
17 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 17 required :amount, Float |
#created_at ⇒ Time
The timestamp when the credit transaction transfer was created
23 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 23 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the credit transaction transfer
29 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 29 required :currency, enum: -> { WhopSDK::Currency } |
#destination_ledger_account_id ⇒ String
The ID of the destination ledger account
35 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 35 required :destination_ledger_account_id, String |
#fee_amount ⇒ Float?
The decimal fee of the credit transaction transfer
41 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 41 required :fee_amount, Float, nil?: true |
#id ⇒ String
The unique identifier of the credit transaction transfer
11 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 11 required :id, String |
#notes ⇒ String?
The notes of the credit transaction transfer
47 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 47 required :notes, String, nil?: true |
#origin_ledger_account_id ⇒ String
The ID of the origin ledger account
53 |
# File 'lib/whop_sdk/models/transfer_list_response.rb', line 53 required :origin_ledger_account_id, String |