Class: WhopSDK::Models::User::EarningsUsd
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::User::EarningsUsd
- Defined in:
- lib/whop_sdk/models/user.rb,
sig/whop_sdk/models/user.rbs
Overview
Defined Under Namespace
Classes: OwnedAccounts, Personal, Total
Instance Attribute Summary collapse
-
#first_earned_at ⇒ String?
The first time the user earned gross income, as an ISO 8601 timestamp.
-
#owned_accounts ⇒ WhopSDK::Models::User::EarningsUsd::OwnedAccounts
Gross income from accounts the user owns or is owner-authorized on.
-
#personal ⇒ WhopSDK::Models::User::EarningsUsd::Personal
Gross income from the user's personal wallet.
-
#total ⇒ WhopSDK::Models::User::EarningsUsd::Total
Gross income from the user's personal wallet plus accounts they own or are owner-authorized on.
Instance Method Summary collapse
-
#initialize(last_24_hours:, last_30_days:, last_7_days:, lifetime:) ⇒ Object
constructor
Gross income from the user's personal wallet.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(last_24_hours:, last_30_days:, last_7_days:, lifetime:) ⇒ Object
Gross income from the user's personal wallet.
|
|
# File 'lib/whop_sdk/models/user.rb', line 196
|
Instance Attribute Details
#first_earned_at ⇒ String?
The first time the user earned gross income, as an ISO 8601 timestamp.
175 |
# File 'lib/whop_sdk/models/user.rb', line 175 required :first_earned_at, String, nil?: true |
#owned_accounts ⇒ WhopSDK::Models::User::EarningsUsd::OwnedAccounts
Gross income from accounts the user owns or is owner-authorized on.
181 |
# File 'lib/whop_sdk/models/user.rb', line 181 required :owned_accounts, -> { WhopSDK::User::EarningsUsd::OwnedAccounts } |
#personal ⇒ WhopSDK::Models::User::EarningsUsd::Personal
Gross income from the user's personal wallet.
187 |
# File 'lib/whop_sdk/models/user.rb', line 187 required :personal, -> { WhopSDK::User::EarningsUsd::Personal } |
#total ⇒ WhopSDK::Models::User::EarningsUsd::Total
Gross income from the user's personal wallet plus accounts they own or are owner-authorized on.
194 |
# File 'lib/whop_sdk/models/user.rb', line 194 required :total, -> { WhopSDK::User::EarningsUsd::Total } |
Instance Method Details
#to_hash ⇒ {
137 |
# File 'sig/whop_sdk/models/user.rbs', line 137
def to_hash: -> {
|