Class: WhopSDK::Models::UserRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::UserRetrieveResponse
- Defined in:
- lib/whop_sdk/models/user_retrieve_response.rb
Overview
Defined Under Namespace
Classes: ProfilePicture
Instance Attribute Summary collapse
-
#bio ⇒ String?
The user’s bio.
-
#created_at ⇒ Time
When the user was created.
-
#id ⇒ String
The internal ID of the user.
-
#name ⇒ String?
The name of the user from their Whop account.
-
#profile_picture ⇒ WhopSDK::Models::UserRetrieveResponse::ProfilePicture?
The user’s profile picture.
-
#username ⇒ String
The username of the user from their Whop account.
Instance Method Summary collapse
-
#initialize(id: , bio: , created_at: , name: , profile_picture: , username: ) ⇒ Object
constructor
An object representing a (sanitized) user of the site.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , bio: , created_at: , name: , profile_picture: , username: ) ⇒ Object
An object representing a (sanitized) user of the site.
|
|
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 43
|
Instance Attribute Details
#bio ⇒ String?
The user’s bio
17 |
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 17 required :bio, String, nil?: true |
#created_at ⇒ Time
When the user was created.
23 |
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 23 required :created_at, Time |
#id ⇒ String
The internal ID of the user.
11 |
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 11 required :id, String |
#name ⇒ String?
The name of the user from their Whop account.
29 |
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 29 required :name, String, nil?: true |
#profile_picture ⇒ WhopSDK::Models::UserRetrieveResponse::ProfilePicture?
The user’s profile picture
35 |
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 35 required :profile_picture, -> { WhopSDK::Models::UserRetrieveResponse::ProfilePicture }, nil?: true |
#username ⇒ String
The username of the user from their Whop account.
41 |
# File 'lib/whop_sdk/models/user_retrieve_response.rb', line 41 required :username, String |