Class: WhopSDK::Models::UserUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::UserUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/user_update_params.rb
Overview
Defined Under Namespace
Classes: ProfilePicture
Instance Attribute Summary collapse
-
#bio ⇒ String?
A short biography displayed on the user’s public profile.
-
#company_id ⇒ String?
When provided, updates the user’s profile overrides for this company instead of the global profile.
- #id ⇒ String
-
#name ⇒ String?
The user’s display name shown on their public profile.
-
#profile_picture ⇒ WhopSDK::Models::UserUpdateParams::ProfilePicture?
The user’s profile picture image attachment.
-
#username ⇒ String?
The user’s unique username.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from WhopSDK::Internal::Type::BaseModel
Instance Attribute Details
#bio ⇒ String?
A short biography displayed on the user’s public profile.
19 |
# File 'lib/whop_sdk/models/user_update_params.rb', line 19 optional :bio, String, nil?: true |
#company_id ⇒ String?
When provided, updates the user’s profile overrides for this company instead of the global profile. Pass name and profile_picture to set overrides, or null to clear them.
27 |
# File 'lib/whop_sdk/models/user_update_params.rb', line 27 optional :company_id, String, nil?: true |
#id ⇒ String
13 |
# File 'lib/whop_sdk/models/user_update_params.rb', line 13 required :id, String |
#name ⇒ String?
The user’s display name shown on their public profile. Maximum 100 characters.
33 |
# File 'lib/whop_sdk/models/user_update_params.rb', line 33 optional :name, String, nil?: true |
#profile_picture ⇒ WhopSDK::Models::UserUpdateParams::ProfilePicture?
The user’s profile picture image attachment.
39 |
# File 'lib/whop_sdk/models/user_update_params.rb', line 39 optional :profile_picture, -> { WhopSDK::UserUpdateParams::ProfilePicture }, nil?: true |
#username ⇒ String?
The user’s unique username. Alphanumeric characters and hyphens only. Maximum 42 characters.
46 |
# File 'lib/whop_sdk/models/user_update_params.rb', line 46 optional :username, String, nil?: true |