Class: WhopSDK::Models::VerificationCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::VerificationCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/verification_create_params.rb,
sig/whop_sdk/models/verification_create_params.rbs
Overview
Defined Under Namespace
Modules: Body
Instance Attribute Summary collapse
-
#account_id ⇒ String
Account or user ID whose identity you want to verify.
-
#body ⇒ WhopSDK::Models::VerificationCreateParams::Body::Individual, WhopSDK::Models::VerificationCreateParams::Body::Business
Request body for an individual (KYC) verification.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(account_id:, body:, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see VerificationCreateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id:, body:, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::VerificationCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/verification_create_params.rb', line 30
|
Instance Attribute Details
#account_id ⇒ String
Account or user ID whose identity you want to verify. Use a biz_ account ID
for account verifications, or the caller's user_ ID for personal verification.
15 |
# File 'lib/whop_sdk/models/verification_create_params.rb', line 15 required :account_id, String |
#body ⇒ WhopSDK::Models::VerificationCreateParams::Body::Individual, WhopSDK::Models::VerificationCreateParams::Body::Business
Request body for an individual (KYC) verification. Omit kind or set it to
individual. KYC is required to pay out funds and is a prerequisite for Whop
Card access. Accepting payments does not require verification until a business
reaches $5000 in payments.
Add business_name, business_structure, and country of incorporation if the
individual operates under a business entity. This enables payouts to be received
by a business bank account.
28 |
# File 'lib/whop_sdk/models/verification_create_params.rb', line 28 required :body, union: -> { WhopSDK::VerificationCreateParams::Body } |
Instance Method Details
#to_hash ⇒ {
24 |
# File 'sig/whop_sdk/models/verification_create_params.rbs', line 24
def to_hash: -> {
|