Class: WhopSDK::Models::VerificationCreateResponse::RequestedInformation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::VerificationCreateResponse::RequestedInformation
- Defined in:
- lib/whop_sdk/models/verification_create_response.rb,
sig/whop_sdk/models/verification_create_response.rbs
Defined Under Namespace
Classes: RequestedFile
Instance Attribute Summary collapse
-
#description ⇒ String?
Additional instructions for this requested item, or
null. -
#error_message ⇒ String?
Reason a previously submitted value was rejected.
-
#field ⇒ String?
Stable field key, such as
ssnorbusiness_description. -
#id ⇒ String?
Requested information item ID, prefixed
inrqi_. -
#label ⇒ String?
Human-readable label for the field, such as
Social Security Number. -
#options ⇒ Array<String>?
Allowed values for a
selectfield (e.g. account_type, business_structure) — the submitted value must be one of these; empty for other types. -
#requested_files ⇒ Array<WhopSDK::Models::VerificationCreateResponse::RequestedInformation::RequestedFile>?
Document upload slots for this item.
-
#type ⇒ String?
Input type expected for this item:
text,date,phone,address,files, orselect.
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
207 |
# File 'sig/whop_sdk/models/verification_create_response.rbs', line 207
def initialize: (
|
Instance Attribute Details
#description ⇒ String?
Additional instructions for this requested item, or null.
217 |
# File 'lib/whop_sdk/models/verification_create_response.rb', line 217 optional :description, String, nil?: true |
#error_message ⇒ String?
Reason a previously submitted value was rejected. null if no submitted value
has been rejected.
224 |
# File 'lib/whop_sdk/models/verification_create_response.rb', line 224 optional :error_message, String, nil?: true |
#field ⇒ String?
Stable field key, such as ssn or business_description.
230 |
# File 'lib/whop_sdk/models/verification_create_response.rb', line 230 optional :field, String |
#id ⇒ String?
Requested information item ID, prefixed inrqi_. Include this ID when
submitting an answer.
211 |
# File 'lib/whop_sdk/models/verification_create_response.rb', line 211 optional :id, String |
#label ⇒ String?
Human-readable label for the field, such as Social Security Number.
236 |
# File 'lib/whop_sdk/models/verification_create_response.rb', line 236 optional :label, String |
#options ⇒ Array<String>?
Allowed values for a select field (e.g. account_type, business_structure) —
the submitted value must be one of these; empty for other types.
243 |
# File 'lib/whop_sdk/models/verification_create_response.rb', line 243 optional :options, WhopSDK::Internal::Type::ArrayOf[String] |
#requested_files ⇒ Array<WhopSDK::Models::VerificationCreateResponse::RequestedInformation::RequestedFile>?
Document upload slots for this item. Present when type is files; upload one
file for each required slot and include the slot's category when submitting
the answer.
251 252 |
# File 'lib/whop_sdk/models/verification_create_response.rb', line 251 optional :requested_files, -> { WhopSDK::Internal::Type::ArrayOf[WhopSDK::Models::VerificationCreateResponse::RequestedInformation::RequestedFile] } |
#type ⇒ String?
Input type expected for this item: text, date, phone, address, files,
or select.
259 |
# File 'lib/whop_sdk/models/verification_create_response.rb', line 259 optional :type, String, nil?: true |
Instance Method Details
#to_hash ⇒ {
218 |
# File 'sig/whop_sdk/models/verification_create_response.rbs', line 218
def to_hash: -> {
|