Class: WhopSDK::Models::Withdrawal::PayoutToken

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/withdrawal.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, destination_currency_code:, nickname:, payer_name:) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::Withdrawal::PayoutToken for more details.

The saved payout destination used for this withdrawal (e.g., a bank account or PayPal address). Null if no payout token was used.

Parameters:

  • id (String)

    The unique identifier for the payout token.

  • created_at (Time)

    The datetime the payout token was created.

  • destination_currency_code (String)

    The three-letter ISO currency code that payouts are delivered in for this destin

  • nickname (String, nil)

    A user-defined label to help identify this payout destination. Not sent to the p

  • payer_name (String, nil)

    The legal name of the account holder receiving payouts. Null if not provided.



# File 'lib/whop_sdk/models/withdrawal.rb', line 263

Instance Attribute Details

#created_atTime

The datetime the payout token was created.

Returns:

  • (Time)


241
# File 'lib/whop_sdk/models/withdrawal.rb', line 241

required :created_at, Time

#destination_currency_codeString

The three-letter ISO currency code that payouts are delivered in for this destination.

Returns:

  • (String)


248
# File 'lib/whop_sdk/models/withdrawal.rb', line 248

required :destination_currency_code, String

#idString

The unique identifier for the payout token.

Returns:

  • (String)


235
# File 'lib/whop_sdk/models/withdrawal.rb', line 235

required :id, String

#nicknameString?

A user-defined label to help identify this payout destination. Not sent to the provider. Null if no nickname has been set.

Returns:

  • (String, nil)


255
# File 'lib/whop_sdk/models/withdrawal.rb', line 255

required :nickname, String, nil?: true

#payer_nameString?

The legal name of the account holder receiving payouts. Null if not provided.

Returns:

  • (String, nil)


261
# File 'lib/whop_sdk/models/withdrawal.rb', line 261

required :payer_name, String, nil?: true