Class: WhopSDK::Models::Withdrawal::PayoutToken
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Withdrawal::PayoutToken
- Defined in:
- lib/whop_sdk/models/withdrawal.rb
Overview
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The datetime the payout token was created.
-
#destination_currency_code ⇒ String
The three-letter ISO currency code that payouts are delivered in for this destination.
-
#id ⇒ String
The unique identifier for the payout token.
-
#nickname ⇒ String?
A user-defined label to help identify this payout destination.
-
#payer_name ⇒ String?
The legal name of the account holder receiving payouts.
Instance Method Summary collapse
-
#initialize(id:, created_at:, destination_currency_code:, nickname:, payer_name:) ⇒ Object
constructor
Some parameter documentations has been truncated, see PayoutToken for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, destination_currency_code:, nickname:, payer_name:) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Withdrawal::PayoutToken for more details.
The saved payout destination used for this withdrawal (e.g., a bank account or PayPal address). Null if no payout token was used.
|
|
# File 'lib/whop_sdk/models/withdrawal.rb', line 263
|
Instance Attribute Details
#created_at ⇒ Time
The datetime the payout token was created.
241 |
# File 'lib/whop_sdk/models/withdrawal.rb', line 241 required :created_at, Time |
#destination_currency_code ⇒ String
The three-letter ISO currency code that payouts are delivered in for this destination.
248 |
# File 'lib/whop_sdk/models/withdrawal.rb', line 248 required :destination_currency_code, String |
#id ⇒ String
The unique identifier for the payout token.
235 |
# File 'lib/whop_sdk/models/withdrawal.rb', line 235 required :id, String |
#nickname ⇒ String?
A user-defined label to help identify this payout destination. Not sent to the provider. Null if no nickname has been set.
255 |
# File 'lib/whop_sdk/models/withdrawal.rb', line 255 required :nickname, String, nil?: true |
#payer_name ⇒ String?
The legal name of the account holder receiving payouts. Null if not provided.
261 |
# File 'lib/whop_sdk/models/withdrawal.rb', line 261 required :payer_name, String, nil?: true |