Class: WhopSDK::Models::WithdrawalCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::WithdrawalCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/withdrawal_create_params.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
The amount to withdraw in the specified currency.
-
#company_id ⇒ String
The ID of the company to withdraw from.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency that is being withdrawn.
-
#payout_method_id ⇒ String?
The ID of the payout method to use for the withdrawal.
-
#platform_covers_fees ⇒ Boolean?
Whether the platform covers the payout fees instead of the connected account.
-
#statement_descriptor ⇒ String?
Custom statement descriptor for the withdrawal.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(amount:, company_id:, currency:, payout_method_id: nil, platform_covers_fees: nil, statement_descriptor: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see WithdrawalCreateParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, company_id:, currency:, payout_method_id: nil, platform_covers_fees: nil, statement_descriptor: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::WithdrawalCreateParams for more details.
|
|
# File 'lib/whop_sdk/models/withdrawal_create_params.rb', line 47
|
Instance Attribute Details
#amount ⇒ Float
The amount to withdraw in the specified currency
14 |
# File 'lib/whop_sdk/models/withdrawal_create_params.rb', line 14 required :amount, Float |
#company_id ⇒ String
The ID of the company to withdraw from.
20 |
# File 'lib/whop_sdk/models/withdrawal_create_params.rb', line 20 required :company_id, String |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency that is being withdrawn.
26 |
# File 'lib/whop_sdk/models/withdrawal_create_params.rb', line 26 required :currency, enum: -> { WhopSDK::Currency } |
#payout_method_id ⇒ String?
The ID of the payout method to use for the withdrawal.
32 |
# File 'lib/whop_sdk/models/withdrawal_create_params.rb', line 32 optional :payout_method_id, String, nil?: true |
#platform_covers_fees ⇒ Boolean?
Whether the platform covers the payout fees instead of the connected account.
38 |
# File 'lib/whop_sdk/models/withdrawal_create_params.rb', line 38 optional :platform_covers_fees, WhopSDK::Internal::Type::Boolean, nil?: true |
#statement_descriptor ⇒ String?
Custom statement descriptor for the withdrawal. Must be between 5 and 22 characters and contain only alphanumeric characters.
45 |
# File 'lib/whop_sdk/models/withdrawal_create_params.rb', line 45 optional :statement_descriptor, String, nil?: true |