Class: WhopSDK::Models::WithdrawalListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/withdrawal_list_response.rb

Overview

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , amount: , created_at: , currency: , fee_amount: , fee_type: , speed: , status: , withdrawal_type: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::WithdrawalListResponse for more details.

A withdrawal request.

Parameters:

  • id (String) (defaults to: )

    Internal ID of the withdrawal request.

  • amount (Float) (defaults to: )

    How much money was attempted to be withdrawn, in a float type.

  • created_at (Time) (defaults to: )

    When the withdrawal request was created.

  • currency (Symbol, WhopSDK::Models::Currency) (defaults to: )

    The currency of the withdrawal request.

  • fee_amount (Float) (defaults to: )

    The fee amount that was charged for the withdrawal. This is in the same currency

  • fee_type (Symbol, WhopSDK::Models::WithdrawalFeeTypes, nil) (defaults to: )

    The different fee types for a withdrawal.

  • speed (Symbol, WhopSDK::Models::WithdrawalSpeeds) (defaults to: )

    The speed of the withdrawal.

  • status (Symbol, WhopSDK::Models::WithdrawalStatus) (defaults to: )

    Status of the withdrawal.

  • withdrawal_type (Symbol, WhopSDK::Models::WithdrawalTypes) (defaults to: )

    The type of withdrawal.



# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 62

Instance Attribute Details

#amountFloat

How much money was attempted to be withdrawn, in a float type.

Returns:

  • (Float)


17
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 17

required :amount, Float

#created_atTime

When the withdrawal request was created.

Returns:

  • (Time)


23
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 23

required :created_at, Time

#currencySymbol, WhopSDK::Models::Currency

The currency of the withdrawal request.

Returns:



29
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 29

required :currency, enum: -> { WhopSDK::Currency }

#fee_amountFloat

The fee amount that was charged for the withdrawal. This is in the same currency as the withdrawal amount.

Returns:

  • (Float)


36
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 36

required :fee_amount, Float

#fee_typeSymbol, ...

The different fee types for a withdrawal.

Returns:



42
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 42

required :fee_type, enum: -> { WhopSDK::WithdrawalFeeTypes }, nil?: true

#idString

Internal ID of the withdrawal request.

Returns:

  • (String)


11
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 11

required :id, String

#speedSymbol, WhopSDK::Models::WithdrawalSpeeds

The speed of the withdrawal.



48
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 48

required :speed, enum: -> { WhopSDK::WithdrawalSpeeds }

#statusSymbol, WhopSDK::Models::WithdrawalStatus

Status of the withdrawal.



54
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 54

required :status, enum: -> { WhopSDK::WithdrawalStatus }

#withdrawal_typeSymbol, WhopSDK::Models::WithdrawalTypes

The type of withdrawal.



60
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 60

required :withdrawal_type, enum: -> { WhopSDK::WithdrawalTypes }