Class: WhopSDK::Models::WithdrawalListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::WithdrawalListResponse
- Defined in:
- lib/whop_sdk/models/withdrawal_list_response.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
How much money was attempted to be withdrawn, in a float type.
-
#created_at ⇒ Time
When the withdrawal request was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the withdrawal request.
-
#fee_amount ⇒ Float
The fee amount that was charged for the withdrawal.
-
#fee_type ⇒ Symbol, ...
The different fee types for a withdrawal.
-
#id ⇒ String
Internal ID of the withdrawal request.
-
#speed ⇒ Symbol, WhopSDK::Models::WithdrawalSpeeds
The speed of the withdrawal.
-
#status ⇒ Symbol, WhopSDK::Models::WithdrawalStatus
Status of the withdrawal.
-
#withdrawal_type ⇒ Symbol, WhopSDK::Models::WithdrawalTypes
The type of withdrawal.
Instance Method Summary collapse
-
#initialize(id: , amount: , created_at: , currency: , fee_amount: , fee_type: , speed: , status: , withdrawal_type: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see WithdrawalListResponse for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , amount: , created_at: , currency: , fee_amount: , fee_type: , speed: , status: , withdrawal_type: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::WithdrawalListResponse for more details.
A withdrawal request.
|
|
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 62
|
Instance Attribute Details
#amount ⇒ Float
How much money was attempted to be withdrawn, in a float type.
17 |
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 17 required :amount, Float |
#created_at ⇒ Time
When the withdrawal request was created.
23 |
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 23 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the withdrawal request.
29 |
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 29 required :currency, enum: -> { WhopSDK::Currency } |
#fee_amount ⇒ Float
The fee amount that was charged for the withdrawal. This is in the same currency as the withdrawal amount.
36 |
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 36 required :fee_amount, Float |
#fee_type ⇒ Symbol, ...
The different fee types for a withdrawal.
42 |
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 42 required :fee_type, enum: -> { WhopSDK::WithdrawalFeeTypes }, nil?: true |
#id ⇒ String
Internal ID of the withdrawal request.
11 |
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 11 required :id, String |
#speed ⇒ Symbol, WhopSDK::Models::WithdrawalSpeeds
The speed of the withdrawal.
48 |
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 48 required :speed, enum: -> { WhopSDK::WithdrawalSpeeds } |
#status ⇒ Symbol, WhopSDK::Models::WithdrawalStatus
Status of the withdrawal.
54 |
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 54 required :status, enum: -> { WhopSDK::WithdrawalStatus } |
#withdrawal_type ⇒ Symbol, WhopSDK::Models::WithdrawalTypes
The type of withdrawal.
60 |
# File 'lib/whop_sdk/models/withdrawal_list_response.rb', line 60 required :withdrawal_type, enum: -> { WhopSDK::WithdrawalTypes } |