Class: WhopSDK::Models::WithdrawalRetrieveResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::WithdrawalRetrieveResponse
- Defined in:
- lib/whop_sdk/models/withdrawal_retrieve_response.rb
Overview
Defined Under Namespace
Modules: ErrorCode Classes: LedgerAccount, PayoutToken
Instance Attribute Summary collapse
-
#amount ⇒ Float
How much money was attempted to be withdrawn, in a float type.
-
#created_at ⇒ Time
When the withdrawal request was created.
-
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the withdrawal request.
-
#error_code ⇒ Symbol, ...
The different error codes a payout can be in.
-
#error_message ⇒ String?
The error message for the withdrawal, if any.
-
#estimated_availability ⇒ Time?
The estimated availability date for the withdrawal, if any.
-
#fee_amount ⇒ Float
The fee amount that was charged for the withdrawal.
-
#fee_type ⇒ Symbol, ...
The different fee types for a withdrawal.
-
#id ⇒ String
Internal ID of the withdrawal request.
-
#ledger_account ⇒ WhopSDK::Models::WithdrawalRetrieveResponse::LedgerAccount
The ledger account associated with the withdrawal.
-
#payout_token ⇒ WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken?
The payout token used for the withdrawal, if applicable.
-
#speed ⇒ Symbol, WhopSDK::Models::WithdrawalSpeeds
The speed of the withdrawal.
-
#status ⇒ Symbol, WhopSDK::Models::WithdrawalStatus
Status of the withdrawal.
-
#trace_code ⇒ String?
The trace code for the payout, if applicable.
-
#withdrawal_type ⇒ Symbol, WhopSDK::Models::WithdrawalTypes
The type of withdrawal.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id: , company_id: ) ⇒ Object
constructor
The ledger account associated with the withdrawal.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , company_id: ) ⇒ Object
The ledger account associated with the withdrawal.
|
|
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 99
|
Instance Attribute Details
#amount ⇒ Float
How much money was attempted to be withdrawn, in a float type.
17 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 17 required :amount, Float |
#created_at ⇒ Time
When the withdrawal request was created.
23 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 23 required :created_at, Time |
#currency ⇒ Symbol, WhopSDK::Models::Currency
The currency of the withdrawal request.
29 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 29 required :currency, enum: -> { WhopSDK::Currency } |
#error_code ⇒ Symbol, ...
The different error codes a payout can be in.
35 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 35 required :error_code, enum: -> { WhopSDK::Models::WithdrawalRetrieveResponse::ErrorCode }, nil?: true |
#error_message ⇒ String?
The error message for the withdrawal, if any.
41 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 41 required :error_message, String, nil?: true |
#estimated_availability ⇒ Time?
The estimated availability date for the withdrawal, if any.
47 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 47 required :estimated_availability, Time, nil?: true |
#fee_amount ⇒ Float
The fee amount that was charged for the withdrawal. This is in the same currency as the withdrawal amount.
54 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 54 required :fee_amount, Float |
#fee_type ⇒ Symbol, ...
The different fee types for a withdrawal.
60 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 60 required :fee_type, enum: -> { WhopSDK::WithdrawalFeeTypes }, nil?: true |
#id ⇒ String
Internal ID of the withdrawal request.
11 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 11 required :id, String |
#ledger_account ⇒ WhopSDK::Models::WithdrawalRetrieveResponse::LedgerAccount
The ledger account associated with the withdrawal.
66 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 66 required :ledger_account, -> { WhopSDK::Models::WithdrawalRetrieveResponse::LedgerAccount } |
#payout_token ⇒ WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken?
The payout token used for the withdrawal, if applicable.
72 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 72 required :payout_token, -> { WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken }, nil?: true |
#speed ⇒ Symbol, WhopSDK::Models::WithdrawalSpeeds
The speed of the withdrawal.
78 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 78 required :speed, enum: -> { WhopSDK::WithdrawalSpeeds } |
#status ⇒ Symbol, WhopSDK::Models::WithdrawalStatus
Status of the withdrawal.
84 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 84 required :status, enum: -> { WhopSDK::WithdrawalStatus } |
#trace_code ⇒ String?
The trace code for the payout, if applicable. Provided on ACH transactions when available.
91 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 91 required :trace_code, String, nil?: true |
#withdrawal_type ⇒ Symbol, WhopSDK::Models::WithdrawalTypes
The type of withdrawal.
97 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 97 required :withdrawal_type, enum: -> { WhopSDK::WithdrawalTypes } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 187
|