Class: WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/whop_sdk/models/withdrawal_retrieve_response.rb

Overview

See Also:

Defined Under Namespace

Modules: Status

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id: , created_at: , destination_currency_code: , nickname: , status: ) ⇒ Object

Some parameter documentations has been truncated, see WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken for more details.

The payout token used for the withdrawal, if applicable.

Parameters:

  • id (String) (defaults to: )

    The ID of the payout token

  • created_at (Time) (defaults to: )

    The date and time the payout token was created

  • destination_currency_code (String) (defaults to: )

    The currency code of the payout destination. This is the currency that payouts w

  • nickname (String, nil) (defaults to: )

    An optional nickname for the payout token to help the user identify it. This is

  • status (Symbol, WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken::Status) (defaults to: )

    The status of the payout token.



# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 288

Instance Attribute Details

#created_atTime

The date and time the payout token was created

Returns:

  • (Time)


266
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 266

required :created_at, Time

#destination_currency_codeString

The currency code of the payout destination. This is the currency that payouts will be made in for this token.

Returns:

  • (String)


273
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 273

required :destination_currency_code, String

#idString

The ID of the payout token

Returns:

  • (String)


260
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 260

required :id, String

#nicknameString?

An optional nickname for the payout token to help the user identify it. This is not used by the provider and is only for the user’s reference.

Returns:

  • (String, nil)


280
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 280

required :nickname, String, nil?: true

#statusSymbol, WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken::Status

The status of the payout token.



286
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 286

required :status, enum: -> { WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken::Status }