Class: WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken
- Defined in:
- lib/whop_sdk/models/withdrawal_retrieve_response.rb
Overview
Defined Under Namespace
Modules: Status
Instance Attribute Summary collapse
-
#created_at ⇒ Time
The date and time the payout token was created.
-
#destination_currency_code ⇒ String
The currency code of the payout destination.
-
#id ⇒ String
The ID of the payout token.
-
#nickname ⇒ String?
An optional nickname for the payout token to help the user identify it.
-
#status ⇒ Symbol, WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken::Status
The status of the payout token.
Instance Method Summary collapse
-
#initialize(id: , created_at: , destination_currency_code: , nickname: , status: ) ⇒ Object
constructor
Some parameter documentations has been truncated, see PayoutToken for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id: , created_at: , destination_currency_code: , nickname: , status: ) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken for more details.
The payout token used for the withdrawal, if applicable.
|
|
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 288
|
Instance Attribute Details
#created_at ⇒ Time
The date and time the payout token was created
266 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 266 required :created_at, Time |
#destination_currency_code ⇒ String
The currency code of the payout destination. This is the currency that payouts will be made in for this token.
273 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 273 required :destination_currency_code, String |
#id ⇒ String
The ID of the payout token
260 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 260 required :id, String |
#nickname ⇒ String?
An optional nickname for the payout token to help the user identify it. This is not used by the provider and is only for the user’s reference.
280 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 280 required :nickname, String, nil?: true |
#status ⇒ Symbol, WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken::Status
The status of the payout token.
286 |
# File 'lib/whop_sdk/models/withdrawal_retrieve_response.rb', line 286 required :status, enum: -> { WhopSDK::Models::WithdrawalRetrieveResponse::PayoutToken::Status } |