Class: WhopSDK::Models::Workforce::BountyListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- WhopSDK::Models::Workforce::BountyListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/whop_sdk/models/workforce/bounty_list_params.rb,
sig/whop_sdk/models/workforce/bounty_list_params.rbs
Overview
Defined Under Namespace
Modules: Direction, Order, Status
Instance Attribute Summary collapse
-
#account_id ⇒ String?
Scope the list to this account (
biz_tag). -
#after ⇒ String?
Cursor to paginate forwards from.
-
#before ⇒ String?
Cursor to paginate backwards from.
-
#created_after ⇒ String?
Only bounties created after this ISO 8601 timestamp.
-
#created_before ⇒ String?
Only bounties created before this ISO 8601 timestamp.
-
#direction ⇒ Symbol, ...
Sort direction.
-
#first ⇒ Integer?
Number of bounties to return from the start of the window.
-
#last ⇒ Integer?
Number of bounties to return from the end of the window.
-
#order ⇒ Symbol, ...
Sort field.
-
#query ⇒ String?
Substring match on the bounty title or ID.
-
#status ⇒ Symbol, ...
Filter by lifecycle state.
-
#user_id ⇒ String?
List the bounties this user participated in (
user_tag).
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(account_id: nil, after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, query: nil, status: nil, user_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see BountyListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(account_id: nil, after: nil, before: nil, created_after: nil, created_before: nil, direction: nil, first: nil, last: nil, order: nil, query: nil, status: nil, user_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see WhopSDK::Models::Workforce::BountyListParams for more details.
|
|
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 85
|
Instance Attribute Details
#account_id ⇒ String?
Scope the list to this account (biz_ tag). Requires read access to the
account; account API keys may pass their own account or a connected account.
16 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 16 optional :account_id, String |
#after ⇒ String?
Cursor to paginate forwards from.
22 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 22 optional :after, String |
#before ⇒ String?
Cursor to paginate backwards from.
28 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 28 optional :before, String |
#created_after ⇒ String?
Only bounties created after this ISO 8601 timestamp.
34 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 34 optional :created_after, String |
#created_before ⇒ String?
Only bounties created before this ISO 8601 timestamp.
40 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 40 optional :created_before, String |
#direction ⇒ Symbol, ...
Sort direction.
46 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 46 optional :direction, enum: -> { WhopSDK::Workforce::BountyListParams::Direction } |
#first ⇒ Integer?
Number of bounties to return from the start of the window.
52 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 52 optional :first, Integer |
#last ⇒ Integer?
Number of bounties to return from the end of the window.
58 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 58 optional :last, Integer |
#order ⇒ Symbol, ...
Sort field.
64 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 64 optional :order, enum: -> { WhopSDK::Workforce::BountyListParams::Order } |
#query ⇒ String?
Substring match on the bounty title or ID.
70 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 70 optional :query, String |
#status ⇒ Symbol, ...
Filter by lifecycle state.
76 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 76 optional :status, enum: -> { WhopSDK::Workforce::BountyListParams::Status } |
#user_id ⇒ String?
List the bounties this user participated in (user_ tag). Must be the
authenticated user.
83 |
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 83 optional :user_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/whop_sdk/models/workforce/bounty_list_params.rb', line 122
|
Instance Method Details
#to_hash ⇒ {
95 |
# File 'sig/whop_sdk/models/workforce/bounty_list_params.rbs', line 95
def to_hash: -> {
|