Class: WhopSDK::Resources::AccessTokens
- Inherits:
-
Object
- Object
- WhopSDK::Resources::AccessTokens
- Defined in:
- lib/whop_sdk/resources/access_tokens.rb
Instance Method Summary collapse
-
#create(scoped_actions: , target_resource_id: , target_resource_type: , expires_at: nil, request_options: {}) ⇒ WhopSDK::Models::AccessTokenCreateResponse
Some parameter documentations has been truncated, see Models::AccessTokenCreateParams for more details.
-
#initialize(client:) ⇒ AccessTokens
constructor
private
A new instance of AccessTokens.
Constructor Details
#initialize(client:) ⇒ AccessTokens
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of AccessTokens.
41 42 43 |
# File 'lib/whop_sdk/resources/access_tokens.rb', line 41 def initialize(client:) @client = client end |
Instance Method Details
#create(scoped_actions: , target_resource_id: , target_resource_type: , expires_at: nil, request_options: {}) ⇒ WhopSDK::Models::AccessTokenCreateResponse
Some parameter documentations has been truncated, see Models::AccessTokenCreateParams for more details.
Creates an access token for a user to access a specific resource. These access tokens are designed to be used with Whop’s embedded components.
27 28 29 30 31 32 33 34 35 36 |
# File 'lib/whop_sdk/resources/access_tokens.rb', line 27 def create(params) parsed, = WhopSDK::AccessTokenCreateParams.dump_request(params) @client.request( method: :post, path: "access_tokens", body: parsed, model: WhopSDK::Models::AccessTokenCreateResponse, options: ) end |