Class: WhopSDK::Resources::AppBuilds
- Inherits:
-
Object
- Object
- WhopSDK::Resources::AppBuilds
- Defined in:
- lib/whop_sdk/resources/app_builds.rb
Overview
App builds
Instance Method Summary collapse
-
#create(attachment:, checksum:, platform:, ai_prompt_id: nil, app_id: nil, supported_app_view_types: nil, request_options: {}) ⇒ WhopSDK::Models::AppBuild
Some parameter documentations has been truncated, see Models::AppBuildCreateParams for more details.
-
#initialize(client:) ⇒ AppBuilds
constructor
private
A new instance of AppBuilds.
-
#list(app_id:, after: nil, before: nil, created_after: nil, created_before: nil, first: nil, last: nil, platform: nil, status: nil, request_options: {}) ⇒ WhopSDK::Internal::CursorPage<WhopSDK::Models::AppBuildListResponse>
Returns a paginated list of build artifacts for a given app, with optional filtering by platform, status, and creation date.
-
#promote(id, request_options: {}) ⇒ WhopSDK::Models::AppBuild
Some parameter documentations has been truncated, see Models::AppBuildPromoteParams for more details.
-
#retrieve(id, request_options: {}) ⇒ WhopSDK::Models::AppBuild
Retrieves the details of an existing app build.
Constructor Details
#initialize(client:) ⇒ AppBuilds
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of AppBuilds.
147 148 149 |
# File 'lib/whop_sdk/resources/app_builds.rb', line 147 def initialize(client:) @client = client end |
Instance Method Details
#create(attachment:, checksum:, platform:, ai_prompt_id: nil, app_id: nil, supported_app_view_types: nil, request_options: {}) ⇒ WhopSDK::Models::AppBuild
Some parameter documentations has been truncated, see Models::AppBuildCreateParams for more details.
Upload a new build artifact for an app. The build must include a compiled code bundle for the specified platform.
Required permissions:
-
‘developer:manage_builds`
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/whop_sdk/resources/app_builds.rb', line 36 def create(params) parsed, = WhopSDK::AppBuildCreateParams.dump_request(params) @client.request( method: :post, path: "app_builds", body: parsed, model: WhopSDK::AppBuild, options: ) end |
#list(app_id:, after: nil, before: nil, created_after: nil, created_before: nil, first: nil, last: nil, platform: nil, status: nil, request_options: {}) ⇒ WhopSDK::Internal::CursorPage<WhopSDK::Models::AppBuildListResponse>
Returns a paginated list of build artifacts for a given app, with optional filtering by platform, status, and creation date.
Required permissions:
-
‘developer:manage_builds`
103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/whop_sdk/resources/app_builds.rb', line 103 def list(params) parsed, = WhopSDK::AppBuildListParams.dump_request(params) query = WhopSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "app_builds", query: query, page: WhopSDK::Internal::CursorPage, model: WhopSDK::Models::AppBuildListResponse, options: ) end |
#promote(id, request_options: {}) ⇒ WhopSDK::Models::AppBuild
Some parameter documentations has been truncated, see Models::AppBuildPromoteParams for more details.
Promote an approved or draft app build to production so it becomes the active version served to users.
Required permissions:
-
‘developer:manage_builds`
135 136 137 138 139 140 141 142 |
# File 'lib/whop_sdk/resources/app_builds.rb', line 135 def promote(id, params = {}) @client.request( method: :post, path: ["app_builds/%1$s/promote", id], model: WhopSDK::AppBuild, options: params[:request_options] ) end |
#retrieve(id, request_options: {}) ⇒ WhopSDK::Models::AppBuild
Retrieves the details of an existing app build.
Required permissions:
-
‘developer:manage_builds`
62 63 64 65 66 67 68 69 |
# File 'lib/whop_sdk/resources/app_builds.rb', line 62 def retrieve(id, params = {}) @client.request( method: :get, path: ["app_builds/%1$s", id], model: WhopSDK::AppBuild, options: params[:request_options] ) end |