Class: WhopSDK::Resources::ChatChannels

Inherits:
Object
  • Object
show all
Defined in:
lib/whop_sdk/resources/chat_channels.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ ChatChannels

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of ChatChannels.

Parameters:



114
115
116
# File 'lib/whop_sdk/resources/chat_channels.rb', line 114

def initialize(client:)
  @client = client
end

Instance Method Details

#list(company_id: , after: nil, before: nil, first: nil, last: nil, product_id: nil, request_options: {}) ⇒ WhopSDK::Internal::CursorPage<WhopSDK::Models::ChatChannelListResponse>

Lists chat channels inside a company

Required permissions:

  • ‘chat:read`

Parameters:

  • company_id (String)

    The ID of the company to list chat channels for

  • after (String, nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil)

    Returns the elements in the list that come before the specified cursor.

  • first (Integer, nil)

    Returns the first n elements from the list.

  • last (Integer, nil)

    Returns the last n elements from the list.

  • product_id (String, nil)

    If provided, only chat channels connected to this product are returned

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



99
100
101
102
103
104
105
106
107
108
109
# File 'lib/whop_sdk/resources/chat_channels.rb', line 99

def list(params)
  parsed, options = WhopSDK::ChatChannelListParams.dump_request(params)
  @client.request(
    method: :get,
    path: "chat_channels",
    query: parsed,
    page: WhopSDK::Internal::CursorPage,
    model: WhopSDK::Models::ChatChannelListResponse,
    options: options
  )
end

#retrieve(id, request_options: {}) ⇒ WhopSDK::Models::ChatChannel

Some parameter documentations has been truncated, see Models::ChatChannelRetrieveParams for more details.

Retrieves a chat channel

Required permissions:

  • ‘chat:read`

Parameters:

  • id (String)

    The ID of the chat channel to fetch, it can be an experience ID or a chat channe

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



24
25
26
27
28
29
30
31
# File 'lib/whop_sdk/resources/chat_channels.rb', line 24

def retrieve(id, params = {})
  @client.request(
    method: :get,
    path: ["chat_channels/%1$s", id],
    model: WhopSDK::ChatChannel,
    options: params[:request_options]
  )
end

#update(id, ban_media: nil, ban_urls: nil, banned_words: nil, user_posts_cooldown_seconds: nil, who_can_post: nil, who_can_react: nil, request_options: {}) ⇒ WhopSDK::Models::ChatChannel

Some parameter documentations has been truncated, see Models::ChatChannelUpdateParams for more details.

Updates a chat channel

Required permissions:

  • ‘chat:moderate`

Parameters:

  • id (String)

    The ID of the chat channel to update. Can be an experience ID or a chat feed ext

  • ban_media (Boolean, nil)

    Whether media uploads are banned in this chat

  • ban_urls (Boolean, nil)

    Whether URLs are banned in this chat

  • banned_words (Array<String>, nil)

    List of banned words for this chat

  • user_posts_cooldown_seconds (Integer, nil)

    The cooldown period in seconds between user posts

  • who_can_post (Symbol, WhopSDK::Models::WhoCanPost, nil)

    Who can post on a chat feed

  • who_can_react (Symbol, WhopSDK::Models::WhoCanReact, nil)

    Who can react on a chat feed

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



63
64
65
66
67
68
69
70
71
72
# File 'lib/whop_sdk/resources/chat_channels.rb', line 63

def update(id, params = {})
  parsed, options = WhopSDK::ChatChannelUpdateParams.dump_request(params)
  @client.request(
    method: :patch,
    path: ["chat_channels/%1$s", id],
    body: parsed,
    model: WhopSDK::ChatChannel,
    options: options
  )
end