Class: WhopSDK::Resources::ChatChannels

Inherits:
Object
  • Object
show all
Defined in:
lib/whop_sdk/resources/chat_channels.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ ChatChannels

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of ChatChannels.

Parameters:



107
108
109
# File 'lib/whop_sdk/resources/chat_channels.rb', line 107

def initialize(client:)
  @client = client
end

Instance Method Details

#list(company_id: , after: nil, before: nil, first: nil, last: nil, product_id: nil, request_options: {}) ⇒ WhopSDK::Internal::CursorPage<WhopSDK::Models::ChatChannelListResponse>

Lists chat channels inside a company

Required permissions:

  • ‘chat:read`

Parameters:

  • company_id (String)

    The ID of the company to list chat channels for

  • after (String, nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil)

    Returns the elements in the list that come before the specified cursor.

  • first (Integer, nil)

    Returns the first n elements from the list.

  • last (Integer, nil)

    Returns the last n elements from the list.

  • product_id (String, nil)

    If provided, only chat channels connected to this product are returned

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



92
93
94
95
96
97
98
99
100
101
102
# File 'lib/whop_sdk/resources/chat_channels.rb', line 92

def list(params)
  parsed, options = WhopSDK::ChatChannelListParams.dump_request(params)
  @client.request(
    method: :get,
    path: "chat_channels",
    query: parsed,
    page: WhopSDK::Internal::CursorPage,
    model: WhopSDK::Models::ChatChannelListResponse,
    options: options
  )
end

#retrieve(id, request_options: {}) ⇒ WhopSDK::Models::ChatChannel

Retrieves a chat channel

Required permissions:

  • ‘chat:read`

Parameters:

Returns:

See Also:



20
21
22
23
24
25
26
27
# File 'lib/whop_sdk/resources/chat_channels.rb', line 20

def retrieve(id, params = {})
  @client.request(
    method: :get,
    path: ["chat_channels/%1$s", id],
    model: WhopSDK::ChatChannel,
    options: params[:request_options]
  )
end

#update(id, ban_media: nil, ban_urls: nil, banned_words: nil, user_posts_cooldown_seconds: nil, who_can_post: nil, who_can_react: nil, request_options: {}) ⇒ WhopSDK::Models::ChatChannel

Updates a chat channel

Required permissions:

  • ‘chat:moderate`

Parameters:

  • id (String)
  • ban_media (Boolean, nil)

    Whether media uploads are banned in this chat

  • ban_urls (Boolean, nil)

    Whether URLs are banned in this chat

  • banned_words (Array<String>, nil)

    List of banned words for this chat

  • user_posts_cooldown_seconds (Integer, nil)

    The cooldown period in seconds between user posts

  • who_can_post (Symbol, WhopSDK::Models::WhoCanPost, nil)

    Who can post on a chat feed

  • who_can_react (Symbol, WhopSDK::Models::WhoCanReact, nil)

    Who can react on a chat feed

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



56
57
58
59
60
61
62
63
64
65
# File 'lib/whop_sdk/resources/chat_channels.rb', line 56

def update(id, params = {})
  parsed, options = WhopSDK::ChatChannelUpdateParams.dump_request(params)
  @client.request(
    method: :patch,
    path: ["chat_channels/%1$s", id],
    body: parsed,
    model: WhopSDK::ChatChannel,
    options: options
  )
end