Class: WhopSDK::Resources::CourseStudents

Inherits:
Object
  • Object
show all
Defined in:
lib/whop_sdk/resources/course_students.rb

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ CourseStudents

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of CourseStudents.

Parameters:



72
73
74
# File 'lib/whop_sdk/resources/course_students.rb', line 72

def initialize(client:)
  @client = client
end

Instance Method Details

#list(course_id: , after: nil, before: nil, first: nil, keyword: nil, last: nil, request_options: {}) ⇒ WhopSDK::Internal::CursorPage<WhopSDK::Models::CourseStudentListResponse>

Lists students for a course

Required permissions:

  • ‘courses:read`

  • ‘course_analytics:read`

Parameters:

  • course_id (String)

    The ID of the course

  • after (String, nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil)

    Returns the elements in the list that come before the specified cursor.

  • first (Integer, nil)

    Returns the first n elements from the list.

  • keyword (String, nil)

    Filter students by name - returns students whose names match the keyword

  • last (Integer, nil)

    Returns the last n elements from the list.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/whop_sdk/resources/course_students.rb', line 57

def list(params)
  parsed, options = WhopSDK::CourseStudentListParams.dump_request(params)
  @client.request(
    method: :get,
    path: "course_students",
    query: parsed,
    page: WhopSDK::Internal::CursorPage,
    model: WhopSDK::Models::CourseStudentListResponse,
    options: options
  )
end

#retrieve(id, request_options: {}) ⇒ WhopSDK::Models::CourseStudentRetrieveResponse

Retrieves a course student by interaction ID

Required permissions:

  • ‘courses:read`

  • ‘course_analytics:read`

Parameters:

  • id (String)

    The ID of the course student interaction

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



22
23
24
25
26
27
28
29
# File 'lib/whop_sdk/resources/course_students.rb', line 22

def retrieve(id, params = {})
  @client.request(
    method: :get,
    path: ["course_students/%1$s", id],
    model: WhopSDK::Models::CourseStudentRetrieveResponse,
    options: params[:request_options]
  )
end