Class: WhopSDK::Resources::Verifications

Inherits:
Object
  • Object
show all
Defined in:
lib/whop_sdk/resources/verifications.rb

Overview

Verifications

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Verifications

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Verifications.

Parameters:



71
72
73
# File 'lib/whop_sdk/resources/verifications.rb', line 71

def initialize(client:)
  @client = client
end

Instance Method Details

#list(payout_account_id:, after: nil, before: nil, first: nil, last: nil, request_options: {}) ⇒ WhopSDK::Internal::CursorPage<WhopSDK::Models::VerificationListResponse>

Returns a list of identity verifications for a payout account, ordered by most recent first.

Required permissions:

  • ‘payout:account:read`

Parameters:

  • payout_account_id (String)

    The unique identifier of the payout account to list verifications for.

  • after (String, nil)

    Returns the elements in the list that come after the specified cursor.

  • before (String, nil)

    Returns the elements in the list that come before the specified cursor.

  • first (Integer, nil)

    Returns the first n elements from the list.

  • last (Integer, nil)

    Returns the last n elements from the list.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/whop_sdk/resources/verifications.rb', line 55

def list(params)
  parsed, options = WhopSDK::VerificationListParams.dump_request(params)
  query = WhopSDK::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "verifications",
    query: query,
    page: WhopSDK::Internal::CursorPage,
    model: WhopSDK::Models::VerificationListResponse,
    options: options
  )
end

#retrieve(id, request_options: {}) ⇒ WhopSDK::Models::VerificationRetrieveResponse

Retrieves the details of an existing verification.

Required permissions:

  • ‘payout:account:read`

Parameters:

  • id (String)

    The unique identifier of the verification to retrieve.

  • request_options (WhopSDK::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



22
23
24
25
26
27
28
29
# File 'lib/whop_sdk/resources/verifications.rb', line 22

def retrieve(id, params = {})
  @client.request(
    method: :get,
    path: ["verifications/%1$s", id],
    model: WhopSDK::Models::VerificationRetrieveResponse,
    options: params[:request_options]
  )
end