Class: WhopSDK::Resources::Verifications
- Inherits:
-
Object
- Object
- WhopSDK::Resources::Verifications
- Defined in:
- lib/whop_sdk/resources/verifications.rb
Overview
Verifications
Instance Method Summary collapse
-
#initialize(client:) ⇒ Verifications
constructor
private
A new instance of Verifications.
-
#list(payout_account_id:, after: nil, before: nil, first: nil, last: nil, request_options: {}) ⇒ WhopSDK::Internal::CursorPage<WhopSDK::Models::VerificationListResponse>
Returns a list of identity verifications for a payout account, ordered by most recent first.
-
#retrieve(id, request_options: {}) ⇒ WhopSDK::Models::VerificationRetrieveResponse
Retrieves the details of an existing verification.
Constructor Details
#initialize(client:) ⇒ Verifications
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Verifications.
71 72 73 |
# File 'lib/whop_sdk/resources/verifications.rb', line 71 def initialize(client:) @client = client end |
Instance Method Details
#list(payout_account_id:, after: nil, before: nil, first: nil, last: nil, request_options: {}) ⇒ WhopSDK::Internal::CursorPage<WhopSDK::Models::VerificationListResponse>
Returns a list of identity verifications for a payout account, ordered by most recent first.
Required permissions:
-
‘payout:account:read`
55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/whop_sdk/resources/verifications.rb', line 55 def list(params) parsed, = WhopSDK::VerificationListParams.dump_request(params) query = WhopSDK::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "verifications", query: query, page: WhopSDK::Internal::CursorPage, model: WhopSDK::Models::VerificationListResponse, options: ) end |
#retrieve(id, request_options: {}) ⇒ WhopSDK::Models::VerificationRetrieveResponse
Retrieves the details of an existing verification.
Required permissions:
-
‘payout:account:read`
22 23 24 25 26 27 28 29 |
# File 'lib/whop_sdk/resources/verifications.rb', line 22 def retrieve(id, params = {}) @client.request( method: :get, path: ["verifications/%1$s", id], model: WhopSDK::Models::VerificationRetrieveResponse, options: params[:request_options] ) end |