Class: Whop_sdk::AdGroups::Types::CreateAdGroupsRequestPlacements
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Whop_sdk::AdGroups::Types::CreateAdGroupsRequestPlacements
- Extended by:
- Internal::Types::Union
- Defined in:
- lib/whop_sdk/ad_groups/types/create_ad_groups_request_placements.rb
Overview
automatic to let the ad platform choose placements, or the list of platforms and positions to target. Omit a
platform's positions to target all of them.
Valid positions per platform:
facebook:feed,right_hand_column,marketplace,search,profile_feed,notification,story,instream_video,facebook_reels,facebook_reels_overlay,biz_disco_feedinstagram:stream,story,explore,explore_home,reels,profile_feed,profile_reels,ig_searchmessenger:storyaudience_network:classic,rewarded_videothreads:threads_streamwhatsapp:status
Method Summary
Methods included from Internal::Types::Union
coerce, discriminant, load, member, members, type_member?
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Constructor Details
This class inherits a constructor from Whop_sdk::Internal::Types::Model