Class: Whop_sdk::Deposits::Client
- Inherits:
-
Object
- Object
- Whop_sdk::Deposits::Client
- Defined in:
- lib/whop_sdk/deposits/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Whop_sdk::Deposits::Types::CreateDepositsResponse
Retrieve the deposit methods for an account, including crypto and bank transfer.
- #initialize(client:) ⇒ void constructor
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/whop_sdk/deposits/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Whop_sdk::Deposits::Types::CreateDepositsResponse
Retrieve the deposit methods for an account, including crypto and bank transfer.
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/whop_sdk/deposits/client.rb', line 27 def create(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "deposits", body: Whop_sdk::Deposits::Types::CreateDepositsRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Deposits::Types::CreateDepositsResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |