Class: Whop_sdk::Payouts::Methods::Client
- Inherits:
-
Object
- Object
- Whop_sdk::Payouts::Methods::Client
- Defined in:
- lib/whop_sdk/payouts/methods/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Whop_sdk::Payouts::Methods::Types::CreateMethodsResponse
Saves a new place an account or user can withdraw to.
-
#delete(request_options: {}, **params) ⇒ Whop_sdk::Payouts::Methods::Types::DeleteMethodsResponse
Deletes a saved payout method so it can no longer receive payouts.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Whop_sdk::Payouts::Methods::Types::ListMethodsResponse
Lists the bank accounts, wallets, and crypto addresses an account or user can withdraw to, newest first.
-
#update(request_options: {}, **params) ⇒ Whop_sdk::Payouts::Methods::Types::UpdateMethodsResponse
Changes the label used to identify a saved payout method.
Constructor Details
#initialize(client:) ⇒ void
10 11 12 |
# File 'lib/whop_sdk/payouts/methods/client.rb', line 10 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Whop_sdk::Payouts::Methods::Types::CreateMethodsResponse
Saves a new place an account or user can withdraw to. Sensitive details are vaulted in transit and never stored raw.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/whop_sdk/payouts/methods/client.rb', line 96 def create(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "payouts/methods", body: Whop_sdk::Payouts::Methods::Types::CreateMethodsRequest.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Payouts::Methods::Types::CreateMethodsResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#delete(request_options: {}, **params) ⇒ Whop_sdk::Payouts::Methods::Types::DeleteMethodsResponse
Deletes a saved payout method so it can no longer receive payouts.
134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/whop_sdk/payouts/methods/client.rb', line 134 def delete(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "DELETE", path: "payouts/methods/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Payouts::Methods::Types::DeleteMethodsResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Whop_sdk::Payouts::Methods::Types::ListMethodsResponse
Lists the bank accounts, wallets, and crypto addresses an account or user can withdraw to, newest first.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/whop_sdk/payouts/methods/client.rb', line 38 def list(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["account_id"] = params[:account_id] if params.key?(:account_id) query_params["user_id"] = params[:user_id] if params.key?(:user_id) query_params["status"] = params[:status] if params.key?(:status) query_params["amount"] = params[:amount] if params.key?(:amount) query_params["currency"] = params[:currency] if params.key?(:currency) query_params["include_limits"] = params[:include_limits] if params.key?(:include_limits) query_params["first"] = params[:first] if params.key?(:first) query_params["after"] = params[:after] if params.key?(:after) query_params["last"] = params[:last] if params.key?(:last) query_params["before"] = params[:before] if params.key?(:before) Whop_sdk::Internal::CursorItemIterator.new( cursor_field: :end_cursor, item_field: :data, initial_cursor: query_params["after"] ) do |next_cursor| query_params["after"] = next_cursor request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "payouts/methods", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) parsed_response = Whop_sdk::Payouts::Methods::Types::ListMethodsResponse.load(response.body) [parsed_response, response] else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end end |
#update(request_options: {}, **params) ⇒ Whop_sdk::Payouts::Methods::Types::UpdateMethodsResponse
Changes the label used to identify a saved payout method.
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/whop_sdk/payouts/methods/client.rb', line 174 def update(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request_data = Whop_sdk::Payouts::Methods::Types::UpdateMethodsRequest.new(params).to_h non_body_param_names = %w[id] body = request_data.except(*non_body_param_names) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "payouts/methods/#{URI.encode_uri_component(params[:id].to_s)}", body: body, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Payouts::Methods::Types::UpdateMethodsResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |