Class: Whop_sdk::Types::ExperienceAppIcon
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Whop_sdk::Types::ExperienceAppIcon
- Defined in:
- lib/whop_sdk/types/experience_app_icon.rb
Overview
The icon image for this app, displayed on the app store, product pages, checkout, and as the default icon for experiences using this app.
Method Summary
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Constructor Details
This class inherits a constructor from Whop_sdk::Internal::Types::Model