Class: Whop_sdk::Verifications::Client
- Inherits:
-
Object
- Object
- Whop_sdk::Verifications::Client
- Defined in:
- lib/whop_sdk/verifications/client.rb
Instance Method Summary collapse
-
#create(request_options: {}, **params) ⇒ Whop_sdk::Verifications::Types::CreateVerificationsResponse
Starts a hosted verification session for an account or user, or returns the active session when one already exists.
- #initialize(client:) ⇒ void constructor
-
#list(request_options: {}, **params) ⇒ Whop_sdk::Verifications::Types::ListVerificationsResponse
Returns verifications for an account, including their status and any required actions.
-
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Verifications::Types::RetrieveVerificationsResponse
Returns verifications for an account, including their status and any required actions.
-
#update(request_options: {}, **params) ⇒ Whop_sdk::Verifications::Types::UpdateVerificationsResponse
Updates editable profile details or submits answers for items returned in
requested_information.
Constructor Details
#initialize(client:) ⇒ void
9 10 11 |
# File 'lib/whop_sdk/verifications/client.rb', line 9 def initialize(client:) @client = client end |
Instance Method Details
#create(request_options: {}, **params) ⇒ Whop_sdk::Verifications::Types::CreateVerificationsResponse
Starts a hosted verification session for an account or user, or returns the active session when one already
exists. Any fields you include in the request body are used to prefill the session. Send documents (with
document_type) to instead verify the person from identity documents included in this request — no hosted
session involved. Send share_token to reuse a verification another Sumsub account has already completed for
this person, instead of verifying them again. If the account already has an approved verification the request
is rejected; unlink it first to start a new one.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/whop_sdk/verifications/client.rb', line 78 def create(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) query_param_names = %i[account_id] query_params = {} query_params["account_id"] = params[:account_id] if params.key?(:account_id) params = params.except(*query_param_names) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "POST", path: "verifications", query: query_params, body: Whop_sdk::Verifications::Types::CreateVerificationsRequestBody.new(params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Verifications::Types::CreateVerificationsResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#list(request_options: {}, **params) ⇒ Whop_sdk::Verifications::Types::ListVerificationsResponse
Returns verifications for an account, including their status and any required actions.
30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/whop_sdk/verifications/client.rb', line 30 def list(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) query_params = {} query_params["account_id"] = params[:account_id] if params.key?(:account_id) query_params["order"] = params[:order] if params.key?(:order) query_params["direction"] = params[:direction] if params.key?(:direction) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "verifications", query: query_params, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Verifications::Types::ListVerificationsResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#retrieve(request_options: {}, **params) ⇒ Whop_sdk::Verifications::Types::RetrieveVerificationsResponse
Returns verifications for an account, including their status and any required actions.
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/whop_sdk/verifications/client.rb', line 122 def retrieve(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "GET", path: "verifications/#{URI.encode_uri_component(params[:id].to_s)}", request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Verifications::Types::RetrieveVerificationsResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |
#update(request_options: {}, **params) ⇒ Whop_sdk::Verifications::Types::UpdateVerificationsResponse
Updates editable profile details or submits answers for items returned in requested_information. Once a
verification is approved its profile details are locked and can no longer be edited.
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/whop_sdk/verifications/client.rb', line 163 def update(request_options: {}, **params) params = Whop_sdk::Internal::Types::Utils.normalize_keys(params) path_param_names = %i[id] body_params = params.except(*path_param_names) request = Whop_sdk::Internal::JSON::Request.new( base_url: [:base_url], method: "PATCH", path: "verifications/#{URI.encode_uri_component(params[:id].to_s)}", body: Whop_sdk::Verifications::Types::UpdateVerificationsRequestBody.new(body_params).to_h, request_options: ) begin response = @client.send(request) rescue Net::HTTPRequestTimeout raise Whop_sdk::Errors::TimeoutError end code = response.code.to_i if code.between?(200, 299) Whop_sdk::Verifications::Types::UpdateVerificationsResponse.load(response.body) else error_class = Whop_sdk::Errors::ResponseError.subclass_for_code(code) raise error_class.new(response.body, code: code) end end |